/********************************************************************************
** Form generated from reading UI file 'skgcategoriespluginwidget_base.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGCATEGORIESPLUGINWIDGET_BASE_H
#define UI_SKGCATEGORIESPLUGINWIDGET_BASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kseparator.h"
#include "skgfilteredtableview.h"

QT_BEGIN_NAMESPACE

class Ui_skgcategoriesplugin_base
{
public:
    QVBoxLayout *verticalLayout_2;
    SKGFilteredTableView *kCategoriesView;
    KSeparator *kseparator;
    QFrame *frame;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *_2;
    QLabel *kNameLbl;
    QWidget *kFrame;
    QHBoxLayout *kLayout;
    QLineEdit *kNameInput1;
    QLabel *kCatSeparator;
    QLineEdit *kNameInput2;
    QPushButton *kAdd;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer;
    QPushButton *kModifyCategoryButton;
    QPushButton *kDeleteUnusedButton;

    void setupUi(QWidget *skgcategoriesplugin_base)
    {
        if (skgcategoriesplugin_base->objectName().isEmpty())
            skgcategoriesplugin_base->setObjectName("skgcategoriesplugin_base");
        skgcategoriesplugin_base->resize(604, 290);
        verticalLayout_2 = new QVBoxLayout(skgcategoriesplugin_base);
        verticalLayout_2->setSpacing(2);
        verticalLayout_2->setObjectName("verticalLayout_2");
        kCategoriesView = new SKGFilteredTableView(skgcategoriesplugin_base);
        kCategoriesView->setObjectName("kCategoriesView");

        verticalLayout_2->addWidget(kCategoriesView);

        kseparator = new KSeparator(skgcategoriesplugin_base);
        kseparator->setObjectName("kseparator");

        verticalLayout_2->addWidget(kseparator);

        frame = new QFrame(skgcategoriesplugin_base);
        frame->setObjectName("frame");
        frame->setFrameShape(QFrame::NoFrame);
        frame->setFrameShadow(QFrame::Raised);
        verticalLayout = new QVBoxLayout(frame);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        _2 = new QHBoxLayout();
        _2->setSpacing(2);
        _2->setObjectName("_2");
        kNameLbl = new QLabel(frame);
        kNameLbl->setObjectName("kNameLbl");
        QFont font;
        font.setBold(true);
        kNameLbl->setFont(font);
        kNameLbl->setText(QString::fromUtf8("&Title:"));

        _2->addWidget(kNameLbl);

        kFrame = new QWidget(frame);
        kFrame->setObjectName("kFrame");
        kLayout = new QHBoxLayout(kFrame);
        kLayout->setSpacing(2);
        kLayout->setObjectName("kLayout");
        kLayout->setContentsMargins(0, 0, 0, 0);

        _2->addWidget(kFrame);

        kNameInput1 = new QLineEdit(frame);
        kNameInput1->setObjectName("kNameInput1");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kNameInput1->sizePolicy().hasHeightForWidth());
        kNameInput1->setSizePolicy(sizePolicy);

        _2->addWidget(kNameInput1);

        kCatSeparator = new QLabel(frame);
        kCatSeparator->setObjectName("kCatSeparator");

        _2->addWidget(kCatSeparator);

        kNameInput2 = new QLineEdit(frame);
        kNameInput2->setObjectName("kNameInput2");

        _2->addWidget(kNameInput2);

        kAdd = new QPushButton(frame);
        kAdd->setObjectName("kAdd");

        _2->addWidget(kAdd);


        verticalLayout->addLayout(_2);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(2);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer = new QSpacerItem(0, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        kModifyCategoryButton = new QPushButton(frame);
        kModifyCategoryButton->setObjectName("kModifyCategoryButton");

        horizontalLayout_2->addWidget(kModifyCategoryButton);

        kDeleteUnusedButton = new QPushButton(frame);
        kDeleteUnusedButton->setObjectName("kDeleteUnusedButton");

        horizontalLayout_2->addWidget(kDeleteUnusedButton);


        verticalLayout->addLayout(horizontalLayout_2);


        verticalLayout_2->addWidget(frame);

#if QT_CONFIG(shortcut)
        kNameLbl->setBuddy(kNameInput1);
        kCatSeparator->setBuddy(kNameInput2);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kNameInput1, kNameInput2);
        QWidget::setTabOrder(kNameInput2, kAdd);
        QWidget::setTabOrder(kAdd, kModifyCategoryButton);
        QWidget::setTabOrder(kModifyCategoryButton, kDeleteUnusedButton);

        retranslateUi(skgcategoriesplugin_base);

        QMetaObject::connectSlotsByName(skgcategoriesplugin_base);
    } // setupUi

    void retranslateUi(QWidget *skgcategoriesplugin_base)
    {
        skgcategoriesplugin_base->setWindowTitle(tr2i18n("Categories", nullptr));
#if QT_CONFIG(tooltip)
        kNameInput1->setToolTip(tr2i18n("The category to modify", nullptr));
#endif // QT_CONFIG(tooltip)
        kCatSeparator->setText(tr2i18n(">", nullptr));
#if QT_CONFIG(tooltip)
        kNameInput2->setToolTip(tr2i18n("The sub category to add", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kModifyCategoryButton->setToolTip(tr2i18n("Update selected categories (Shift+Enter)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kModifyCategoryButton->setStatusTip(tr2i18n("Update selected categories (Shift+Enter)", nullptr));
#endif // QT_CONFIG(statustip)
        kModifyCategoryButton->setText(tr2i18n("Modify", "Verb, modify an item"));
#if QT_CONFIG(tooltip)
        kDeleteUnusedButton->setToolTip(tr2i18n("Delete unused categories", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kDeleteUnusedButton->setStatusTip(tr2i18n("Delete unused categories", nullptr));
#endif // QT_CONFIG(statustip)
        kDeleteUnusedButton->setText(tr2i18n("Delete unused", "Verb, delete unused categories"));
    } // retranslateUi

};

namespace Ui {
    class skgcategoriesplugin_base: public Ui_skgcategoriesplugin_base {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGCATEGORIESPLUGINWIDGET_BASE_H

