/********************************************************************************
** Form generated from reading UI file 'skgreportpluginwidget_base.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGREPORTPLUGINWIDGET_BASE_H
#define UI_SKGREPORTPLUGINWIDGET_BASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QSlider>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "skgcombobox.h"
#include "skgperiodedit.h"
#include "skgtablewithgraph.h"
#include "skgunitcombobox.h"
#include "skgwidgetselector.h"

QT_BEGIN_NAMESPACE

class Ui_skgreportplugin_base
{
public:
    QVBoxLayout *verticalLayout;
    SKGTableWithGraph *kTableWithGraph;
    QWidget *setupWidget;
    QGridLayout *gridLayout;
    QLabel *label_6;
    QFrame *line_3;
    QFrame *line;
    QLabel *label_4;
    QLabel *kColumnsLabel;
    SKGComboBox *kCorrectedByMode;
    QToolButton *kColDown;
    QToolButton *kLineDown;
    QToolButton *kLineRemove;
    QCheckBox *kGrouped;
    SKGComboBox *kMode;
    QCheckBox *kTracked;
    QCheckBox *kIncomes;
    QFrame *line_2;
    SKGPeriodEdit *kPeriod;
    QLabel *kLinesLabel;
    QLabel *label;
    QLabel *label_5;
    QLabel *kLineLabel;
    SKGComboBox *kLines;
    QCheckBox *kExpenses;
    QToolButton *kLineUp;
    QLabel *label_3;
    QLabel *kModeLabel;
    QFrame *kForecastFrm;
    QHBoxLayout *horizontalLayout_4;
    QLabel *label_2;
    SKGComboBox *kForecastCmb;
    QSlider *kForecastValue;
    SKGUnitComboBox *kCorrectedBy;
    QToolButton *kColUp;
    QCheckBox *kTransfers;
    QToolButton *kLineAdd;
    SKGComboBox *kColumns;
    QListWidget *kOtherFilters;
    QFrame *kLine;
    SKGWidgetSelector *kWidgetSelector;

    void setupUi(QWidget *skgreportplugin_base)
    {
        if (skgreportplugin_base->objectName().isEmpty())
            skgreportplugin_base->setObjectName("skgreportplugin_base");
        skgreportplugin_base->resize(1047, 669);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(skgreportplugin_base->sizePolicy().hasHeightForWidth());
        skgreportplugin_base->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(skgreportplugin_base);
        verticalLayout->setSpacing(2);
        verticalLayout->setObjectName("verticalLayout");
        kTableWithGraph = new SKGTableWithGraph(skgreportplugin_base);
        kTableWithGraph->setObjectName("kTableWithGraph");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(kTableWithGraph->sizePolicy().hasHeightForWidth());
        kTableWithGraph->setSizePolicy(sizePolicy1);

        verticalLayout->addWidget(kTableWithGraph);

        setupWidget = new QWidget(skgreportplugin_base);
        setupWidget->setObjectName("setupWidget");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Maximum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(setupWidget->sizePolicy().hasHeightForWidth());
        setupWidget->setSizePolicy(sizePolicy2);
        gridLayout = new QGridLayout(setupWidget);
        gridLayout->setSpacing(2);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        label_6 = new QLabel(setupWidget);
        label_6->setObjectName("label_6");
        label_6->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(label_6, 0, 13, 1, 2);

        line_3 = new QFrame(setupWidget);
        line_3->setObjectName("line_3");
        line_3->setFrameShape(QFrame::Shape::VLine);
        line_3->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line_3, 0, 12, 7, 1);

        line = new QFrame(setupWidget);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::VLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line, 0, 7, 7, 1);

        label_4 = new QLabel(setupWidget);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(label_4, 0, 10, 1, 2);

        kColumnsLabel = new QLabel(setupWidget);
        kColumnsLabel->setObjectName("kColumnsLabel");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(kColumnsLabel->sizePolicy().hasHeightForWidth());
        kColumnsLabel->setSizePolicy(sizePolicy3);
        kColumnsLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(kColumnsLabel, 4, 0, 1, 1);

        kCorrectedByMode = new SKGComboBox(setupWidget);
        kCorrectedByMode->setObjectName("kCorrectedByMode");
        kCorrectedByMode->setMaximumSize(QSize(40, 16777215));
        kCorrectedByMode->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        gridLayout->addWidget(kCorrectedByMode, 6, 1, 1, 1);

        kColDown = new QToolButton(setupWidget);
        kColDown->setObjectName("kColDown");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(kColDown->sizePolicy().hasHeightForWidth());
        kColDown->setSizePolicy(sizePolicy4);
        kColDown->setMaximumSize(QSize(22, 22));
        kColDown->setAutoRaise(true);

        gridLayout->addWidget(kColDown, 4, 5, 1, 1);

        kLineDown = new QToolButton(setupWidget);
        kLineDown->setObjectName("kLineDown");
        sizePolicy4.setHeightForWidth(kLineDown->sizePolicy().hasHeightForWidth());
        kLineDown->setSizePolicy(sizePolicy4);
        kLineDown->setMaximumSize(QSize(22, 22));
        kLineDown->setAutoRaise(true);

        gridLayout->addWidget(kLineDown, 3, 5, 1, 1);

        kLineRemove = new QToolButton(setupWidget);
        kLineRemove->setObjectName("kLineRemove");
        sizePolicy4.setHeightForWidth(kLineRemove->sizePolicy().hasHeightForWidth());
        kLineRemove->setSizePolicy(sizePolicy4);
        kLineRemove->setMaximumSize(QSize(22, 22));
        kLineRemove->setAutoRaise(true);

        gridLayout->addWidget(kLineRemove, 3, 3, 1, 1);

        kGrouped = new QCheckBox(setupWidget);
        kGrouped->setObjectName("kGrouped");
        kGrouped->setChecked(true);

        gridLayout->addWidget(kGrouped, 4, 10, 1, 1);

        kMode = new SKGComboBox(setupWidget);
        kMode->setObjectName("kMode");
        kMode->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        gridLayout->addWidget(kMode, 5, 1, 1, 4);

        kTracked = new QCheckBox(setupWidget);
        kTracked->setObjectName("kTracked");
        kTracked->setChecked(true);

        gridLayout->addWidget(kTracked, 5, 10, 1, 1);

        kIncomes = new QCheckBox(setupWidget);
        kIncomes->setObjectName("kIncomes");
        kIncomes->setChecked(true);

        gridLayout->addWidget(kIncomes, 3, 10, 1, 1);

        line_2 = new QFrame(setupWidget);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::VLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line_2, 0, 9, 7, 1);

        kPeriod = new SKGPeriodEdit(setupWidget);
        kPeriod->setObjectName("kPeriod");

        gridLayout->addWidget(kPeriod, 3, 8, 2, 1);

        kLinesLabel = new QLabel(setupWidget);
        kLinesLabel->setObjectName("kLinesLabel");
        sizePolicy3.setHeightForWidth(kLinesLabel->sizePolicy().hasHeightForWidth());
        kLinesLabel->setSizePolicy(sizePolicy3);
        kLinesLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(kLinesLabel, 3, 0, 1, 1);

        label = new QLabel(setupWidget);
        label->setObjectName("label");

        gridLayout->addWidget(label, 6, 0, 1, 1);

        label_5 = new QLabel(setupWidget);
        label_5->setObjectName("label_5");
        label_5->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(label_5, 0, 0, 1, 7);

        kLineLabel = new QLabel(setupWidget);
        kLineLabel->setObjectName("kLineLabel");
        kLineLabel->setMaximumSize(QSize(200, 16777215));
        kLineLabel->setText(QString::fromUtf8(""));

        gridLayout->addWidget(kLineLabel, 3, 1, 1, 1);

        kLines = new SKGComboBox(setupWidget);
        kLines->setObjectName("kLines");
        kLines->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        gridLayout->addWidget(kLines, 3, 2, 1, 1);

        kExpenses = new QCheckBox(setupWidget);
        kExpenses->setObjectName("kExpenses");
        kExpenses->setChecked(true);

        gridLayout->addWidget(kExpenses, 3, 11, 1, 1);

        kLineUp = new QToolButton(setupWidget);
        kLineUp->setObjectName("kLineUp");
        kLineUp->setMaximumSize(QSize(22, 22));
        kLineUp->setAutoRaise(true);

        gridLayout->addWidget(kLineUp, 3, 6, 1, 1);

        label_3 = new QLabel(setupWidget);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(label_3, 0, 8, 1, 1);

        kModeLabel = new QLabel(setupWidget);
        kModeLabel->setObjectName("kModeLabel");
        sizePolicy3.setHeightForWidth(kModeLabel->sizePolicy().hasHeightForWidth());
        kModeLabel->setSizePolicy(sizePolicy3);
        kModeLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(kModeLabel, 5, 0, 1, 1);

        kForecastFrm = new QFrame(setupWidget);
        kForecastFrm->setObjectName("kForecastFrm");
        horizontalLayout_4 = new QHBoxLayout(kForecastFrm);
        horizontalLayout_4->setSpacing(2);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        horizontalLayout_4->setContentsMargins(0, 0, 0, 0);
        label_2 = new QLabel(kForecastFrm);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_4->addWidget(label_2);

        kForecastCmb = new SKGComboBox(kForecastFrm);
        kForecastCmb->setObjectName("kForecastCmb");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(kForecastCmb->sizePolicy().hasHeightForWidth());
        kForecastCmb->setSizePolicy(sizePolicy5);
        kForecastCmb->setMaximumSize(QSize(150, 16777215));
        kForecastCmb->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        horizontalLayout_4->addWidget(kForecastCmb);

        kForecastValue = new QSlider(kForecastFrm);
        kForecastValue->setObjectName("kForecastValue");
        sizePolicy5.setHeightForWidth(kForecastValue->sizePolicy().hasHeightForWidth());
        kForecastValue->setSizePolicy(sizePolicy5);
        kForecastValue->setMaximum(100);
        kForecastValue->setValue(20);
        kForecastValue->setOrientation(Qt::Horizontal);

        horizontalLayout_4->addWidget(kForecastValue);


        gridLayout->addWidget(kForecastFrm, 5, 8, 1, 1);

        kCorrectedBy = new SKGUnitComboBox(setupWidget);
        kCorrectedBy->setObjectName("kCorrectedBy");

        gridLayout->addWidget(kCorrectedBy, 6, 2, 1, 3);

        kColUp = new QToolButton(setupWidget);
        kColUp->setObjectName("kColUp");
        kColUp->setMaximumSize(QSize(22, 22));
        kColUp->setAutoRaise(true);

        gridLayout->addWidget(kColUp, 4, 6, 1, 1);

        kTransfers = new QCheckBox(setupWidget);
        kTransfers->setObjectName("kTransfers");

        gridLayout->addWidget(kTransfers, 4, 11, 1, 1);

        kLineAdd = new QToolButton(setupWidget);
        kLineAdd->setObjectName("kLineAdd");
        sizePolicy4.setHeightForWidth(kLineAdd->sizePolicy().hasHeightForWidth());
        kLineAdd->setSizePolicy(sizePolicy4);
        kLineAdd->setMaximumSize(QSize(22, 22));
        kLineAdd->setText(QString::fromUtf8(">"));
        kLineAdd->setAutoRaise(true);

        gridLayout->addWidget(kLineAdd, 3, 4, 1, 1);

        kColumns = new SKGComboBox(setupWidget);
        kColumns->setObjectName("kColumns");
        kColumns->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        gridLayout->addWidget(kColumns, 4, 1, 1, 4);

        kOtherFilters = new QListWidget(setupWidget);
        kOtherFilters->setObjectName("kOtherFilters");

        gridLayout->addWidget(kOtherFilters, 3, 13, 4, 1);


        verticalLayout->addWidget(setupWidget);

        kLine = new QFrame(skgreportplugin_base);
        kLine->setObjectName("kLine");
        kLine->setFrameShape(QFrame::Shape::HLine);
        kLine->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(kLine);

        kWidgetSelector = new SKGWidgetSelector(skgreportplugin_base);
        kWidgetSelector->setObjectName("kWidgetSelector");

        verticalLayout->addWidget(kWidgetSelector);

#if QT_CONFIG(shortcut)
        label_6->setBuddy(kOtherFilters);
        kColumnsLabel->setBuddy(kColumns);
        kLinesLabel->setBuddy(kLines);
        label->setBuddy(kCorrectedByMode);
        kModeLabel->setBuddy(kMode);
        label_2->setBuddy(kForecastCmb);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kLines, kLineRemove);
        QWidget::setTabOrder(kLineRemove, kLineAdd);
        QWidget::setTabOrder(kLineAdd, kLineDown);
        QWidget::setTabOrder(kLineDown, kLineUp);
        QWidget::setTabOrder(kLineUp, kColumns);
        QWidget::setTabOrder(kColumns, kColDown);
        QWidget::setTabOrder(kColDown, kColUp);
        QWidget::setTabOrder(kColUp, kMode);
        QWidget::setTabOrder(kMode, kCorrectedByMode);
        QWidget::setTabOrder(kCorrectedByMode, kCorrectedBy);
        QWidget::setTabOrder(kCorrectedBy, kPeriod);
        QWidget::setTabOrder(kPeriod, kForecastCmb);
        QWidget::setTabOrder(kForecastCmb, kForecastValue);
        QWidget::setTabOrder(kForecastValue, kIncomes);
        QWidget::setTabOrder(kIncomes, kExpenses);
        QWidget::setTabOrder(kExpenses, kGrouped);
        QWidget::setTabOrder(kGrouped, kTransfers);
        QWidget::setTabOrder(kTransfers, kTracked);
        QWidget::setTabOrder(kTracked, kOtherFilters);

        retranslateUi(skgreportplugin_base);

        QMetaObject::connectSlotsByName(skgreportplugin_base);
    } // setupUi

    void retranslateUi(QWidget *skgreportplugin_base)
    {
        label_6->setText(tr2i18n("Other filters", nullptr));
        label_4->setText(tr2i18n("Transaction Types", nullptr));
        kColumnsLabel->setText(tr2i18n("Columns:", nullptr));
#if QT_CONFIG(tooltip)
        kCorrectedByMode->setToolTip(tr2i18n("Select how you want to correct values", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kCorrectedByMode->setStatusTip(tr2i18n("Select how you want to correct values", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kColDown->setToolTip(tr2i18n("Reduce level", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kColDown->setStatusTip(tr2i18n("Reduce level", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kLineDown->setToolTip(tr2i18n("Collapse", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kLineDown->setStatusTip(tr2i18n("Collapse", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kLineRemove->setToolTip(tr2i18n("Remove", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kLineRemove->setStatusTip(tr2i18n("Remove", nullptr));
#endif // QT_CONFIG(statustip)
        kLineRemove->setText(QString());
#if QT_CONFIG(tooltip)
        kGrouped->setToolTip(tr2i18n("Include grouped transactions or not in report", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kGrouped->setStatusTip(tr2i18n("Include grouped transactions or not in report", nullptr));
#endif // QT_CONFIG(statustip)
        kGrouped->setText(tr2i18n("Grouped", nullptr));
#if QT_CONFIG(tooltip)
        kMode->setToolTip(tr2i18n("Select what you want to do with values", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kMode->setStatusTip(tr2i18n("Select what you want to do with values", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kTracked->setToolTip(tr2i18n("Include tracked transactions or not in report", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kTracked->setStatusTip(tr2i18n("Include tracked transactions or not in report", nullptr));
#endif // QT_CONFIG(statustip)
        kTracked->setText(tr2i18n("Tracked", nullptr));
#if QT_CONFIG(tooltip)
        kIncomes->setToolTip(tr2i18n("Include incomes or not in report", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kIncomes->setStatusTip(tr2i18n("Include incomes or not in report", nullptr));
#endif // QT_CONFIG(statustip)
        kIncomes->setText(tr2i18n("Incomes", nullptr));
        kLinesLabel->setText(tr2i18n("Lines:", nullptr));
        label->setText(tr2i18n("Corrected &by:", nullptr));
        label_5->setText(tr2i18n("Data", nullptr));
#if QT_CONFIG(tooltip)
        kLines->setToolTip(tr2i18n("Select what you want to see in the rows", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kLines->setStatusTip(tr2i18n("Select what you want to see in the rows", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kExpenses->setToolTip(tr2i18n("Include expenses or not in report", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kExpenses->setStatusTip(tr2i18n("Include expenses or not in report", nullptr));
#endif // QT_CONFIG(statustip)
        kExpenses->setText(tr2i18n("Expenses", nullptr));
#if QT_CONFIG(tooltip)
        kLineUp->setToolTip(tr2i18n("Expand", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kLineUp->setStatusTip(tr2i18n("Expand", nullptr));
#endif // QT_CONFIG(statustip)
        label_3->setText(tr2i18n("Dates", nullptr));
        kModeLabel->setText(tr2i18n("Mode:", nullptr));
        label_2->setText(tr2i18n("Forecast:", nullptr));
#if QT_CONFIG(tooltip)
        kForecastCmb->setToolTip(tr2i18n("Choose forecast method:\n"
"- Schedule: Use the scheduled transactions in forecast.\n"
"- Average: Use average of the three previous months in forecast", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kCorrectedBy->setToolTip(tr2i18n("Select the index to correct the values", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kCorrectedBy->setStatusTip(tr2i18n("Select the index to correct the values", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kColUp->setToolTip(tr2i18n("Increase level", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kColUp->setStatusTip(tr2i18n("Increase level", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kTransfers->setToolTip(tr2i18n("Include transfers or not in report", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kTransfers->setStatusTip(tr2i18n("Include transfers or not in report", nullptr));
#endif // QT_CONFIG(statustip)
        kTransfers->setText(tr2i18n("Transfers", nullptr));
#if QT_CONFIG(tooltip)
        kLineAdd->setToolTip(tr2i18n("Add", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kLineAdd->setStatusTip(tr2i18n("Add", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kColumns->setToolTip(tr2i18n("Select what you want to see in the columns", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kColumns->setStatusTip(tr2i18n("Select what you want to see in the columns", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kOtherFilters->setToolTip(tr2i18n("The list of additional filters from other open pages that can be added", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)skgreportplugin_base;
    } // retranslateUi

};

namespace Ui {
    class skgreportplugin_base: public Ui_skgreportplugin_base {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGREPORTPLUGINWIDGET_BASE_H

