// This file is autogenerated. Changes will be overwritten.
#include "EWIEGA46WW/moc_skgadviceboardwidget.cpp"
#include "EWIEGA46WW/moc_skgadviceplugin.cpp"
#include "EWIEGA46WW/moc_skgtipofdayboardwidget.cpp"
