/********************************************************************************
** Form generated from reading UI file 'skgperiodedit.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGPERIODEDIT_H
#define UI_SKGPERIODEDIT_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "skgcombobox.h"
#include "skgdateedit.h"

QT_BEGIN_NAMESPACE

class Ui_skgperiodedit_base
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *hl7;
    SKGComboBox *kPeriod;
    QSpinBox *kNbIntervals;
    SKGComboBox *kInterval;
    QCheckBox *kFuture;
    QSlider *kTimeline;
    QSpacerItem *kSpacer;
    QSpacerItem *hs3;
    QWidget *kDateSelect;
    QHBoxLayout *bl;
    QLabel *kDateBeginLabel;
    SKGDateEdit *kDateBegin;
    QLabel *kDateEndLabel;
    SKGDateEdit *kDateEnd;
    QSpacerItem *hs5;

    void setupUi(QWidget *skgperiodedit_base)
    {
        if (skgperiodedit_base->objectName().isEmpty())
            skgperiodedit_base->setObjectName("skgperiodedit_base");
        skgperiodedit_base->resize(410, 65);
        skgperiodedit_base->setMinimumSize(QSize(410, 65));
        skgperiodedit_base->setFocusPolicy(Qt::TabFocus);
        verticalLayout = new QVBoxLayout(skgperiodedit_base);
        verticalLayout->setSpacing(2);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        hl7 = new QHBoxLayout();
        hl7->setSpacing(2);
        hl7->setObjectName("hl7");
        kPeriod = new SKGComboBox(skgperiodedit_base);
        kPeriod->setObjectName("kPeriod");
        kPeriod->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        hl7->addWidget(kPeriod);

        kNbIntervals = new QSpinBox(skgperiodedit_base);
        kNbIntervals->setObjectName("kNbIntervals");
        kNbIntervals->setMaximumSize(QSize(50, 16777215));
        kNbIntervals->setMinimum(1);
        kNbIntervals->setMaximum(365);

        hl7->addWidget(kNbIntervals);

        kInterval = new SKGComboBox(skgperiodedit_base);
        kInterval->setObjectName("kInterval");
        kInterval->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        hl7->addWidget(kInterval);

        kFuture = new QCheckBox(skgperiodedit_base);
        kFuture->setObjectName("kFuture");

        hl7->addWidget(kFuture);

        kTimeline = new QSlider(skgperiodedit_base);
        kTimeline->setObjectName("kTimeline");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(100);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kTimeline->sizePolicy().hasHeightForWidth());
        kTimeline->setSizePolicy(sizePolicy);
        kTimeline->setMinimum(1);
        kTimeline->setMaximum(12);
        kTimeline->setPageStep(1);
        kTimeline->setValue(12);
        kTimeline->setOrientation(Qt::Horizontal);
        kTimeline->setInvertedAppearance(false);

        hl7->addWidget(kTimeline);

        kSpacer = new QSpacerItem(0, 10, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hl7->addItem(kSpacer);

        hs3 = new QSpacerItem(0, 20, QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);

        hl7->addItem(hs3);


        verticalLayout->addLayout(hl7);

        kDateSelect = new QWidget(skgperiodedit_base);
        kDateSelect->setObjectName("kDateSelect");
        bl = new QHBoxLayout(kDateSelect);
        bl->setSpacing(2);
        bl->setObjectName("bl");
        bl->setContentsMargins(0, 0, 0, 0);
        kDateBeginLabel = new QLabel(kDateSelect);
        kDateBeginLabel->setObjectName("kDateBeginLabel");
        kDateBeginLabel->setEnabled(true);
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(kDateBeginLabel->sizePolicy().hasHeightForWidth());
        kDateBeginLabel->setSizePolicy(sizePolicy1);
        kDateBeginLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        bl->addWidget(kDateBeginLabel);

        kDateBegin = new SKGDateEdit(kDateSelect);
        kDateBegin->setObjectName("kDateBegin");
        kDateBegin->setEnabled(true);
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(kDateBegin->sizePolicy().hasHeightForWidth());
        kDateBegin->setSizePolicy(sizePolicy2);
        kDateBegin->setMinimumSize(QSize(120, 0));

        bl->addWidget(kDateBegin);

        kDateEndLabel = new QLabel(kDateSelect);
        kDateEndLabel->setObjectName("kDateEndLabel");
        kDateEndLabel->setEnabled(true);
        sizePolicy1.setHeightForWidth(kDateEndLabel->sizePolicy().hasHeightForWidth());
        kDateEndLabel->setSizePolicy(sizePolicy1);

        bl->addWidget(kDateEndLabel);

        kDateEnd = new SKGDateEdit(kDateSelect);
        kDateEnd->setObjectName("kDateEnd");
        kDateEnd->setEnabled(true);
        sizePolicy2.setHeightForWidth(kDateEnd->sizePolicy().hasHeightForWidth());
        kDateEnd->setSizePolicy(sizePolicy2);
        kDateEnd->setMinimumSize(QSize(120, 0));

        bl->addWidget(kDateEnd);

        hs5 = new QSpacerItem(127, 21, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        bl->addItem(hs5);


        verticalLayout->addWidget(kDateSelect);

        QWidget::setTabOrder(kPeriod, kNbIntervals);
        QWidget::setTabOrder(kNbIntervals, kInterval);
        QWidget::setTabOrder(kInterval, kFuture);
        QWidget::setTabOrder(kFuture, kTimeline);
        QWidget::setTabOrder(kTimeline, kDateBegin);
        QWidget::setTabOrder(kDateBegin, kDateEnd);

        retranslateUi(skgperiodedit_base);

        QMetaObject::connectSlotsByName(skgperiodedit_base);
    } // setupUi

    void retranslateUi(QWidget *skgperiodedit_base)
    {
        kFuture->setText(tr2i18n("including future", nullptr));
#if QT_CONFIG(tooltip)
        kDateBeginLabel->setToolTip(tr2i18n("Begin date", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kDateBeginLabel->setStatusTip(tr2i18n("Begin date", nullptr));
#endif // QT_CONFIG(statustip)
        kDateBeginLabel->setText(tr2i18n("from", nullptr));
#if QT_CONFIG(tooltip)
        kDateBegin->setToolTip(tr2i18n("Begin date", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kDateBegin->setStatusTip(tr2i18n("Begin date", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kDateEndLabel->setToolTip(tr2i18n("End date", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kDateEndLabel->setStatusTip(tr2i18n("End date", nullptr));
#endif // QT_CONFIG(statustip)
        kDateEndLabel->setText(tr2i18n("to", nullptr));
#if QT_CONFIG(tooltip)
        kDateEnd->setToolTip(tr2i18n("End date", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kDateEnd->setStatusTip(tr2i18n("End date", nullptr));
#endif // QT_CONFIG(statustip)
        (void)skgperiodedit_base;
    } // retranslateUi

};

namespace Ui {
    class skgperiodedit_base: public Ui_skgperiodedit_base {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGPERIODEDIT_H

