// This file is generated by kconfig_compiler_kf6 from skgundoredo_settings.kcfg.
// All changes you do to this file will be lost.
#ifndef SKGUNDOREDO_SETTINGS_H
#define SKGUNDOREDO_SETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class skgundoredo_settings : public KConfigSkeleton
{
  public:

    static skgundoredo_settings *self();
    ~skgundoredo_settings() override;

    /**
      Get Maximum undo depth
    */
    static
    int maxNumberOfUndo()
    {
      return self()->mMaxNumberOfUndo;
    }

    /**
      Is Maximum undo depth Immutable
    */
    static
    bool isMaxNumberOfUndoImmutable()
    {
      return self()->isImmutable( QStringLiteral( "maxNumberOfUndo" ) );
    }

    /**
      Get Clean history on save
    */
    static
    bool cleanHistoryOnSave()
    {
      return self()->mCleanHistoryOnSave;
    }

    /**
      Is Clean history on save Immutable
    */
    static
    bool isCleanHistoryOnSaveImmutable()
    {
      return self()->isImmutable( QStringLiteral( "cleanHistoryOnSave" ) );
    }

  protected:
    skgundoredo_settings();
    friend class skgundoredo_settingsHelper;


    // skg_undoredo
    int mMaxNumberOfUndo;
    bool mCleanHistoryOnSave;
};

#endif

