/********************************************************************************
** Form generated from reading UI file 'skgquerycreator.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGQUERYCREATOR_H
#define UI_SKGQUERYCREATOR_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"
#include "skgtablewidget.h"

QT_BEGIN_NAMESPACE

class Ui_skgquerycreator_base
{
public:
    QGridLayout *gridLayout;
    QSpacerItem *horizontalSpacer;
    KLineEdit *kFilterEdit;
    QFrame *kFrmAdvanced;
    QHBoxLayout *horizontalLayout;
    QListWidget *kListAtt;
    SKGTableWidget *kList;
    QToolButton *kToolHelp;
    QPushButton *kCheckMode;

    void setupUi(QWidget *skgquerycreator_base)
    {
        if (skgquerycreator_base->objectName().isEmpty())
            skgquerycreator_base->setObjectName("skgquerycreator_base");
        skgquerycreator_base->resize(440, 270);
        gridLayout = new QGridLayout(skgquerycreator_base);
        gridLayout->setSpacing(2);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 3, 1, 1);

        kFilterEdit = new KLineEdit(skgquerycreator_base);
        kFilterEdit->setObjectName("kFilterEdit");

        gridLayout->addWidget(kFilterEdit, 0, 0, 1, 1);

        kFrmAdvanced = new QFrame(skgquerycreator_base);
        kFrmAdvanced->setObjectName("kFrmAdvanced");
        kFrmAdvanced->setFrameShape(QFrame::NoFrame);
        kFrmAdvanced->setFrameShadow(QFrame::Plain);
        horizontalLayout = new QHBoxLayout(kFrmAdvanced);
        horizontalLayout->setSpacing(2);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 2);
        kListAtt = new QListWidget(kFrmAdvanced);
        kListAtt->setObjectName("kListAtt");
        kListAtt->setMaximumSize(QSize(150, 16777215));

        horizontalLayout->addWidget(kListAtt);

        kList = new SKGTableWidget(kFrmAdvanced);
        kList->setObjectName("kList");
        kList->setAcceptDrops(true);
        kList->setEditTriggers(QAbstractItemView::AnyKeyPressed|QAbstractItemView::DoubleClicked|QAbstractItemView::EditKeyPressed|QAbstractItemView::SelectedClicked);
        kList->horizontalHeader()->setMinimumSectionSize(50);
        kList->horizontalHeader()->setStretchLastSection(true);

        horizontalLayout->addWidget(kList);


        gridLayout->addWidget(kFrmAdvanced, 1, 0, 1, 5);

        kToolHelp = new QToolButton(skgquerycreator_base);
        kToolHelp->setObjectName("kToolHelp");
        kToolHelp->setMaximumSize(QSize(28, 28));
        kToolHelp->setPopupMode(QToolButton::InstantPopup);
        kToolHelp->setAutoRaise(true);

        gridLayout->addWidget(kToolHelp, 0, 1, 1, 1);

        kCheckMode = new QPushButton(skgquerycreator_base);
        kCheckMode->setObjectName("kCheckMode");
        kCheckMode->setMaximumSize(QSize(28, 28));
        kCheckMode->setFlat(true);

        gridLayout->addWidget(kCheckMode, 0, 2, 1, 1);

        QWidget::setTabOrder(kFilterEdit, kListAtt);
        QWidget::setTabOrder(kListAtt, kList);

        retranslateUi(skgquerycreator_base);

        QMetaObject::connectSlotsByName(skgquerycreator_base);
    } // setupUi

    void retranslateUi(QWidget *skgquerycreator_base)
    {
        kFilterEdit->setText(QString());
        kFilterEdit->setPlaceholderText(tr2i18n("Search", nullptr));
#if QT_CONFIG(tooltip)
        kList->setToolTip(tr2i18n("Double click on items in the list on the left to add them to the query definition", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kList->setWhatsThis(tr2i18n("Define your query here. Double click on items in the list on the left to add them to the query as defined in the table.\n"
"\n"
"There is a \"And\" relationship between columns, and a \"Or\" relationship between lines.\n"
"\n"
"Read the Skrooge documentation for more details.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        kToolHelp->setToolTip(tr2i18n("This menu can help you to build your query", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)skgquerycreator_base;
    } // retranslateUi

};

namespace Ui {
    class skgquerycreator_base: public Ui_skgquerycreator_base {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGQUERYCREATOR_H

