// This file is generated by kconfig_compiler_kf6 from skgscheduled_settings.kcfg.
// All changes you do to this file will be lost.

#include "skgscheduled_settings.h"

#include <qglobal.h>
#include <QFile>

class skgscheduled_settingsHelper
{
  public:
    skgscheduled_settingsHelper() noexcept : q(nullptr) {}
    ~skgscheduled_settingsHelper() noexcept { delete q; q = nullptr; }
    skgscheduled_settingsHelper(const skgscheduled_settingsHelper&) = delete;
    skgscheduled_settingsHelper& operator=(const skgscheduled_settingsHelper&) = delete;
    skgscheduled_settings *q;
};
Q_GLOBAL_STATIC(skgscheduled_settingsHelper, s_globalskgscheduled_settings)
skgscheduled_settings *skgscheduled_settings::self()
{
  if (!s_globalskgscheduled_settings()->q) {
    new skgscheduled_settings;
    s_globalskgscheduled_settings()->q->read();
  }

  return s_globalskgscheduled_settings()->q;
}

skgscheduled_settings::skgscheduled_settings( )
  : KConfigSkeleton()
{
  Q_ASSERT(!s_globalskgscheduled_settings()->q);
  s_globalskgscheduled_settings()->q = this;
  setCurrentGroup( QStringLiteral( "skrooge_scheduled" ) );

  KConfigSkeleton::ItemBool  *itemCheck_on_open;
  itemCheck_on_open = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "check_on_open" ), mCheck_on_open, true );
  addItem( itemCheck_on_open, QStringLiteral( "check_on_open" ) );
  KConfigSkeleton::ItemBool  *itemCreate_template;
  itemCreate_template = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "create_template" ), mCreate_template, false );
  addItem( itemCreate_template, QStringLiteral( "create_template" ) );
  KConfigSkeleton::ItemBool  *itemConvert_to_from_template;
  itemConvert_to_from_template = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "convert_to_from_template" ), mConvert_to_from_template, false );
  addItem( itemConvert_to_from_template, QStringLiteral( "convert_to_from_template" ) );
  KConfigSkeleton::ItemBool  *itemRemind_me;
  itemRemind_me = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "remind_me" ), mRemind_me, true );
  addItem( itemRemind_me, QStringLiteral( "remind_me" ) );
  KConfigSkeleton::ItemInt  *itemRemind_me_days;
  itemRemind_me_days = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "remind_me_days" ), mRemind_me_days, 5 );
  addItem( itemRemind_me_days, QStringLiteral( "remind_me_days" ) );
  KConfigSkeleton::ItemBool  *itemAuto_write;
  itemAuto_write = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "auto_write" ), mAuto_write, true );
  addItem( itemAuto_write, QStringLiteral( "auto_write" ) );
  KConfigSkeleton::ItemInt  *itemAuto_write_days;
  itemAuto_write_days = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "auto_write_days" ), mAuto_write_days, 0 );
  addItem( itemAuto_write_days, QStringLiteral( "auto_write_days" ) );
  KConfigSkeleton::ItemInt  *itemOnce_every;
  itemOnce_every = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "once_every" ), mOnce_every, 1 );
  addItem( itemOnce_every, QStringLiteral( "once_every" ) );
  KConfigSkeleton::ItemString  *itemOnce_every_unit;
  itemOnce_every_unit = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "once_every_unit" ), mOnce_every_unit, QStringLiteral( "1" ) );
  addItem( itemOnce_every_unit, QStringLiteral( "once_every_unit" ) );
  KConfigSkeleton::ItemBool  *itemNb_times;
  itemNb_times = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "nb_times" ), mNb_times, false );
  addItem( itemNb_times, QStringLiteral( "nb_times" ) );
  KConfigSkeleton::ItemInt  *itemNb_times_val;
  itemNb_times_val = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "nb_times_val" ), mNb_times_val, 1 );
  addItem( itemNb_times_val, QStringLiteral( "nb_times_val" ) );
  KConfigSkeleton::ItemColor  *itemFontDisabledColor;
  itemFontDisabledColor = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "fontDisabledColor" ), mFontDisabledColor, Qt::gray );
  addItem( itemFontDisabledColor, QStringLiteral( "fontDisabledColor" ) );
}

skgscheduled_settings::~skgscheduled_settings()
{
  if (s_globalskgscheduled_settings.exists() && !s_globalskgscheduled_settings.isDestroyed()) {
    s_globalskgscheduled_settings()->q = nullptr;
  }
}

