// This file is generated by kconfig_compiler_kf6 from skgoperation_settings.kcfg.
// All changes you do to this file will be lost.
#ifndef SKGOPERATION_SETTINGS_H
#define SKGOPERATION_SETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class skgoperation_settings : public KConfigSkeleton
{
  public:

    static skgoperation_settings *self();
    ~skgoperation_settings() override;

    /**
      Get Color of font for future transactions
    */
    static
    QColor fontFutureColor()
    {
      return self()->mFontFutureColor;
    }

    /**
      Is Color of font for future transactions Immutable
    */
    static
    bool isFontFutureColorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "fontFutureColor" ) );
    }

    /**
      Get Color of font for non-validated transactions
    */
    static
    QColor fontNotValidatedColor()
    {
      return self()->mFontNotValidatedColor;
    }

    /**
      Is Color of font for non-validated transactions Immutable
    */
    static
    bool isFontNotValidatedColorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "fontNotValidatedColor" ) );
    }

    /**
      Get Color of font for sub transactions
    */
    static
    QColor fontSubOperationColor()
    {
      return self()->mFontSubOperationColor;
    }

    /**
      Is Color of font for sub transactions Immutable
    */
    static
    bool isFontSubOperationColorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "fontSubOperationColor" ) );
    }

    /**
      Get Fast edit mode
    */
    static
    QString fasteditmode()
    {
      return self()->mFasteditmode;
    }

    /**
      Is Fast edit mode Immutable
    */
    static
    bool isFasteditmodeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "fasteditmode" ) );
    }

    /**
      Get What to do, if an action breaks a reconciliation:
    */
    static
    QString broken_reconciliation()
    {
      return self()->mBroken_reconciliation;
    }

    /**
      Is What to do, if an action breaks a reconciliation: Immutable
    */
    static
    bool isBroken_reconciliationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "broken_reconciliation" ) );
    }

    /**
      Get What to do, if an action breaks an import:
    */
    static
    QString broken_import()
    {
      return self()->mBroken_import;
    }

    /**
      Is What to do, if an action breaks an import: Immutable
    */
    static
    bool isBroken_importImmutable()
    {
      return self()->isImmutable( QStringLiteral( "broken_import" ) );
    }

    /**
      Get Compute balances
    */
    static
    bool computeBalances()
    {
      return self()->mComputeBalances;
    }

    /**
      Is Compute balances Immutable
    */
    static
    bool isComputeBalancesImmutable()
    {
      return self()->isImmutable( QStringLiteral( "computeBalances" ) );
    }

    /**
      Get On current account only
    */
    static
    bool oncurrentaccountonly()
    {
      return self()->mOncurrentaccountonly;
    }

    /**
      Is On current account only Immutable
    */
    static
    bool isOncurrentaccountonlyImmutable()
    {
      return self()->isImmutable( QStringLiteral( "oncurrentaccountonly" ) );
    }

    /**
      Get Set the most used category when the payee is modified
    */
    static
    bool setCategoryForPayee()
    {
      return self()->mSetCategoryForPayee;
    }

    /**
      Is Set the most used category when the payee is modified Immutable
    */
    static
    bool isSetCategoryForPayeeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "setCategoryForPayee" ) );
    }

    /**
      Get Automatic mark transactions created during reconciliation
    */
    static
    bool automaticPointInReconciliation()
    {
      return self()->mAutomaticPointInReconciliation;
    }

    /**
      Is Automatic mark transactions created during reconciliation Immutable
    */
    static
    bool isAutomaticPointInReconciliationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "automaticPointInReconciliation" ) );
    }

    /**
      Get Default comment for fake transaction
    */
    static
    QString commentFakeOperation()
    {
      return self()->mCommentFakeOperation;
    }

    /**
      Is Default comment for fake transaction Immutable
    */
    static
    bool isCommentFakeOperationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "commentFakeOperation" ) );
    }

    /**
      Get Default payee for fake transaction
    */
    static
    QString payeeFakeOperation()
    {
      return self()->mPayeeFakeOperation;
    }

    /**
      Is Default payee for fake transaction Immutable
    */
    static
    bool isPayeeFakeOperationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "payeeFakeOperation" ) );
    }

    /**
      Get Default category for fake transaction
    */
    static
    QString categoryFakeOperation()
    {
      return self()->mCategoryFakeOperation;
    }

    /**
      Is Default category for fake transaction Immutable
    */
    static
    bool isCategoryFakeOperationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "categoryFakeOperation" ) );
    }

    /**
      Get Default comment for commission transaction
    */
    static
    QString commentCommissionOperation()
    {
      return self()->mCommentCommissionOperation;
    }

    /**
      Is Default comment for commission transaction Immutable
    */
    static
    bool isCommentCommissionOperationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "commentCommissionOperation" ) );
    }

    /**
      Get Default category for commission transaction
    */
    static
    QString categoryCommissionOperation()
    {
      return self()->mCategoryCommissionOperation;
    }

    /**
      Is Default category for commission transaction Immutable
    */
    static
    bool isCategoryCommissionOperationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "categoryCommissionOperation" ) );
    }

    /**
      Get Default comment for tax transaction
    */
    static
    QString commentTaxOperation()
    {
      return self()->mCommentTaxOperation;
    }

    /**
      Is Default comment for tax transaction Immutable
    */
    static
    bool isCommentTaxOperationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "commentTaxOperation" ) );
    }

    /**
      Get Default category for tax transaction
    */
    static
    QString categoryTaxOperation()
    {
      return self()->mCategoryTaxOperation;
    }

    /**
      Is Default category for tax transaction Immutable
    */
    static
    bool isCategoryTaxOperationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "categoryTaxOperation" ) );
    }

  protected:
    skgoperation_settings();
    friend class skgoperation_settingsHelper;


    // skrooge_operation
    QColor mFontFutureColor;
    QColor mFontNotValidatedColor;
    QColor mFontSubOperationColor;
    QString mFasteditmode;
    QString mBroken_reconciliation;
    QString mBroken_import;
    bool mComputeBalances;
    bool mOncurrentaccountonly;
    bool mSetCategoryForPayee;
    bool mAutomaticPointInReconciliation;
    QString mCommentFakeOperation;
    QString mPayeeFakeOperation;
    QString mCategoryFakeOperation;
    QString mCommentCommissionOperation;
    QString mCategoryCommissionOperation;
    QString mCommentTaxOperation;
    QString mCategoryTaxOperation;
};

#endif

