// This file is generated by kconfig_compiler_kf6 from skgimportexport_settings.kcfg.
// All changes you do to this file will be lost.

#include "skgimportexport_settings.h"

#include <qglobal.h>
#include <QFile>

class skgimportexport_settingsHelper
{
  public:
    skgimportexport_settingsHelper() noexcept : q(nullptr) {}
    ~skgimportexport_settingsHelper() noexcept { delete q; q = nullptr; }
    skgimportexport_settingsHelper(const skgimportexport_settingsHelper&) = delete;
    skgimportexport_settingsHelper& operator=(const skgimportexport_settingsHelper&) = delete;
    skgimportexport_settings *q;
};
Q_GLOBAL_STATIC(skgimportexport_settingsHelper, s_globalskgimportexport_settings)
skgimportexport_settings *skgimportexport_settings::self()
{
  if (!s_globalskgimportexport_settings()->q) {
    new skgimportexport_settings;
    s_globalskgimportexport_settings()->q->read();
  }

  return s_globalskgimportexport_settings()->q;
}

skgimportexport_settings::skgimportexport_settings( )
  : KConfigSkeleton()
{
  Q_ASSERT(!s_globalskgimportexport_settings()->q);
  s_globalskgimportexport_settings()->q = this;
  setCurrentGroup( QStringLiteral( "skrooge_importexport" ) );

  KConfigSkeleton::ItemBool  *itemAutomatic_validation;
  itemAutomatic_validation = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "automatic_validation" ), mAutomatic_validation, false );
  addItem( itemAutomatic_validation, QStringLiteral( "automatic_validation" ) );
  KConfigSkeleton::ItemBool  *itemApply_rules;
  itemApply_rules = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "apply_rules" ), mApply_rules, false );
  addItem( itemApply_rules, QStringLiteral( "apply_rules" ) );
  KConfigSkeleton::ItemBool  *itemOpen_after_import_or_processing;
  itemOpen_after_import_or_processing = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "open_after_import_or_processing" ), mOpen_after_import_or_processing, false );
  addItem( itemOpen_after_import_or_processing, QStringLiteral( "open_after_import_or_processing" ) );
  KConfigSkeleton::ItemBool  *itemSince_last_import;
  itemSince_last_import = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "since_last_import" ), mSince_last_import, false );
  addItem( itemSince_last_import, QStringLiteral( "since_last_import" ) );
  KConfigSkeleton::ItemBool  *itemAutomatic_search_header;
  itemAutomatic_search_header = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "automatic_search_header" ), mAutomatic_search_header, true );
  addItem( itemAutomatic_search_header, QStringLiteral( "automatic_search_header" ) );
  KConfigSkeleton::ItemBool  *itemAutomatic_search_columns;
  itemAutomatic_search_columns = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "automatic_search_columns" ), mAutomatic_search_columns, true );
  addItem( itemAutomatic_search_columns, QStringLiteral( "automatic_search_columns" ) );
  KConfigSkeleton::ItemInt  *itemHeader_position;
  itemHeader_position = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "header_position" ), mHeader_position, 1 );
  addItem( itemHeader_position, QStringLiteral( "header_position" ) );
  KConfigSkeleton::ItemString  *itemColumns_positions;
  itemColumns_positions = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "columns_positions" ), mColumns_positions );
  addItem( itemColumns_positions, QStringLiteral( "columns_positions" ) );
  KConfigSkeleton::ItemString  *itemMapping_date;
  itemMapping_date = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "mapping_date" ), mMapping_date, SKGImportExportManager().getParameterDefaultValue("mapping_date") );
  addItem( itemMapping_date, QStringLiteral( "mapping_date" ) );
  KConfigSkeleton::ItemString  *itemMapping_number;
  itemMapping_number = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "mapping_number" ), mMapping_number, SKGImportExportManager().getParameterDefaultValue("mapping_number") );
  addItem( itemMapping_number, QStringLiteral( "mapping_number" ) );
  KConfigSkeleton::ItemString  *itemMapping_mode;
  itemMapping_mode = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "mapping_mode" ), mMapping_mode, SKGImportExportManager().getParameterDefaultValue("mapping_mode") );
  addItem( itemMapping_mode, QStringLiteral( "mapping_mode" ) );
  KConfigSkeleton::ItemString  *itemMapping_payee;
  itemMapping_payee = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "mapping_payee" ), mMapping_payee, SKGImportExportManager().getParameterDefaultValue("mapping_payee") );
  addItem( itemMapping_payee, QStringLiteral( "mapping_payee" ) );
  KConfigSkeleton::ItemString  *itemMapping_comment;
  itemMapping_comment = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "mapping_comment" ), mMapping_comment, SKGImportExportManager().getParameterDefaultValue("mapping_comment") );
  addItem( itemMapping_comment, QStringLiteral( "mapping_comment" ) );
  KConfigSkeleton::ItemString  *itemMapping_status;
  itemMapping_status = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "mapping_status" ), mMapping_status, SKGImportExportManager().getParameterDefaultValue("mapping_status") );
  addItem( itemMapping_status, QStringLiteral( "mapping_status" ) );
  KConfigSkeleton::ItemString  *itemMapping_bookmarked;
  itemMapping_bookmarked = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "mapping_bookmarked" ), mMapping_bookmarked, SKGImportExportManager().getParameterDefaultValue("mapping_bookmarked") );
  addItem( itemMapping_bookmarked, QStringLiteral( "mapping_bookmarked" ) );
  KConfigSkeleton::ItemString  *itemMapping_account;
  itemMapping_account = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "mapping_account" ), mMapping_account, SKGImportExportManager().getParameterDefaultValue("mapping_account") );
  addItem( itemMapping_account, QStringLiteral( "mapping_account" ) );
  KConfigSkeleton::ItemString  *itemMapping_category;
  itemMapping_category = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "mapping_category" ), mMapping_category, SKGImportExportManager().getParameterDefaultValue("mapping_category") );
  addItem( itemMapping_category, QStringLiteral( "mapping_category" ) );
  KConfigSkeleton::ItemString  *itemMapping_amount;
  itemMapping_amount = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "mapping_amount" ), mMapping_amount, SKGImportExportManager().getParameterDefaultValue("mapping_amount") );
  addItem( itemMapping_amount, QStringLiteral( "mapping_amount" ) );
  KConfigSkeleton::ItemString  *itemMapping_quantity;
  itemMapping_quantity = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "mapping_quantity" ), mMapping_quantity, SKGImportExportManager().getParameterDefaultValue("mapping_quantity") );
  addItem( itemMapping_quantity, QStringLiteral( "mapping_quantity" ) );
  KConfigSkeleton::ItemString  *itemMapping_sign;
  itemMapping_sign = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "mapping_sign" ), mMapping_sign, SKGImportExportManager().getParameterDefaultValue("mapping_sign") );
  addItem( itemMapping_sign, QStringLiteral( "mapping_sign" ) );
  KConfigSkeleton::ItemString  *itemMapping_debit;
  itemMapping_debit = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "mapping_debit" ), mMapping_debit, SKGImportExportManager().getParameterDefaultValue("mapping_debit") );
  addItem( itemMapping_debit, QStringLiteral( "mapping_debit" ) );
  KConfigSkeleton::ItemString  *itemMapping_unit;
  itemMapping_unit = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "mapping_unit" ), mMapping_unit, SKGImportExportManager().getParameterDefaultValue("mapping_unit") );
  addItem( itemMapping_unit, QStringLiteral( "mapping_unit" ) );
  KConfigSkeleton::ItemString  *itemMapping_idtransaction;
  itemMapping_idtransaction = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "mapping_idtransaction" ), mMapping_idtransaction, SKGImportExportManager().getParameterDefaultValue("mapping_idtransaction") );
  addItem( itemMapping_idtransaction, QStringLiteral( "mapping_idtransaction" ) );
  KConfigSkeleton::ItemString  *itemMapping_idgroup;
  itemMapping_idgroup = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "mapping_idgroup" ), mMapping_idgroup, SKGImportExportManager().getParameterDefaultValue("mapping_idgroup") );
  addItem( itemMapping_idgroup, QStringLiteral( "mapping_idgroup" ) );
  KConfigSkeleton::ItemString  *itemMapping_property;
  itemMapping_property = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "mapping_property" ), mMapping_property );
  addItem( itemMapping_property, QStringLiteral( "mapping_property" ) );
  KConfigSkeleton::ItemString  *itemBackends;
  itemBackends = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "backends" ), mBackends, QStringLiteral( "weboob" ) );
  addItem( itemBackends, QStringLiteral( "backends" ) );
  KConfigSkeleton::ItemString  *itemCsv_date_format;
  itemCsv_date_format = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "csv_date_format" ), mCsv_date_format, QStringLiteral( "Automatic detection" ) );
  addItem( itemCsv_date_format, QStringLiteral( "csv_date_format" ) );
  KConfigSkeleton::ItemString  *itemLedger_account_identification;
  itemLedger_account_identification = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "ledger_account_identification" ), mLedger_account_identification, QStringLiteral( "COMPTE,COMPTES,CAPITAUX,ASSETS,LIABILITIES,SAVING" ) );
  addItem( itemLedger_account_identification, QStringLiteral( "ledger_account_identification" ) );
  KConfigSkeleton::ItemString  *itemQif_date_format;
  itemQif_date_format = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "qif_date_format" ), mQif_date_format, QStringLiteral( "Automatic detection" ) );
  addItem( itemQif_date_format, QStringLiteral( "qif_date_format" ) );
  KConfigSkeleton::ItemBool  *itemDownload_on_open;
  itemDownload_on_open = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "download_on_open" ), mDownload_on_open, false );
  addItem( itemDownload_on_open, QStringLiteral( "download_on_open" ) );
  KConfigSkeleton::ItemInt  *itemDownload_frequency;
  itemDownload_frequency = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "download_frequency" ), mDownload_frequency, 0 );
  addItem( itemDownload_frequency, QStringLiteral( "download_frequency" ) );
}

skgimportexport_settings::~skgimportexport_settings()
{
  if (s_globalskgimportexport_settings.exists() && !s_globalskgimportexport_settings.isDestroyed()) {
    s_globalskgimportexport_settings()->q = nullptr;
  }
}

