/********************************************************************************
** Form generated from reading UI file 'skgoperationpluginwidget_pref.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGOPERATIONPLUGINWIDGET_PREF_H
#define UI_SKGOPERATIONPLUGINWIDGET_PREF_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <kcombobox.h>
#include <klocalizedstring.h>
#include "kcolorbutton.h"
#include "klineedit.h"
#include "skgcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_skgoperationplugin_pref
{
public:
    QGridLayout *gridLayout_2;
    QLabel *label_3;
    QSpacerItem *verticalSpacer;
    KComboBox *kcfg_broken_reconciliation;
    QSpacerItem *horizontalSpacer_3;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_2;
    QTabWidget *tabWidget;
    QWidget *tab;
    QFormLayout *formLayout;
    QLabel *kCommentFakeLbl;
    QLabel *kPayeeFakeLbl;
    QLabel *kCategoryFakeLbl;
    SKGComboBox *kcfg_payeeFakeOperation;
    SKGComboBox *kcfg_categoryFakeOperation;
    KLineEdit *kcfg_commentFakeOperation;
    QWidget *tab_2;
    QFormLayout *formLayout_2;
    QLabel *kCommentCommissionLbl;
    KLineEdit *kcfg_commentCommissionOperation;
    QLabel *kCategoryCommissionLbl;
    SKGComboBox *kcfg_categoryCommissionOperation;
    QLabel *kCommentTaxLbl;
    KLineEdit *kcfg_commentTaxOperation;
    QLabel *kCategoryTaxLbl;
    SKGComboBox *kcfg_categoryTaxOperation;
    QLabel *label;
    QLabel *label_2;
    QCheckBox *kcfg_setCategoryForPayee;
    QCheckBox *kcfg_computeBalances;
    QCheckBox *kcfg_automaticPointInReconciliation;
    QGroupBox *fontBox;
    QGridLayout *gridLayout;
    QLabel *fontFutureLbl;
    KColorButton *kcfg_fontFutureColor;
    QLabel *fontNotValidatedLbl;
    KColorButton *kcfg_fontNotValidatedColor;
    QLabel *fontSubOperationLbl;
    KColorButton *kcfg_fontSubOperationColor;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout;
    QLabel *fasteditmodelbl;
    KComboBox *kcfg_fasteditmode;
    QCheckBox *kcfg_oncurrentaccountonly;
    QSpacerItem *horizontalSpacer_2;
    QLabel *label_4;
    KComboBox *kcfg_broken_import;

    void setupUi(QWidget *skgoperationplugin_pref)
    {
        if (skgoperationplugin_pref->objectName().isEmpty())
            skgoperationplugin_pref->setObjectName("skgoperationplugin_pref");
        skgoperationplugin_pref->resize(668, 644);
        gridLayout_2 = new QGridLayout(skgoperationplugin_pref);
        gridLayout_2->setObjectName("gridLayout_2");
        label_3 = new QLabel(skgoperationplugin_pref);
        label_3->setObjectName("label_3");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_3->sizePolicy().hasHeightForWidth());
        label_3->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(label_3, 5, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 126, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 8, 0, 1, 1);

        kcfg_broken_reconciliation = new KComboBox(skgoperationplugin_pref);
        kcfg_broken_reconciliation->addItem(QString());
        kcfg_broken_reconciliation->addItem(QString());
        kcfg_broken_reconciliation->addItem(QString());
        kcfg_broken_reconciliation->setObjectName("kcfg_broken_reconciliation");

        gridLayout_2->addWidget(kcfg_broken_reconciliation, 5, 1, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_3, 5, 2, 1, 1);

        groupBox = new QGroupBox(skgoperationplugin_pref);
        groupBox->setObjectName("groupBox");
        verticalLayout_2 = new QVBoxLayout(groupBox);
        verticalLayout_2->setSpacing(0);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        tabWidget = new QTabWidget(groupBox);
        tabWidget->setObjectName("tabWidget");
        QFont font;
        font.setBold(false);
        tabWidget->setFont(font);
        tab = new QWidget();
        tab->setObjectName("tab");
        formLayout = new QFormLayout(tab);
        formLayout->setObjectName("formLayout");
        formLayout->setHorizontalSpacing(2);
        formLayout->setVerticalSpacing(2);
        formLayout->setContentsMargins(0, 0, 0, 0);
        kCommentFakeLbl = new QLabel(tab);
        kCommentFakeLbl->setObjectName("kCommentFakeLbl");
        kCommentFakeLbl->setText(QString::fromUtf8("&TextLabel"));

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, kCommentFakeLbl);

        kPayeeFakeLbl = new QLabel(tab);
        kPayeeFakeLbl->setObjectName("kPayeeFakeLbl");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, kPayeeFakeLbl);

        kCategoryFakeLbl = new QLabel(tab);
        kCategoryFakeLbl->setObjectName("kCategoryFakeLbl");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, kCategoryFakeLbl);

        kcfg_payeeFakeOperation = new SKGComboBox(tab);
        kcfg_payeeFakeOperation->setObjectName("kcfg_payeeFakeOperation");
        kcfg_payeeFakeOperation->setEditable(true);
        kcfg_payeeFakeOperation->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_payeeFakeOperation);

        kcfg_categoryFakeOperation = new SKGComboBox(tab);
        kcfg_categoryFakeOperation->setObjectName("kcfg_categoryFakeOperation");
        kcfg_categoryFakeOperation->setEditable(true);
        kcfg_categoryFakeOperation->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_categoryFakeOperation);

        kcfg_commentFakeOperation = new KLineEdit(tab);
        kcfg_commentFakeOperation->setObjectName("kcfg_commentFakeOperation");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_commentFakeOperation);

        tabWidget->addTab(tab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        formLayout_2 = new QFormLayout(tab_2);
        formLayout_2->setObjectName("formLayout_2");
        kCommentCommissionLbl = new QLabel(tab_2);
        kCommentCommissionLbl->setObjectName("kCommentCommissionLbl");
        kCommentCommissionLbl->setText(QString::fromUtf8("&TextLabel"));

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, kCommentCommissionLbl);

        kcfg_commentCommissionOperation = new KLineEdit(tab_2);
        kcfg_commentCommissionOperation->setObjectName("kcfg_commentCommissionOperation");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_commentCommissionOperation);

        kCategoryCommissionLbl = new QLabel(tab_2);
        kCategoryCommissionLbl->setObjectName("kCategoryCommissionLbl");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::LabelRole, kCategoryCommissionLbl);

        kcfg_categoryCommissionOperation = new SKGComboBox(tab_2);
        kcfg_categoryCommissionOperation->setObjectName("kcfg_categoryCommissionOperation");
        kcfg_categoryCommissionOperation->setEditable(true);
        kcfg_categoryCommissionOperation->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        formLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_categoryCommissionOperation);

        kCommentTaxLbl = new QLabel(tab_2);
        kCommentTaxLbl->setObjectName("kCommentTaxLbl");
        kCommentTaxLbl->setText(QString::fromUtf8("TextLabel"));

        formLayout_2->setWidget(4, QFormLayout::ItemRole::LabelRole, kCommentTaxLbl);

        kcfg_commentTaxOperation = new KLineEdit(tab_2);
        kcfg_commentTaxOperation->setObjectName("kcfg_commentTaxOperation");

        formLayout_2->setWidget(4, QFormLayout::ItemRole::FieldRole, kcfg_commentTaxOperation);

        kCategoryTaxLbl = new QLabel(tab_2);
        kCategoryTaxLbl->setObjectName("kCategoryTaxLbl");

        formLayout_2->setWidget(5, QFormLayout::ItemRole::LabelRole, kCategoryTaxLbl);

        kcfg_categoryTaxOperation = new SKGComboBox(tab_2);
        kcfg_categoryTaxOperation->setObjectName("kcfg_categoryTaxOperation");
        kcfg_categoryTaxOperation->setEditable(true);
        kcfg_categoryTaxOperation->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        formLayout_2->setWidget(5, QFormLayout::ItemRole::FieldRole, kcfg_categoryTaxOperation);

        label = new QLabel(tab_2);
        label->setObjectName("label");
        QFont font1;
        font1.setBold(true);
        label->setFont(font1);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::SpanningRole, label);

        label_2 = new QLabel(tab_2);
        label_2->setObjectName("label_2");
        label_2->setFont(font1);

        formLayout_2->setWidget(3, QFormLayout::ItemRole::SpanningRole, label_2);

        tabWidget->addTab(tab_2, QString());

        verticalLayout_2->addWidget(tabWidget);


        gridLayout_2->addWidget(groupBox, 7, 0, 1, 3);

        kcfg_setCategoryForPayee = new QCheckBox(skgoperationplugin_pref);
        kcfg_setCategoryForPayee->setObjectName("kcfg_setCategoryForPayee");

        gridLayout_2->addWidget(kcfg_setCategoryForPayee, 2, 0, 1, 3);

        kcfg_computeBalances = new QCheckBox(skgoperationplugin_pref);
        kcfg_computeBalances->setObjectName("kcfg_computeBalances");
        kcfg_computeBalances->setChecked(true);

        gridLayout_2->addWidget(kcfg_computeBalances, 3, 0, 1, 3);

        kcfg_automaticPointInReconciliation = new QCheckBox(skgoperationplugin_pref);
        kcfg_automaticPointInReconciliation->setObjectName("kcfg_automaticPointInReconciliation");

        gridLayout_2->addWidget(kcfg_automaticPointInReconciliation, 4, 0, 1, 3);

        fontBox = new QGroupBox(skgoperationplugin_pref);
        fontBox->setObjectName("fontBox");
        gridLayout = new QGridLayout(fontBox);
        gridLayout->setSpacing(2);
        gridLayout->setObjectName("gridLayout");
        fontFutureLbl = new QLabel(fontBox);
        fontFutureLbl->setObjectName("fontFutureLbl");
        fontFutureLbl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(fontFutureLbl, 0, 0, 1, 2);

        kcfg_fontFutureColor = new KColorButton(fontBox);
        kcfg_fontFutureColor->setObjectName("kcfg_fontFutureColor");
        kcfg_fontFutureColor->setProperty("color", QVariant(QColor(195, 195, 195)));
        kcfg_fontFutureColor->setProperty("defaultColor", QVariant(QColor(195, 195, 195)));

        gridLayout->addWidget(kcfg_fontFutureColor, 0, 2, 1, 1);

        fontNotValidatedLbl = new QLabel(fontBox);
        fontNotValidatedLbl->setObjectName("fontNotValidatedLbl");
        fontNotValidatedLbl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(fontNotValidatedLbl, 1, 0, 1, 2);

        kcfg_fontNotValidatedColor = new KColorButton(fontBox);
        kcfg_fontNotValidatedColor->setObjectName("kcfg_fontNotValidatedColor");
        kcfg_fontNotValidatedColor->setProperty("color", QVariant(QColor(0, 0, 255)));
        kcfg_fontNotValidatedColor->setProperty("defaultColor", QVariant(QColor(195, 195, 195)));

        gridLayout->addWidget(kcfg_fontNotValidatedColor, 1, 2, 1, 1);

        fontSubOperationLbl = new QLabel(fontBox);
        fontSubOperationLbl->setObjectName("fontSubOperationLbl");
        fontSubOperationLbl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(fontSubOperationLbl, 2, 0, 1, 2);

        kcfg_fontSubOperationColor = new KColorButton(fontBox);
        kcfg_fontSubOperationColor->setObjectName("kcfg_fontSubOperationColor");
        kcfg_fontSubOperationColor->setProperty("color", QVariant(QColor(0, 85, 0)));
        kcfg_fontSubOperationColor->setProperty("defaultColor", QVariant(QColor(195, 195, 195)));

        gridLayout->addWidget(kcfg_fontSubOperationColor, 2, 2, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 3, 1, 1);


        gridLayout_2->addWidget(fontBox, 0, 0, 1, 3);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(2);
        horizontalLayout->setObjectName("horizontalLayout");
        fasteditmodelbl = new QLabel(skgoperationplugin_pref);
        fasteditmodelbl->setObjectName("fasteditmodelbl");
        sizePolicy.setHeightForWidth(fasteditmodelbl->sizePolicy().hasHeightForWidth());
        fasteditmodelbl->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(fasteditmodelbl);

        kcfg_fasteditmode = new KComboBox(skgoperationplugin_pref);
        kcfg_fasteditmode->addItem(QString());
        kcfg_fasteditmode->addItem(QString());
        kcfg_fasteditmode->addItem(QString());
        kcfg_fasteditmode->addItem(QString());
        kcfg_fasteditmode->setObjectName("kcfg_fasteditmode");
        kcfg_fasteditmode->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        horizontalLayout->addWidget(kcfg_fasteditmode);

        kcfg_oncurrentaccountonly = new QCheckBox(skgoperationplugin_pref);
        kcfg_oncurrentaccountonly->setObjectName("kcfg_oncurrentaccountonly");

        horizontalLayout->addWidget(kcfg_oncurrentaccountonly);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        gridLayout_2->addLayout(horizontalLayout, 1, 0, 1, 3);

        label_4 = new QLabel(skgoperationplugin_pref);
        label_4->setObjectName("label_4");
        sizePolicy.setHeightForWidth(label_4->sizePolicy().hasHeightForWidth());
        label_4->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(label_4, 6, 0, 1, 1);

        kcfg_broken_import = new KComboBox(skgoperationplugin_pref);
        kcfg_broken_import->addItem(QString());
        kcfg_broken_import->addItem(QString());
        kcfg_broken_import->addItem(QString());
        kcfg_broken_import->setObjectName("kcfg_broken_import");

        gridLayout_2->addWidget(kcfg_broken_import, 6, 1, 1, 1);

#if QT_CONFIG(shortcut)
        label_3->setBuddy(kcfg_broken_reconciliation);
        kCommentFakeLbl->setBuddy(kcfg_commentFakeOperation);
        kPayeeFakeLbl->setBuddy(kcfg_payeeFakeOperation);
        kCategoryFakeLbl->setBuddy(kcfg_categoryFakeOperation);
        kCommentCommissionLbl->setBuddy(kcfg_commentFakeOperation);
        kCategoryCommissionLbl->setBuddy(kcfg_categoryFakeOperation);
        kCommentTaxLbl->setBuddy(kcfg_commentFakeOperation);
        kCategoryTaxLbl->setBuddy(kcfg_categoryFakeOperation);
        fontFutureLbl->setBuddy(kcfg_fontFutureColor);
        fontNotValidatedLbl->setBuddy(kcfg_fontNotValidatedColor);
        fontSubOperationLbl->setBuddy(kcfg_fontSubOperationColor);
        fasteditmodelbl->setBuddy(kcfg_fasteditmode);
        label_4->setBuddy(kcfg_broken_import);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kcfg_fontFutureColor, kcfg_fontNotValidatedColor);
        QWidget::setTabOrder(kcfg_fontNotValidatedColor, kcfg_fontSubOperationColor);
        QWidget::setTabOrder(kcfg_fontSubOperationColor, kcfg_fasteditmode);
        QWidget::setTabOrder(kcfg_fasteditmode, kcfg_oncurrentaccountonly);
        QWidget::setTabOrder(kcfg_oncurrentaccountonly, kcfg_setCategoryForPayee);
        QWidget::setTabOrder(kcfg_setCategoryForPayee, kcfg_computeBalances);
        QWidget::setTabOrder(kcfg_computeBalances, kcfg_automaticPointInReconciliation);
        QWidget::setTabOrder(kcfg_automaticPointInReconciliation, kcfg_broken_reconciliation);
        QWidget::setTabOrder(kcfg_broken_reconciliation, kcfg_broken_import);
        QWidget::setTabOrder(kcfg_broken_import, tabWidget);
        QWidget::setTabOrder(tabWidget, kcfg_commentFakeOperation);
        QWidget::setTabOrder(kcfg_commentFakeOperation, kcfg_payeeFakeOperation);
        QWidget::setTabOrder(kcfg_payeeFakeOperation, kcfg_categoryFakeOperation);
        QWidget::setTabOrder(kcfg_categoryFakeOperation, kcfg_commentCommissionOperation);
        QWidget::setTabOrder(kcfg_commentCommissionOperation, kcfg_categoryCommissionOperation);
        QWidget::setTabOrder(kcfg_categoryCommissionOperation, kcfg_commentTaxOperation);
        QWidget::setTabOrder(kcfg_commentTaxOperation, kcfg_categoryTaxOperation);

        retranslateUi(skgoperationplugin_pref);

        tabWidget->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(skgoperationplugin_pref);
    } // setupUi

    void retranslateUi(QWidget *skgoperationplugin_pref)
    {
        label_3->setText(tr2i18n("&What to do, if an action breaks a reconciliation:", nullptr));
        kcfg_broken_reconciliation->setItemText(0, tr2i18n("Nothing", nullptr));
        kcfg_broken_reconciliation->setItemText(1, tr2i18n("Display a warning message", nullptr));
        kcfg_broken_reconciliation->setItemText(2, tr2i18n("Display an error message and cancel the current action", nullptr));

        groupBox->setTitle(tr2i18n("Default values for special transactions", nullptr));
        kPayeeFakeLbl->setText(tr2i18n("Te&xtLabel", nullptr));
        kCategoryFakeLbl->setText(tr2i18n("TextLabel", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab), tr2i18n("Fake", nullptr));
        kCategoryCommissionLbl->setText(tr2i18n("Te&xtLabel", nullptr));
        kCategoryTaxLbl->setText(tr2i18n("TextLabel", nullptr));
        label->setText(tr2i18n("Commission", nullptr));
        label_2->setText(tr2i18n("Tax", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_2), tr2i18n("Commission / Tax", nullptr));
        kcfg_setCategoryForPayee->setText(tr2i18n("Set the most used category when the payee is modified", nullptr));
        kcfg_computeBalances->setText(tr2i18n("Compute balances (uncheck to improve performances)", nullptr));
        kcfg_automaticPointInReconciliation->setText(tr2i18n("Automatic mark transactions created during reconciliation", nullptr));
        fontBox->setTitle(tr2i18n("Fonts", nullptr));
        fontFutureLbl->setText(tr2i18n("Font fo&r future transactions:", nullptr));
        fontNotValidatedLbl->setText(tr2i18n("Font for non-&validated transactions:", nullptr));
        fontSubOperationLbl->setText(tr2i18n("Font for sub transactions:", nullptr));
        fasteditmodelbl->setText(tr2i18n("Fast edit &mode:", nullptr));
        kcfg_fasteditmode->setItemText(0, tr2i18n("Search in templates only", nullptr));
        kcfg_fasteditmode->setItemText(1, tr2i18n("Search first in templates and after in transactions", nullptr));
        kcfg_fasteditmode->setItemText(2, tr2i18n("Search in transactions only", nullptr));
        kcfg_fasteditmode->setItemText(3, tr2i18n("Search first in transactions and after in templates", nullptr));

        kcfg_oncurrentaccountonly->setText(tr2i18n("On current account only", nullptr));
        label_4->setText(tr2i18n("W&hat to do, if an action breaks an import:", nullptr));
        kcfg_broken_import->setItemText(0, tr2i18n("Nothing", nullptr));
        kcfg_broken_import->setItemText(1, tr2i18n("Display a warning message", nullptr));
        kcfg_broken_import->setItemText(2, tr2i18n("Display an error message and cancel the current action", nullptr));

        (void)skgoperationplugin_pref;
    } // retranslateUi

};

namespace Ui {
    class skgoperationplugin_pref: public Ui_skgoperationplugin_pref {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGOPERATIONPLUGINWIDGET_PREF_H

