/********************************************************************************
** Form generated from reading UI file 'skgfilteredtableview.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGFILTEREDTABLEVIEW_H
#define UI_SKGFILTEREDTABLEVIEW_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "ktitlewidget.h"
#include "skgshow.h"
#include "skgtableview.h"
#include "skgtreeview.h"

QT_BEGIN_NAMESPACE

class Ui_skgfilteredtableview_base
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_8;
    KTitleWidget *kTitle;
    QToolButton *kResetInternalFilter;
    QHBoxLayout *horizontalLayout_7;
    SKGShow *kShow;
    QSpacerItem *horizontalSpacer;
    QLineEdit *kFilterEdit;
    QToolButton *kConfigure;
    SKGTableView *kView;

    void setupUi(QWidget *skgfilteredtableview_base)
    {
        if (skgfilteredtableview_base->objectName().isEmpty())
            skgfilteredtableview_base->setObjectName("skgfilteredtableview_base");
        skgfilteredtableview_base->resize(488, 364);
        verticalLayout = new QVBoxLayout(skgfilteredtableview_base);
        verticalLayout->setSpacing(2);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setSpacing(2);
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        kTitle = new KTitleWidget(skgfilteredtableview_base);
        kTitle->setObjectName("kTitle");
        kTitle->setMaximumSize(QSize(16777215, 80));

        horizontalLayout_8->addWidget(kTitle);

        kResetInternalFilter = new QToolButton(skgfilteredtableview_base);
        kResetInternalFilter->setObjectName("kResetInternalFilter");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kResetInternalFilter->sizePolicy().hasHeightForWidth());
        kResetInternalFilter->setSizePolicy(sizePolicy);
        kResetInternalFilter->setFocusPolicy(Qt::NoFocus);
        kResetInternalFilter->setCheckable(false);
        kResetInternalFilter->setChecked(false);
        kResetInternalFilter->setAutoRaise(true);

        horizontalLayout_8->addWidget(kResetInternalFilter);


        verticalLayout->addLayout(horizontalLayout_8);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setSpacing(2);
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        horizontalLayout_7->setContentsMargins(-1, 0, -1, -1);
        kShow = new SKGShow(skgfilteredtableview_base);
        kShow->setObjectName("kShow");

        horizontalLayout_7->addWidget(kShow);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer);

        kFilterEdit = new QLineEdit(skgfilteredtableview_base);
        kFilterEdit->setObjectName("kFilterEdit");
        kFilterEdit->setMinimumSize(QSize(250, 0));
        kFilterEdit->setMaximumSize(QSize(250, 16777215));
        kFilterEdit->setClearButtonEnabled(true);

        horizontalLayout_7->addWidget(kFilterEdit);

        kConfigure = new QToolButton(skgfilteredtableview_base);
        kConfigure->setObjectName("kConfigure");
        kConfigure->setMaximumSize(QSize(22, 22));
        kConfigure->setFocusPolicy(Qt::ClickFocus);
        kConfigure->setPopupMode(QToolButton::InstantPopup);
        kConfigure->setAutoRaise(true);

        horizontalLayout_7->addWidget(kConfigure);


        verticalLayout->addLayout(horizontalLayout_7);

        kView = new SKGTableView(skgfilteredtableview_base);
        kView->setObjectName("kView");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(kView->sizePolicy().hasHeightForWidth());
        kView->setSizePolicy(sizePolicy1);
        kView->setAcceptDrops(true);
        kView->setEditTriggers(QAbstractItemView::AnyKeyPressed|QAbstractItemView::EditKeyPressed);
        kView->setDragEnabled(true);
        kView->setAlternatingRowColors(true);
        kView->setSelectionMode(QAbstractItemView::ExtendedSelection);
        kView->setSortingEnabled(true);

        verticalLayout->addWidget(kView);

        QWidget::setTabOrder(kResetInternalFilter, kFilterEdit);
        QWidget::setTabOrder(kFilterEdit, kConfigure);
        QWidget::setTabOrder(kConfigure, kView);

        retranslateUi(skgfilteredtableview_base);

        QMetaObject::connectSlotsByName(skgfilteredtableview_base);
    } // setupUi

    void retranslateUi(QWidget *skgfilteredtableview_base)
    {
#if QT_CONFIG(tooltip)
        kResetInternalFilter->setToolTip(tr2i18n("Reset the internal filter", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kResetInternalFilter->setStatusTip(tr2i18n("Reset the internal filter", nullptr));
#endif // QT_CONFIG(statustip)
        kFilterEdit->setPlaceholderText(tr2i18n("Search", nullptr));
#if QT_CONFIG(tooltip)
        kConfigure->setToolTip(tr2i18n("To configure the table", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kConfigure->setStatusTip(tr2i18n("To configure the table", nullptr));
#endif // QT_CONFIG(statustip)
        (void)skgfilteredtableview_base;
    } // retranslateUi

};

namespace Ui {
    class skgfilteredtableview_base: public Ui_skgfilteredtableview_base {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGFILTEREDTABLEVIEW_H

