/********************************************************************************
** Form generated from reading UI file 'skgpropertiesplugindockwidget_base.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGPROPERTIESPLUGINDOCKWIDGET_BASE_H
#define UI_SKGPROPERTIESPLUGINDOCKWIDGET_BASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kimagefilepreview.h"
#include "skgcombobox.h"
#include "skgtableview.h"
#include "skgtreeview.h"

QT_BEGIN_NAMESPACE

class Ui_skgpropertiesdockplugin_base
{
public:
    QGridLayout *gridLayout;
    QLineEdit *kFilterEdit;
    QHBoxLayout *horizontalLayout;
    SKGComboBox *kAttribute;
    QPushButton *kRename;
    QPushButton *kAdd;
    QHBoxLayout *horizontalLayout_2;
    SKGComboBox *kValue;
    QPushButton *kSelectFile;
    QPushButton *kRemove;
    QPushButton *kOpenBtn;
    KImageFilePreview *kPicture;
    QLabel *label;
    SKGComboBox *kForCmb;
    SKGTableView *kView;

    void setupUi(QWidget *skgpropertiesdockplugin_base)
    {
        if (skgpropertiesdockplugin_base->objectName().isEmpty())
            skgpropertiesdockplugin_base->setObjectName("skgpropertiesdockplugin_base");
        skgpropertiesdockplugin_base->resize(192, 310);
        gridLayout = new QGridLayout(skgpropertiesdockplugin_base);
        gridLayout->setSpacing(2);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        kFilterEdit = new QLineEdit(skgpropertiesdockplugin_base);
        kFilterEdit->setObjectName("kFilterEdit");
        kFilterEdit->setFocusPolicy(Qt::WheelFocus);
        kFilterEdit->setClearButtonEnabled(true);

        gridLayout->addWidget(kFilterEdit, 2, 0, 1, 3);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(2);
        horizontalLayout->setObjectName("horizontalLayout");
        kAttribute = new SKGComboBox(skgpropertiesdockplugin_base);
        kAttribute->setObjectName("kAttribute");
        kAttribute->setEditable(true);
        kAttribute->setAutoCompletion(false);

        horizontalLayout->addWidget(kAttribute);

        kRename = new QPushButton(skgpropertiesdockplugin_base);
        kRename->setObjectName("kRename");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kRename->sizePolicy().hasHeightForWidth());
        kRename->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(kRename);

        kAdd = new QPushButton(skgpropertiesdockplugin_base);
        kAdd->setObjectName("kAdd");
        sizePolicy.setHeightForWidth(kAdd->sizePolicy().hasHeightForWidth());
        kAdd->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(kAdd);


        gridLayout->addLayout(horizontalLayout, 4, 0, 1, 3);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(2);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        kValue = new SKGComboBox(skgpropertiesdockplugin_base);
        kValue->setObjectName("kValue");
        kValue->setEditable(true);
        kValue->setAutoCompletion(false);

        horizontalLayout_2->addWidget(kValue);

        kSelectFile = new QPushButton(skgpropertiesdockplugin_base);
        kSelectFile->setObjectName("kSelectFile");
        sizePolicy.setHeightForWidth(kSelectFile->sizePolicy().hasHeightForWidth());
        kSelectFile->setSizePolicy(sizePolicy);

        horizontalLayout_2->addWidget(kSelectFile);

        kRemove = new QPushButton(skgpropertiesdockplugin_base);
        kRemove->setObjectName("kRemove");
        sizePolicy.setHeightForWidth(kRemove->sizePolicy().hasHeightForWidth());
        kRemove->setSizePolicy(sizePolicy);

        horizontalLayout_2->addWidget(kRemove);


        gridLayout->addLayout(horizontalLayout_2, 5, 0, 1, 3);

        kOpenBtn = new QPushButton(skgpropertiesdockplugin_base);
        kOpenBtn->setObjectName("kOpenBtn");
        sizePolicy.setHeightForWidth(kOpenBtn->sizePolicy().hasHeightForWidth());
        kOpenBtn->setSizePolicy(sizePolicy);

        gridLayout->addWidget(kOpenBtn, 6, 2, 1, 1);

        kPicture = new KImageFilePreview(skgpropertiesdockplugin_base);
        kPicture->setObjectName("kPicture");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(kPicture->sizePolicy().hasHeightForWidth());
        kPicture->setSizePolicy(sizePolicy1);
        kPicture->setMinimumSize(QSize(80, 80));
        kPicture->setMaximumSize(QSize(16777215, 80));

        gridLayout->addWidget(kPicture, 6, 1, 1, 1);

        label = new QLabel(skgpropertiesdockplugin_base);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label, 1, 0, 1, 1);

        kForCmb = new SKGComboBox(skgpropertiesdockplugin_base);
        kForCmb->setObjectName("kForCmb");

        gridLayout->addWidget(kForCmb, 1, 1, 1, 2);

        kView = new SKGTableView(skgpropertiesdockplugin_base);
        kView->setObjectName("kView");
        kView->setAlternatingRowColors(true);
        kView->setSelectionMode(QAbstractItemView::ExtendedSelection);
        kView->setSelectionBehavior(QAbstractItemView::SelectRows);

        gridLayout->addWidget(kView, 3, 0, 1, 3);

#if QT_CONFIG(shortcut)
        label->setBuddy(kForCmb);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kForCmb, kFilterEdit);
        QWidget::setTabOrder(kFilterEdit, kView);
        QWidget::setTabOrder(kView, kAttribute);
        QWidget::setTabOrder(kAttribute, kValue);
        QWidget::setTabOrder(kValue, kRename);
        QWidget::setTabOrder(kRename, kAdd);
        QWidget::setTabOrder(kAdd, kSelectFile);
        QWidget::setTabOrder(kSelectFile, kRemove);
        QWidget::setTabOrder(kRemove, kOpenBtn);

        retranslateUi(skgpropertiesdockplugin_base);

        QMetaObject::connectSlotsByName(skgpropertiesdockplugin_base);
    } // setupUi

    void retranslateUi(QWidget *skgpropertiesdockplugin_base)
    {
        kFilterEdit->setPlaceholderText(tr2i18n("Search", nullptr));
#if QT_CONFIG(tooltip)
        kAttribute->setToolTip(tr2i18n("The property name", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kAttribute->setStatusTip(tr2i18n("The property name", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kRename->setToolTip(tr2i18n("Rename property", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kRename->setStatusTip(tr2i18n("Rename property", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kAdd->setToolTip(tr2i18n("Add property", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kAdd->setStatusTip(tr2i18n("Add property", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kValue->setToolTip(tr2i18n("The property value", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kValue->setStatusTip(tr2i18n("The property value", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kSelectFile->setToolTip(tr2i18n("Select a file as property", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kSelectFile->setStatusTip(tr2i18n("Select a file as property", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kRemove->setToolTip(tr2i18n("Remove property", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kRemove->setStatusTip(tr2i18n("Remove property", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kOpenBtn->setToolTip(tr2i18n("Open file", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kOpenBtn->setStatusTip(tr2i18n("Open file", nullptr));
#endif // QT_CONFIG(statustip)
        kOpenBtn->setText(tr2i18n("Open\342\200\246", nullptr));
        label->setText(tr2i18n("For:", nullptr));
#if QT_CONFIG(tooltip)
        kView->setToolTip(tr2i18n("List of properties", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kView->setStatusTip(tr2i18n("List of properties", nullptr));
#endif // QT_CONFIG(statustip)
        (void)skgpropertiesdockplugin_base;
    } // retranslateUi

};

namespace Ui {
    class skgpropertiesdockplugin_base: public Ui_skgpropertiesdockplugin_base {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGPROPERTIESPLUGINDOCKWIDGET_BASE_H

