/********************************************************************************
** Form generated from reading UI file 'skgpayeepluginwidget_base.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGPAYEEPLUGINWIDGET_BASE_H
#define UI_SKGPAYEEPLUGINWIDGET_BASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kseparator.h"
#include "skgcombobox.h"
#include "skgfilteredtableview.h"

QT_BEGIN_NAMESPACE

class Ui_skgpayeeplugin_base
{
public:
    QVBoxLayout *verticalLayout_2;
    SKGFilteredTableView *kView;
    KSeparator *kseparator;
    QFrame *frame;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *kNameLbl;
    QLineEdit *kNameInput;
    QLabel *kAddressLabel;
    QLineEdit *kAddressEdit;
    QLabel *kCategoryLabel;
    SKGComboBox *kCategoryEdit;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer;
    QPushButton *kAddButton;
    QPushButton *kModifyButton;
    QPushButton *kDeleteUnusedButton;

    void setupUi(QWidget *skgpayeeplugin_base)
    {
        if (skgpayeeplugin_base->objectName().isEmpty())
            skgpayeeplugin_base->setObjectName("skgpayeeplugin_base");
        skgpayeeplugin_base->resize(394, 216);
        verticalLayout_2 = new QVBoxLayout(skgpayeeplugin_base);
        verticalLayout_2->setSpacing(2);
        verticalLayout_2->setObjectName("verticalLayout_2");
        kView = new SKGFilteredTableView(skgpayeeplugin_base);
        kView->setObjectName("kView");

        verticalLayout_2->addWidget(kView);

        kseparator = new KSeparator(skgpayeeplugin_base);
        kseparator->setObjectName("kseparator");

        verticalLayout_2->addWidget(kseparator);

        frame = new QFrame(skgpayeeplugin_base);
        frame->setObjectName("frame");
        frame->setFrameShape(QFrame::NoFrame);
        frame->setFrameShadow(QFrame::Raised);
        verticalLayout = new QVBoxLayout(frame);
        verticalLayout->setSpacing(2);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(2);
        horizontalLayout->setObjectName("horizontalLayout");
        kNameLbl = new QLabel(frame);
        kNameLbl->setObjectName("kNameLbl");
        QFont font;
        font.setBold(true);
        kNameLbl->setFont(font);
        kNameLbl->setText(QString::fromUtf8("&Title:"));

        horizontalLayout->addWidget(kNameLbl);

        kNameInput = new QLineEdit(frame);
        kNameInput->setObjectName("kNameInput");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kNameInput->sizePolicy().hasHeightForWidth());
        kNameInput->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(kNameInput);

        kAddressLabel = new QLabel(frame);
        kAddressLabel->setObjectName("kAddressLabel");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(kAddressLabel->sizePolicy().hasHeightForWidth());
        kAddressLabel->setSizePolicy(sizePolicy1);
        kAddressLabel->setText(QString::fromUtf8("Title:"));

        horizontalLayout->addWidget(kAddressLabel);

        kAddressEdit = new QLineEdit(frame);
        kAddressEdit->setObjectName("kAddressEdit");
        sizePolicy.setHeightForWidth(kAddressEdit->sizePolicy().hasHeightForWidth());
        kAddressEdit->setSizePolicy(sizePolicy);
        kAddressEdit->setProperty("showClearButton", QVariant(true));

        horizontalLayout->addWidget(kAddressEdit);

        kCategoryLabel = new QLabel(frame);
        kCategoryLabel->setObjectName("kCategoryLabel");
        sizePolicy1.setHeightForWidth(kCategoryLabel->sizePolicy().hasHeightForWidth());
        kCategoryLabel->setSizePolicy(sizePolicy1);
        kCategoryLabel->setText(QString::fromUtf8("Title:"));
        kCategoryLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout->addWidget(kCategoryLabel);

        kCategoryEdit = new SKGComboBox(frame);
        kCategoryEdit->setObjectName("kCategoryEdit");
        sizePolicy.setHeightForWidth(kCategoryEdit->sizePolicy().hasHeightForWidth());
        kCategoryEdit->setSizePolicy(sizePolicy);
        kCategoryEdit->setMinimumSize(QSize(200, 0));
        kCategoryEdit->setEditable(true);
        kCategoryEdit->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);

        horizontalLayout->addWidget(kCategoryEdit);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(2);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer = new QSpacerItem(0, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        kAddButton = new QPushButton(frame);
        kAddButton->setObjectName("kAddButton");

        horizontalLayout_2->addWidget(kAddButton);

        kModifyButton = new QPushButton(frame);
        kModifyButton->setObjectName("kModifyButton");

        horizontalLayout_2->addWidget(kModifyButton);

        kDeleteUnusedButton = new QPushButton(frame);
        kDeleteUnusedButton->setObjectName("kDeleteUnusedButton");

        horizontalLayout_2->addWidget(kDeleteUnusedButton);


        verticalLayout->addLayout(horizontalLayout_2);


        verticalLayout_2->addWidget(frame);

#if QT_CONFIG(shortcut)
        kNameLbl->setBuddy(kNameInput);
        kAddressLabel->setBuddy(kAddressEdit);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kNameInput, kAddressEdit);
        QWidget::setTabOrder(kAddressEdit, kCategoryEdit);
        QWidget::setTabOrder(kCategoryEdit, kAddButton);
        QWidget::setTabOrder(kAddButton, kModifyButton);
        QWidget::setTabOrder(kModifyButton, kDeleteUnusedButton);

        retranslateUi(skgpayeeplugin_base);

        QMetaObject::connectSlotsByName(skgpayeeplugin_base);
    } // setupUi

    void retranslateUi(QWidget *skgpayeeplugin_base)
    {
#if QT_CONFIG(tooltip)
        kNameInput->setToolTip(tr2i18n("Name of the payee", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kNameInput->setStatusTip(tr2i18n("Name of the payee", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kAddressEdit->setToolTip(tr2i18n("Address of the payee", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kAddressEdit->setStatusTip(tr2i18n("Address of the payee", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kCategoryEdit->setToolTip(tr2i18n("Category of the transaction.\n"
"Use  \" > \" as a separator between a category and a subcategory.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kCategoryEdit->setStatusTip(tr2i18n("Category of the transaction", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kAddButton->setToolTip(tr2i18n("Create a payee (Ctrl+Enter)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kAddButton->setStatusTip(tr2i18n("Create a payee (Ctrl+Enter)", nullptr));
#endif // QT_CONFIG(statustip)
        kAddButton->setText(tr2i18n("Add", nullptr));
#if QT_CONFIG(tooltip)
        kModifyButton->setToolTip(tr2i18n("Modify selected payee (Shift+Enter)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kModifyButton->setStatusTip(tr2i18n("Modify selected payee (Shift+Enter)", nullptr));
#endif // QT_CONFIG(statustip)
        kModifyButton->setText(tr2i18n("Modify", nullptr));
#if QT_CONFIG(tooltip)
        kDeleteUnusedButton->setToolTip(tr2i18n("Delete unused tiers", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kDeleteUnusedButton->setStatusTip(tr2i18n("Delete unused tiers", nullptr));
#endif // QT_CONFIG(statustip)
        kDeleteUnusedButton->setText(tr2i18n("Delete unused", "Verb, delete unused tiers"));
        (void)skgpayeeplugin_base;
    } // retranslateUi

};

namespace Ui {
    class skgpayeeplugin_base: public Ui_skgpayeeplugin_base {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGPAYEEPLUGINWIDGET_BASE_H

