/****************************************************************************
** Meta object code from reading C++ file 'skgreportbank.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../skrooge-26.8.0/skgbankmodeler/skgreportbank.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'skgreportbank.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13SKGReportBankE_t {};
} // unnamed namespace

template <> constexpr inline auto SKGReportBank::qt_create_metaobjectdata<qt_meta_tag_ZN13SKGReportBankE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SKGReportBank",
        "changed2",
        "",
        "getBudgetTable",
        "QVariantList",
        "getUnitTable",
        "getPortfolio",
        "getAccountTable",
        "getBankTable",
        "getScheduledOperations",
        "getMainCategoriesForPeriod",
        "getMainCategoriesForPreviousPeriod",
        "get5MainCategoriesVariation",
        "get5MainCategoriesVariationIssue",
        "getIncomeVsExpenditure",
        "iOnSubOperation",
        "iGrouped",
        "iTransfer",
        "iTracker",
        "iWhereClause1",
        "iWhereClause2",
        "getNetWorth",
        "getAnnualSpending",
        "getPersonalFinanceScore",
        "getPersonalFinanceScoreDetails",
        "QVariantMap",
        "getAlarms",
        "getInterests",
        "budget_table",
        "unit_table",
        "portfolio",
        "account_table",
        "bank_table",
        "alarms",
        "interests",
        "scheduled_operations",
        "categories_period",
        "categories_previous_period",
        "categories_month",
        "categories_previous_month",
        "income_vs_expenditure",
        "networth",
        "annual_spending",
        "personal_finance_score",
        "personal_finance_score_details",
        "categories_variations",
        "categories_variations_issues"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'changed2'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'getBudgetTable'
        QtMocHelpers::MethodData<QVariantList()>(3, 2, QMC::AccessPublic, 0x80000000 | 4),
        // Method 'getUnitTable'
        QtMocHelpers::MethodData<QVariantList()>(5, 2, QMC::AccessPublic, 0x80000000 | 4),
        // Method 'getPortfolio'
        QtMocHelpers::MethodData<QVariantList()>(6, 2, QMC::AccessPublic, 0x80000000 | 4),
        // Method 'getAccountTable'
        QtMocHelpers::MethodData<QVariantList()>(7, 2, QMC::AccessPublic, 0x80000000 | 4),
        // Method 'getBankTable'
        QtMocHelpers::MethodData<QVariantList()>(8, 2, QMC::AccessPublic, 0x80000000 | 4),
        // Method 'getScheduledOperations'
        QtMocHelpers::MethodData<QVariantList()>(9, 2, QMC::AccessPublic, 0x80000000 | 4),
        // Method 'getMainCategoriesForPeriod'
        QtMocHelpers::MethodData<QVariantList()>(10, 2, QMC::AccessPublic, 0x80000000 | 4),
        // Method 'getMainCategoriesForPreviousPeriod'
        QtMocHelpers::MethodData<QVariantList()>(11, 2, QMC::AccessPublic, 0x80000000 | 4),
        // Method 'get5MainCategoriesVariation'
        QtMocHelpers::MethodData<QStringList()>(12, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Method 'get5MainCategoriesVariationIssue'
        QtMocHelpers::MethodData<QStringList()>(13, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Method 'getIncomeVsExpenditure'
        QtMocHelpers::MethodData<QVariantList(bool, bool, bool, bool, const QString &, const QString &)>(14, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::Bool, 15 }, { QMetaType::Bool, 16 }, { QMetaType::Bool, 17 }, { QMetaType::Bool, 18 },
            { QMetaType::QString, 19 }, { QMetaType::QString, 20 },
        }}),
        // Method 'getIncomeVsExpenditure'
        QtMocHelpers::MethodData<QVariantList(bool, bool, bool, bool, const QString &)>(14, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 4, {{
            { QMetaType::Bool, 15 }, { QMetaType::Bool, 16 }, { QMetaType::Bool, 17 }, { QMetaType::Bool, 18 },
            { QMetaType::QString, 19 },
        }}),
        // Method 'getIncomeVsExpenditure'
        QtMocHelpers::MethodData<QVariantList(bool, bool, bool, bool)>(14, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 4, {{
            { QMetaType::Bool, 15 }, { QMetaType::Bool, 16 }, { QMetaType::Bool, 17 }, { QMetaType::Bool, 18 },
        }}),
        // Method 'getIncomeVsExpenditure'
        QtMocHelpers::MethodData<QVariantList(bool, bool, bool)>(14, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 4, {{
            { QMetaType::Bool, 15 }, { QMetaType::Bool, 16 }, { QMetaType::Bool, 17 },
        }}),
        // Method 'getIncomeVsExpenditure'
        QtMocHelpers::MethodData<QVariantList(bool, bool)>(14, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 4, {{
            { QMetaType::Bool, 15 }, { QMetaType::Bool, 16 },
        }}),
        // Method 'getIncomeVsExpenditure'
        QtMocHelpers::MethodData<QVariantList(bool)>(14, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 4, {{
            { QMetaType::Bool, 15 },
        }}),
        // Method 'getIncomeVsExpenditure'
        QtMocHelpers::MethodData<QVariantList()>(14, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 4),
        // Method 'getNetWorth'
        QtMocHelpers::MethodData<double(bool, bool)>(21, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Bool, 17 }, { QMetaType::Bool, 18 },
        }}),
        // Method 'getNetWorth'
        QtMocHelpers::MethodData<double(bool)>(21, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Bool, 17 },
        }}),
        // Method 'getNetWorth'
        QtMocHelpers::MethodData<double()>(21, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double),
        // Method 'getAnnualSpending'
        QtMocHelpers::MethodData<double(bool, bool)>(22, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Bool, 17 }, { QMetaType::Bool, 18 },
        }}),
        // Method 'getAnnualSpending'
        QtMocHelpers::MethodData<double(bool)>(22, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Bool, 17 },
        }}),
        // Method 'getAnnualSpending'
        QtMocHelpers::MethodData<double()>(22, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double),
        // Method 'getPersonalFinanceScore'
        QtMocHelpers::MethodData<double(bool, bool)>(23, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::Bool, 17 }, { QMetaType::Bool, 18 },
        }}),
        // Method 'getPersonalFinanceScore'
        QtMocHelpers::MethodData<double(bool)>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::Bool, 17 },
        }}),
        // Method 'getPersonalFinanceScore'
        QtMocHelpers::MethodData<double()>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double),
        // Method 'getPersonalFinanceScoreDetails'
        QtMocHelpers::MethodData<QVariantMap(bool, bool)>(24, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::Bool, 17 }, { QMetaType::Bool, 18 },
        }}),
        // Method 'getPersonalFinanceScoreDetails'
        QtMocHelpers::MethodData<QVariantMap(bool)>(24, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 25, {{
            { QMetaType::Bool, 17 },
        }}),
        // Method 'getPersonalFinanceScoreDetails'
        QtMocHelpers::MethodData<QVariantMap()>(24, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 25),
        // Method 'getAlarms'
        QtMocHelpers::MethodData<QVariantList()>(26, 2, QMC::AccessPublic, 0x80000000 | 4),
        // Method 'getInterests'
        QtMocHelpers::MethodData<QVariantList()>(27, 2, QMC::AccessPublic, 0x80000000 | 4),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'budget_table'
        QtMocHelpers::PropertyData<QVariantList>(28, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'unit_table'
        QtMocHelpers::PropertyData<QVariantList>(29, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'portfolio'
        QtMocHelpers::PropertyData<QVariantList>(30, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'account_table'
        QtMocHelpers::PropertyData<QVariantList>(31, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'bank_table'
        QtMocHelpers::PropertyData<QVariantList>(32, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'alarms'
        QtMocHelpers::PropertyData<QVariantList>(33, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'interests'
        QtMocHelpers::PropertyData<QVariantList>(34, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'scheduled_operations'
        QtMocHelpers::PropertyData<QVariantList>(35, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'categories_period'
        QtMocHelpers::PropertyData<QVariantList>(36, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'categories_previous_period'
        QtMocHelpers::PropertyData<QVariantList>(37, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'categories_month'
        QtMocHelpers::PropertyData<QVariantList>(38, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'categories_previous_month'
        QtMocHelpers::PropertyData<QVariantList>(39, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'income_vs_expenditure'
        QtMocHelpers::PropertyData<QVariantList>(40, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'networth'
        QtMocHelpers::PropertyData<double>(41, QMetaType::Double, QMC::DefaultPropertyFlags, 0),
        // property 'annual_spending'
        QtMocHelpers::PropertyData<double>(42, QMetaType::Double, QMC::DefaultPropertyFlags, 0),
        // property 'personal_finance_score'
        QtMocHelpers::PropertyData<double>(43, QMetaType::Double, QMC::DefaultPropertyFlags, 0),
        // property 'personal_finance_score_details'
        QtMocHelpers::PropertyData<QVariantMap>(44, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'categories_variations'
        QtMocHelpers::PropertyData<QStringList>(45, QMetaType::QStringList, QMC::DefaultPropertyFlags, 0),
        // property 'categories_variations_issues'
        QtMocHelpers::PropertyData<QStringList>(46, QMetaType::QStringList, QMC::DefaultPropertyFlags, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SKGReportBank, qt_meta_tag_ZN13SKGReportBankE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SKGReportBank::staticMetaObject = { {
    QMetaObject::SuperData::link<SKGReport::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13SKGReportBankE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13SKGReportBankE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13SKGReportBankE_t>.metaTypes,
    nullptr
} };

void SKGReportBank::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SKGReportBank *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->changed2(); break;
        case 1: { QVariantList _r = _t->getBudgetTable();
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 2: { QVariantList _r = _t->getUnitTable();
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 3: { QVariantList _r = _t->getPortfolio();
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 4: { QVariantList _r = _t->getAccountTable();
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 5: { QVariantList _r = _t->getBankTable();
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 6: { QVariantList _r = _t->getScheduledOperations();
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 7: { QVariantList _r = _t->getMainCategoriesForPeriod();
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 8: { QVariantList _r = _t->getMainCategoriesForPreviousPeriod();
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 9: { QStringList _r = _t->get5MainCategoriesVariation();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 10: { QStringList _r = _t->get5MainCategoriesVariationIssue();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 11: { QVariantList _r = _t->getIncomeVsExpenditure((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 12: { QVariantList _r = _t->getIncomeVsExpenditure((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 13: { QVariantList _r = _t->getIncomeVsExpenditure((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 14: { QVariantList _r = _t->getIncomeVsExpenditure((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 15: { QVariantList _r = _t->getIncomeVsExpenditure((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 16: { QVariantList _r = _t->getIncomeVsExpenditure((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 17: { QVariantList _r = _t->getIncomeVsExpenditure();
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 18: { double _r = _t->getNetWorth((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 19: { double _r = _t->getNetWorth((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 20: { double _r = _t->getNetWorth();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 21: { double _r = _t->getAnnualSpending((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 22: { double _r = _t->getAnnualSpending((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 23: { double _r = _t->getAnnualSpending();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 24: { double _r = _t->getPersonalFinanceScore((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 25: { double _r = _t->getPersonalFinanceScore((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 26: { double _r = _t->getPersonalFinanceScore();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 27: { QVariantMap _r = _t->getPersonalFinanceScoreDetails((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 28: { QVariantMap _r = _t->getPersonalFinanceScoreDetails((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 29: { QVariantMap _r = _t->getPersonalFinanceScoreDetails();
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 30: { QVariantList _r = _t->getAlarms();
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 31: { QVariantList _r = _t->getInterests();
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SKGReportBank::*)()>(_a, &SKGReportBank::changed2, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QVariantList*>(_v) = _t->getBudgetTable(); break;
        case 1: *reinterpret_cast<QVariantList*>(_v) = _t->getUnitTable(); break;
        case 2: *reinterpret_cast<QVariantList*>(_v) = _t->getPortfolio(); break;
        case 3: *reinterpret_cast<QVariantList*>(_v) = _t->getAccountTable(); break;
        case 4: *reinterpret_cast<QVariantList*>(_v) = _t->getBankTable(); break;
        case 5: *reinterpret_cast<QVariantList*>(_v) = _t->getAlarms(); break;
        case 6: *reinterpret_cast<QVariantList*>(_v) = _t->getInterests(); break;
        case 7: *reinterpret_cast<QVariantList*>(_v) = _t->getScheduledOperations(); break;
        case 8: *reinterpret_cast<QVariantList*>(_v) = _t->getMainCategoriesForPeriod(); break;
        case 9: *reinterpret_cast<QVariantList*>(_v) = _t->getMainCategoriesForPreviousPeriod(); break;
        case 10: *reinterpret_cast<QVariantList*>(_v) = _t->getMainCategoriesForPeriod(); break;
        case 11: *reinterpret_cast<QVariantList*>(_v) = _t->getMainCategoriesForPreviousPeriod(); break;
        case 12: *reinterpret_cast<QVariantList*>(_v) = _t->getIncomeVsExpenditure(); break;
        case 13: *reinterpret_cast<double*>(_v) = _t->getNetWorth(); break;
        case 14: *reinterpret_cast<double*>(_v) = _t->getAnnualSpending(); break;
        case 15: *reinterpret_cast<double*>(_v) = _t->getPersonalFinanceScore(); break;
        case 16: *reinterpret_cast<QVariantMap*>(_v) = _t->getPersonalFinanceScoreDetails(); break;
        case 17: *reinterpret_cast<QStringList*>(_v) = _t->get5MainCategoriesVariation(); break;
        case 18: *reinterpret_cast<QStringList*>(_v) = _t->get5MainCategoriesVariationIssue(); break;
        default: break;
        }
    }
}

const QMetaObject *SKGReportBank::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SKGReportBank::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13SKGReportBankE_t>.strings))
        return static_cast<void*>(this);
    return SKGReport::qt_metacast(_clname);
}

int SKGReportBank::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SKGReport::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 32)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 32;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void SKGReportBank::changed2()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
