// This file is generated by kconfig_compiler_kf6 from skgprint_settings.kcfg.
// All changes you do to this file will be lost.
#ifndef SKGPRINT_SETTINGS_H
#define SKGPRINT_SETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class skgprint_settings : public KConfigSkeleton
{
  public:

    static skgprint_settings *self();
    ~skgprint_settings() override;

    /**
      Get undefined
    */
    static
    QString undefined()
    {
      return self()->mUndefined;
    }

    /**
      Is undefined Immutable
    */
    static
    bool isUndefinedImmutable()
    {
      return self()->isImmutable( QStringLiteral( "undefined" ) );
    }

  protected:
    skgprint_settings();
    friend class skgprint_settingsHelper;


    // skg_print
    QString mUndefined;
};

#endif

