/********************************************************************************
** Form generated from reading UI file 'skgassistantpluginwidget_dock.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGASSISTANTPLUGINWIDGET_DOCK_H
#define UI_SKGASSISTANTPLUGINWIDGET_DOCK_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "skgshow.h"

QT_BEGIN_NAMESPACE

class Ui_skgassistantplugin_dock
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *kAiSessionMngt;
    QComboBox *kAiSessions;
    QPushButton *kSaveCurrentAiSession;
    QPushButton *kDeleteAiSession;
    QPushButton *kHelpButton;
    QPushButton *kSettingsButton;
    QFrame *kHelpArea;
    QVBoxLayout *kHelpArea_2;
    QLabel *kHelpTitle;
    QFrame *line;
    QTextEdit *kAnswer;
    QPlainTextEdit *kUserPrompt;
    QHBoxLayout *buttonsLayout;
    QPushButton *kAskButton;
    QPushButton *kClearButton;
    SKGShow *kDisplayReasoning;
    QSpacerItem *horizontalSpacer;

    void setupUi(QWidget *skgassistantplugin_dock)
    {
        if (skgassistantplugin_dock->objectName().isEmpty())
            skgassistantplugin_dock->setObjectName("skgassistantplugin_dock");
        skgassistantplugin_dock->resize(395, 758);
        verticalLayout = new QVBoxLayout(skgassistantplugin_dock);
        verticalLayout->setSpacing(2);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(2, 2, 2, 2);
        kAiSessionMngt = new QHBoxLayout();
        kAiSessionMngt->setObjectName("kAiSessionMngt");
        kAiSessions = new QComboBox(skgassistantplugin_dock);
        kAiSessions->setObjectName("kAiSessions");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kAiSessions->sizePolicy().hasHeightForWidth());
        kAiSessions->setSizePolicy(sizePolicy);

        kAiSessionMngt->addWidget(kAiSessions);

        kSaveCurrentAiSession = new QPushButton(skgassistantplugin_dock);
        kSaveCurrentAiSession->setObjectName("kSaveCurrentAiSession");

        kAiSessionMngt->addWidget(kSaveCurrentAiSession);

        kDeleteAiSession = new QPushButton(skgassistantplugin_dock);
        kDeleteAiSession->setObjectName("kDeleteAiSession");

        kAiSessionMngt->addWidget(kDeleteAiSession);

        kHelpButton = new QPushButton(skgassistantplugin_dock);
        kHelpButton->setObjectName("kHelpButton");

        kAiSessionMngt->addWidget(kHelpButton);

        kSettingsButton = new QPushButton(skgassistantplugin_dock);
        kSettingsButton->setObjectName("kSettingsButton");

        kAiSessionMngt->addWidget(kSettingsButton);


        verticalLayout->addLayout(kAiSessionMngt);

        kHelpArea = new QFrame(skgassistantplugin_dock);
        kHelpArea->setObjectName("kHelpArea");
        kHelpArea_2 = new QVBoxLayout(kHelpArea);
        kHelpArea_2->setObjectName("kHelpArea_2");
        kHelpTitle = new QLabel(kHelpArea);
        kHelpTitle->setObjectName("kHelpTitle");
        kHelpTitle->setWordWrap(true);

        kHelpArea_2->addWidget(kHelpTitle);

        line = new QFrame(kHelpArea);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        kHelpArea_2->addWidget(line);


        verticalLayout->addWidget(kHelpArea);

        kAnswer = new QTextEdit(skgassistantplugin_dock);
        kAnswer->setObjectName("kAnswer");
        kAnswer->setReadOnly(true);
        kAnswer->setAcceptRichText(false);

        verticalLayout->addWidget(kAnswer);

        kUserPrompt = new QPlainTextEdit(skgassistantplugin_dock);
        kUserPrompt->setObjectName("kUserPrompt");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(kUserPrompt->sizePolicy().hasHeightForWidth());
        kUserPrompt->setSizePolicy(sizePolicy1);

        verticalLayout->addWidget(kUserPrompt);

        buttonsLayout = new QHBoxLayout();
        buttonsLayout->setObjectName("buttonsLayout");
        kAskButton = new QPushButton(skgassistantplugin_dock);
        kAskButton->setObjectName("kAskButton");

        buttonsLayout->addWidget(kAskButton);

        kClearButton = new QPushButton(skgassistantplugin_dock);
        kClearButton->setObjectName("kClearButton");

        buttonsLayout->addWidget(kClearButton);

        kDisplayReasoning = new SKGShow(skgassistantplugin_dock);
        kDisplayReasoning->setObjectName("kDisplayReasoning");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(kDisplayReasoning->sizePolicy().hasHeightForWidth());
        kDisplayReasoning->setSizePolicy(sizePolicy2);

        buttonsLayout->addWidget(kDisplayReasoning);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        buttonsLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(buttonsLayout);

        QWidget::setTabOrder(kAiSessions, kSaveCurrentAiSession);
        QWidget::setTabOrder(kSaveCurrentAiSession, kDeleteAiSession);
        QWidget::setTabOrder(kDeleteAiSession, kHelpButton);
        QWidget::setTabOrder(kHelpButton, kSettingsButton);
        QWidget::setTabOrder(kSettingsButton, kAnswer);
        QWidget::setTabOrder(kAnswer, kUserPrompt);
        QWidget::setTabOrder(kUserPrompt, kAskButton);
        QWidget::setTabOrder(kAskButton, kClearButton);
        QWidget::setTabOrder(kClearButton, kDisplayReasoning);

        retranslateUi(skgassistantplugin_dock);

        QMetaObject::connectSlotsByName(skgassistantplugin_dock);
    } // setupUi

    void retranslateUi(QWidget *skgassistantplugin_dock)
    {
#if QT_CONFIG(tooltip)
        kAiSessions->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kSaveCurrentAiSession->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kHelpButton->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        kHelpButton->setText(QString());
#if QT_CONFIG(tooltip)
        kSettingsButton->setToolTip(tr2i18n("Open settings", nullptr));
#endif // QT_CONFIG(tooltip)
        kSettingsButton->setText(QString());
        kHelpTitle->setText(tr2i18n("Here are some examples of questions you can ask your Dickens AI assistant.", nullptr));
        kAnswer->setPlaceholderText(tr2i18n("How can I help you today ?", nullptr));
        kUserPrompt->setPlaceholderText(tr2i18n("Ask your question", nullptr));
#if QT_CONFIG(tooltip)
        kAskButton->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kClearButton->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        (void)skgassistantplugin_dock;
    } // retranslateUi

};

namespace Ui {
    class skgassistantplugin_dock: public Ui_skgassistantplugin_dock {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGASSISTANTPLUGINWIDGET_DOCK_H

