/****************************************************************************
** Meta object code from reading C++ file 'skgoperationplugin.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../skrooge-26.8.0/plugins/skrooge/skrooge_operation/skgoperationplugin.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'skgoperationplugin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18SKGOperationPluginE_t {};
} // unnamed namespace

template <> constexpr inline auto SKGOperationPlugin::qt_create_metaobjectdata<qt_meta_tag_ZN18SKGOperationPluginE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SKGOperationPlugin",
        "onDuplicate",
        "",
        "onCreateTemplate",
        "onSwitchToMarked",
        "onSwitchToChecked",
        "onOpenOperations",
        "onGroupOperation",
        "onUngroupOperation",
        "onMergeSubOperations",
        "onAlignComment",
        "onAlignComment2",
        "onAlignDate",
        "onAlignWithCategoryOfPayee",
        "onRemoveGroupWithOneOperation",
        "onShowApplyTemplateMenu",
        "onApplyTemplate",
        "onShowOpenWithMenu"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'onDuplicate'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onCreateTemplate'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onSwitchToMarked'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onSwitchToChecked'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onOpenOperations'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onGroupOperation'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onUngroupOperation'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onMergeSubOperations'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onAlignComment'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onAlignComment2'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onAlignDate'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onAlignWithCategoryOfPayee'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onRemoveGroupWithOneOperation'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onShowApplyTemplateMenu'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onApplyTemplate'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onShowOpenWithMenu'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SKGOperationPlugin, qt_meta_tag_ZN18SKGOperationPluginE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SKGOperationPlugin::staticMetaObject = { {
    QMetaObject::SuperData::link<SKGInterfacePlugin::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18SKGOperationPluginE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18SKGOperationPluginE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18SKGOperationPluginE_t>.metaTypes,
    nullptr
} };

void SKGOperationPlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SKGOperationPlugin *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->onDuplicate(); break;
        case 1: _t->onCreateTemplate(); break;
        case 2: _t->onSwitchToMarked(); break;
        case 3: _t->onSwitchToChecked(); break;
        case 4: _t->onOpenOperations(); break;
        case 5: _t->onGroupOperation(); break;
        case 6: _t->onUngroupOperation(); break;
        case 7: _t->onMergeSubOperations(); break;
        case 8: _t->onAlignComment(); break;
        case 9: _t->onAlignComment2(); break;
        case 10: _t->onAlignDate(); break;
        case 11: _t->onAlignWithCategoryOfPayee(); break;
        case 12: _t->onRemoveGroupWithOneOperation(); break;
        case 13: _t->onShowApplyTemplateMenu(); break;
        case 14: _t->onApplyTemplate(); break;
        case 15: _t->onShowOpenWithMenu(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *SKGOperationPlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SKGOperationPlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18SKGOperationPluginE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "skrooge.com.SKGInterfacePlugin/1.0"))
        return static_cast< SKGInterfacePlugin*>(this);
    return SKGInterfacePlugin::qt_metacast(_clname);
}

int SKGOperationPlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SKGInterfacePlugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    return _id;
}
QT_WARNING_POP
