/********************************************************************************
** Form generated from reading UI file 'skgscheduledpluginwidget_base.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGSCHEDULEDPLUGINWIDGET_BASE_H
#define UI_SKGSCHEDULEDPLUGINWIDGET_BASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "kseparator.h"
#include "ktitlewidget.h"
#include "skgdateedit.h"
#include "skgfilteredtableview.h"

QT_BEGIN_NAMESPACE

class Ui_skgscheduledplugin_base
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout_3;
    QSpinBox *kNbTimesVal;
    SKGDateEdit *kLastOccurenceDate;
    QLabel *label_4;
    QLabel *label;
    QCheckBox *kIsTemplate;
    QSpacerItem *horizontalSpacer_2;
    QSpinBox *kAutoWriteVal;
    QLabel *label_2;
    SKGFilteredTableView *kView;
    QCheckBox *kAutoWrite;
    QCheckBox *kRemindMe;
    QSpinBox *kRemindMeVal;
    QFrame *line_2;
    SKGDateEdit *kFirstOccurenceDate;
    QSpinBox *kOnceEveryVal;
    KSeparator *kseparator;
    QLabel *label_3;
    QHBoxLayout *horizontalLayout_5;
    QSpacerItem *horizontalSpacer_4;
    QPushButton *kModifyBtn;
    QToolButton *kProcessBtn;
    QPushButton *kJumpBtn;
    KComboBox *kOnceEveryUnit;
    KTitleWidget *kTitle;
    QCheckBox *kNbTimes;
    QLabel *label_5;
    KComboBox *kAdapter;

    void setupUi(QWidget *skgscheduledplugin_base)
    {
        if (skgscheduledplugin_base->objectName().isEmpty())
            skgscheduledplugin_base->setObjectName("skgscheduledplugin_base");
        skgscheduledplugin_base->resize(988, 279);
        gridLayout = new QGridLayout(skgscheduledplugin_base);
        gridLayout->setSpacing(2);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(6, 6, 6, 6);
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setSpacing(2);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        kNbTimesVal = new QSpinBox(skgscheduledplugin_base);
        kNbTimesVal->setObjectName("kNbTimesVal");
        kNbTimesVal->setEnabled(false);
        kNbTimesVal->setMinimumSize(QSize(60, 0));
        kNbTimesVal->setMaximumSize(QSize(60, 16777215));
        kNbTimesVal->setMinimum(0);
        kNbTimesVal->setMaximum(999);

        horizontalLayout_3->addWidget(kNbTimesVal);

        kLastOccurenceDate = new SKGDateEdit(skgscheduledplugin_base);
        kLastOccurenceDate->setObjectName("kLastOccurenceDate");
        kLastOccurenceDate->setEnabled(false);
        kLastOccurenceDate->setMinimumSize(QSize(120, 0));

        horizontalLayout_3->addWidget(kLastOccurenceDate);


        gridLayout->addLayout(horizontalLayout_3, 10, 2, 1, 2);

        label_4 = new QLabel(skgscheduledplugin_base);
        label_4->setObjectName("label_4");
        label_4->setEnabled(false);

        gridLayout->addWidget(label_4, 7, 7, 2, 1);

        label = new QLabel(skgscheduledplugin_base);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label, 5, 1, 1, 1);

        kIsTemplate = new QCheckBox(skgscheduledplugin_base);
        kIsTemplate->setObjectName("kIsTemplate");

        gridLayout->addWidget(kIsTemplate, 10, 5, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 3, 8, 8, 1);

        kAutoWriteVal = new QSpinBox(skgscheduledplugin_base);
        kAutoWriteVal->setObjectName("kAutoWriteVal");
        kAutoWriteVal->setEnabled(false);
        kAutoWriteVal->setMinimum(0);

        gridLayout->addWidget(kAutoWriteVal, 7, 6, 2, 1);

        label_2 = new QLabel(skgscheduledplugin_base);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_2, 7, 1, 2, 1);

        kView = new SKGFilteredTableView(skgscheduledplugin_base);
        kView->setObjectName("kView");

        gridLayout->addWidget(kView, 1, 0, 1, 9);

        kAutoWrite = new QCheckBox(skgscheduledplugin_base);
        kAutoWrite->setObjectName("kAutoWrite");

        gridLayout->addWidget(kAutoWrite, 8, 5, 1, 1);

        kRemindMe = new QCheckBox(skgscheduledplugin_base);
        kRemindMe->setObjectName("kRemindMe");

        gridLayout->addWidget(kRemindMe, 5, 5, 1, 1);

        kRemindMeVal = new QSpinBox(skgscheduledplugin_base);
        kRemindMeVal->setObjectName("kRemindMeVal");
        kRemindMeVal->setEnabled(false);
        kRemindMeVal->setMinimum(0);

        gridLayout->addWidget(kRemindMeVal, 4, 6, 2, 1);

        line_2 = new QFrame(skgscheduledplugin_base);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::VLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line_2, 3, 4, 8, 2);

        kFirstOccurenceDate = new SKGDateEdit(skgscheduledplugin_base);
        kFirstOccurenceDate->setObjectName("kFirstOccurenceDate");
        kFirstOccurenceDate->setMinimumSize(QSize(120, 0));

        gridLayout->addWidget(kFirstOccurenceDate, 4, 2, 2, 2);

        kOnceEveryVal = new QSpinBox(skgscheduledplugin_base);
        kOnceEveryVal->setObjectName("kOnceEveryVal");
        kOnceEveryVal->setMinimumSize(QSize(60, 0));
        kOnceEveryVal->setMaximumSize(QSize(60, 16777215));
        kOnceEveryVal->setMinimum(1);

        gridLayout->addWidget(kOnceEveryVal, 7, 2, 2, 1);

        kseparator = new KSeparator(skgscheduledplugin_base);
        kseparator->setObjectName("kseparator");

        gridLayout->addWidget(kseparator, 2, 1, 1, 8);

        label_3 = new QLabel(skgscheduledplugin_base);
        label_3->setObjectName("label_3");
        label_3->setEnabled(false);

        gridLayout->addWidget(label_3, 4, 7, 2, 1);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setSpacing(2);
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        horizontalSpacer_4 = new QSpacerItem(0, 26, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_4);

        kModifyBtn = new QPushButton(skgscheduledplugin_base);
        kModifyBtn->setObjectName("kModifyBtn");
        kModifyBtn->setEnabled(false);

        horizontalLayout_5->addWidget(kModifyBtn);

        kProcessBtn = new QToolButton(skgscheduledplugin_base);
        kProcessBtn->setObjectName("kProcessBtn");
        kProcessBtn->setEnabled(false);
        kProcessBtn->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);

        horizontalLayout_5->addWidget(kProcessBtn);

        kJumpBtn = new QPushButton(skgscheduledplugin_base);
        kJumpBtn->setObjectName("kJumpBtn");
        kJumpBtn->setEnabled(false);

        horizontalLayout_5->addWidget(kJumpBtn);


        gridLayout->addLayout(horizontalLayout_5, 11, 0, 1, 9);

        kOnceEveryUnit = new KComboBox(skgscheduledplugin_base);
        kOnceEveryUnit->addItem(QString());
        kOnceEveryUnit->addItem(QString());
        kOnceEveryUnit->addItem(QString());
        kOnceEveryUnit->addItem(QString());
        kOnceEveryUnit->setObjectName("kOnceEveryUnit");

        gridLayout->addWidget(kOnceEveryUnit, 7, 3, 2, 1);

        kTitle = new KTitleWidget(skgscheduledplugin_base);
        kTitle->setObjectName("kTitle");

        gridLayout->addWidget(kTitle, 0, 0, 1, 9);

        kNbTimes = new QCheckBox(skgscheduledplugin_base);
        kNbTimes->setObjectName("kNbTimes");

        gridLayout->addWidget(kNbTimes, 10, 1, 1, 1);

        label_5 = new QLabel(skgscheduledplugin_base);
        label_5->setObjectName("label_5");
        label_5->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_5, 9, 1, 1, 1);

        kAdapter = new KComboBox(skgscheduledplugin_base);
        kAdapter->setObjectName("kAdapter");

        gridLayout->addWidget(kAdapter, 9, 2, 1, 2);

#if QT_CONFIG(shortcut)
        label_4->setBuddy(kAutoWriteVal);
        label->setBuddy(kFirstOccurenceDate);
        label_2->setBuddy(kOnceEveryVal);
        label_3->setBuddy(kRemindMeVal);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kFirstOccurenceDate, kOnceEveryVal);
        QWidget::setTabOrder(kOnceEveryVal, kOnceEveryUnit);
        QWidget::setTabOrder(kOnceEveryUnit, kNbTimes);
        QWidget::setTabOrder(kNbTimes, kNbTimesVal);
        QWidget::setTabOrder(kNbTimesVal, kLastOccurenceDate);
        QWidget::setTabOrder(kLastOccurenceDate, kRemindMe);
        QWidget::setTabOrder(kRemindMe, kRemindMeVal);
        QWidget::setTabOrder(kRemindMeVal, kAutoWrite);
        QWidget::setTabOrder(kAutoWrite, kAutoWriteVal);
        QWidget::setTabOrder(kAutoWriteVal, kIsTemplate);
        QWidget::setTabOrder(kIsTemplate, kModifyBtn);
        QWidget::setTabOrder(kModifyBtn, kProcessBtn);

        retranslateUi(skgscheduledplugin_base);

        QMetaObject::connectSlotsByName(skgscheduledplugin_base);
    } // setupUi

    void retranslateUi(QWidget *skgscheduledplugin_base)
    {
        label_4->setText(tr2i18n("days before &term", nullptr));
        label->setText(tr2i18n("Next occurrence:", nullptr));
        kIsTemplate->setText(tr2i18n("Template", nullptr));
        label_2->setText(tr2i18n("Once ever&y:", nullptr));
        kAutoWrite->setText(tr2i18n("Automatically write:", nullptr));
        kRemindMe->setText(tr2i18n("Remind me:", nullptr));
        label_3->setText(tr2i18n("days &before term", nullptr));
#if QT_CONFIG(tooltip)
        kModifyBtn->setToolTip(tr2i18n("Update selected transactions (Shift+Enter)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kModifyBtn->setStatusTip(tr2i18n("Update selected transactions (Shift+Enter)", nullptr));
#endif // QT_CONFIG(statustip)
        kModifyBtn->setText(tr2i18n("Modify", nullptr));
#if QT_CONFIG(tooltip)
        kProcessBtn->setToolTip(tr2i18n("Insert scheduled transactions", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kProcessBtn->setStatusTip(tr2i18n("Insert scheduled transactions", nullptr));
#endif // QT_CONFIG(statustip)
        kProcessBtn->setText(tr2i18n("Process", nullptr));
#if QT_CONFIG(tooltip)
        kJumpBtn->setToolTip(tr2i18n("Open the transaction page with the selected scheduled transactions", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kJumpBtn->setStatusTip(tr2i18n("Open the transaction page with the selected scheduled transactions", nullptr));
#endif // QT_CONFIG(statustip)
        kJumpBtn->setText(tr2i18n("Jump to the operation", nullptr));
        kOnceEveryUnit->setItemText(0, tr2i18n("day(s)", nullptr));
        kOnceEveryUnit->setItemText(1, tr2i18n("week(s)", nullptr));
        kOnceEveryUnit->setItemText(2, tr2i18n("month(s)", nullptr));
        kOnceEveryUnit->setItemText(3, tr2i18n("year(s)", nullptr));

        kTitle->setText(tr2i18n("First, you have to schedule a transaction or a template from the transactions page.", nullptr));
        kNbTimes->setText(tr2i18n("Number of occurrences:", nullptr));
        label_5->setText(tr2i18n("Adaptation:", nullptr));
        (void)skgscheduledplugin_base;
    } // retranslateUi

};

namespace Ui {
    class skgscheduledplugin_base: public Ui_skgscheduledplugin_base {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGSCHEDULEDPLUGINWIDGET_BASE_H

