// This file is generated by kconfig_compiler_kf6 from skgbookmark_settings.kcfg.
// All changes you do to this file will be lost.

#include "skgbookmark_settings.h"

#include <qglobal.h>
#include <QFile>

class skgbookmark_settingsHelper
{
  public:
    skgbookmark_settingsHelper() noexcept : q(nullptr) {}
    ~skgbookmark_settingsHelper() noexcept { delete q; q = nullptr; }
    skgbookmark_settingsHelper(const skgbookmark_settingsHelper&) = delete;
    skgbookmark_settingsHelper& operator=(const skgbookmark_settingsHelper&) = delete;
    skgbookmark_settings *q;
};
Q_GLOBAL_STATIC(skgbookmark_settingsHelper, s_globalskgbookmark_settings)
skgbookmark_settings *skgbookmark_settings::self()
{
  if (!s_globalskgbookmark_settings()->q) {
    new skgbookmark_settings;
    s_globalskgbookmark_settings()->q->read();
  }

  return s_globalskgbookmark_settings()->q;
}

skgbookmark_settings::skgbookmark_settings( )
  : KConfigSkeleton()
{
  Q_ASSERT(!s_globalskgbookmark_settings()->q);
  s_globalskgbookmark_settings()->q = this;
  setCurrentGroup( QStringLiteral( "Bookmark" ) );

  KConfigSkeleton::ItemBool  *itemPinhomebookmarks;
  itemPinhomebookmarks = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "pinhomebookmarks" ), mPinhomebookmarks, false );
  addItem( itemPinhomebookmarks, QStringLiteral( "pinhomebookmarks" ) );
}

skgbookmark_settings::~skgbookmark_settings()
{
  if (s_globalskgbookmark_settings.exists() && !s_globalskgbookmark_settings.isDestroyed()) {
    s_globalskgbookmark_settings()->q = nullptr;
  }
}

