/********************************************************************************
** Form generated from reading UI file 'skgscheduledpluginwidget_pref.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGSCHEDULEDPLUGINWIDGET_PREF_H
#define UI_SKGSCHEDULEDPLUGINWIDGET_PREF_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_skgscheduledplugin_pref
{
public:
    QVBoxLayout *verticalLayout;
    QCheckBox *kcfg_check_on_open;
    QCheckBox *kcfg_create_template;
    QCheckBox *kcfg_convert_to_from_template;
    QGroupBox *fontBox;
    QGridLayout *gridLayout_2;
    QLabel *fontdisable;
    KColorButton *kcfg_fontDisabledColor;
    QSpacerItem *horizontalSpacer;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QLabel *label_2;
    QSpinBox *kcfg_once_every;
    KComboBox *kcfg_once_every_unit;
    QCheckBox *kcfg_remind_me;
    QSpinBox *kcfg_remind_me_days;
    QLabel *label_3;
    QCheckBox *kcfg_auto_write;
    QSpinBox *kcfg_auto_write_days;
    QSpacerItem *horizontalSpacer_4;
    QSpinBox *kcfg_nb_times_val;
    QCheckBox *kcfg_nb_times;
    QLabel *label_4;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *skgscheduledplugin_pref)
    {
        if (skgscheduledplugin_pref->objectName().isEmpty())
            skgscheduledplugin_pref->setObjectName("skgscheduledplugin_pref");
        skgscheduledplugin_pref->resize(555, 330);
        verticalLayout = new QVBoxLayout(skgscheduledplugin_pref);
        verticalLayout->setSpacing(2);
        verticalLayout->setObjectName("verticalLayout");
        kcfg_check_on_open = new QCheckBox(skgscheduledplugin_pref);
        kcfg_check_on_open->setObjectName("kcfg_check_on_open");
        kcfg_check_on_open->setChecked(true);

        verticalLayout->addWidget(kcfg_check_on_open);

        kcfg_create_template = new QCheckBox(skgscheduledplugin_pref);
        kcfg_create_template->setObjectName("kcfg_create_template");
        kcfg_create_template->setChecked(true);

        verticalLayout->addWidget(kcfg_create_template);

        kcfg_convert_to_from_template = new QCheckBox(skgscheduledplugin_pref);
        kcfg_convert_to_from_template->setObjectName("kcfg_convert_to_from_template");

        verticalLayout->addWidget(kcfg_convert_to_from_template);

        fontBox = new QGroupBox(skgscheduledplugin_pref);
        fontBox->setObjectName("fontBox");
        gridLayout_2 = new QGridLayout(fontBox);
        gridLayout_2->setSpacing(2);
        gridLayout_2->setObjectName("gridLayout_2");
        fontdisable = new QLabel(fontBox);
        fontdisable->setObjectName("fontdisable");
        fontdisable->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(fontdisable, 0, 0, 1, 2);

        kcfg_fontDisabledColor = new KColorButton(fontBox);
        kcfg_fontDisabledColor->setObjectName("kcfg_fontDisabledColor");
        kcfg_fontDisabledColor->setProperty("color", QVariant(QColor(195, 195, 195)));
        kcfg_fontDisabledColor->setProperty("defaultColor", QVariant(QColor(195, 195, 195)));

        gridLayout_2->addWidget(kcfg_fontDisabledColor, 0, 2, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer, 0, 3, 1, 1);


        verticalLayout->addWidget(fontBox);

        groupBox = new QGroupBox(skgscheduledplugin_pref);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setSpacing(2);
        gridLayout->setObjectName("gridLayout");
        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_2, 0, 0, 1, 1);

        kcfg_once_every = new QSpinBox(groupBox);
        kcfg_once_every->setObjectName("kcfg_once_every");
        kcfg_once_every->setMinimum(1);

        gridLayout->addWidget(kcfg_once_every, 0, 1, 1, 3);

        kcfg_once_every_unit = new KComboBox(groupBox);
        kcfg_once_every_unit->addItem(QString());
        kcfg_once_every_unit->addItem(QString());
        kcfg_once_every_unit->addItem(QString());
        kcfg_once_every_unit->addItem(QString());
        kcfg_once_every_unit->addItem(QString());
        kcfg_once_every_unit->setObjectName("kcfg_once_every_unit");

        gridLayout->addWidget(kcfg_once_every_unit, 0, 4, 1, 3);

        kcfg_remind_me = new QCheckBox(groupBox);
        kcfg_remind_me->setObjectName("kcfg_remind_me");

        gridLayout->addWidget(kcfg_remind_me, 4, 0, 1, 1);

        kcfg_remind_me_days = new QSpinBox(groupBox);
        kcfg_remind_me_days->setObjectName("kcfg_remind_me_days");
        kcfg_remind_me_days->setEnabled(false);
        kcfg_remind_me_days->setMinimum(0);

        gridLayout->addWidget(kcfg_remind_me_days, 4, 1, 1, 3);

        label_3 = new QLabel(groupBox);
        label_3->setObjectName("label_3");
        label_3->setEnabled(false);

        gridLayout->addWidget(label_3, 4, 4, 1, 1);

        kcfg_auto_write = new QCheckBox(groupBox);
        kcfg_auto_write->setObjectName("kcfg_auto_write");

        gridLayout->addWidget(kcfg_auto_write, 5, 0, 1, 1);

        kcfg_auto_write_days = new QSpinBox(groupBox);
        kcfg_auto_write_days->setObjectName("kcfg_auto_write_days");
        kcfg_auto_write_days->setEnabled(false);
        kcfg_auto_write_days->setMinimum(0);

        gridLayout->addWidget(kcfg_auto_write_days, 5, 1, 1, 3);

        horizontalSpacer_4 = new QSpacerItem(252, 26, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_4, 5, 9, 1, 1);

        kcfg_nb_times_val = new QSpinBox(groupBox);
        kcfg_nb_times_val->setObjectName("kcfg_nb_times_val");
        kcfg_nb_times_val->setEnabled(false);
        kcfg_nb_times_val->setMinimum(1);
        kcfg_nb_times_val->setMaximum(999);

        gridLayout->addWidget(kcfg_nb_times_val, 1, 1, 1, 3);

        kcfg_nb_times = new QCheckBox(groupBox);
        kcfg_nb_times->setObjectName("kcfg_nb_times");

        gridLayout->addWidget(kcfg_nb_times, 1, 0, 1, 1);

        label_4 = new QLabel(groupBox);
        label_4->setObjectName("label_4");
        label_4->setEnabled(false);

        gridLayout->addWidget(label_4, 5, 4, 1, 1);


        verticalLayout->addWidget(groupBox);

        verticalSpacer = new QSpacerItem(20, 126, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

#if QT_CONFIG(shortcut)
        label_2->setBuddy(kcfg_once_every);
        label_3->setBuddy(kcfg_remind_me_days);
        label_4->setBuddy(kcfg_auto_write_days);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kcfg_check_on_open, kcfg_create_template);
        QWidget::setTabOrder(kcfg_create_template, kcfg_convert_to_from_template);
        QWidget::setTabOrder(kcfg_convert_to_from_template, kcfg_fontDisabledColor);
        QWidget::setTabOrder(kcfg_fontDisabledColor, kcfg_once_every);
        QWidget::setTabOrder(kcfg_once_every, kcfg_once_every_unit);
        QWidget::setTabOrder(kcfg_once_every_unit, kcfg_nb_times);
        QWidget::setTabOrder(kcfg_nb_times, kcfg_nb_times_val);
        QWidget::setTabOrder(kcfg_nb_times_val, kcfg_remind_me);
        QWidget::setTabOrder(kcfg_remind_me, kcfg_remind_me_days);
        QWidget::setTabOrder(kcfg_remind_me_days, kcfg_auto_write);
        QWidget::setTabOrder(kcfg_auto_write, kcfg_auto_write_days);

        retranslateUi(skgscheduledplugin_pref);

        QMetaObject::connectSlotsByName(skgscheduledplugin_pref);
    } // setupUi

    void retranslateUi(QWidget *skgscheduledplugin_pref)
    {
#if QT_CONFIG(tooltip)
        kcfg_check_on_open->setToolTip(tr2i18n("If checked, Skrooge will insert relevant occurrences when starting.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_check_on_open->setText(tr2i18n("Check scheduled transactions on open", nullptr));
        kcfg_create_template->setText(tr2i18n("Create a template when a transaction is scheduled", nullptr));
        kcfg_convert_to_from_template->setText(tr2i18n("Convert all existing scheduled transactions to/from template", nullptr));
        fontBox->setTitle(tr2i18n("Fonts", nullptr));
        fontdisable->setText(tr2i18n("Font for disabled schedule:", nullptr));
        groupBox->setTitle(tr2i18n("Default parameters", nullptr));
        label_2->setText(tr2i18n("Once ever&y:", nullptr));
        kcfg_once_every_unit->setItemText(0, tr2i18n("day(s)", nullptr));
        kcfg_once_every_unit->setItemText(1, tr2i18n("week(s)", nullptr));
        kcfg_once_every_unit->setItemText(2, tr2i18n("month(s)", nullptr));
        kcfg_once_every_unit->setItemText(3, tr2i18n("year(s)", nullptr));
        kcfg_once_every_unit->setItemText(4, QString());

        kcfg_remind_me->setText(tr2i18n("Remind me", nullptr));
        label_3->setText(tr2i18n("days &before term", nullptr));
        kcfg_auto_write->setText(tr2i18n("Automatically write", nullptr));
        kcfg_nb_times->setText(tr2i18n("Number of occurrences", nullptr));
        label_4->setText(tr2i18n("days before &term", nullptr));
        (void)skgscheduledplugin_pref;
    } // retranslateUi

};

namespace Ui {
    class skgscheduledplugin_pref: public Ui_skgscheduledplugin_pref {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGSCHEDULEDPLUGINWIDGET_PREF_H

