/********************************************************************************
** Form generated from reading UI file 'skgwidgetselector.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGWIDGETSELECTOR_H
#define UI_SKGWIDGETSELECTOR_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_skgwidgetselector_base
{
public:
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;

    void setupUi(QWidget *skgwidgetselector_base)
    {
        if (skgwidgetselector_base->objectName().isEmpty())
            skgwidgetselector_base->setObjectName("skgwidgetselector_base");
        skgwidgetselector_base->resize(166, 25);
        horizontalLayout = new QHBoxLayout(skgwidgetselector_base);
        horizontalLayout->setSpacing(2);
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        retranslateUi(skgwidgetselector_base);

        QMetaObject::connectSlotsByName(skgwidgetselector_base);
    } // setupUi

    void retranslateUi(QWidget *skgwidgetselector_base)
    {
        (void)skgwidgetselector_base;
    } // retranslateUi

};

namespace Ui {
    class skgwidgetselector_base: public Ui_skgwidgetselector_base {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGWIDGETSELECTOR_H

