/****************************************************************************
** Meta object code from reading C++ file 'skgtreeview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../skrooge-26.8.0/skgbasegui/skgtreeview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'skgtreeview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11SKGTreeViewE_t {};
} // unnamed namespace

template <> constexpr inline auto SKGTreeView::qt_create_metaobjectdata<qt_meta_tag_ZN11SKGTreeViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SKGTreeView",
        "clickEmptyArea",
        "",
        "selectionChangedDelayed",
        "zoomChanged",
        "iZoomPosition",
        "modified",
        "setTextResizable",
        "resizable",
        "setZoomPosition",
        "zoomPosition",
        "saveSelection",
        "resetSelection",
        "scroolOnSelection",
        "selectObject",
        "iUniqueID",
        "selectObjects",
        "iUniqueIDs",
        "iFocusOnFirstOne",
        "setAlternatingRowColors",
        "enable",
        "resetColumnsOrder",
        "resizeColumnsToContents",
        "resizeColumnsToContentsDelayed",
        "onSelectionChanged",
        "expandAll",
        "copy",
        "switchAutoResize",
        "onExport",
        "setupHeaderMenu",
        "showHeaderMenu",
        "QPoint",
        "iPos",
        "showHideColumn",
        "respanFirstColumns",
        "refreshExpandCollapse",
        "changeSchema",
        "saveDefaultClicked",
        "groupByChanged",
        "QAction*",
        "onSortChanged",
        "Qt::SortOrder",
        "onExpand",
        "QModelIndex",
        "index",
        "onCollapse",
        "onClick",
        "onActionTriggered",
        "action",
        "onRangeChanged",
        "rebuildContextualMenu",
        "textResizable",
        "autoResized"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'clickEmptyArea'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectionChangedDelayed'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'zoomChanged'
        QtMocHelpers::SignalData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Signal 'modified'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setTextResizable'
        QtMocHelpers::SlotData<void(bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Slot 'setZoomPosition'
        QtMocHelpers::SlotData<void(int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'zoomPosition'
        QtMocHelpers::SlotData<int()>(10, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'saveSelection'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'resetSelection'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'scroolOnSelection'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'selectObject'
        QtMocHelpers::SlotData<void(const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'selectObjects'
        QtMocHelpers::SlotData<void(const QStringList &, bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 17 }, { QMetaType::Bool, 18 },
        }}),
        // Slot 'selectObjects'
        QtMocHelpers::SlotData<void(const QStringList &)>(16, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QStringList, 17 },
        }}),
        // Slot 'setAlternatingRowColors'
        QtMocHelpers::SlotData<void(bool)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Slot 'resetColumnsOrder'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'resizeColumnsToContents'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'resizeColumnsToContentsDelayed'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onSelectionChanged'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'expandAll'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'copy'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'switchAutoResize'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onExport'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setupHeaderMenu'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showHeaderMenu'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showHeaderMenu'
        QtMocHelpers::SlotData<void(QPoint)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 31, 32 },
        }}),
        // Slot 'showHideColumn'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'respanFirstColumns'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'refreshExpandCollapse'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'changeSchema'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveDefaultClicked'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'groupByChanged'
        QtMocHelpers::SlotData<void(QAction *)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 39, 2 },
        }}),
        // Slot 'onSortChanged'
        QtMocHelpers::SlotData<void(int, Qt::SortOrder)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { 0x80000000 | 41, 2 },
        }}),
        // Slot 'onExpand'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(42, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 43, 44 },
        }}),
        // Slot 'onCollapse'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(45, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 43, 44 },
        }}),
        // Slot 'onClick'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(46, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 43, 44 },
        }}),
        // Slot 'onActionTriggered'
        QtMocHelpers::SlotData<void(int)>(47, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 48 },
        }}),
        // Slot 'onRangeChanged'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'rebuildContextualMenu'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'textResizable'
        QtMocHelpers::PropertyData<bool>(51, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'autoResized'
        QtMocHelpers::PropertyData<bool>(52, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SKGTreeView, qt_meta_tag_ZN11SKGTreeViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SKGTreeView::staticMetaObject = { {
    QMetaObject::SuperData::link<QTreeView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11SKGTreeViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11SKGTreeViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11SKGTreeViewE_t>.metaTypes,
    nullptr
} };

void SKGTreeView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SKGTreeView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->clickEmptyArea(); break;
        case 1: _t->selectionChangedDelayed(); break;
        case 2: _t->zoomChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->modified(); break;
        case 4: _t->setTextResizable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->setZoomPosition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: { int _r = _t->zoomPosition();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->saveSelection(); break;
        case 8: _t->resetSelection(); break;
        case 9: _t->scroolOnSelection(); break;
        case 10: _t->selectObject((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->selectObjects((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 12: _t->selectObjects((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 13: _t->setAlternatingRowColors((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->resetColumnsOrder(); break;
        case 15: _t->resizeColumnsToContents(); break;
        case 16: _t->resizeColumnsToContentsDelayed(); break;
        case 17: _t->onSelectionChanged(); break;
        case 18: _t->expandAll(); break;
        case 19: _t->copy(); break;
        case 20: _t->switchAutoResize(); break;
        case 21: _t->onExport(); break;
        case 22: _t->setupHeaderMenu(); break;
        case 23: _t->showHeaderMenu(); break;
        case 24: _t->showHeaderMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 25: _t->showHideColumn(); break;
        case 26: _t->respanFirstColumns(); break;
        case 27: _t->refreshExpandCollapse(); break;
        case 28: _t->changeSchema(); break;
        case 29: _t->saveDefaultClicked(); break;
        case 30: _t->groupByChanged((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 31: _t->onSortChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Qt::SortOrder>>(_a[2]))); break;
        case 32: _t->onExpand((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 33: _t->onCollapse((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 34: _t->onClick((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 35: _t->onActionTriggered((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 36: _t->onRangeChanged(); break;
        case 37: _t->rebuildContextualMenu(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SKGTreeView::*)()>(_a, &SKGTreeView::clickEmptyArea, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SKGTreeView::*)()>(_a, &SKGTreeView::selectionChangedDelayed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SKGTreeView::*)(int )>(_a, &SKGTreeView::zoomChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SKGTreeView::*)()>(_a, &SKGTreeView::modified, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isTextResizable(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isAutoResized(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setTextResizable(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *SKGTreeView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SKGTreeView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11SKGTreeViewE_t>.strings))
        return static_cast<void*>(this);
    return QTreeView::qt_metacast(_clname);
}

int SKGTreeView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTreeView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 38)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 38;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 38)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 38;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void SKGTreeView::clickEmptyArea()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SKGTreeView::selectionChangedDelayed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void SKGTreeView::zoomChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void SKGTreeView::modified()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
