/********************************************************************************
** Form generated from reading UI file 'skgmonthlypluginwidget_base.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGMONTHLYPLUGINWIDGET_BASE_H
#define UI_SKGMONTHLYPLUGINWIDGET_BASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "skgcombobox.h"
#include "skgsimpleperiodedit.h"
#include "skgwebview.h"

QT_BEGIN_NAMESPACE

class Ui_skgmonthlyplugin_base
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    SKGSimplePeriodEdit *kMonth;
    QToolButton *kRefresh;
    QSpacerItem *horizontalSpacer;
    QLabel *label_2;
    SKGSimplePeriodEdit *kTemplate;
    QToolButton *kDeleteTemplate;
    QToolButton *kGetNewHotStuff;
    QFrame *frame;
    QGridLayout *gridLayout;
    SKGWebView *kWebView;

    void setupUi(QWidget *skgmonthlyplugin_base)
    {
        if (skgmonthlyplugin_base->objectName().isEmpty())
            skgmonthlyplugin_base->setObjectName("skgmonthlyplugin_base");
        skgmonthlyplugin_base->resize(614, 356);
        verticalLayout = new QVBoxLayout(skgmonthlyplugin_base);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(2);
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(skgmonthlyplugin_base);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        kMonth = new SKGSimplePeriodEdit(skgmonthlyplugin_base);
        kMonth->setObjectName("kMonth");
        kMonth->setMinimumSize(QSize(100, 0));
        kMonth->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        horizontalLayout->addWidget(kMonth);

        kRefresh = new QToolButton(skgmonthlyplugin_base);
        kRefresh->setObjectName("kRefresh");
        kRefresh->setAutoRaise(true);

        horizontalLayout->addWidget(kRefresh);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        label_2 = new QLabel(skgmonthlyplugin_base);
        label_2->setObjectName("label_2");

        horizontalLayout->addWidget(label_2);

        kTemplate = new SKGSimplePeriodEdit(skgmonthlyplugin_base);
        kTemplate->setObjectName("kTemplate");
        kTemplate->setEditable(true);

        horizontalLayout->addWidget(kTemplate);

        kDeleteTemplate = new QToolButton(skgmonthlyplugin_base);
        kDeleteTemplate->setObjectName("kDeleteTemplate");
        kDeleteTemplate->setMaximumSize(QSize(22, 22));
        kDeleteTemplate->setAutoRaise(true);

        horizontalLayout->addWidget(kDeleteTemplate);

        kGetNewHotStuff = new QToolButton(skgmonthlyplugin_base);
        kGetNewHotStuff->setObjectName("kGetNewHotStuff");
        kGetNewHotStuff->setMaximumSize(QSize(22, 22));
        kGetNewHotStuff->setAutoRaise(true);

        horizontalLayout->addWidget(kGetNewHotStuff);


        verticalLayout->addLayout(horizontalLayout);

        frame = new QFrame(skgmonthlyplugin_base);
        frame->setObjectName("frame");
        frame->setFrameShape(QFrame::StyledPanel);
        frame->setFrameShadow(QFrame::Raised);
        gridLayout = new QGridLayout(frame);
        gridLayout->setSpacing(2);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        kWebView = new SKGWebView(frame);
        kWebView->setObjectName("kWebView");

        gridLayout->addWidget(kWebView, 0, 0, 1, 1);


        verticalLayout->addWidget(frame);

#if QT_CONFIG(shortcut)
        label->setBuddy(kMonth);
        label_2->setBuddy(kTemplate);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kMonth, kRefresh);
        QWidget::setTabOrder(kRefresh, kTemplate);
        QWidget::setTabOrder(kTemplate, kWebView);

        retranslateUi(skgmonthlyplugin_base);

        QMetaObject::connectSlotsByName(skgmonthlyplugin_base);
    } // setupUi

    void retranslateUi(QWidget *skgmonthlyplugin_base)
    {
        label->setText(tr2i18n("Report of:", "Will be followed by a month on which the report will be built"));
#if QT_CONFIG(tooltip)
        kMonth->setToolTip(tr2i18n("Month of the report", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kMonth->setStatusTip(tr2i18n("Month of the report", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kRefresh->setToolTip(tr2i18n("Refresh the monthly report", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kRefresh->setStatusTip(tr2i18n("Refresh the monthly report", nullptr));
#endif // QT_CONFIG(statustip)
        label_2->setText(tr2i18n("&Template:", nullptr));
#if QT_CONFIG(tooltip)
        kTemplate->setToolTip(tr2i18n("The template to use", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kTemplate->setStatusTip(tr2i18n("The template to use", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kDeleteTemplate->setToolTip(tr2i18n("Delete the selected source", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kDeleteTemplate->setStatusTip(tr2i18n("Delete the selected source", nullptr));
#endif // QT_CONFIG(statustip)
        kDeleteTemplate->setText(QString());
#if QT_CONFIG(tooltip)
        kGetNewHotStuff->setToolTip(tr2i18n("Get more templates", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kGetNewHotStuff->setStatusTip(tr2i18n("Get more templates", nullptr));
#endif // QT_CONFIG(statustip)
        kGetNewHotStuff->setText(QString());
        (void)skgmonthlyplugin_base;
    } // retranslateUi

};

namespace Ui {
    class skgmonthlyplugin_base: public Ui_skgmonthlyplugin_base {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGMONTHLYPLUGINWIDGET_BASE_H

