// This file is generated by kconfig_compiler_kf6 from skgsearch_settings.kcfg.
// All changes you do to this file will be lost.

#include "skgsearch_settings.h"

#include <qglobal.h>
#include <QFile>

class skgsearch_settingsHelper
{
  public:
    skgsearch_settingsHelper() noexcept : q(nullptr) {}
    ~skgsearch_settingsHelper() noexcept { delete q; q = nullptr; }
    skgsearch_settingsHelper(const skgsearch_settingsHelper&) = delete;
    skgsearch_settingsHelper& operator=(const skgsearch_settingsHelper&) = delete;
    skgsearch_settings *q;
};
Q_GLOBAL_STATIC(skgsearch_settingsHelper, s_globalskgsearch_settings)
skgsearch_settings *skgsearch_settings::self()
{
  if (!s_globalskgsearch_settings()->q) {
    new skgsearch_settings;
    s_globalskgsearch_settings()->q->read();
  }

  return s_globalskgsearch_settings()->q;
}

skgsearch_settings::skgsearch_settings( )
  : KConfigSkeleton()
{
  Q_ASSERT(!s_globalskgsearch_settings()->q);
  s_globalskgsearch_settings()->q = this;
  setCurrentGroup( QStringLiteral( "skrooge_search" ) );

  KConfigSkeleton::ItemInt  *itemAlarm_frequency;
  itemAlarm_frequency = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "alarm_frequency" ), mAlarm_frequency, 10 );
  addItem( itemAlarm_frequency, QStringLiteral( "alarm_frequency" ) );
}

skgsearch_settings::~skgsearch_settings()
{
  if (s_globalskgsearch_settings.exists() && !s_globalskgsearch_settings.isDestroyed()) {
    s_globalskgsearch_settings()->q = nullptr;
  }
}

