// This file is generated by kconfig_compiler_kf6 from skgtracker_settings.kcfg.
// All changes you do to this file will be lost.

#include "skgtracker_settings.h"

#include <qglobal.h>
#include <QFile>

class skgtracker_settingsHelper
{
  public:
    skgtracker_settingsHelper() noexcept : q(nullptr) {}
    ~skgtracker_settingsHelper() noexcept { delete q; q = nullptr; }
    skgtracker_settingsHelper(const skgtracker_settingsHelper&) = delete;
    skgtracker_settingsHelper& operator=(const skgtracker_settingsHelper&) = delete;
    skgtracker_settings *q;
};
Q_GLOBAL_STATIC(skgtracker_settingsHelper, s_globalskgtracker_settings)
skgtracker_settings *skgtracker_settings::self()
{
  if (!s_globalskgtracker_settings()->q) {
    new skgtracker_settings;
    s_globalskgtracker_settings()->q->read();
  }

  return s_globalskgtracker_settings()->q;
}

skgtracker_settings::skgtracker_settings( )
  : KConfigSkeleton()
{
  Q_ASSERT(!s_globalskgtracker_settings()->q);
  s_globalskgtracker_settings()->q = this;
  setCurrentGroup( QStringLiteral( "skrooge_tracker" ) );

  KConfigSkeleton::ItemString  *itemUndefined;
  itemUndefined = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "undefined" ), mUndefined );
  addItem( itemUndefined, QStringLiteral( "undefined" ) );
}

skgtracker_settings::~skgtracker_settings()
{
  if (s_globalskgtracker_settings.exists() && !s_globalskgtracker_settings.isDestroyed()) {
    s_globalskgtracker_settings()->q = nullptr;
  }
}

