// This file is generated by kconfig_compiler_kf6 from skgscheduled_settings.kcfg.
// All changes you do to this file will be lost.
#ifndef SKGSCHEDULED_SETTINGS_H
#define SKGSCHEDULED_SETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class skgscheduled_settings : public KConfigSkeleton
{
  public:

    static skgscheduled_settings *self();
    ~skgscheduled_settings() override;

    /**
      Get Check on open
    */
    static
    bool check_on_open()
    {
      return self()->mCheck_on_open;
    }

    /**
      Is Check on open Immutable
    */
    static
    bool isCheck_on_openImmutable()
    {
      return self()->isImmutable( QStringLiteral( "check_on_open" ) );
    }

    /**
      Get Create a template when a transaction is scheduled
    */
    static
    bool create_template()
    {
      return self()->mCreate_template;
    }

    /**
      Is Create a template when a transaction is scheduled Immutable
    */
    static
    bool isCreate_templateImmutable()
    {
      return self()->isImmutable( QStringLiteral( "create_template" ) );
    }

    /**
      Set Convert all existing scheduled transactions to/from template
    */
    static
    void setConvert_to_from_template( bool v )
    {
      if (!self()->isConvert_to_from_templateImmutable())
        self()->mConvert_to_from_template = v;
    }

    /**
      Get Convert all existing scheduled transactions to/from template
    */
    static
    bool convert_to_from_template()
    {
      return self()->mConvert_to_from_template;
    }

    /**
      Is Convert all existing scheduled transactions to/from template Immutable
    */
    static
    bool isConvert_to_from_templateImmutable()
    {
      return self()->isImmutable( QStringLiteral( "convert_to_from_template" ) );
    }

    /**
      Get Remind Me
    */
    static
    bool remind_me()
    {
      return self()->mRemind_me;
    }

    /**
      Is Remind Me Immutable
    */
    static
    bool isRemind_meImmutable()
    {
      return self()->isImmutable( QStringLiteral( "remind_me" ) );
    }

    /**
      Get Remind Me
    */
    static
    int remind_me_days()
    {
      return self()->mRemind_me_days;
    }

    /**
      Is Remind Me Immutable
    */
    static
    bool isRemind_me_daysImmutable()
    {
      return self()->isImmutable( QStringLiteral( "remind_me_days" ) );
    }

    /**
      Get Automatically Write
    */
    static
    bool auto_write()
    {
      return self()->mAuto_write;
    }

    /**
      Is Automatically Write Immutable
    */
    static
    bool isAuto_writeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "auto_write" ) );
    }

    /**
      Get Automatically Write
    */
    static
    int auto_write_days()
    {
      return self()->mAuto_write_days;
    }

    /**
      Is Automatically Write Immutable
    */
    static
    bool isAuto_write_daysImmutable()
    {
      return self()->isImmutable( QStringLiteral( "auto_write_days" ) );
    }

    /**
      Get Periodicity
    */
    static
    int once_every()
    {
      return self()->mOnce_every;
    }

    /**
      Is Periodicity Immutable
    */
    static
    bool isOnce_everyImmutable()
    {
      return self()->isImmutable( QStringLiteral( "once_every" ) );
    }

    /**
      Get Periodicity
    */
    static
    QString once_every_unit()
    {
      return self()->mOnce_every_unit;
    }

    /**
      Is Periodicity Immutable
    */
    static
    bool isOnce_every_unitImmutable()
    {
      return self()->isImmutable( QStringLiteral( "once_every_unit" ) );
    }

    /**
      Get Number of times
    */
    static
    bool nb_times()
    {
      return self()->mNb_times;
    }

    /**
      Is Number of times Immutable
    */
    static
    bool isNb_timesImmutable()
    {
      return self()->isImmutable( QStringLiteral( "nb_times" ) );
    }

    /**
      Get Number of times
    */
    static
    int nb_times_val()
    {
      return self()->mNb_times_val;
    }

    /**
      Is Number of times Immutable
    */
    static
    bool isNb_times_valImmutable()
    {
      return self()->isImmutable( QStringLiteral( "nb_times_val" ) );
    }

    /**
      Get Color of font for disabled schedule
    */
    static
    QColor fontDisabledColor()
    {
      return self()->mFontDisabledColor;
    }

    /**
      Is Color of font for disabled schedule Immutable
    */
    static
    bool isFontDisabledColorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "fontDisabledColor" ) );
    }

  protected:
    skgscheduled_settings();
    friend class skgscheduled_settingsHelper;


    // skrooge_scheduled
    bool mCheck_on_open;
    bool mCreate_template;
    bool mConvert_to_from_template;
    bool mRemind_me;
    int mRemind_me_days;
    bool mAuto_write;
    int mAuto_write_days;
    int mOnce_every;
    QString mOnce_every_unit;
    bool mNb_times;
    int mNb_times_val;
    QColor mFontDisabledColor;
};

#endif

