// This file is generated by kconfig_compiler_kf6 from skgreport_settings.kcfg.
// All changes you do to this file will be lost.
#ifndef SKGREPORT_SETTINGS_H
#define SKGREPORT_SETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class skgreport_settings : public KConfigSkeleton
{
  public:

    static skgreport_settings *self();
    ~skgreport_settings() override;

    /**
      Get Background color
    */
    static
    QColor backgroundColor()
    {
      return self()->mBackgroundColor;
    }

    /**
      Is Background color Immutable
    */
    static
    bool isBackgroundColorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "backgroundColor" ) );
    }

    /**
      Get Text color
    */
    static
    QColor textColor()
    {
      return self()->mTextColor;
    }

    /**
      Is Text color Immutable
    */
    static
    bool isTextColorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "textColor" ) );
    }

    /**
      Get Outline color
    */
    static
    QColor outlineColor()
    {
      return self()->mOutlineColor;
    }

    /**
      Is Outline color Immutable
    */
    static
    bool isOutlineColorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "outlineColor" ) );
    }

    /**
      Get Axis color
    */
    static
    QColor axisColor()
    {
      return self()->mAxisColor;
    }

    /**
      Is Axis color Immutable
    */
    static
    bool isAxisColorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "axisColor" ) );
    }

    /**
      Get Grid color
    */
    static
    QColor gridColor()
    {
      return self()->mGridColor;
    }

    /**
      Is Grid color Immutable
    */
    static
    bool isGridColorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "gridColor" ) );
    }

    /**
      Get Minimum color
    */
    static
    QColor minColor()
    {
      return self()->mMinColor;
    }

    /**
      Is Minimum color Immutable
    */
    static
    bool isMinColorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "minColor" ) );
    }

    /**
      Get Maximum color
    */
    static
    QColor maxColor()
    {
      return self()->mMaxColor;
    }

    /**
      Is Maximum color Immutable
    */
    static
    bool isMaxColorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "maxColor" ) );
    }

    /**
      Get Average color
    */
    static
    QColor averageColor()
    {
      return self()->mAverageColor;
    }

    /**
      Is Average color Immutable
    */
    static
    bool isAverageColorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "averageColor" ) );
    }

    /**
      Get Tendency color
    */
    static
    QColor tendencyColor()
    {
      return self()->mTendencyColor;
    }

    /**
      Is Tendency color Immutable
    */
    static
    bool isTendencyColorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "tendencyColor" ) );
    }

    /**
      Get Pareto color
    */
    static
    QColor paretoColor()
    {
      return self()->mParetoColor;
    }

    /**
      Is Pareto color Immutable
    */
    static
    bool isParetoColorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "paretoColor" ) );
    }

    /**
      Get Antialiasing
    */
    static
    bool antialiasing()
    {
      return self()->mAntialiasing;
    }

    /**
      Is Antialiasing Immutable
    */
    static
    bool isAntialiasingImmutable()
    {
      return self()->isImmutable( QStringLiteral( "antialiasing" ) );
    }

    /**
      Get Maximum duration of forecasts on scheduled transactions (years)
    */
    static
    int maxForecasts()
    {
      return self()->mMaxForecasts;
    }

    /**
      Is Maximum duration of forecasts on scheduled transactions (years) Immutable
    */
    static
    bool isMaxForecastsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "maxForecasts" ) );
    }

  protected:
    skgreport_settings();
    friend class skgreport_settingsHelper;


    // skrooge_report
    QColor mBackgroundColor;
    QColor mTextColor;
    QColor mOutlineColor;
    QColor mAxisColor;
    QColor mGridColor;
    QColor mMinColor;
    QColor mMaxColor;
    QColor mAverageColor;
    QColor mTendencyColor;
    QColor mParetoColor;
    bool mAntialiasing;
    int mMaxForecasts;
};

#endif

