/********************************************************************************
** Form generated from reading UI file 'skgundoredoplugindockwidget_base.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGUNDOREDOPLUGINDOCKWIDGET_BASE_H
#define UI_SKGUNDOREDOPLUGINDOCKWIDGET_BASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "skgtableview.h"
#include "skgtreeview.h"

QT_BEGIN_NAMESPACE

class Ui_skgundoredoplugindockwidget_base
{
public:
    QVBoxLayout *verticalLayout;
    SKGTableView *kTransactionList;
    QPushButton *kClearHistoryBtn;

    void setupUi(QWidget *skgundoredoplugindockwidget_base)
    {
        if (skgundoredoplugindockwidget_base->objectName().isEmpty())
            skgundoredoplugindockwidget_base->setObjectName("skgundoredoplugindockwidget_base");
        skgundoredoplugindockwidget_base->resize(105, 104);
        verticalLayout = new QVBoxLayout(skgundoredoplugindockwidget_base);
        verticalLayout->setSpacing(2);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        kTransactionList = new SKGTableView(skgundoredoplugindockwidget_base);
        kTransactionList->setObjectName("kTransactionList");
        kTransactionList->setFocusPolicy(Qt::NoFocus);
        kTransactionList->setFrameShape(QFrame::NoFrame);
        kTransactionList->setSelectionMode(QAbstractItemView::SingleSelection);
        kTransactionList->setSelectionBehavior(QAbstractItemView::SelectRows);

        verticalLayout->addWidget(kTransactionList);

        kClearHistoryBtn = new QPushButton(skgundoredoplugindockwidget_base);
        kClearHistoryBtn->setObjectName("kClearHistoryBtn");
        kClearHistoryBtn->setFocusPolicy(Qt::NoFocus);

        verticalLayout->addWidget(kClearHistoryBtn);


        retranslateUi(skgundoredoplugindockwidget_base);

        QMetaObject::connectSlotsByName(skgundoredoplugindockwidget_base);
    } // setupUi

    void retranslateUi(QWidget *skgundoredoplugindockwidget_base)
    {
#if QT_CONFIG(tooltip)
        kTransactionList->setToolTip(tr2i18n("History of modifications", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kTransactionList->setStatusTip(tr2i18n("History of modifications", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kClearHistoryBtn->setToolTip(tr2i18n("Clear history", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kClearHistoryBtn->setStatusTip(tr2i18n("Clear history", nullptr));
#endif // QT_CONFIG(statustip)
        kClearHistoryBtn->setText(tr2i18n("Clear history", nullptr));
        (void)skgundoredoplugindockwidget_base;
    } // retranslateUi

};

namespace Ui {
    class skgundoredoplugindockwidget_base: public Ui_skgundoredoplugindockwidget_base {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGUNDOREDOPLUGINDOCKWIDGET_BASE_H

