/********************************************************************************
** Form generated from reading UI file 'skgassistantpluginwidget_pref.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGASSISTANTPLUGINWIDGET_PREF_H
#define UI_SKGASSISTANTPLUGINWIDGET_PREF_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_skgassistantplugin_pref
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *kConnectionGroup;
    QFormLayout *formLayout;
    QLabel *kServerUrlLabel;
    QLineEdit *kcfg_serverUrl;
    QLabel *kApiTokenLabel;
    QLineEdit *kcfg_apiToken;
    QCheckBox *kcfg_enableWebSearch;
    QLabel *kFamilySituationLabel;
    QPlainTextEdit *kcfg_familySituation;
    QLabel *kLabel;
    QLabel *label_2;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *skgassistantplugin_pref)
    {
        if (skgassistantplugin_pref->objectName().isEmpty())
            skgassistantplugin_pref->setObjectName("skgassistantplugin_pref");
        skgassistantplugin_pref->resize(631, 693);
        verticalLayout = new QVBoxLayout(skgassistantplugin_pref);
        verticalLayout->setObjectName("verticalLayout");
        kConnectionGroup = new QGroupBox(skgassistantplugin_pref);
        kConnectionGroup->setObjectName("kConnectionGroup");
        formLayout = new QFormLayout(kConnectionGroup);
        formLayout->setObjectName("formLayout");
        kServerUrlLabel = new QLabel(kConnectionGroup);
        kServerUrlLabel->setObjectName("kServerUrlLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, kServerUrlLabel);

        kcfg_serverUrl = new QLineEdit(kConnectionGroup);
        kcfg_serverUrl->setObjectName("kcfg_serverUrl");
        kcfg_serverUrl->setText(QString::fromUtf8("http://127.0.0.1:8080"));
        kcfg_serverUrl->setPlaceholderText(QString::fromUtf8("http://127.0.0.1:8080"));

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_serverUrl);

        kApiTokenLabel = new QLabel(kConnectionGroup);
        kApiTokenLabel->setObjectName("kApiTokenLabel");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, kApiTokenLabel);

        kcfg_apiToken = new QLineEdit(kConnectionGroup);
        kcfg_apiToken->setObjectName("kcfg_apiToken");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_apiToken);

        kcfg_enableWebSearch = new QCheckBox(kConnectionGroup);
        kcfg_enableWebSearch->setObjectName("kcfg_enableWebSearch");

        formLayout->setWidget(4, QFormLayout::ItemRole::SpanningRole, kcfg_enableWebSearch);

        kFamilySituationLabel = new QLabel(kConnectionGroup);
        kFamilySituationLabel->setObjectName("kFamilySituationLabel");

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, kFamilySituationLabel);

        kcfg_familySituation = new QPlainTextEdit(kConnectionGroup);
        kcfg_familySituation->setObjectName("kcfg_familySituation");
        kcfg_familySituation->setMaximumSize(QSize(16777215, 200));

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, kcfg_familySituation);

        kLabel = new QLabel(kConnectionGroup);
        kLabel->setObjectName("kLabel");
        kLabel->setWordWrap(true);

        formLayout->setWidget(0, QFormLayout::ItemRole::SpanningRole, kLabel);

        label_2 = new QLabel(kConnectionGroup);
        label_2->setObjectName("label_2");
        label_2->setWordWrap(true);

        formLayout->setWidget(3, QFormLayout::ItemRole::SpanningRole, label_2);


        verticalLayout->addWidget(kConnectionGroup);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

#if QT_CONFIG(shortcut)
        kServerUrlLabel->setBuddy(kcfg_serverUrl);
        kApiTokenLabel->setBuddy(kcfg_apiToken);
        kFamilySituationLabel->setBuddy(kcfg_familySituation);
#endif // QT_CONFIG(shortcut)

        retranslateUi(skgassistantplugin_pref);

        QMetaObject::connectSlotsByName(skgassistantplugin_pref);
    } // setupUi

    void retranslateUi(QWidget *skgassistantplugin_pref)
    {
        kServerUrlLabel->setText(tr2i18n("Server URL:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_serverUrl->setToolTip(tr2i18n("Base URL of OpenAI server. The API path /v1/chat/completions is appended automatically.", nullptr));
#endif // QT_CONFIG(tooltip)
        kApiTokenLabel->setText(tr2i18n("API Token:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_apiToken->setToolTip(tr2i18n("API token for authentication (optional). Leave empty if not required.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kcfg_enableWebSearch->setToolTip(tr2i18n("Allow the AI assistant to search the internet to provide more accurate and up-to-date information.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_enableWebSearch->setText(tr2i18n("Enable internet searches", nullptr));
        kFamilySituationLabel->setText(tr2i18n("Family Situation:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_familySituation->setToolTip(tr2i18n("Describe your family situation (e.g., single, married, with children, etc.). This helps the AI assistant provide more personalized recommendations.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_familySituation->setPlaceholderText(tr2i18n("You can help Dickens by telling him more about your family situation (number of people, employed, self-employed, or retired, homeowner or renter) and your plans. You can use Markdown syntax.", nullptr));
        label_2->setText(tr2i18n("<html><head/><body><p>Your AI companion may need internet access. You can allow it to do so, but be mindful of <span style=\" text-decoration: underline;\">privacy concerns</span>. For your information, the internet searchs are done with <span style=\" font-weight:700;\">duckduckgo</span>.</p></body></html>", nullptr));
        (void)skgassistantplugin_pref;
    } // retranslateUi

};

namespace Ui {
    class skgassistantplugin_pref: public Ui_skgassistantplugin_pref {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGASSISTANTPLUGINWIDGET_PREF_H

