/********************************************************************************
** Form generated from reading UI file 'skgmainpanel_pref.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGMAINPANEL_PREF_H
#define UI_SKGMAINPANEL_PREF_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_skgmainpanel_pref
{
public:
    QVBoxLayout *verticalLayout;
    QCheckBox *kcfg_icon_in_system_tray;
    QCheckBox *kcfg_show_splash_screen;
    QGridLayout *gridLayout;
    KComboBox *kcfg_update_modified_contexts;
    KComboBox *kcfg_main_tabs_position;
    KComboBox *kcfg_update_modified_bookmarks;
    QLabel *label;
    QLabel *label_2;
    QLabel *label_3;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *horizontalSpacer_3;
    QGroupBox *groupBox;
    QFormLayout *formLayout;
    QLabel *label_4;
    KComboBox *kcfg_date_format;
    QLabel *label_5;
    KComboBox *kcfg_currency_format;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *skgmainpanel_pref)
    {
        if (skgmainpanel_pref->objectName().isEmpty())
            skgmainpanel_pref->setObjectName("skgmainpanel_pref");
        skgmainpanel_pref->resize(465, 450);
        skgmainpanel_pref->setMinimumSize(QSize(0, 450));
        verticalLayout = new QVBoxLayout(skgmainpanel_pref);
        verticalLayout->setObjectName("verticalLayout");
        kcfg_icon_in_system_tray = new QCheckBox(skgmainpanel_pref);
        kcfg_icon_in_system_tray->setObjectName("kcfg_icon_in_system_tray");

        verticalLayout->addWidget(kcfg_icon_in_system_tray);

        kcfg_show_splash_screen = new QCheckBox(skgmainpanel_pref);
        kcfg_show_splash_screen->setObjectName("kcfg_show_splash_screen");
        kcfg_show_splash_screen->setChecked(true);

        verticalLayout->addWidget(kcfg_show_splash_screen);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        kcfg_update_modified_contexts = new KComboBox(skgmainpanel_pref);
        kcfg_update_modified_contexts->addItem(QString());
        kcfg_update_modified_contexts->addItem(QString());
        kcfg_update_modified_contexts->addItem(QString());
        kcfg_update_modified_contexts->setObjectName("kcfg_update_modified_contexts");
        kcfg_update_modified_contexts->setSizeAdjustPolicy(QComboBox::SizeAdjustPolicy::AdjustToContents);

        gridLayout->addWidget(kcfg_update_modified_contexts, 0, 1, 1, 1);

        kcfg_main_tabs_position = new KComboBox(skgmainpanel_pref);
        kcfg_main_tabs_position->addItem(QString());
        kcfg_main_tabs_position->addItem(QString());
        kcfg_main_tabs_position->addItem(QString());
        kcfg_main_tabs_position->addItem(QString());
        kcfg_main_tabs_position->setObjectName("kcfg_main_tabs_position");
        kcfg_main_tabs_position->setSizeAdjustPolicy(QComboBox::SizeAdjustPolicy::AdjustToContents);

        gridLayout->addWidget(kcfg_main_tabs_position, 2, 1, 1, 1);

        kcfg_update_modified_bookmarks = new KComboBox(skgmainpanel_pref);
        kcfg_update_modified_bookmarks->addItem(QString());
        kcfg_update_modified_bookmarks->addItem(QString());
        kcfg_update_modified_bookmarks->addItem(QString());
        kcfg_update_modified_bookmarks->setObjectName("kcfg_update_modified_bookmarks");
        kcfg_update_modified_bookmarks->setSizeAdjustPolicy(QComboBox::SizeAdjustPolicy::AdjustToContents);

        gridLayout->addWidget(kcfg_update_modified_bookmarks, 1, 1, 1, 1);

        label = new QLabel(skgmainpanel_pref);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label, 1, 0, 1, 1);

        label_2 = new QLabel(skgmainpanel_pref);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_2, 2, 0, 1, 1);

        label_3 = new QLabel(skgmainpanel_pref);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_3, 0, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 2, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 1, 2, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_3, 2, 2, 1, 1);


        verticalLayout->addLayout(gridLayout);

        groupBox = new QGroupBox(skgmainpanel_pref);
        groupBox->setObjectName("groupBox");
        formLayout = new QFormLayout(groupBox);
        formLayout->setObjectName("formLayout");
        label_4 = new QLabel(groupBox);
        label_4->setObjectName("label_4");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_4);

        kcfg_date_format = new KComboBox(groupBox);
        kcfg_date_format->setObjectName("kcfg_date_format");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_date_format);

        label_5 = new QLabel(groupBox);
        label_5->setObjectName("label_5");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_5);

        kcfg_currency_format = new KComboBox(groupBox);
        kcfg_currency_format->setObjectName("kcfg_currency_format");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_currency_format);


        verticalLayout->addWidget(groupBox);

        verticalSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

#if QT_CONFIG(shortcut)
        label->setBuddy(kcfg_update_modified_bookmarks);
        label_2->setBuddy(kcfg_main_tabs_position);
        label_3->setBuddy(kcfg_update_modified_contexts);
        label_4->setBuddy(kcfg_date_format);
        label_5->setBuddy(kcfg_currency_format);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kcfg_icon_in_system_tray, kcfg_show_splash_screen);
        QWidget::setTabOrder(kcfg_show_splash_screen, kcfg_update_modified_contexts);
        QWidget::setTabOrder(kcfg_update_modified_contexts, kcfg_update_modified_bookmarks);
        QWidget::setTabOrder(kcfg_update_modified_bookmarks, kcfg_main_tabs_position);
        QWidget::setTabOrder(kcfg_main_tabs_position, kcfg_date_format);

        retranslateUi(skgmainpanel_pref);

        QMetaObject::connectSlotsByName(skgmainpanel_pref);
    } // setupUi

    void retranslateUi(QWidget *skgmainpanel_pref)
    {
        kcfg_icon_in_system_tray->setText(tr2i18n("Show icon in system tray", nullptr));
        kcfg_show_splash_screen->setText(tr2i18n("Show splash screen", nullptr));
        kcfg_update_modified_contexts->setItemText(0, tr2i18n("Ask", "Verb, ask something to the user"));
        kcfg_update_modified_contexts->setItemText(1, tr2i18n("Always", nullptr));
        kcfg_update_modified_contexts->setItemText(2, tr2i18n("Never", nullptr));

        kcfg_main_tabs_position->setItemText(0, tr2i18n("North", nullptr));
        kcfg_main_tabs_position->setItemText(1, tr2i18n("South", nullptr));
        kcfg_main_tabs_position->setItemText(2, tr2i18n("West", nullptr));
        kcfg_main_tabs_position->setItemText(3, tr2i18n("East", nullptr));

        kcfg_update_modified_bookmarks->setItemText(0, tr2i18n("Ask", nullptr));
        kcfg_update_modified_bookmarks->setItemText(1, tr2i18n("Always", nullptr));
        kcfg_update_modified_bookmarks->setItemText(2, tr2i18n("Never", nullptr));

        label->setText(tr2i18n("Update modified &bookmarks on close:", nullptr));
        label_2->setText(tr2i18n("&Main tabs position:", nullptr));
        label_3->setText(tr2i18n("Update modified pages on close:", nullptr));
        groupBox->setTitle(tr2i18n("Display", nullptr));
        label_4->setText(tr2i18n("Date fo&rmat:", nullptr));
        label_5->setText(tr2i18n("Currency format:", nullptr));
        (void)skgmainpanel_pref;
    } // retranslateUi

};

namespace Ui {
    class skgmainpanel_pref: public Ui_skgmainpanel_pref {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGMAINPANEL_PREF_H

