/********************************************************************************
** Form generated from reading UI file 'skgcalculatorpluginwidget_base.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGCALCULATORPLUGINWIDGET_BASE_H
#define UI_SKGCALCULATORPLUGINWIDGET_BASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "ktitlewidget.h"
#include "skgcalculatoredit.h"
#include "skgcombobox.h"
#include "skgdateedit.h"
#include "skgtableview.h"
#include "skgtreeview.h"
#include "skgunitcombobox.h"
#include "skgwidgetselector.h"

QT_BEGIN_NAMESPACE

class Ui_skgcalculatorplugin_base
{
public:
    QVBoxLayout *verticalLayout_5;
    QFrame *kCalculatorFrm;
    QGridLayout *gridLayout_2;
    QFrame *kInterestFrm;
    QVBoxLayout *verticalLayout_4;
    QWidget *widget;
    QGridLayout *gridLayout;
    QHBoxLayout *hboxLayout;
    QLabel *kAccountLabel;
    SKGComboBox *kDisplayAccountCombo;
    QLabel *kYearLabel;
    SKGComboBox *KYearEdit;
    QSpacerItem *spacerItem;
    KTitleWidget *kInterestResultsTitle;
    SKGTableView *kInterestResultTable;
    QLabel *kInterestLbl;
    KTitleWidget *kInterestValuesTitle;
    KTitleWidget *kDefineValueTitle;
    SKGTableView *kInterestView;
    QLabel *kDateLabel;
    SKGDateEdit *kDateEdit;
    QLabel *kRateLabel;
    QLabel *kCreditValueDateLbl;
    SKGComboBox *kCreditValueDate;
    QLabel *kDebitValueDateLbl;
    SKGComboBox *kDebitValueDate;
    QLabel *kModeLbl;
    SKGComboBox *kMode;
    QSpacerItem *verticalSpacer;
    QDoubleSpinBox *kRateEdit;
    QFrame *kAmortizationFrm;
    QGridLayout *gridLayout_3;
    KTitleWidget *kAmortizationTableTitle;
    QWidget *gridWidget_2;
    QGridLayout *gridLayout_5;
    QLabel *kAnnualRateLabel;
    QLabel *kLoanLabel;
    QLabel *kLength;
    QSpacerItem *verticalSpacer_2;
    SKGCalculatorEdit *kLoanEdit;
    QFrame *line;
    QLabel *kAmortizationResult;
    SKGUnitComboBox *kUnitEdit;
    KTitleWidget *kPaymentSummaryTitle;
    KTitleWidget *kLoadSummaryTitle;
    QLabel *kInsuranceRateLbl;
    QSpinBox *kLenghtEdit;
    QDoubleSpinBox *kAnnualRateEdit;
    QDoubleSpinBox *kInsuranceRateEdit;
    QTableWidget *kAmortizationTable;
    QHBoxLayout *horizontalLayout_12;
    SKGWidgetSelector *kWidgetSelector;
    QFrame *kBtnFrm;
    QHBoxLayout *horizontalLayout;
    QPushButton *kAdd;
    QPushButton *kUpdate;

    void setupUi(QWidget *skgcalculatorplugin_base)
    {
        if (skgcalculatorplugin_base->objectName().isEmpty())
            skgcalculatorplugin_base->setObjectName("skgcalculatorplugin_base");
        skgcalculatorplugin_base->resize(489, 722);
        verticalLayout_5 = new QVBoxLayout(skgcalculatorplugin_base);
        verticalLayout_5->setObjectName("verticalLayout_5");
        kCalculatorFrm = new QFrame(skgcalculatorplugin_base);
        kCalculatorFrm->setObjectName("kCalculatorFrm");
        gridLayout_2 = new QGridLayout(kCalculatorFrm);
        gridLayout_2->setSpacing(2);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(0, 0, 0, 0);

        verticalLayout_5->addWidget(kCalculatorFrm);

        kInterestFrm = new QFrame(skgcalculatorplugin_base);
        kInterestFrm->setObjectName("kInterestFrm");
        verticalLayout_4 = new QVBoxLayout(kInterestFrm);
        verticalLayout_4->setSpacing(2);
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout_4->setContentsMargins(0, 0, 0, 0);
        widget = new QWidget(kInterestFrm);
        widget->setObjectName("widget");
        gridLayout = new QGridLayout(widget);
        gridLayout->setSpacing(2);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(2);
        hboxLayout->setObjectName("hboxLayout");
        kAccountLabel = new QLabel(widget);
        kAccountLabel->setObjectName("kAccountLabel");

        hboxLayout->addWidget(kAccountLabel);

        kDisplayAccountCombo = new SKGComboBox(widget);
        kDisplayAccountCombo->setObjectName("kDisplayAccountCombo");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kDisplayAccountCombo->sizePolicy().hasHeightForWidth());
        kDisplayAccountCombo->setSizePolicy(sizePolicy);
        kDisplayAccountCombo->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        hboxLayout->addWidget(kDisplayAccountCombo);

        kYearLabel = new QLabel(widget);
        kYearLabel->setObjectName("kYearLabel");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(kYearLabel->sizePolicy().hasHeightForWidth());
        kYearLabel->setSizePolicy(sizePolicy1);
        kYearLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        hboxLayout->addWidget(kYearLabel);

        KYearEdit = new SKGComboBox(widget);
        KYearEdit->setObjectName("KYearEdit");

        hboxLayout->addWidget(KYearEdit);

        spacerItem = new QSpacerItem(0, 35, QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);


        gridLayout->addLayout(hboxLayout, 0, 0, 1, 3);

        kInterestResultsTitle = new KTitleWidget(widget);
        kInterestResultsTitle->setObjectName("kInterestResultsTitle");

        gridLayout->addWidget(kInterestResultsTitle, 1, 0, 1, 3);

        kInterestResultTable = new SKGTableView(widget);
        kInterestResultTable->setObjectName("kInterestResultTable");
        kInterestResultTable->setAlternatingRowColors(true);
        kInterestResultTable->setSelectionMode(QAbstractItemView::NoSelection);

        gridLayout->addWidget(kInterestResultTable, 2, 0, 1, 3);

        kInterestLbl = new QLabel(widget);
        kInterestLbl->setObjectName("kInterestLbl");
        kInterestLbl->setText(QString::fromUtf8(""));
        kInterestLbl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        kInterestLbl->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        gridLayout->addWidget(kInterestLbl, 3, 0, 1, 3);

        kInterestValuesTitle = new KTitleWidget(widget);
        kInterestValuesTitle->setObjectName("kInterestValuesTitle");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(kInterestValuesTitle->sizePolicy().hasHeightForWidth());
        kInterestValuesTitle->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(kInterestValuesTitle, 4, 0, 1, 1);

        kDefineValueTitle = new KTitleWidget(widget);
        kDefineValueTitle->setObjectName("kDefineValueTitle");

        gridLayout->addWidget(kDefineValueTitle, 4, 1, 1, 2);

        kInterestView = new SKGTableView(widget);
        kInterestView->setObjectName("kInterestView");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(kInterestView->sizePolicy().hasHeightForWidth());
        kInterestView->setSizePolicy(sizePolicy3);
        kInterestView->setAlternatingRowColors(true);
        kInterestView->setSelectionBehavior(QAbstractItemView::SelectRows);

        gridLayout->addWidget(kInterestView, 5, 0, 6, 1);

        kDateLabel = new QLabel(widget);
        kDateLabel->setObjectName("kDateLabel");
        QFont font;
        font.setBold(true);
        kDateLabel->setFont(font);
        kDateLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(kDateLabel, 5, 1, 1, 1);

        kDateEdit = new SKGDateEdit(widget);
        kDateEdit->setObjectName("kDateEdit");
        kDateEdit->setMinimumSize(QSize(120, 0));

        gridLayout->addWidget(kDateEdit, 5, 2, 1, 1);

        kRateLabel = new QLabel(widget);
        kRateLabel->setObjectName("kRateLabel");
        kRateLabel->setFont(font);
        kRateLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(kRateLabel, 6, 1, 1, 1);

        kCreditValueDateLbl = new QLabel(widget);
        kCreditValueDateLbl->setObjectName("kCreditValueDateLbl");
        kCreditValueDateLbl->setFont(font);
        kCreditValueDateLbl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(kCreditValueDateLbl, 7, 1, 1, 1);

        kCreditValueDate = new SKGComboBox(widget);
        kCreditValueDate->setObjectName("kCreditValueDate");

        gridLayout->addWidget(kCreditValueDate, 7, 2, 1, 1);

        kDebitValueDateLbl = new QLabel(widget);
        kDebitValueDateLbl->setObjectName("kDebitValueDateLbl");
        kDebitValueDateLbl->setFont(font);
        kDebitValueDateLbl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(kDebitValueDateLbl, 8, 1, 1, 1);

        kDebitValueDate = new SKGComboBox(widget);
        kDebitValueDate->setObjectName("kDebitValueDate");

        gridLayout->addWidget(kDebitValueDate, 8, 2, 1, 1);

        kModeLbl = new QLabel(widget);
        kModeLbl->setObjectName("kModeLbl");
        kModeLbl->setFont(font);
        kModeLbl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(kModeLbl, 9, 1, 1, 1);

        kMode = new SKGComboBox(widget);
        kMode->setObjectName("kMode");

        gridLayout->addWidget(kMode, 9, 2, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 10, 2, 1, 1);

        kRateEdit = new QDoubleSpinBox(widget);
        kRateEdit->setObjectName("kRateEdit");
        kRateEdit->setFocusPolicy(Qt::WheelFocus);
        kRateEdit->setMaximum(100.000000000000000);

        gridLayout->addWidget(kRateEdit, 6, 2, 1, 1);


        verticalLayout_4->addWidget(widget);


        verticalLayout_5->addWidget(kInterestFrm);

        kAmortizationFrm = new QFrame(skgcalculatorplugin_base);
        kAmortizationFrm->setObjectName("kAmortizationFrm");
        gridLayout_3 = new QGridLayout(kAmortizationFrm);
        gridLayout_3->setSpacing(2);
        gridLayout_3->setObjectName("gridLayout_3");
        gridLayout_3->setContentsMargins(0, 0, 0, 0);
        kAmortizationTableTitle = new KTitleWidget(kAmortizationFrm);
        kAmortizationTableTitle->setObjectName("kAmortizationTableTitle");
        sizePolicy2.setHeightForWidth(kAmortizationTableTitle->sizePolicy().hasHeightForWidth());
        kAmortizationTableTitle->setSizePolicy(sizePolicy2);

        gridLayout_3->addWidget(kAmortizationTableTitle, 0, 0, 1, 1);

        gridWidget_2 = new QWidget(kAmortizationFrm);
        gridWidget_2->setObjectName("gridWidget_2");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(gridWidget_2->sizePolicy().hasHeightForWidth());
        gridWidget_2->setSizePolicy(sizePolicy4);
        gridLayout_5 = new QGridLayout(gridWidget_2);
        gridLayout_5->setSpacing(2);
        gridLayout_5->setObjectName("gridLayout_5");
        gridLayout_5->setContentsMargins(0, 0, 0, 0);
        kAnnualRateLabel = new QLabel(gridWidget_2);
        kAnnualRateLabel->setObjectName("kAnnualRateLabel");
        kAnnualRateLabel->setFont(font);
        kAnnualRateLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_5->addWidget(kAnnualRateLabel, 2, 0, 1, 1);

        kLoanLabel = new QLabel(gridWidget_2);
        kLoanLabel->setObjectName("kLoanLabel");
        kLoanLabel->setFont(font);
        kLoanLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_5->addWidget(kLoanLabel, 1, 0, 1, 1);

        kLength = new QLabel(gridWidget_2);
        kLength->setObjectName("kLength");
        kLength->setFont(font);
        kLength->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_5->addWidget(kLength, 5, 0, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_5->addItem(verticalSpacer_2, 11, 1, 1, 1);

        kLoanEdit = new SKGCalculatorEdit(gridWidget_2);
        kLoanEdit->setObjectName("kLoanEdit");
        sizePolicy.setHeightForWidth(kLoanEdit->sizePolicy().hasHeightForWidth());
        kLoanEdit->setSizePolicy(sizePolicy);
        kLoanEdit->setMaximumSize(QSize(70, 16777215));
        kLoanEdit->setValue(100000.000000000000000);

        gridLayout_5->addWidget(kLoanEdit, 1, 1, 1, 1);

        line = new QFrame(gridWidget_2);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout_5->addWidget(line, 8, 0, 1, 3);

        kAmortizationResult = new QLabel(gridWidget_2);
        kAmortizationResult->setObjectName("kAmortizationResult");
        kAmortizationResult->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        gridLayout_5->addWidget(kAmortizationResult, 10, 0, 1, 3);

        kUnitEdit = new SKGUnitComboBox(gridWidget_2);
        kUnitEdit->setObjectName("kUnitEdit");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Fixed);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(kUnitEdit->sizePolicy().hasHeightForWidth());
        kUnitEdit->setSizePolicy(sizePolicy5);
        kUnitEdit->setMinimumSize(QSize(100, 0));
        kUnitEdit->setMaximumSize(QSize(100, 16777215));
        kUnitEdit->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        gridLayout_5->addWidget(kUnitEdit, 1, 2, 1, 1);

        kPaymentSummaryTitle = new KTitleWidget(gridWidget_2);
        kPaymentSummaryTitle->setObjectName("kPaymentSummaryTitle");

        gridLayout_5->addWidget(kPaymentSummaryTitle, 9, 0, 1, 3);

        kLoadSummaryTitle = new KTitleWidget(gridWidget_2);
        kLoadSummaryTitle->setObjectName("kLoadSummaryTitle");

        gridLayout_5->addWidget(kLoadSummaryTitle, 0, 0, 1, 3);

        kInsuranceRateLbl = new QLabel(gridWidget_2);
        kInsuranceRateLbl->setObjectName("kInsuranceRateLbl");
        kInsuranceRateLbl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_5->addWidget(kInsuranceRateLbl, 6, 0, 1, 1);

        kLenghtEdit = new QSpinBox(gridWidget_2);
        kLenghtEdit->setObjectName("kLenghtEdit");
        kLenghtEdit->setMinimum(1);
        kLenghtEdit->setMaximum(100);
        kLenghtEdit->setSingleStep(5);
        kLenghtEdit->setValue(15);

        gridLayout_5->addWidget(kLenghtEdit, 5, 1, 1, 2);

        kAnnualRateEdit = new QDoubleSpinBox(gridWidget_2);
        kAnnualRateEdit->setObjectName("kAnnualRateEdit");
        kAnnualRateEdit->setFocusPolicy(Qt::WheelFocus);
        kAnnualRateEdit->setMaximum(100.000000000000000);

        gridLayout_5->addWidget(kAnnualRateEdit, 2, 1, 1, 2);

        kInsuranceRateEdit = new QDoubleSpinBox(gridWidget_2);
        kInsuranceRateEdit->setObjectName("kInsuranceRateEdit");
        kInsuranceRateEdit->setFocusPolicy(Qt::WheelFocus);
        kInsuranceRateEdit->setMaximum(100.000000000000000);

        gridLayout_5->addWidget(kInsuranceRateEdit, 6, 1, 1, 2);


        gridLayout_3->addWidget(gridWidget_2, 0, 1, 2, 1);

        kAmortizationTable = new QTableWidget(kAmortizationFrm);
        if (kAmortizationTable->columnCount() < 5)
            kAmortizationTable->setColumnCount(5);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        kAmortizationTable->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        kAmortizationTable->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        QTableWidgetItem *__qtablewidgetitem2 = new QTableWidgetItem();
        kAmortizationTable->setHorizontalHeaderItem(2, __qtablewidgetitem2);
        QTableWidgetItem *__qtablewidgetitem3 = new QTableWidgetItem();
        kAmortizationTable->setHorizontalHeaderItem(3, __qtablewidgetitem3);
        QTableWidgetItem *__qtablewidgetitem4 = new QTableWidgetItem();
        kAmortizationTable->setHorizontalHeaderItem(4, __qtablewidgetitem4);
        kAmortizationTable->setObjectName("kAmortizationTable");
        sizePolicy3.setHeightForWidth(kAmortizationTable->sizePolicy().hasHeightForWidth());
        kAmortizationTable->setSizePolicy(sizePolicy3);
        kAmortizationTable->setEditTriggers(QAbstractItemView::NoEditTriggers);
        kAmortizationTable->setAlternatingRowColors(true);
        kAmortizationTable->setSelectionMode(QAbstractItemView::NoSelection);
        kAmortizationTable->setShowGrid(false);

        gridLayout_3->addWidget(kAmortizationTable, 1, 0, 1, 1);


        verticalLayout_5->addWidget(kAmortizationFrm);

        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setSpacing(2);
        horizontalLayout_12->setObjectName("horizontalLayout_12");
        kWidgetSelector = new SKGWidgetSelector(skgcalculatorplugin_base);
        kWidgetSelector->setObjectName("kWidgetSelector");
        kWidgetSelector->setAlwaysOneOpen(true);

        horizontalLayout_12->addWidget(kWidgetSelector);

        kBtnFrm = new QFrame(skgcalculatorplugin_base);
        kBtnFrm->setObjectName("kBtnFrm");
        kBtnFrm->setMinimumSize(QSize(100, 0));
        horizontalLayout = new QHBoxLayout(kBtnFrm);
        horizontalLayout->setSpacing(2);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        kAdd = new QPushButton(kBtnFrm);
        kAdd->setObjectName("kAdd");
        kAdd->setEnabled(true);
        kAdd->setAutoDefault(true);

        horizontalLayout->addWidget(kAdd);

        kUpdate = new QPushButton(kBtnFrm);
        kUpdate->setObjectName("kUpdate");

        horizontalLayout->addWidget(kUpdate);


        horizontalLayout_12->addWidget(kBtnFrm);


        verticalLayout_5->addLayout(horizontalLayout_12);

#if QT_CONFIG(shortcut)
        kAccountLabel->setBuddy(kDisplayAccountCombo);
        kYearLabel->setBuddy(KYearEdit);
        kDateLabel->setBuddy(kDateEdit);
        kRateLabel->setBuddy(kRateEdit);
        kCreditValueDateLbl->setBuddy(kCreditValueDate);
        kDebitValueDateLbl->setBuddy(kDebitValueDate);
        kModeLbl->setBuddy(kMode);
        kAnnualRateLabel->setBuddy(kAnnualRateEdit);
        kLoanLabel->setBuddy(kLoanEdit);
        kLength->setBuddy(kLenghtEdit);
        kInsuranceRateLbl->setBuddy(kInsuranceRateEdit);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kDisplayAccountCombo, KYearEdit);
        QWidget::setTabOrder(KYearEdit, kInterestResultTable);
        QWidget::setTabOrder(kInterestResultTable, kInterestView);
        QWidget::setTabOrder(kInterestView, kDateEdit);
        QWidget::setTabOrder(kDateEdit, kRateEdit);
        QWidget::setTabOrder(kRateEdit, kCreditValueDate);
        QWidget::setTabOrder(kCreditValueDate, kDebitValueDate);
        QWidget::setTabOrder(kDebitValueDate, kMode);
        QWidget::setTabOrder(kMode, kAmortizationTable);
        QWidget::setTabOrder(kAmortizationTable, kLoanEdit);
        QWidget::setTabOrder(kLoanEdit, kUnitEdit);
        QWidget::setTabOrder(kUnitEdit, kAnnualRateEdit);
        QWidget::setTabOrder(kAnnualRateEdit, kLenghtEdit);
        QWidget::setTabOrder(kLenghtEdit, kInsuranceRateEdit);
        QWidget::setTabOrder(kInsuranceRateEdit, kAdd);
        QWidget::setTabOrder(kAdd, kUpdate);

        retranslateUi(skgcalculatorplugin_base);

        kAdd->setDefault(true);


        QMetaObject::connectSlotsByName(skgcalculatorplugin_base);
    } // setupUi

    void retranslateUi(QWidget *skgcalculatorplugin_base)
    {
        kAccountLabel->setText(tr2i18n("Account:", "Noun, an account as in a bank account"));
#if QT_CONFIG(tooltip)
        kDisplayAccountCombo->setToolTip(tr2i18n("Displayed account", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kDisplayAccountCombo->setStatusTip(tr2i18n("Displayed account", nullptr));
#endif // QT_CONFIG(statustip)
        kYearLabel->setText(tr2i18n("&Year:", "Noun, a year"));
#if QT_CONFIG(tooltip)
        KYearEdit->setToolTip(tr2i18n("Year of computation", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        KYearEdit->setStatusTip(tr2i18n("Year of computation", nullptr));
#endif // QT_CONFIG(statustip)
        kInterestResultsTitle->setProperty("text", QVariant(tr2i18n("Interest Results", nullptr)));
#if QT_CONFIG(tooltip)
        kInterestResultTable->setToolTip(tr2i18n("Result of interest computation", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kInterestResultTable->setStatusTip(tr2i18n("Result of interest computation", nullptr));
#endif // QT_CONFIG(statustip)
        kInterestValuesTitle->setProperty("text", QVariant(tr2i18n("Interest Values", nullptr)));
        kDefineValueTitle->setProperty("text", QVariant(tr2i18n("Define Value", nullptr)));
#if QT_CONFIG(tooltip)
        kInterestView->setToolTip(tr2i18n("Parameters for interest computation", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kInterestView->setStatusTip(tr2i18n("Parameters for interest computation", nullptr));
#endif // QT_CONFIG(statustip)
        kDateLabel->setText(tr2i18n("Da&te:", nullptr));
#if QT_CONFIG(tooltip)
        kDateEdit->setToolTip(tr2i18n("Date of the interest's quote", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kDateEdit->setStatusTip(tr2i18n("Date of the interest's quote", nullptr));
#endif // QT_CONFIG(statustip)
        kRateLabel->setText(tr2i18n("Rate (%):", nullptr));
        kCreditValueDateLbl->setText(tr2i18n("Credit value date:", nullptr));
#if QT_CONFIG(tooltip)
        kCreditValueDate->setToolTip(tr2i18n("The credit value date computation mode.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kCreditValueDate->setStatusTip(tr2i18n("The credit value date computation mode.", nullptr));
#endif // QT_CONFIG(statustip)
        kDebitValueDateLbl->setText(tr2i18n("Debit value date:", nullptr));
#if QT_CONFIG(tooltip)
        kDebitValueDate->setToolTip(tr2i18n("The debit value date computation mode.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kDebitValueDate->setStatusTip(tr2i18n("The debit value date computation mode.", nullptr));
#endif // QT_CONFIG(statustip)
        kModeLbl->setText(tr2i18n("&Base computation:", nullptr));
#if QT_CONFIG(tooltip)
        kMode->setToolTip(tr2i18n("The base of the computation.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kMode->setStatusTip(tr2i18n("The base of the computation.", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kRateEdit->setToolTip(tr2i18n("Rate of the interest", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kRateEdit->setStatusTip(tr2i18n("Rate of the interest", nullptr));
#endif // QT_CONFIG(statustip)
        kAmortizationTableTitle->setProperty("text", QVariant(tr2i18n("Amortization Table", nullptr)));
        kAnnualRateLabel->setText(tr2i18n("Annual interest rate (%):", nullptr));
        kLoanLabel->setText(tr2i18n("Loan amount (principal):", nullptr));
        kLength->setText(tr2i18n("Length (years):", nullptr));
#if QT_CONFIG(tooltip)
        kLoanEdit->setToolTip(tr2i18n("Amount of the loan", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kLoanEdit->setStatusTip(tr2i18n("Amount of the loan", nullptr));
#endif // QT_CONFIG(statustip)
        kLoanEdit->setText(tr2i18n("100000", nullptr));
        kAmortizationResult->setText(QString());
#if QT_CONFIG(tooltip)
        kUnitEdit->setToolTip(tr2i18n("Unit of the loan", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kUnitEdit->setStatusTip(tr2i18n("Unit of the loan", nullptr));
#endif // QT_CONFIG(statustip)
        kPaymentSummaryTitle->setProperty("text", QVariant(tr2i18n("Payment Summary", nullptr)));
        kLoadSummaryTitle->setProperty("text", QVariant(tr2i18n("Loan Summary", nullptr)));
        kInsuranceRateLbl->setText(tr2i18n("Insurance rate(%):", nullptr));
#if QT_CONFIG(tooltip)
        kLenghtEdit->setToolTip(tr2i18n("Length of the loan in years", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kLenghtEdit->setStatusTip(tr2i18n("Length of the loan in years", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kAnnualRateEdit->setToolTip(tr2i18n("Annual rate of the loan", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kAnnualRateEdit->setStatusTip(tr2i18n("Annual rate of the loan", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kInsuranceRateEdit->setToolTip(tr2i18n("Insurance rate of the loan", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kInsuranceRateEdit->setStatusTip(tr2i18n("Insurance rate of the loan", nullptr));
#endif // QT_CONFIG(statustip)
        QTableWidgetItem *___qtablewidgetitem = kAmortizationTable->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(tr2i18n("Amount", nullptr));
        QTableWidgetItem *___qtablewidgetitem1 = kAmortizationTable->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(tr2i18n("Principal", nullptr));
        QTableWidgetItem *___qtablewidgetitem2 = kAmortizationTable->horizontalHeaderItem(2);
        ___qtablewidgetitem2->setText(tr2i18n("Interest", nullptr));
        QTableWidgetItem *___qtablewidgetitem3 = kAmortizationTable->horizontalHeaderItem(3);
        ___qtablewidgetitem3->setText(tr2i18n("Insurance", nullptr));
        QTableWidgetItem *___qtablewidgetitem4 = kAmortizationTable->horizontalHeaderItem(4);
        ___qtablewidgetitem4->setText(tr2i18n("Balance", nullptr));
#if QT_CONFIG(tooltip)
        kAmortizationTable->setToolTip(tr2i18n("Amortization Table", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kAmortizationTable->setStatusTip(tr2i18n("Amortization Table", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kAdd->setToolTip(tr2i18n("Create a new interest parameter (Ctrl+Enter)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kAdd->setStatusTip(tr2i18n("Create a new interest parameter (Ctrl+Enter)", nullptr));
#endif // QT_CONFIG(statustip)
        kAdd->setText(tr2i18n("Add", nullptr));
#if QT_CONFIG(tooltip)
        kUpdate->setToolTip(tr2i18n("Update interest parameters (Shift+Enter)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kUpdate->setStatusTip(tr2i18n("Update interest parameters (Shift+Enter)", nullptr));
#endif // QT_CONFIG(statustip)
        kUpdate->setText(tr2i18n("Modify", nullptr));
        (void)skgcalculatorplugin_base;
    } // retranslateUi

};

namespace Ui {
    class skgcalculatorplugin_base: public Ui_skgcalculatorplugin_base {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGCALCULATORPLUGINWIDGET_BASE_H

