// This file is generated by kconfig_compiler_kf6 from skgfile_settings.kcfg.
// All changes you do to this file will be lost.
#ifndef SKGFILE_SETTINGS_H
#define SKGFILE_SETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class skgfile_settings : public KConfigSkeleton
{
  public:

    static skgfile_settings *self();
    ~skgfile_settings() override;

    /**
      Get Open last file on startup
    */
    static
    bool openlastfile()
    {
      return self()->mOpenlastfile;
    }

    /**
      Is Open last file on startup Immutable
    */
    static
    bool isOpenlastfileImmutable()
    {
      return self()->isImmutable( QStringLiteral( "openlastfile" ) );
    }

    /**
      Get Save on close
    */
    static
    bool saveonclose()
    {
      return self()->mSaveonclose;
    }

    /**
      Is Save on close Immutable
    */
    static
    bool isSaveoncloseImmutable()
    {
      return self()->isImmutable( QStringLiteral( "saveonclose" ) );
    }

    /**
      Get Store passwords in KDE Wallet
    */
    static
    bool storeInKdeWallet()
    {
      return self()->mStoreInKdeWallet;
    }

    /**
      Is Store passwords in KDE Wallet Immutable
    */
    static
    bool isStoreInKdeWalletImmutable()
    {
      return self()->isImmutable( QStringLiteral( "storeInKdeWallet" ) );
    }

    /**
      Get Selected Wallet
    */
    static
    QString selectedWallet()
    {
      return self()->mSelectedWallet;
    }

    /**
      Is Selected Wallet Immutable
    */
    static
    bool isSelectedWalletImmutable()
    {
      return self()->isImmutable( QStringLiteral( "selectedWallet" ) );
    }

    /**
      Get Enable backup
    */
    static
    bool backup_enabled()
    {
      return self()->mBackup_enabled;
    }

    /**
      Is Enable backup Immutable
    */
    static
    bool isBackup_enabledImmutable()
    {
      return self()->isImmutable( QStringLiteral( "backup_enabled" ) );
    }

    /**
      Get Prefix
    */
    static
    QString prefix()
    {
      return self()->mPrefix;
    }

    /**
      Is Prefix Immutable
    */
    static
    bool isPrefixImmutable()
    {
      return self()->isImmutable( QStringLiteral( "prefix" ) );
    }

    /**
      Get Suffix
    */
    static
    QString suffix()
    {
      return self()->mSuffix;
    }

    /**
      Is Suffix Immutable
    */
    static
    bool isSuffixImmutable()
    {
      return self()->isImmutable( QStringLiteral( "suffix" ) );
    }

    /**
      Get lastfilepath
    */
    static
    QString lastfilepath()
    {
      return self()->mLastfilepath;
    }

    /**
      Is lastfilepath Immutable
    */
    static
    bool isLastfilepathImmutable()
    {
      return self()->isImmutable( QStringLiteral( "lastfilepath" ) );
    }

  protected:
    skgfile_settings();
    friend class skgfile_settingsHelper;


    // File
    bool mOpenlastfile;
    bool mSaveonclose;
    bool mStoreInKdeWallet;
    QString mSelectedWallet;
    bool mBackup_enabled;
    QString mPrefix;
    QString mSuffix;
    QString mLastfilepath;
};

#endif

