// This file is generated by kconfig_compiler_kf6 from skgassistant_settings.kcfg.
// All changes you do to this file will be lost.
#ifndef SKGASSISTANT_SETTINGS_H
#define SKGASSISTANT_SETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class skgassistant_settings : public KConfigSkeleton
{
  public:

    static skgassistant_settings *self();
    ~skgassistant_settings() override;

    /**
      Get serverUrl
    */
    static
    QString serverUrl()
    {
      return self()->mServerUrl;
    }

    /**
      Is serverUrl Immutable
    */
    static
    bool isServerUrlImmutable()
    {
      return self()->isImmutable( QStringLiteral( "serverUrl" ) );
    }

    /**
      Get apiToken
    */
    static
    QString apiToken()
    {
      return self()->mApiToken;
    }

    /**
      Is apiToken Immutable
    */
    static
    bool isApiTokenImmutable()
    {
      return self()->isImmutable( QStringLiteral( "apiToken" ) );
    }

    /**
      Get enableWebSearch
    */
    static
    bool enableWebSearch()
    {
      return self()->mEnableWebSearch;
    }

    /**
      Is enableWebSearch Immutable
    */
    static
    bool isEnableWebSearchImmutable()
    {
      return self()->isImmutable( QStringLiteral( "enableWebSearch" ) );
    }

    /**
      Get Family Situation
    */
    static
    QString familySituation()
    {
      return self()->mFamilySituation;
    }

    /**
      Is Family Situation Immutable
    */
    static
    bool isFamilySituationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "familySituation" ) );
    }

  protected:
    skgassistant_settings();
    friend class skgassistant_settingsHelper;


    // skrooge_aiassistant
    QString mServerUrl;
    QString mApiToken;
    bool mEnableWebSearch;
    QString mFamilySituation;
};

#endif

