/********************************************************************************
** Form generated from reading UI file 'skgoperationpluginwidget_base.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGOPERATIONPLUGINWIDGET_BASE_H
#define UI_SKGOPERATIONPLUGINWIDGET_BASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "ktitlewidget.h"
#include "skgcalculatoredit.h"
#include "skgcombobox.h"
#include "skgdateedit.h"
#include "skgfilteredtableview.h"
#include "skgtablewidget.h"
#include "skgunitcombobox.h"
#include "skgwidgetselector.h"

QT_BEGIN_NAMESPACE

class Ui_skgoperationplugin_base
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_5;
    KTitleWidget *kTitle;
    SKGFilteredTableView *kOperationView;
    QFrame *kReconciliatorFrame;
    QHBoxLayout *horizontalLayout_6;
    QVBoxLayout *verticalLayout_4;
    QFrame *kReconciliatorFrame2;
    QHBoxLayout *horizontalLayout_9;
    QSpacerItem *horizontalSpacer_3;
    QLabel *kReconciliationTitle;
    SKGCalculatorEdit *kReconcilitorAmountEdit;
    QLabel *kReconciliatorInfo;
    QToolButton *kCreateFakeOperation;
    SKGComboBox *kReconciliateAccount;
    QToolButton *kValidate;
    QToolButton *kAutoPoint;
    QLabel *kInfo;
    QToolButton *kReconciliatorButton;
    QFrame *line;
    QWidget *horizontalWidget_3;
    QGridLayout *gridLayout_6;
    QWidget *SKGBasicSection;
    QGridLayout *gridLayout_5;
    QLabel *kAccountLabel2;
    SKGComboBox *kAccountEdit;
    QLabel *kDateLabel;
    SKGDateEdit *kDateEdit;
    QLabel *kAmountLabel;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout_11;
    SKGCalculatorEdit *kAmountEdit;
    SKGUnitComboBox *kUnitEdit;
    QWidget *SKGPayeeModeSection;
    QGridLayout *gridLayout_2;
    QLabel *kPayeeLabel;
    SKGComboBox *kPayeeEdit;
    QLabel *kTypeLabel;
    QHBoxLayout *horizontalLayout_13;
    SKGComboBox *kTypeEdit;
    QLineEdit *kNumberEdit;
    QSpacerItem *verticalSpacer_2;
    SKGComboBox *kTargetAccountEdit;
    QLabel *kTargetAccountLabel;
    QLabel *kCommentLabel;
    SKGComboBox *kCommentEdit;
    QWidget *SKGSingleOpSection;
    QGridLayout *gridLayout_3;
    QLabel *kCategoryLabel;
    SKGComboBox *kCategoryEdit;
    QLabel *kTrackerLabel;
    SKGComboBox *kTrackerEdit;
    QSpacerItem *verticalSpacer_3;
    QWidget *SKGSharesSection;
    QGridLayout *gridLayout_4;
    QLabel *kAccountLabel3_2;
    QLabel *kAmountSharesLabel;
    SKGCalculatorEdit *kAmountSharesEdit;
    QLabel *kCommissionLabel;
    SKGCalculatorEdit *kCommissionEdit;
    QLabel *kTaxLabel;
    SKGCalculatorEdit *kTaxEdit;
    QLabel *kTotalLabel;
    QSpacerItem *verticalSpacer_4;
    QLabel *kUnitCommission;
    QLabel *kUnitTax;
    SKGUnitComboBox *kUnitShare;
    SKGComboBox *kPaymentAccountEdit;
    QLabel *KTotal;
    QWidget *SKGSmallButtons;
    QGridLayout *gridLayout;
    QToolButton *kFreezeBtn;
    QPushButton *kCleanBtn;
    QSpacerItem *verticalSpacer_5;
    QPushButton *kFastEditBtn;
    QFrame *SKGSplitOpSection;
    QVBoxLayout *verticalLayout_2;
    SKGTableWidget *kSubOperationsTable;
    QHBoxLayout *horizontalLayout_12;
    SKGWidgetSelector *kWidgetSelector;
    QWidget *SKGEditionButtonsWidget;
    QHBoxLayout *horizontalLayout;
    QPushButton *kAddOperationBtn;
    QPushButton *kModifyOperationBtn;

    void setupUi(QWidget *skgoperationplugin_base)
    {
        if (skgoperationplugin_base->objectName().isEmpty())
            skgoperationplugin_base->setObjectName("skgoperationplugin_base");
        skgoperationplugin_base->resize(1369, 660);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(skgoperationplugin_base->sizePolicy().hasHeightForWidth());
        skgoperationplugin_base->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(skgoperationplugin_base);
        verticalLayout->setSpacing(2);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setSpacing(2);
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        kTitle = new KTitleWidget(skgoperationplugin_base);
        kTitle->setObjectName("kTitle");
        kTitle->setMaximumSize(QSize(16777215, 80));

        horizontalLayout_5->addWidget(kTitle);


        verticalLayout->addLayout(horizontalLayout_5);

        kOperationView = new SKGFilteredTableView(skgoperationplugin_base);
        kOperationView->setObjectName("kOperationView");
        kOperationView->setFocusPolicy(Qt::StrongFocus);
        kOperationView->setAcceptDrops(true);
        kOperationView->setProperty("dragEnabled", QVariant(true));
        kOperationView->setProperty("alternatingRowColors", QVariant(true));
        kOperationView->setProperty("sortingEnabled", QVariant(true));
        kOperationView->setProperty("wordWrap", QVariant(false));

        verticalLayout->addWidget(kOperationView);

        kReconciliatorFrame = new QFrame(skgoperationplugin_base);
        kReconciliatorFrame->setObjectName("kReconciliatorFrame");
        kReconciliatorFrame->setFrameShape(QFrame::NoFrame);
        kReconciliatorFrame->setFrameShadow(QFrame::Raised);
        horizontalLayout_6 = new QHBoxLayout(kReconciliatorFrame);
        horizontalLayout_6->setSpacing(2);
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        horizontalLayout_6->setContentsMargins(0, 0, 0, 0);
        verticalLayout_4 = new QVBoxLayout();
        verticalLayout_4->setSpacing(2);
        verticalLayout_4->setObjectName("verticalLayout_4");
        kReconciliatorFrame2 = new QFrame(kReconciliatorFrame);
        kReconciliatorFrame2->setObjectName("kReconciliatorFrame2");
        kReconciliatorFrame2->setFrameShape(QFrame::NoFrame);
        kReconciliatorFrame2->setFrameShadow(QFrame::Raised);
        horizontalLayout_9 = new QHBoxLayout(kReconciliatorFrame2);
        horizontalLayout_9->setSpacing(2);
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        horizontalLayout_9->setContentsMargins(0, 0, 0, 0);
        horizontalSpacer_3 = new QSpacerItem(0, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_9->addItem(horizontalSpacer_3);

        kReconciliationTitle = new QLabel(kReconciliatorFrame2);
        kReconciliationTitle->setObjectName("kReconciliationTitle");
        kReconciliationTitle->setText(QString::fromUtf8("Final &balance:"));

        horizontalLayout_9->addWidget(kReconciliationTitle);

        kReconcilitorAmountEdit = new SKGCalculatorEdit(kReconciliatorFrame2);
        kReconcilitorAmountEdit->setObjectName("kReconcilitorAmountEdit");
        kReconcilitorAmountEdit->setEnabled(true);
        kReconcilitorAmountEdit->setMaximumSize(QSize(100, 16777215));
        kReconcilitorAmountEdit->setFocusPolicy(Qt::ClickFocus);
        kReconcilitorAmountEdit->setMode(SKGCalculatorEdit::EXPRESSION);

        horizontalLayout_9->addWidget(kReconcilitorAmountEdit);

        kReconciliatorInfo = new QLabel(kReconciliatorFrame2);
        kReconciliatorInfo->setObjectName("kReconciliatorInfo");

        horizontalLayout_9->addWidget(kReconciliatorInfo);

        kCreateFakeOperation = new QToolButton(kReconciliatorFrame2);
        kCreateFakeOperation->setObjectName("kCreateFakeOperation");
        kCreateFakeOperation->setMaximumSize(QSize(22, 22));
        kCreateFakeOperation->setFocusPolicy(Qt::NoFocus);
        kCreateFakeOperation->setAutoRaise(true);

        horizontalLayout_9->addWidget(kCreateFakeOperation);

        kReconciliateAccount = new SKGComboBox(kReconciliatorFrame2);
        kReconciliateAccount->setObjectName("kReconciliateAccount");
        kReconciliateAccount->setFocusPolicy(Qt::ClickFocus);
        kReconciliateAccount->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        horizontalLayout_9->addWidget(kReconciliateAccount);

        kValidate = new QToolButton(kReconciliatorFrame2);
        kValidate->setObjectName("kValidate");
        kValidate->setFocusPolicy(Qt::NoFocus);
        kValidate->setAutoRaise(true);

        horizontalLayout_9->addWidget(kValidate);

        kAutoPoint = new QToolButton(kReconciliatorFrame2);
        kAutoPoint->setObjectName("kAutoPoint");
        kAutoPoint->setMaximumSize(QSize(22, 22));
        kAutoPoint->setFocusPolicy(Qt::NoFocus);
        kAutoPoint->setAutoRaise(true);

        horizontalLayout_9->addWidget(kAutoPoint);


        verticalLayout_4->addWidget(kReconciliatorFrame2);

        kInfo = new QLabel(kReconciliatorFrame);
        kInfo->setObjectName("kInfo");
        kInfo->setText(QString::fromUtf8("Computing\342\200\246"));
        kInfo->setScaledContents(true);
        kInfo->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        verticalLayout_4->addWidget(kInfo);


        horizontalLayout_6->addLayout(verticalLayout_4);

        kReconciliatorButton = new QToolButton(kReconciliatorFrame);
        kReconciliatorButton->setObjectName("kReconciliatorButton");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(kReconciliatorButton->sizePolicy().hasHeightForWidth());
        kReconciliatorButton->setSizePolicy(sizePolicy1);
        kReconciliatorButton->setMinimumSize(QSize(0, 0));
        kReconciliatorButton->setMaximumSize(QSize(22, 22));
        kReconciliatorButton->setFocusPolicy(Qt::NoFocus);
        kReconciliatorButton->setAutoRaise(true);

        horizontalLayout_6->addWidget(kReconciliatorButton);


        verticalLayout->addWidget(kReconciliatorFrame);

        line = new QFrame(skgoperationplugin_base);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        horizontalWidget_3 = new QWidget(skgoperationplugin_base);
        horizontalWidget_3->setObjectName("horizontalWidget_3");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Maximum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(horizontalWidget_3->sizePolicy().hasHeightForWidth());
        horizontalWidget_3->setSizePolicy(sizePolicy2);
        gridLayout_6 = new QGridLayout(horizontalWidget_3);
        gridLayout_6->setObjectName("gridLayout_6");
        gridLayout_6->setContentsMargins(0, 0, 0, 0);
        SKGBasicSection = new QWidget(horizontalWidget_3);
        SKGBasicSection->setObjectName("SKGBasicSection");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(SKGBasicSection->sizePolicy().hasHeightForWidth());
        SKGBasicSection->setSizePolicy(sizePolicy3);
        gridLayout_5 = new QGridLayout(SKGBasicSection);
        gridLayout_5->setSpacing(2);
        gridLayout_5->setObjectName("gridLayout_5");
        gridLayout_5->setContentsMargins(0, 0, 0, 0);
        kAccountLabel2 = new QLabel(SKGBasicSection);
        kAccountLabel2->setObjectName("kAccountLabel2");
        QFont font;
        font.setBold(true);
        kAccountLabel2->setFont(font);
        kAccountLabel2->setText(QString::fromUtf8("&Title:"));
        kAccountLabel2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_5->addWidget(kAccountLabel2, 0, 0, 1, 1);

        kAccountEdit = new SKGComboBox(SKGBasicSection);
        kAccountEdit->setObjectName("kAccountEdit");
        kAccountEdit->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        gridLayout_5->addWidget(kAccountEdit, 0, 1, 1, 1);

        kDateLabel = new QLabel(SKGBasicSection);
        kDateLabel->setObjectName("kDateLabel");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(kDateLabel->sizePolicy().hasHeightForWidth());
        kDateLabel->setSizePolicy(sizePolicy4);
        kDateLabel->setFont(font);
        kDateLabel->setText(QString::fromUtf8("Title:"));
        kDateLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_5->addWidget(kDateLabel, 1, 0, 1, 1);

        kDateEdit = new SKGDateEdit(SKGBasicSection);
        kDateEdit->setObjectName("kDateEdit");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(kDateEdit->sizePolicy().hasHeightForWidth());
        kDateEdit->setSizePolicy(sizePolicy5);
        kDateEdit->setMinimumSize(QSize(120, 0));
        kDateEdit->setMode(SKGDateEdit::PREVIOUS);

        gridLayout_5->addWidget(kDateEdit, 1, 1, 1, 1);

        kAmountLabel = new QLabel(SKGBasicSection);
        kAmountLabel->setObjectName("kAmountLabel");
        sizePolicy4.setHeightForWidth(kAmountLabel->sizePolicy().hasHeightForWidth());
        kAmountLabel->setSizePolicy(sizePolicy4);
        kAmountLabel->setFont(font);
        kAmountLabel->setText(QString::fromUtf8("Title:"));
        kAmountLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_5->addWidget(kAmountLabel, 2, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_5->addItem(verticalSpacer, 3, 0, 1, 1);

        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setSpacing(2);
        horizontalLayout_11->setObjectName("horizontalLayout_11");
        kAmountEdit = new SKGCalculatorEdit(SKGBasicSection);
        kAmountEdit->setObjectName("kAmountEdit");
        kAmountEdit->setMode(SKGCalculatorEdit::EXPRESSION);

        horizontalLayout_11->addWidget(kAmountEdit);

        kUnitEdit = new SKGUnitComboBox(SKGBasicSection);
        kUnitEdit->setObjectName("kUnitEdit");
        QSizePolicy sizePolicy6(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Fixed);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(0);
        sizePolicy6.setHeightForWidth(kUnitEdit->sizePolicy().hasHeightForWidth());
        kUnitEdit->setSizePolicy(sizePolicy6);
        kUnitEdit->setMinimumSize(QSize(100, 0));
        kUnitEdit->setMaximumSize(QSize(100, 16777215));
        kUnitEdit->setEditable(true);
        kUnitEdit->setSizeAdjustPolicy(QComboBox::AdjustToContents);
        kUnitEdit->setAutoCompletion(false);

        horizontalLayout_11->addWidget(kUnitEdit);


        gridLayout_5->addLayout(horizontalLayout_11, 2, 1, 1, 1);


        gridLayout_6->addWidget(SKGBasicSection, 0, 0, 1, 1);

        SKGPayeeModeSection = new QWidget(horizontalWidget_3);
        SKGPayeeModeSection->setObjectName("SKGPayeeModeSection");
        QSizePolicy sizePolicy7(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy7.setHorizontalStretch(0);
        sizePolicy7.setVerticalStretch(0);
        sizePolicy7.setHeightForWidth(SKGPayeeModeSection->sizePolicy().hasHeightForWidth());
        SKGPayeeModeSection->setSizePolicy(sizePolicy7);
        gridLayout_2 = new QGridLayout(SKGPayeeModeSection);
        gridLayout_2->setSpacing(2);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(0, 0, 0, 0);
        kPayeeLabel = new QLabel(SKGPayeeModeSection);
        kPayeeLabel->setObjectName("kPayeeLabel");
        kPayeeLabel->setText(QString::fromUtf8("Title:"));
        kPayeeLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(kPayeeLabel, 2, 0, 1, 1);

        kPayeeEdit = new SKGComboBox(SKGPayeeModeSection);
        kPayeeEdit->setObjectName("kPayeeEdit");
        QSizePolicy sizePolicy8(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy8.setHorizontalStretch(0);
        sizePolicy8.setVerticalStretch(0);
        sizePolicy8.setHeightForWidth(kPayeeEdit->sizePolicy().hasHeightForWidth());
        kPayeeEdit->setSizePolicy(sizePolicy8);
        kPayeeEdit->setEditable(true);
        kPayeeEdit->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);

        gridLayout_2->addWidget(kPayeeEdit, 2, 1, 1, 1);

        kTypeLabel = new QLabel(SKGPayeeModeSection);
        kTypeLabel->setObjectName("kTypeLabel");
        kTypeLabel->setText(QString::fromUtf8("Title:"));
        kTypeLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(kTypeLabel, 4, 0, 1, 1);

        horizontalLayout_13 = new QHBoxLayout();
        horizontalLayout_13->setSpacing(2);
        horizontalLayout_13->setObjectName("horizontalLayout_13");
        kTypeEdit = new SKGComboBox(SKGPayeeModeSection);
        kTypeEdit->setObjectName("kTypeEdit");
        kTypeEdit->setMinimumSize(QSize(100, 0));
        kTypeEdit->setEditable(true);
        kTypeEdit->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);
        kTypeEdit->setAutoCompletion(false);

        horizontalLayout_13->addWidget(kTypeEdit);

        kNumberEdit = new QLineEdit(SKGPayeeModeSection);
        kNumberEdit->setObjectName("kNumberEdit");
        QSizePolicy sizePolicy9(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy9.setHorizontalStretch(0);
        sizePolicy9.setVerticalStretch(0);
        sizePolicy9.setHeightForWidth(kNumberEdit->sizePolicy().hasHeightForWidth());
        kNumberEdit->setSizePolicy(sizePolicy9);
        kNumberEdit->setAcceptDrops(false);
        kNumberEdit->setProperty("showClearButton", QVariant(true));

        horizontalLayout_13->addWidget(kNumberEdit);


        gridLayout_2->addLayout(horizontalLayout_13, 4, 1, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer_2, 7, 0, 1, 1);

        kTargetAccountEdit = new SKGComboBox(SKGPayeeModeSection);
        kTargetAccountEdit->setObjectName("kTargetAccountEdit");
        sizePolicy8.setHeightForWidth(kTargetAccountEdit->sizePolicy().hasHeightForWidth());
        kTargetAccountEdit->setSizePolicy(sizePolicy8);
        kTargetAccountEdit->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        gridLayout_2->addWidget(kTargetAccountEdit, 0, 1, 1, 1);

        kTargetAccountLabel = new QLabel(SKGPayeeModeSection);
        kTargetAccountLabel->setObjectName("kTargetAccountLabel");
        kTargetAccountLabel->setFont(font);
        kTargetAccountLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(kTargetAccountLabel, 0, 0, 1, 1);

        kCommentLabel = new QLabel(SKGPayeeModeSection);
        kCommentLabel->setObjectName("kCommentLabel");
        sizePolicy4.setHeightForWidth(kCommentLabel->sizePolicy().hasHeightForWidth());
        kCommentLabel->setSizePolicy(sizePolicy4);
        kCommentLabel->setText(QString::fromUtf8("Title:"));
        kCommentLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(kCommentLabel, 5, 0, 1, 1);

        kCommentEdit = new SKGComboBox(SKGPayeeModeSection);
        kCommentEdit->setObjectName("kCommentEdit");
        sizePolicy8.setHeightForWidth(kCommentEdit->sizePolicy().hasHeightForWidth());
        kCommentEdit->setSizePolicy(sizePolicy8);
        kCommentEdit->setEditable(true);
        kCommentEdit->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);
        kCommentEdit->setProperty("showClearButton", QVariant(false));

        gridLayout_2->addWidget(kCommentEdit, 5, 1, 1, 1);


        gridLayout_6->addWidget(SKGPayeeModeSection, 0, 1, 1, 1);

        SKGSingleOpSection = new QWidget(horizontalWidget_3);
        SKGSingleOpSection->setObjectName("SKGSingleOpSection");
        sizePolicy7.setHeightForWidth(SKGSingleOpSection->sizePolicy().hasHeightForWidth());
        SKGSingleOpSection->setSizePolicy(sizePolicy7);
        gridLayout_3 = new QGridLayout(SKGSingleOpSection);
        gridLayout_3->setSpacing(2);
        gridLayout_3->setObjectName("gridLayout_3");
        gridLayout_3->setContentsMargins(0, 0, 0, 0);
        kCategoryLabel = new QLabel(SKGSingleOpSection);
        kCategoryLabel->setObjectName("kCategoryLabel");
        sizePolicy4.setHeightForWidth(kCategoryLabel->sizePolicy().hasHeightForWidth());
        kCategoryLabel->setSizePolicy(sizePolicy4);
        kCategoryLabel->setText(QString::fromUtf8("Title:"));
        kCategoryLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(kCategoryLabel, 0, 0, 1, 1);

        kCategoryEdit = new SKGComboBox(SKGSingleOpSection);
        kCategoryEdit->setObjectName("kCategoryEdit");
        sizePolicy8.setHeightForWidth(kCategoryEdit->sizePolicy().hasHeightForWidth());
        kCategoryEdit->setSizePolicy(sizePolicy8);
        kCategoryEdit->setMinimumSize(QSize(200, 0));
        kCategoryEdit->setEditable(true);
        kCategoryEdit->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);

        gridLayout_3->addWidget(kCategoryEdit, 0, 1, 1, 1);

        kTrackerLabel = new QLabel(SKGSingleOpSection);
        kTrackerLabel->setObjectName("kTrackerLabel");
        kTrackerLabel->setText(QString::fromUtf8("Title:"));
        kTrackerLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(kTrackerLabel, 2, 0, 1, 1);

        kTrackerEdit = new SKGComboBox(SKGSingleOpSection);
        kTrackerEdit->setObjectName("kTrackerEdit");
        sizePolicy8.setHeightForWidth(kTrackerEdit->sizePolicy().hasHeightForWidth());
        kTrackerEdit->setSizePolicy(sizePolicy8);
        kTrackerEdit->setEditable(true);
        kTrackerEdit->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);

        gridLayout_3->addWidget(kTrackerEdit, 2, 1, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_3->addItem(verticalSpacer_3, 5, 0, 1, 1);


        gridLayout_6->addWidget(SKGSingleOpSection, 0, 2, 1, 1);

        SKGSharesSection = new QWidget(horizontalWidget_3);
        SKGSharesSection->setObjectName("SKGSharesSection");
        gridLayout_4 = new QGridLayout(SKGSharesSection);
        gridLayout_4->setSpacing(2);
        gridLayout_4->setObjectName("gridLayout_4");
        gridLayout_4->setContentsMargins(0, 0, 0, 0);
        kAccountLabel3_2 = new QLabel(SKGSharesSection);
        kAccountLabel3_2->setObjectName("kAccountLabel3_2");
        sizePolicy1.setHeightForWidth(kAccountLabel3_2->sizePolicy().hasHeightForWidth());
        kAccountLabel3_2->setSizePolicy(sizePolicy1);
        kAccountLabel3_2->setFont(font);

        gridLayout_4->addWidget(kAccountLabel3_2, 0, 0, 1, 1);

        kAmountSharesLabel = new QLabel(SKGSharesSection);
        kAmountSharesLabel->setObjectName("kAmountSharesLabel");
        kAmountSharesLabel->setFont(font);
        kAmountSharesLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_4->addWidget(kAmountSharesLabel, 1, 0, 1, 1);

        kAmountSharesEdit = new SKGCalculatorEdit(SKGSharesSection);
        kAmountSharesEdit->setObjectName("kAmountSharesEdit");
        kAmountSharesEdit->setMode(SKGCalculatorEdit::EXPRESSION);

        gridLayout_4->addWidget(kAmountSharesEdit, 1, 1, 1, 1);

        kCommissionLabel = new QLabel(SKGSharesSection);
        kCommissionLabel->setObjectName("kCommissionLabel");
        kCommissionLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_4->addWidget(kCommissionLabel, 2, 0, 1, 1);

        kCommissionEdit = new SKGCalculatorEdit(SKGSharesSection);
        kCommissionEdit->setObjectName("kCommissionEdit");
        kCommissionEdit->setMode(SKGCalculatorEdit::EXPRESSION);

        gridLayout_4->addWidget(kCommissionEdit, 2, 1, 1, 1);

        kTaxLabel = new QLabel(SKGSharesSection);
        kTaxLabel->setObjectName("kTaxLabel");
        kTaxLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_4->addWidget(kTaxLabel, 3, 0, 1, 1);

        kTaxEdit = new SKGCalculatorEdit(SKGSharesSection);
        kTaxEdit->setObjectName("kTaxEdit");
        kTaxEdit->setMode(SKGCalculatorEdit::EXPRESSION);

        gridLayout_4->addWidget(kTaxEdit, 3, 1, 1, 1);

        kTotalLabel = new QLabel(SKGSharesSection);
        kTotalLabel->setObjectName("kTotalLabel");
        kTotalLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_4->addWidget(kTotalLabel, 4, 0, 1, 1);

        verticalSpacer_4 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_4->addItem(verticalSpacer_4, 5, 0, 1, 1);

        kUnitCommission = new QLabel(SKGSharesSection);
        kUnitCommission->setObjectName("kUnitCommission");
        sizePolicy4.setHeightForWidth(kUnitCommission->sizePolicy().hasHeightForWidth());
        kUnitCommission->setSizePolicy(sizePolicy4);
        kUnitCommission->setFont(font);
        kUnitCommission->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_4->addWidget(kUnitCommission, 2, 2, 1, 2);

        kUnitTax = new QLabel(SKGSharesSection);
        kUnitTax->setObjectName("kUnitTax");
        sizePolicy4.setHeightForWidth(kUnitTax->sizePolicy().hasHeightForWidth());
        kUnitTax->setSizePolicy(sizePolicy4);
        kUnitTax->setFont(font);
        kUnitTax->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_4->addWidget(kUnitTax, 3, 2, 1, 2);

        kUnitShare = new SKGUnitComboBox(SKGSharesSection);
        kUnitShare->setObjectName("kUnitShare");

        gridLayout_4->addWidget(kUnitShare, 1, 2, 1, 1);

        kPaymentAccountEdit = new SKGComboBox(SKGSharesSection);
        kPaymentAccountEdit->setObjectName("kPaymentAccountEdit");
        kPaymentAccountEdit->setSizeAdjustPolicy(QComboBox::AdjustToContents);
        kPaymentAccountEdit->setFrame(true);
        kPaymentAccountEdit->setAutoCompletion(false);

        gridLayout_4->addWidget(kPaymentAccountEdit, 0, 1, 1, 2);

        KTotal = new QLabel(SKGSharesSection);
        KTotal->setObjectName("KTotal");
        KTotal->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_4->addWidget(KTotal, 4, 1, 1, 2);


        gridLayout_6->addWidget(SKGSharesSection, 0, 3, 1, 1);

        SKGSmallButtons = new QWidget(horizontalWidget_3);
        SKGSmallButtons->setObjectName("SKGSmallButtons");
        gridLayout = new QGridLayout(SKGSmallButtons);
        gridLayout->setSpacing(2);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(10, 0, 0, 0);
        kFreezeBtn = new QToolButton(SKGSmallButtons);
        kFreezeBtn->setObjectName("kFreezeBtn");
        kFreezeBtn->setMaximumSize(QSize(48, 48));
        kFreezeBtn->setFocusPolicy(Qt::NoFocus);
        kFreezeBtn->setText(QString::fromUtf8(""));
        kFreezeBtn->setCheckable(true);
        kFreezeBtn->setChecked(false);

        gridLayout->addWidget(kFreezeBtn, 0, 0, 1, 1);

        kCleanBtn = new QPushButton(SKGSmallButtons);
        kCleanBtn->setObjectName("kCleanBtn");
        kCleanBtn->setMaximumSize(QSize(48, 48));
        kCleanBtn->setFocusPolicy(Qt::NoFocus);
        kCleanBtn->setText(QString::fromUtf8(""));

        gridLayout->addWidget(kCleanBtn, 2, 0, 1, 1);

        verticalSpacer_5 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_5, 4, 0, 1, 1);

        kFastEditBtn = new QPushButton(SKGSmallButtons);
        kFastEditBtn->setObjectName("kFastEditBtn");
        kFastEditBtn->setMaximumSize(QSize(48, 48));
        kFastEditBtn->setFocusPolicy(Qt::NoFocus);
        kFastEditBtn->setText(QString::fromUtf8(""));

        gridLayout->addWidget(kFastEditBtn, 1, 0, 1, 1);


        gridLayout_6->addWidget(SKGSmallButtons, 0, 4, 1, 1);


        verticalLayout->addWidget(horizontalWidget_3);

        SKGSplitOpSection = new QFrame(skgoperationplugin_base);
        SKGSplitOpSection->setObjectName("SKGSplitOpSection");
        sizePolicy9.setHeightForWidth(SKGSplitOpSection->sizePolicy().hasHeightForWidth());
        SKGSplitOpSection->setSizePolicy(sizePolicy9);
        SKGSplitOpSection->setMinimumSize(QSize(0, 100));
        verticalLayout_2 = new QVBoxLayout(SKGSplitOpSection);
        verticalLayout_2->setSpacing(0);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, -1, 0);
        kSubOperationsTable = new SKGTableWidget(SKGSplitOpSection);
        kSubOperationsTable->setObjectName("kSubOperationsTable");
        kSubOperationsTable->setMaximumSize(QSize(16777215, 150));
        kSubOperationsTable->setEditTriggers(QAbstractItemView::AnyKeyPressed|QAbstractItemView::DoubleClicked|QAbstractItemView::EditKeyPressed|QAbstractItemView::SelectedClicked);
        kSubOperationsTable->setAlternatingRowColors(true);
        kSubOperationsTable->setSelectionBehavior(QAbstractItemView::SelectRows);
        kSubOperationsTable->setShowGrid(false);
        kSubOperationsTable->horizontalHeader()->setStretchLastSection(true);

        verticalLayout_2->addWidget(kSubOperationsTable);


        verticalLayout->addWidget(SKGSplitOpSection);

        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setSpacing(2);
        horizontalLayout_12->setObjectName("horizontalLayout_12");
        kWidgetSelector = new SKGWidgetSelector(skgoperationplugin_base);
        kWidgetSelector->setObjectName("kWidgetSelector");

        horizontalLayout_12->addWidget(kWidgetSelector);

        SKGEditionButtonsWidget = new QWidget(skgoperationplugin_base);
        SKGEditionButtonsWidget->setObjectName("SKGEditionButtonsWidget");
        horizontalLayout = new QHBoxLayout(SKGEditionButtonsWidget);
        horizontalLayout->setSpacing(2);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        kAddOperationBtn = new QPushButton(SKGEditionButtonsWidget);
        kAddOperationBtn->setObjectName("kAddOperationBtn");
        kAddOperationBtn->setEnabled(false);
        QSizePolicy sizePolicy10(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy10.setHorizontalStretch(0);
        sizePolicy10.setVerticalStretch(0);
        sizePolicy10.setHeightForWidth(kAddOperationBtn->sizePolicy().hasHeightForWidth());
        kAddOperationBtn->setSizePolicy(sizePolicy10);

        horizontalLayout->addWidget(kAddOperationBtn);

        kModifyOperationBtn = new QPushButton(SKGEditionButtonsWidget);
        kModifyOperationBtn->setObjectName("kModifyOperationBtn");
        kModifyOperationBtn->setEnabled(false);

        horizontalLayout->addWidget(kModifyOperationBtn);


        horizontalLayout_12->addWidget(SKGEditionButtonsWidget);


        verticalLayout->addLayout(horizontalLayout_12);

#if QT_CONFIG(shortcut)
        kReconciliationTitle->setBuddy(kReconcilitorAmountEdit);
        kAccountLabel2->setBuddy(kAccountEdit);
        kDateLabel->setBuddy(kDateEdit);
        kAmountLabel->setBuddy(kAmountEdit);
        kPayeeLabel->setBuddy(kPayeeEdit);
        kTypeLabel->setBuddy(kTypeEdit);
        kTargetAccountLabel->setBuddy(kTargetAccountEdit);
        kCommentLabel->setBuddy(kCommentEdit);
        kCategoryLabel->setBuddy(kCategoryEdit);
        kTrackerLabel->setBuddy(kTrackerEdit);
        kAccountLabel3_2->setBuddy(kPaymentAccountEdit);
        kAmountSharesLabel->setBuddy(kAmountSharesEdit);
        kCommissionLabel->setBuddy(kCommissionEdit);
        kTaxLabel->setBuddy(kTaxEdit);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kOperationView, kAccountEdit);
        QWidget::setTabOrder(kAccountEdit, kDateEdit);
        QWidget::setTabOrder(kDateEdit, kAmountEdit);
        QWidget::setTabOrder(kAmountEdit, kUnitEdit);
        QWidget::setTabOrder(kUnitEdit, kTargetAccountEdit);
        QWidget::setTabOrder(kTargetAccountEdit, kPayeeEdit);
        QWidget::setTabOrder(kPayeeEdit, kTypeEdit);
        QWidget::setTabOrder(kTypeEdit, kNumberEdit);
        QWidget::setTabOrder(kNumberEdit, kCommentEdit);
        QWidget::setTabOrder(kCommentEdit, kCategoryEdit);
        QWidget::setTabOrder(kCategoryEdit, kTrackerEdit);
        QWidget::setTabOrder(kTrackerEdit, kPaymentAccountEdit);
        QWidget::setTabOrder(kPaymentAccountEdit, kAmountSharesEdit);
        QWidget::setTabOrder(kAmountSharesEdit, kCommissionEdit);
        QWidget::setTabOrder(kCommissionEdit, kTaxEdit);
        QWidget::setTabOrder(kTaxEdit, kReconcilitorAmountEdit);
        QWidget::setTabOrder(kReconcilitorAmountEdit, kReconciliateAccount);
        QWidget::setTabOrder(kReconciliateAccount, kAddOperationBtn);
        QWidget::setTabOrder(kAddOperationBtn, kModifyOperationBtn);
        QWidget::setTabOrder(kModifyOperationBtn, kSubOperationsTable);

        retranslateUi(skgoperationplugin_base);

        QMetaObject::connectSlotsByName(skgoperationplugin_base);
    } // setupUi

    void retranslateUi(QWidget *skgoperationplugin_base)
    {
#if QT_CONFIG(tooltip)
        kOperationView->setToolTip(tr2i18n("list of transactions", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kOperationView->setStatusTip(tr2i18n("list of transactions", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kReconcilitorAmountEdit->setToolTip(tr2i18n("Last balance on your account record", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kReconcilitorAmountEdit->setStatusTip(tr2i18n("Last balance on your account record", nullptr));
#endif // QT_CONFIG(statustip)
        kReconciliatorInfo->setText(QString());
#if QT_CONFIG(tooltip)
        kCreateFakeOperation->setToolTip(tr2i18n("Create fake transaction", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kCreateFakeOperation->setStatusTip(tr2i18n("Create fake transaction", nullptr));
#endif // QT_CONFIG(statustip)
        kCreateFakeOperation->setText(QString());
#if QT_CONFIG(tooltip)
        kReconciliateAccount->setToolTip(tr2i18n("Account linked to the card, where to transfer the marked transactions", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kReconciliateAccount->setStatusTip(tr2i18n("Account linked to the card, where to transfer the marked transactions", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kValidate->setToolTip(tr2i18n("Validate marked transactions", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kValidate->setStatusTip(tr2i18n("Validate marked transactions", nullptr));
#endif // QT_CONFIG(statustip)
        kValidate->setText(QString());
#if QT_CONFIG(tooltip)
        kAutoPoint->setToolTip(tr2i18n("Auto mark all imported transactions", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kAutoPoint->setStatusTip(tr2i18n("Auto mark all imported transactions", nullptr));
#endif // QT_CONFIG(statustip)
        kAutoPoint->setText(QString());
#if QT_CONFIG(tooltip)
        kReconciliatorButton->setToolTip(tr2i18n("Switch information", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kReconciliatorButton->setStatusTip(tr2i18n("Switch information", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kAccountEdit->setToolTip(tr2i18n("Account of the transaction", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kAccountEdit->setStatusTip(tr2i18n("Account of the transaction", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(statustip)
        kDateEdit->setStatusTip(tr2i18n("Date of the transaction", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kAmountEdit->setToolTip(tr2i18n("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"https://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Bitstream Vera Sans'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Amount of the transaction.</p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">You can enter expressions here, such as <span style=\" font-style:italic;\">3+4*2</span>, skrooge will compute the result (<span style=\" font-style:italic;\">11</span>)</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kAmountEdit->setStatusTip(tr2i18n("Amount of the transaction", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kUnitEdit->setToolTip(tr2i18n("Unit of the transaction", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kUnitEdit->setStatusTip(tr2i18n("Unit of the transaction", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kPayeeEdit->setToolTip(tr2i18n("Payee of the transaction", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kPayeeEdit->setStatusTip(tr2i18n("Payee of the transaction", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kTypeEdit->setToolTip(tr2i18n("Transaction mode (how you made the operation). \n"
"Examples: Credit Card, Check, Transfer\342\200\246\n"
"", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kTypeEdit->setStatusTip(tr2i18n("Transaction mode", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kNumberEdit->setToolTip(tr2i18n("Number of the transaction, for example the Check number, or a Transfer reference.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kNumberEdit->setStatusTip(tr2i18n("Number of the transaction", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kTargetAccountEdit->setToolTip(tr2i18n("Target account for this transfer", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kTargetAccountEdit->setStatusTip(tr2i18n("Target account for this transfer", nullptr));
#endif // QT_CONFIG(statustip)
        kTargetAccountLabel->setText(tr2i18n("To Account:", "as in \"make a money transfer from account A *to account* B\""));
#if QT_CONFIG(tooltip)
        kCommentEdit->setToolTip(tr2i18n("Comment of the transaction", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kCommentEdit->setStatusTip(tr2i18n("Comment of the transaction", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kCategoryEdit->setToolTip(tr2i18n("Category of the transaction.\n"
"Use  \" > \" as a separator between a category and a subcategory.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kCategoryEdit->setStatusTip(tr2i18n("Category of the transaction", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kTrackerEdit->setToolTip(tr2i18n("Tracker associated to this transaction", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kTrackerEdit->setStatusTip(tr2i18n("Tracker associated to this transaction", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(whatsthis)
        kTrackerEdit->setWhatsThis(tr2i18n("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"https://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Bitstream Vera Sans'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">A <span style=\" font-style:italic;\">Tracker</span> is a way to group some transactions together. For example, you may use it to follow refunds.</p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">You will find more information on this in the documentation in the chapter \"Trackers\".</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        kAccountLabel3_2->setText(tr2i18n("Account for pa&yment:", nullptr));
        kAmountSharesLabel->setText(tr2i18n("A&mount of shares:", nullptr));
#if QT_CONFIG(tooltip)
        kAmountSharesEdit->setToolTip(tr2i18n("Amount of shares", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kAmountSharesEdit->setStatusTip(tr2i18n("Amount of shares", nullptr));
#endif // QT_CONFIG(statustip)
        kCommissionLabel->setText(tr2i18n("+ Commission:", "Noun, a quantity of money taken by a financial institution to perform an operation"));
#if QT_CONFIG(tooltip)
        kCommissionEdit->setToolTip(tr2i18n("Amount of the commission", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kCommissionEdit->setStatusTip(tr2i18n("Amount of the commission", nullptr));
#endif // QT_CONFIG(statustip)
        kTaxLabel->setText(tr2i18n("+ Tax:", "Noun, Taxes applied on a financial operation"));
#if QT_CONFIG(tooltip)
        kTaxEdit->setToolTip(tr2i18n("Amount of the Tax", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kTaxEdit->setStatusTip(tr2i18n("Amount of the Tax", nullptr));
#endif // QT_CONFIG(statustip)
        kTotalLabel->setText(tr2i18n(" = Total:", "Noun, the numerical total of a sum of values"));
        kUnitCommission->setText(tr2i18n("$", nullptr));
        kUnitTax->setText(tr2i18n("$", nullptr));
#if QT_CONFIG(tooltip)
        kPaymentAccountEdit->setToolTip(tr2i18n("Payment account for bought share", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kPaymentAccountEdit->setStatusTip(tr2i18n("Payment account for bought share", nullptr));
#endif // QT_CONFIG(statustip)
        KTotal->setText(tr2i18n("$", nullptr));
#if QT_CONFIG(tooltip)
        kFreezeBtn->setToolTip(tr2i18n("Freeze / unfreeze fields", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kFreezeBtn->setStatusTip(tr2i18n("Freeze / unfreeze fields", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kCleanBtn->setToolTip(tr2i18n("Clean editor", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kCleanBtn->setStatusTip(tr2i18n("Clean editor", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kFastEditBtn->setToolTip(tr2i18n("Fast edition", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kFastEditBtn->setStatusTip(tr2i18n("Fast edition", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kSubOperationsTable->setToolTip(tr2i18n("List of splits", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kSubOperationsTable->setStatusTip(tr2i18n("List of splits", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kAddOperationBtn->setToolTip(tr2i18n("Create a new transaction (Ctrl+Enter)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kAddOperationBtn->setStatusTip(tr2i18n("Create a new transaction (Ctrl+Enter)", nullptr));
#endif // QT_CONFIG(statustip)
        kAddOperationBtn->setText(tr2i18n("Add", "Verb, add an item to a list"));
#if QT_CONFIG(tooltip)
        kModifyOperationBtn->setToolTip(tr2i18n("Update selected transactions (Shift+Enter)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kModifyOperationBtn->setStatusTip(tr2i18n("Update selected transactions (Shift+Enter)", nullptr));
#endif // QT_CONFIG(statustip)
        kModifyOperationBtn->setText(tr2i18n("Modify", "Verb, modify an item"));
        (void)skgoperationplugin_base;
    } // retranslateUi

};

namespace Ui {
    class skgoperationplugin_base: public Ui_skgoperationplugin_base {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGOPERATIONPLUGINWIDGET_BASE_H

