/********************************************************************************
** Form generated from reading UI file 'skgsearchpluginwidget_pref.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGSEARCHPLUGINWIDGET_PREF_H
#define UI_SKGSEARCHPLUGINWIDGET_PREF_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_skgsearchplugin_pref
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QSpinBox *kcfg_alarm_frequency;
    QLabel *label_2;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *skgsearchplugin_pref)
    {
        if (skgsearchplugin_pref->objectName().isEmpty())
            skgsearchplugin_pref->setObjectName("skgsearchplugin_pref");
        skgsearchplugin_pref->resize(350, 46);
        verticalLayout = new QVBoxLayout(skgsearchplugin_pref);
        verticalLayout->setSpacing(2);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(skgsearchplugin_pref);
        label->setObjectName("label");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(label);

        kcfg_alarm_frequency = new QSpinBox(skgsearchplugin_pref);
        kcfg_alarm_frequency->setObjectName("kcfg_alarm_frequency");
        kcfg_alarm_frequency->setMinimumSize(QSize(111, 0));
        kcfg_alarm_frequency->setValue(10);
        kcfg_alarm_frequency->setMinimum(1);
        kcfg_alarm_frequency->setMaximum(99);

        horizontalLayout->addWidget(kcfg_alarm_frequency);

        label_2 = new QLabel(skgsearchplugin_pref);
        label_2->setObjectName("label_2");

        horizontalLayout->addWidget(label_2);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);

        verticalSpacer = new QSpacerItem(20, 126, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(skgsearchplugin_pref);

        QMetaObject::connectSlotsByName(skgsearchplugin_pref);
    } // setupUi

    void retranslateUi(QWidget *skgsearchplugin_pref)
    {
        label->setText(tr2i18n("Raise alarm every:", nullptr));
        label_2->setText(tr2i18n("minutes", nullptr));
        (void)skgsearchplugin_pref;
    } // retranslateUi

};

namespace Ui {
    class skgsearchplugin_pref: public Ui_skgsearchplugin_pref {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGSEARCHPLUGINWIDGET_PREF_H

