/********************************************************************************
** Form generated from reading UI file 'skgunitpluginwidget_pref.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGUNITPLUGINWIDGET_PREF_H
#define UI_SKGUNITPLUGINWIDGET_PREF_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_skgunitplugin_pref
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *kcfg_download_on_open;
    KComboBox *kcfg_download_frequency;
    QSpacerItem *horizontalSpacer_2;
    QGroupBox *downloadmode;
    QVBoxLayout *verticalLayout;
    QRadioButton *kcfg_last;
    QRadioButton *kcfg_last_monthly;
    QRadioButton *kcfg_last_weekly;
    QRadioButton *kcfg_last_daily;
    QRadioButton *kcfg_all_monthly;
    QRadioButton *kcfg_all_weekly;
    QRadioButton *kcfg_all_daily;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QSpinBox *kcfg_nb_loaded_values;
    QSpacerItem *horizontalSpacer;
    QGroupBox *apikeysBox;
    QVBoxLayout *verticalLayout_3;
    QLabel *apikeys_label;
    QGridLayout *kAPIKeyLayout;
    QPushButton *kSave;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *skgunitplugin_pref)
    {
        if (skgunitplugin_pref->objectName().isEmpty())
            skgunitplugin_pref->setObjectName("skgunitplugin_pref");
        skgunitplugin_pref->resize(596, 542);
        verticalLayout_2 = new QVBoxLayout(skgunitplugin_pref);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(2);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        kcfg_download_on_open = new QCheckBox(skgunitplugin_pref);
        kcfg_download_on_open->setObjectName("kcfg_download_on_open");

        horizontalLayout_2->addWidget(kcfg_download_on_open);

        kcfg_download_frequency = new KComboBox(skgunitplugin_pref);
        kcfg_download_frequency->addItem(QString());
        kcfg_download_frequency->addItem(QString());
        kcfg_download_frequency->addItem(QString());
        kcfg_download_frequency->setObjectName("kcfg_download_frequency");
        kcfg_download_frequency->setEnabled(false);

        horizontalLayout_2->addWidget(kcfg_download_frequency);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);


        verticalLayout_2->addLayout(horizontalLayout_2);

        downloadmode = new QGroupBox(skgunitplugin_pref);
        downloadmode->setObjectName("downloadmode");
        verticalLayout = new QVBoxLayout(downloadmode);
        verticalLayout->setSpacing(2);
        verticalLayout->setObjectName("verticalLayout");
        kcfg_last = new QRadioButton(downloadmode);
        kcfg_last->setObjectName("kcfg_last");

        verticalLayout->addWidget(kcfg_last);

        kcfg_last_monthly = new QRadioButton(downloadmode);
        kcfg_last_monthly->setObjectName("kcfg_last_monthly");

        verticalLayout->addWidget(kcfg_last_monthly);

        kcfg_last_weekly = new QRadioButton(downloadmode);
        kcfg_last_weekly->setObjectName("kcfg_last_weekly");

        verticalLayout->addWidget(kcfg_last_weekly);

        kcfg_last_daily = new QRadioButton(downloadmode);
        kcfg_last_daily->setObjectName("kcfg_last_daily");

        verticalLayout->addWidget(kcfg_last_daily);

        kcfg_all_monthly = new QRadioButton(downloadmode);
        kcfg_all_monthly->setObjectName("kcfg_all_monthly");

        verticalLayout->addWidget(kcfg_all_monthly);

        kcfg_all_weekly = new QRadioButton(downloadmode);
        kcfg_all_weekly->setObjectName("kcfg_all_weekly");

        verticalLayout->addWidget(kcfg_all_weekly);

        kcfg_all_daily = new QRadioButton(downloadmode);
        kcfg_all_daily->setObjectName("kcfg_all_daily");

        verticalLayout->addWidget(kcfg_all_daily);


        verticalLayout_2->addWidget(downloadmode);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(2);
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(skgunitplugin_pref);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        kcfg_nb_loaded_values = new QSpinBox(skgunitplugin_pref);
        kcfg_nb_loaded_values->setObjectName("kcfg_nb_loaded_values");
        kcfg_nb_loaded_values->setValue(50);

        horizontalLayout->addWidget(kcfg_nb_loaded_values);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout_2->addLayout(horizontalLayout);

        apikeysBox = new QGroupBox(skgunitplugin_pref);
        apikeysBox->setObjectName("apikeysBox");
        verticalLayout_3 = new QVBoxLayout(apikeysBox);
        verticalLayout_3->setObjectName("verticalLayout_3");
        apikeys_label = new QLabel(apikeysBox);
        apikeys_label->setObjectName("apikeys_label");
        apikeys_label->setWordWrap(true);

        verticalLayout_3->addWidget(apikeys_label);

        kAPIKeyLayout = new QGridLayout();
        kAPIKeyLayout->setSpacing(2);
        kAPIKeyLayout->setObjectName("kAPIKeyLayout");

        verticalLayout_3->addLayout(kAPIKeyLayout);

        kSave = new QPushButton(apikeysBox);
        kSave->setObjectName("kSave");
        kSave->setAutoDefault(true);

        verticalLayout_3->addWidget(kSave);


        verticalLayout_2->addWidget(apikeysBox);

        verticalSpacer = new QSpacerItem(20, 44, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

#if QT_CONFIG(shortcut)
        label->setBuddy(kcfg_nb_loaded_values);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kcfg_download_on_open, kcfg_download_frequency);
        QWidget::setTabOrder(kcfg_download_frequency, kcfg_last);
        QWidget::setTabOrder(kcfg_last, kcfg_last_monthly);
        QWidget::setTabOrder(kcfg_last_monthly, kcfg_last_weekly);
        QWidget::setTabOrder(kcfg_last_weekly, kcfg_last_daily);
        QWidget::setTabOrder(kcfg_last_daily, kcfg_all_monthly);
        QWidget::setTabOrder(kcfg_all_monthly, kcfg_all_weekly);
        QWidget::setTabOrder(kcfg_all_weekly, kcfg_all_daily);
        QWidget::setTabOrder(kcfg_all_daily, kcfg_nb_loaded_values);

        retranslateUi(skgunitplugin_pref);

        QMetaObject::connectSlotsByName(skgunitplugin_pref);
    } // setupUi

    void retranslateUi(QWidget *skgunitplugin_pref)
    {
        kcfg_download_on_open->setText(tr2i18n("Download on open", nullptr));
        kcfg_download_frequency->setItemText(0, tr2i18n("Once a day", nullptr));
        kcfg_download_frequency->setItemText(1, tr2i18n("Once a week", nullptr));
        kcfg_download_frequency->setItemText(2, tr2i18n("Once a month", nullptr));

        downloadmode->setTitle(tr2i18n("Download mode", nullptr));
        kcfg_last->setText(tr2i18n("Last &value found only", nullptr));
        kcfg_last_monthly->setText(tr2i18n("&Monthly values since last download", nullptr));
        kcfg_last_weekly->setText(tr2i18n("Wee&kly values since last download", nullptr));
        kcfg_last_daily->setText(tr2i18n("Dail&y values since last download", nullptr));
        kcfg_all_monthly->setText(tr2i18n("Monthly values for all dates", nullptr));
        kcfg_all_weekly->setText(tr2i18n("Weekly values for all dates", nullptr));
        kcfg_all_daily->setText(tr2i18n("Daily values for all dates", nullptr));
        label->setText(tr2i18n("Maximum num&ber of imported values:", nullptr));
        apikeysBox->setTitle(tr2i18n("API Keys", nullptr));
        apikeys_label->setText(tr2i18n("<html><head/><body><p>The following download sources need an API key. So you need to request one from the source site web and enter it here:</p></body></html>", nullptr));
#if QT_CONFIG(tooltip)
        kSave->setToolTip(tr2i18n("For security reasons, these keys are not saved in setting file but in your document.", nullptr));
#endif // QT_CONFIG(tooltip)
        kSave->setText(tr2i18n("Save in document", nullptr));
        (void)skgunitplugin_pref;
    } // retranslateUi

};

namespace Ui {
    class skgunitplugin_pref: public Ui_skgunitplugin_pref {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGUNITPLUGINWIDGET_PREF_H

