/****************************************************************************
** Meta object code from reading C++ file 'skgdocument.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../skrooge-26.8.0/skgbasemodeler/skgdocument.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'skgdocument.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11SKGDocumentE_t {};
} // unnamed namespace

template <> constexpr inline auto SKGDocument::qt_create_metaobjectdata<qt_meta_tag_ZN11SKGDocumentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SKGDocument",
        "D-Bus Interface",
        "org.skg.SKGDocument",
        "tableModified",
        "",
        "iTableName",
        "iIdTransaction",
        "iLightTransaction",
        "transactionSuccessfullyEnded",
        "modified",
        "stepForward",
        "SKGError",
        "iPosition",
        "iText",
        "beginTransaction",
        "iName",
        "iNbStep",
        "iDate",
        "iRefreshViews",
        "endTransaction",
        "succeedded",
        "removeAllTransactions",
        "sendMessage",
        "iMessage",
        "SKGDocument::MessageType",
        "iMessageType",
        "iAction",
        "changePassword",
        "iNewPassword",
        "setLanguage",
        "iLanguage",
        "initialize",
        "recover",
        "iPassword",
        "QString&",
        "oRecoveredFile",
        "load",
        "iRestoreTmpFile",
        "iForceReadOnly",
        "setFileNotModified",
        "save",
        "saveAs",
        "iOverwrite",
        "close",
        "iDeletingDocument",
        "addSqlResultInCache",
        "iKey",
        "SKGStringListList",
        "iValue",
        "addValueInCache",
        "refreshCache",
        "iTable",
        "setBackupParameters",
        "iPrefix",
        "iSuffix",
        "formatMoney",
        "SKGServices::SKGUnitInfo",
        "iUnit",
        "iHtml",
        "formatPrimaryMoney",
        "iForcedNbOfDigit",
        "formatSecondaryMoney",
        "formatPercentage",
        "iInvertColors",
        "uuid",
        "fileName",
        "readOnly",
        "ModificationType",
        "U",
        "I",
        "D",
        "MessageType",
        "Positive",
        "Information",
        "Warning",
        "Error",
        "Hidden",
        "UndoRedoMode",
        "UNDOLASTSAVE",
        "UNDO",
        "REDO"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'tableModified'
        QtMocHelpers::SignalData<void(const QString &, int, bool)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::Int, 6 }, { QMetaType::Bool, 7 },
        }}),
        // Signal 'transactionSuccessfullyEnded'
        QtMocHelpers::SignalData<void(int)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Signal 'modified'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stepForward'
        QtMocHelpers::SlotData<SKGError(int, const QString &)>(10, 4, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::Int, 12 }, { QMetaType::QString, 13 },
        }}),
        // Slot 'stepForward'
        QtMocHelpers::SlotData<SKGError(int)>(10, 4, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 11, {{
            { QMetaType::Int, 12 },
        }}),
        // Slot 'beginTransaction'
        QtMocHelpers::SlotData<SKGError(const QString &, int, const QDateTime &, bool)>(14, 4, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::QString, 15 }, { QMetaType::Int, 16 }, { QMetaType::QDateTime, 17 }, { QMetaType::Bool, 18 },
        }}),
        // Slot 'beginTransaction'
        QtMocHelpers::SlotData<SKGError(const QString &, int, const QDateTime &)>(14, 4, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 11, {{
            { QMetaType::QString, 15 }, { QMetaType::Int, 16 }, { QMetaType::QDateTime, 17 },
        }}),
        // Slot 'beginTransaction'
        QtMocHelpers::SlotData<SKGError(const QString &, int)>(14, 4, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 11, {{
            { QMetaType::QString, 15 }, { QMetaType::Int, 16 },
        }}),
        // Slot 'beginTransaction'
        QtMocHelpers::SlotData<SKGError(const QString &)>(14, 4, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 11, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'endTransaction'
        QtMocHelpers::SlotData<SKGError(bool)>(19, 4, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::Bool, 20 },
        }}),
        // Slot 'removeAllTransactions'
        QtMocHelpers::SlotData<SKGError()>(21, 4, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'sendMessage'
        QtMocHelpers::SlotData<SKGError(const QString &, SKGDocument::MessageType, const QString &)>(22, 4, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::QString, 23 }, { 0x80000000 | 24, 25 }, { QMetaType::QString, 26 },
        }}),
        // Slot 'sendMessage'
        QtMocHelpers::SlotData<SKGError(const QString &, SKGDocument::MessageType)>(22, 4, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 11, {{
            { QMetaType::QString, 23 }, { 0x80000000 | 24, 25 },
        }}),
        // Slot 'sendMessage'
        QtMocHelpers::SlotData<SKGError(const QString &)>(22, 4, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 11, {{
            { QMetaType::QString, 23 },
        }}),
        // Slot 'changePassword'
        QtMocHelpers::SlotData<SKGError(const QString &)>(27, 4, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'setLanguage'
        QtMocHelpers::SlotData<SKGError(const QString &)>(29, 4, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::QString, 30 },
        }}),
        // Slot 'initialize'
        QtMocHelpers::SlotData<SKGError()>(31, 4, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'recover'
        QtMocHelpers::SlotData<SKGError(const QString &, const QString &, QString &)>(32, 4, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::QString, 15 }, { QMetaType::QString, 33 }, { 0x80000000 | 34, 35 },
        }}),
        // Slot 'load'
        QtMocHelpers::SlotData<SKGError(const QString &, const QString &, bool, bool)>(36, 4, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::QString, 15 }, { QMetaType::QString, 33 }, { QMetaType::Bool, 37 }, { QMetaType::Bool, 38 },
        }}),
        // Slot 'load'
        QtMocHelpers::SlotData<SKGError(const QString &, const QString &, bool)>(36, 4, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 11, {{
            { QMetaType::QString, 15 }, { QMetaType::QString, 33 }, { QMetaType::Bool, 37 },
        }}),
        // Slot 'load'
        QtMocHelpers::SlotData<SKGError(const QString &, const QString &)>(36, 4, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 11, {{
            { QMetaType::QString, 15 }, { QMetaType::QString, 33 },
        }}),
        // Slot 'load'
        QtMocHelpers::SlotData<SKGError(const QString &)>(36, 4, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 11, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'setFileNotModified'
        QtMocHelpers::SlotData<void() const>(39, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'save'
        QtMocHelpers::SlotData<SKGError()>(40, 4, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'saveAs'
        QtMocHelpers::SlotData<SKGError(const QString &, bool)>(41, 4, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::QString, 15 }, { QMetaType::Bool, 42 },
        }}),
        // Slot 'saveAs'
        QtMocHelpers::SlotData<SKGError(const QString &)>(41, 4, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 11, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'close'
        QtMocHelpers::SlotData<SKGError(bool)>(43, 4, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::Bool, 44 },
        }}),
        // Slot 'close'
        QtMocHelpers::SlotData<SKGError()>(43, 4, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 11),
        // Slot 'addSqlResultInCache'
        QtMocHelpers::SlotData<void(const QString &, const SKGStringListList &) const>(45, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 46 }, { 0x80000000 | 47, 48 },
        }}),
        // Slot 'addValueInCache'
        QtMocHelpers::SlotData<void(const QString &, const QString &) const>(49, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 46 }, { QMetaType::QString, 48 },
        }}),
        // Slot 'refreshCache'
        QtMocHelpers::SlotData<void(const QString &) const>(50, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 51 },
        }}),
        // Slot 'setBackupParameters'
        QtMocHelpers::SlotData<void(const QString &, const QString &) const>(52, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 53 }, { QMetaType::QString, 54 },
        }}),
        // Slot 'setBackupParameters'
        QtMocHelpers::SlotData<void(const QString &) const>(52, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 53 },
        }}),
        // Slot 'setBackupParameters'
        QtMocHelpers::SlotData<void() const>(52, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Method 'formatMoney'
        QtMocHelpers::MethodData<QString(double, const SKGServices::SKGUnitInfo &, bool) const>(55, 4, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Double, 48 }, { 0x80000000 | 56, 57 }, { QMetaType::Bool, 58 },
        }}),
        // Method 'formatMoney'
        QtMocHelpers::MethodData<QString(double, const SKGServices::SKGUnitInfo &) const>(55, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::Double, 48 }, { 0x80000000 | 56, 57 },
        }}),
        // Method 'formatPrimaryMoney'
        QtMocHelpers::MethodData<QString(double, int) const>(59, 4, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Double, 48 }, { QMetaType::Int, 60 },
        }}),
        // Method 'formatPrimaryMoney'
        QtMocHelpers::MethodData<QString(double) const>(59, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::Double, 48 },
        }}),
        // Method 'formatSecondaryMoney'
        QtMocHelpers::MethodData<QString(double, int) const>(61, 4, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Double, 48 }, { QMetaType::Int, 60 },
        }}),
        // Method 'formatSecondaryMoney'
        QtMocHelpers::MethodData<QString(double) const>(61, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::Double, 48 },
        }}),
        // Method 'formatPercentage'
        QtMocHelpers::MethodData<QString(double, bool) const>(62, 4, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Double, 48 }, { QMetaType::Bool, 63 },
        }}),
        // Method 'formatPercentage'
        QtMocHelpers::MethodData<QString(double) const>(62, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::Double, 48 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'uuid'
        QtMocHelpers::PropertyData<QString>(64, QMetaType::QString, QMC::DefaultPropertyFlags, 2),
        // property 'fileName'
        QtMocHelpers::PropertyData<QString>(65, QMetaType::QString, QMC::DefaultPropertyFlags, 2),
        // property 'readOnly'
        QtMocHelpers::PropertyData<bool>(66, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'modified'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ModificationType'
        QtMocHelpers::EnumData<enum ModificationType>(67, 67, QMC::EnumFlags{}).add({
            {   68, ModificationType::U },
            {   69, ModificationType::I },
            {   70, ModificationType::D },
        }),
        // enum 'MessageType'
        QtMocHelpers::EnumData<enum MessageType>(71, 71, QMC::EnumFlags{}).add({
            {   72, MessageType::Positive },
            {   73, MessageType::Information },
            {   74, MessageType::Warning },
            {   75, MessageType::Error },
            {   76, MessageType::Hidden },
        }),
        // enum 'UndoRedoMode'
        QtMocHelpers::EnumData<enum UndoRedoMode>(77, 77, QMC::EnumFlags{}).add({
            {   78, UndoRedoMode::UNDOLASTSAVE },
            {   79, UndoRedoMode::UNDO },
            {   80, UndoRedoMode::REDO },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<SKGDocument, qt_meta_tag_ZN11SKGDocumentE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject SKGDocument::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11SKGDocumentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11SKGDocumentE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11SKGDocumentE_t>.metaTypes,
    nullptr
} };

void SKGDocument::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SKGDocument *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->tableModified((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 1: _t->transactionSuccessfullyEnded((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->modified(); break;
        case 3: { SKGError _r = _t->stepForward((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<SKGError*>(_a[0]) = std::move(_r); }  break;
        case 4: { SKGError _r = _t->stepForward((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<SKGError*>(_a[0]) = std::move(_r); }  break;
        case 5: { SKGError _r = _t->beginTransaction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])));
            if (_a[0]) *reinterpret_cast<SKGError*>(_a[0]) = std::move(_r); }  break;
        case 6: { SKGError _r = _t->beginTransaction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[3])));
            if (_a[0]) *reinterpret_cast<SKGError*>(_a[0]) = std::move(_r); }  break;
        case 7: { SKGError _r = _t->beginTransaction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<SKGError*>(_a[0]) = std::move(_r); }  break;
        case 8: { SKGError _r = _t->beginTransaction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<SKGError*>(_a[0]) = std::move(_r); }  break;
        case 9: { SKGError _r = _t->endTransaction((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<SKGError*>(_a[0]) = std::move(_r); }  break;
        case 10: { SKGError _r = _t->removeAllTransactions();
            if (_a[0]) *reinterpret_cast<SKGError*>(_a[0]) = std::move(_r); }  break;
        case 11: { SKGError _r = _t->sendMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<SKGDocument::MessageType>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<SKGError*>(_a[0]) = std::move(_r); }  break;
        case 12: { SKGError _r = _t->sendMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<SKGDocument::MessageType>>(_a[2])));
            if (_a[0]) *reinterpret_cast<SKGError*>(_a[0]) = std::move(_r); }  break;
        case 13: { SKGError _r = _t->sendMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<SKGError*>(_a[0]) = std::move(_r); }  break;
        case 14: { SKGError _r = _t->changePassword((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<SKGError*>(_a[0]) = std::move(_r); }  break;
        case 15: { SKGError _r = _t->setLanguage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<SKGError*>(_a[0]) = std::move(_r); }  break;
        case 16: { SKGError _r = _t->initialize();
            if (_a[0]) *reinterpret_cast<SKGError*>(_a[0]) = std::move(_r); }  break;
        case 17: { SKGError _r = _t->recover((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[3])));
            if (_a[0]) *reinterpret_cast<SKGError*>(_a[0]) = std::move(_r); }  break;
        case 18: { SKGError _r = _t->load((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])));
            if (_a[0]) *reinterpret_cast<SKGError*>(_a[0]) = std::move(_r); }  break;
        case 19: { SKGError _r = _t->load((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<SKGError*>(_a[0]) = std::move(_r); }  break;
        case 20: { SKGError _r = _t->load((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<SKGError*>(_a[0]) = std::move(_r); }  break;
        case 21: { SKGError _r = _t->load((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<SKGError*>(_a[0]) = std::move(_r); }  break;
        case 22: _t->setFileNotModified(); break;
        case 23: { SKGError _r = _t->save();
            if (_a[0]) *reinterpret_cast<SKGError*>(_a[0]) = std::move(_r); }  break;
        case 24: { SKGError _r = _t->saveAs((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<SKGError*>(_a[0]) = std::move(_r); }  break;
        case 25: { SKGError _r = _t->saveAs((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<SKGError*>(_a[0]) = std::move(_r); }  break;
        case 26: { SKGError _r = _t->close((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<SKGError*>(_a[0]) = std::move(_r); }  break;
        case 27: { SKGError _r = _t->close();
            if (_a[0]) *reinterpret_cast<SKGError*>(_a[0]) = std::move(_r); }  break;
        case 28: _t->addSqlResultInCache((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<SKGStringListList>>(_a[2]))); break;
        case 29: _t->addValueInCache((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 30: _t->refreshCache((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 31: _t->setBackupParameters((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 32: _t->setBackupParameters((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 33: _t->setBackupParameters(); break;
        case 34: { QString _r = _t->formatMoney((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<SKGServices::SKGUnitInfo>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 35: { QString _r = _t->formatMoney((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<SKGServices::SKGUnitInfo>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 36: { QString _r = _t->formatPrimaryMoney((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 37: { QString _r = _t->formatPrimaryMoney((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 38: { QString _r = _t->formatSecondaryMoney((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 39: { QString _r = _t->formatSecondaryMoney((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 40: { QString _r = _t->formatPercentage((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 41: { QString _r = _t->formatPercentage((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SKGDocument::*)(const QString & , int , bool )>(_a, &SKGDocument::tableModified, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SKGDocument::*)(int )>(_a, &SKGDocument::transactionSuccessfullyEnded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SKGDocument::*)()>(_a, &SKGDocument::modified, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->getUniqueIdentifier(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->getCurrentFileName(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isReadOnly(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isFileModified(); break;
        default: break;
        }
    }
}

const QMetaObject *SKGDocument::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SKGDocument::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11SKGDocumentE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SKGDocument::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 42)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 42;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 42)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 42;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void SKGDocument::tableModified(const QString & _t1, int _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void SKGDocument::transactionSuccessfullyEnded(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void SKGDocument::modified()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
