// This file is generated by kconfig_compiler_kf6 from skgoperation_settings.kcfg.
// All changes you do to this file will be lost.

#include "skgoperation_settings.h"

#include <qglobal.h>
#include <QFile>

class skgoperation_settingsHelper
{
  public:
    skgoperation_settingsHelper() noexcept : q(nullptr) {}
    ~skgoperation_settingsHelper() noexcept { delete q; q = nullptr; }
    skgoperation_settingsHelper(const skgoperation_settingsHelper&) = delete;
    skgoperation_settingsHelper& operator=(const skgoperation_settingsHelper&) = delete;
    skgoperation_settings *q;
};
Q_GLOBAL_STATIC(skgoperation_settingsHelper, s_globalskgoperation_settings)
skgoperation_settings *skgoperation_settings::self()
{
  if (!s_globalskgoperation_settings()->q) {
    new skgoperation_settings;
    s_globalskgoperation_settings()->q->read();
  }

  return s_globalskgoperation_settings()->q;
}

skgoperation_settings::skgoperation_settings( )
  : KConfigSkeleton()
{
  Q_ASSERT(!s_globalskgoperation_settings()->q);
  s_globalskgoperation_settings()->q = this;
  setCurrentGroup( QStringLiteral( "skrooge_operation" ) );

  KConfigSkeleton::ItemColor  *itemFontFutureColor;
  itemFontFutureColor = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "fontFutureColor" ), mFontFutureColor, Qt::gray );
  addItem( itemFontFutureColor, QStringLiteral( "fontFutureColor" ) );
  KConfigSkeleton::ItemColor  *itemFontNotValidatedColor;
  itemFontNotValidatedColor = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "fontNotValidatedColor" ), mFontNotValidatedColor, Qt::blue );
  addItem( itemFontNotValidatedColor, QStringLiteral( "fontNotValidatedColor" ) );
  KConfigSkeleton::ItemColor  *itemFontSubOperationColor;
  itemFontSubOperationColor = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "fontSubOperationColor" ), mFontSubOperationColor, Qt::darkGreen );
  addItem( itemFontSubOperationColor, QStringLiteral( "fontSubOperationColor" ) );
  KConfigSkeleton::ItemString  *itemFasteditmode;
  itemFasteditmode = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "fasteditmode" ), mFasteditmode, QStringLiteral( "1" ) );
  addItem( itemFasteditmode, QStringLiteral( "fasteditmode" ) );
  KConfigSkeleton::ItemString  *itemBroken_reconciliation;
  itemBroken_reconciliation = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "broken_reconciliation" ), mBroken_reconciliation, QStringLiteral( "0" ) );
  addItem( itemBroken_reconciliation, QStringLiteral( "broken_reconciliation" ) );
  KConfigSkeleton::ItemString  *itemBroken_import;
  itemBroken_import = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "broken_import" ), mBroken_import, QStringLiteral( "0" ) );
  addItem( itemBroken_import, QStringLiteral( "broken_import" ) );
  KConfigSkeleton::ItemBool  *itemComputeBalances;
  itemComputeBalances = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "computeBalances" ), mComputeBalances, true );
  addItem( itemComputeBalances, QStringLiteral( "computeBalances" ) );
  KConfigSkeleton::ItemBool  *itemOncurrentaccountonly;
  itemOncurrentaccountonly = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "oncurrentaccountonly" ), mOncurrentaccountonly, false );
  addItem( itemOncurrentaccountonly, QStringLiteral( "oncurrentaccountonly" ) );
  KConfigSkeleton::ItemBool  *itemSetCategoryForPayee;
  itemSetCategoryForPayee = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "setCategoryForPayee" ), mSetCategoryForPayee, false );
  addItem( itemSetCategoryForPayee, QStringLiteral( "setCategoryForPayee" ) );
  KConfigSkeleton::ItemBool  *itemAutomaticPointInReconciliation;
  itemAutomaticPointInReconciliation = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "automaticPointInReconciliation" ), mAutomaticPointInReconciliation, true );
  addItem( itemAutomaticPointInReconciliation, QStringLiteral( "automaticPointInReconciliation" ) );
  KConfigSkeleton::ItemString  *itemCommentFakeOperation;
  itemCommentFakeOperation = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "commentFakeOperation" ), mCommentFakeOperation, QStringLiteral( "fake transaction" ) );
  addItem( itemCommentFakeOperation, QStringLiteral( "commentFakeOperation" ) );
  KConfigSkeleton::ItemString  *itemPayeeFakeOperation;
  itemPayeeFakeOperation = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "payeeFakeOperation" ), mPayeeFakeOperation );
  addItem( itemPayeeFakeOperation, QStringLiteral( "payeeFakeOperation" ) );
  KConfigSkeleton::ItemString  *itemCategoryFakeOperation;
  itemCategoryFakeOperation = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "categoryFakeOperation" ), mCategoryFakeOperation );
  addItem( itemCategoryFakeOperation, QStringLiteral( "categoryFakeOperation" ) );
  KConfigSkeleton::ItemString  *itemCommentCommissionOperation;
  itemCommentCommissionOperation = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "commentCommissionOperation" ), mCommentCommissionOperation, QStringLiteral( "Commission" ) );
  addItem( itemCommentCommissionOperation, QStringLiteral( "commentCommissionOperation" ) );
  KConfigSkeleton::ItemString  *itemCategoryCommissionOperation;
  itemCategoryCommissionOperation = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "categoryCommissionOperation" ), mCategoryCommissionOperation );
  addItem( itemCategoryCommissionOperation, QStringLiteral( "categoryCommissionOperation" ) );
  KConfigSkeleton::ItemString  *itemCommentTaxOperation;
  itemCommentTaxOperation = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "commentTaxOperation" ), mCommentTaxOperation, QStringLiteral( "Tax" ) );
  addItem( itemCommentTaxOperation, QStringLiteral( "commentTaxOperation" ) );
  KConfigSkeleton::ItemString  *itemCategoryTaxOperation;
  itemCategoryTaxOperation = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "categoryTaxOperation" ), mCategoryTaxOperation );
  addItem( itemCategoryTaxOperation, QStringLiteral( "categoryTaxOperation" ) );
}

skgoperation_settings::~skgoperation_settings()
{
  if (s_globalskgoperation_settings.exists() && !s_globalskgoperation_settings.isDestroyed()) {
    s_globalskgoperation_settings()->q = nullptr;
  }
}

