/****************************************************************************
** Meta object code from reading C++ file 'skgbookmarkplugindockwidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../skrooge-26.8.0/plugins/generic/skg_bookmark/skgbookmarkplugindockwidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'skgbookmarkplugindockwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN27SKGBookmarkPluginDockWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto SKGBookmarkPluginDockWidget::qt_create_metaobjectdata<qt_meta_tag_ZN27SKGBookmarkPluginDockWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SKGBookmarkPluginDockWidget",
        "refresh",
        "",
        "initMenu",
        "showMenu",
        "QPoint",
        "iPos",
        "onAddBookmarkGroup",
        "onAddBookmark",
        "onAddBookmarks",
        "onRemoveBookmark",
        "onRenameBookmark",
        "onChangeIconBookmark",
        "onBeforeOpenBookmark",
        "onOpenBookmark",
        "QModelIndex",
        "index",
        "onOpenBookmarkFolder",
        "onBookmarkEditorChanged",
        "onSetAutostart",
        "onUnsetAutostart",
        "onPageChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'refresh'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'initMenu'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showMenu'
        QtMocHelpers::SlotData<void(QPoint)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'onAddBookmarkGroup'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onAddBookmark'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onAddBookmarks'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onRemoveBookmark'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onRenameBookmark'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onChangeIconBookmark'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onBeforeOpenBookmark'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onOpenBookmark'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'onOpenBookmarkFolder'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'onBookmarkEditorChanged'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onSetAutostart'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onUnsetAutostart'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onPageChanged'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SKGBookmarkPluginDockWidget, qt_meta_tag_ZN27SKGBookmarkPluginDockWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SKGBookmarkPluginDockWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<SKGWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27SKGBookmarkPluginDockWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27SKGBookmarkPluginDockWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN27SKGBookmarkPluginDockWidgetE_t>.metaTypes,
    nullptr
} };

void SKGBookmarkPluginDockWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SKGBookmarkPluginDockWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->refresh(); break;
        case 1: _t->initMenu(); break;
        case 2: _t->showMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 3: _t->onAddBookmarkGroup(); break;
        case 4: _t->onAddBookmark(); break;
        case 5: _t->onAddBookmarks(); break;
        case 6: _t->onRemoveBookmark(); break;
        case 7: _t->onRenameBookmark(); break;
        case 8: _t->onChangeIconBookmark(); break;
        case 9: _t->onBeforeOpenBookmark(); break;
        case 10: _t->onOpenBookmark((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 11: _t->onOpenBookmarkFolder((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 12: _t->onBookmarkEditorChanged(); break;
        case 13: _t->onSetAutostart(); break;
        case 14: _t->onUnsetAutostart(); break;
        case 15: _t->onPageChanged(); break;
        default: ;
        }
    }
}

const QMetaObject *SKGBookmarkPluginDockWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SKGBookmarkPluginDockWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27SKGBookmarkPluginDockWidgetE_t>.strings))
        return static_cast<void*>(this);
    return SKGWidget::qt_metacast(_clname);
}

int SKGBookmarkPluginDockWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SKGWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    return _id;
}
QT_WARNING_POP
