// This file is generated by kconfig_compiler_kf6 from skgbasegui_settings.kcfg.
// All changes you do to this file will be lost.

#include "skgbasegui_settings.h"

#include <qglobal.h>
#include <QFile>

class skgbasegui_settingsHelper
{
  public:
    skgbasegui_settingsHelper() noexcept : q(nullptr) {}
    ~skgbasegui_settingsHelper() noexcept { delete q; q = nullptr; }
    skgbasegui_settingsHelper(const skgbasegui_settingsHelper&) = delete;
    skgbasegui_settingsHelper& operator=(const skgbasegui_settingsHelper&) = delete;
    skgbasegui_settings *q;
};
Q_GLOBAL_STATIC(skgbasegui_settingsHelper, s_globalskgbasegui_settings)
skgbasegui_settings *skgbasegui_settings::self()
{
  if (!s_globalskgbasegui_settings()->q) {
    new skgbasegui_settings;
    s_globalskgbasegui_settings()->q->read();
  }

  return s_globalskgbasegui_settings()->q;
}

skgbasegui_settings::skgbasegui_settings( )
  : KConfigSkeleton()
{
  Q_ASSERT(!s_globalskgbasegui_settings()->q);
  s_globalskgbasegui_settings()->q = this;
  setCurrentGroup( QStringLiteral( "Main Panel" ) );

  KConfigSkeleton::ItemBool  *itemShow_splash_screen;
  itemShow_splash_screen = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "show_splash_screen" ), mShow_splash_screen, true );
  addItem( itemShow_splash_screen, QStringLiteral( "show_splash_screen" ) );
  KConfigSkeleton::ItemInt  *itemUpdate_modified_bookmarks;
  itemUpdate_modified_bookmarks = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "update_modified_bookmarks" ), mUpdate_modified_bookmarks, 2 );
  addItem( itemUpdate_modified_bookmarks, QStringLiteral( "update_modified_bookmarks" ) );
  KConfigSkeleton::ItemInt  *itemUpdate_modified_contexts;
  itemUpdate_modified_contexts = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "update_modified_contexts" ), mUpdate_modified_contexts, 2 );
  addItem( itemUpdate_modified_contexts, QStringLiteral( "update_modified_contexts" ) );
  KConfigSkeleton::ItemInt  *itemMain_tabs_position;
  itemMain_tabs_position = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "main_tabs_position" ), mMain_tabs_position, 0 );
  addItem( itemMain_tabs_position, QStringLiteral( "main_tabs_position" ) );
  KConfigSkeleton::ItemInt  *itemDate_format;
  itemDate_format = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "date_format" ), mDate_format, 2 );
  addItem( itemDate_format, QStringLiteral( "date_format" ) );
  KConfigSkeleton::ItemInt  *itemCurrency_format;
  itemCurrency_format = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "currency_format" ), mCurrency_format, 0 );
  addItem( itemCurrency_format, QStringLiteral( "currency_format" ) );
  KConfigSkeleton::ItemBool  *itemIcon_in_system_tray;
  itemIcon_in_system_tray = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "icon_in_system_tray" ), mIcon_in_system_tray, false );
  addItem( itemIcon_in_system_tray, QStringLiteral( "icon_in_system_tray" ) );
}

skgbasegui_settings::~skgbasegui_settings()
{
  if (s_globalskgbasegui_settings.exists() && !s_globalskgbasegui_settings.isDestroyed()) {
    s_globalskgbasegui_settings()->q = nullptr;
  }
}

