/********************************************************************************
** Form generated from reading UI file 'skgcolorbutton.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGCOLORBUTTON_H
#define UI_SKGCOLORBUTTON_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"
#include "ksqueezedtextlabel.h"

QT_BEGIN_NAMESPACE

class Ui_skgcolorbutton_base
{
public:
    QHBoxLayout *horizontalLayout;
    KColorButton *button;
    KSqueezedTextLabel *label;

    void setupUi(QWidget *skgcolorbutton_base)
    {
        if (skgcolorbutton_base->objectName().isEmpty())
            skgcolorbutton_base->setObjectName("skgcolorbutton_base");
        skgcolorbutton_base->resize(86, 34);
        horizontalLayout = new QHBoxLayout(skgcolorbutton_base);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        button = new KColorButton(skgcolorbutton_base);
        button->setObjectName("button");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(button->sizePolicy().hasHeightForWidth());
        button->setSizePolicy(sizePolicy);
        button->setMinimumSize(QSize(50, 0));
        button->setMaximumSize(QSize(50, 16777215));

        horizontalLayout->addWidget(button);

        label = new KSqueezedTextLabel(skgcolorbutton_base);
        label->setObjectName("label");
        label->setText(QString::fromUtf8(""));
        label->setTextFormat(Qt::PlainText);

        horizontalLayout->addWidget(label);


        retranslateUi(skgcolorbutton_base);

        button->setDefault(false);


        QMetaObject::connectSlotsByName(skgcolorbutton_base);
    } // setupUi

    void retranslateUi(QWidget *skgcolorbutton_base)
    {
        (void)skgcolorbutton_base;
    } // retranslateUi

};

namespace Ui {
    class skgcolorbutton_base: public Ui_skgcolorbutton_base {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGCOLORBUTTON_H

