/********************************************************************************
** Form generated from reading UI file 'skgunitpluginwidget_base.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGUNITPLUGINWIDGET_BASE_H
#define UI_SKGUNITPLUGINWIDGET_BASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "skgcalculatoredit.h"
#include "skgcombobox.h"
#include "skgdateedit.h"
#include "skgfilteredtableview.h"
#include "skgtableview.h"
#include "skgtablewithgraph.h"
#include "skgtreeview.h"
#include "skgunitcombobox.h"
#include "skgwidgetselector.h"

QT_BEGIN_NAMESPACE

class Ui_skgunitplugin_base
{
public:
    QVBoxLayout *verticalLayout;
    QSplitter *kMainSplitter;
    SKGFilteredTableView *kUnitTableViewEdition;
    QFrame *kUnitValueFrame;
    QHBoxLayout *horizontalLayout_6;
    QSplitter *kValuesSplitter;
    SKGTableView *kUnitValueTableViewEdition;
    QFrame *frame;
    QGridLayout *gridLayout;
    SKGTableWithGraph *kGraph;
    QFrame *line;
    QHBoxLayout *horizontalLayout;
    QVBoxLayout *verticalLayout_2;
    QWidget *kManualFrm;
    QHBoxLayout *horizontalLayout_4;
    QGridLayout *gridLayout_2;
    QSpinBox *kNbDecimal;
    QLineEdit *kCountryCreatorUnit;
    SKGUnitComboBox *kUnitCreatorUnit;
    QLabel *kUnitLbl;
    QLabel *kCountyLbl;
    QLabel *kDecimalLbl;
    QLineEdit *kNameCreatorUnit;
    QLineEdit *kSymbolCreatorUnit;
    SKGComboBox *kTypeCreatorUnit;
    QLabel *kTypeLbl;
    QLabel *kSymbolLbl;
    QLabel *kNameLbl;
    QLabel *kDownloadSourceLbl;
    SKGComboBox *kDownloadSource;
    QToolButton *kDeleteSource;
    QLabel *kInternetLbl;
    QLineEdit *kInternetCreatorUnit;
    QToolButton *kGetNewHotStuff;
    QLabel *kSourceHelp;
    QWidget *kStandardFrm;
    QHBoxLayout *horizontalLayout_7;
    SKGComboBox *kCurrencyList;
    QCheckBox *kObsolete;
    QSpacerItem *horizontalSpacer_3;
    QFrame *kValuesFrm;
    QHBoxLayout *horizontalLayout_2;
    QLabel *kDateLabel;
    SKGDateEdit *kDateEdit;
    QLabel *kAmountLabel;
    SKGCalculatorEdit *kAmountEdit;
    QLabel *kUnitOfUnitLbl;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *verticalSpacer_2;
    QHBoxLayout *horizontalLayout_12;
    SKGWidgetSelector *kWidgetSelector;
    QFrame *kBtnFrm;
    QHBoxLayout *horizontalLayout_3;
    QSpacerItem *verticalSpacer;
    QPushButton *kUnitAdd;
    QPushButton *kUnitUpdate;
    QToolButton *kUnitValueDownload;
    QPushButton *kUnitOpen;

    void setupUi(QWidget *skgunitplugin_base)
    {
        if (skgunitplugin_base->objectName().isEmpty())
            skgunitplugin_base->setObjectName("skgunitplugin_base");
        skgunitplugin_base->resize(662, 512);
        verticalLayout = new QVBoxLayout(skgunitplugin_base);
        verticalLayout->setObjectName("verticalLayout");
        kMainSplitter = new QSplitter(skgunitplugin_base);
        kMainSplitter->setObjectName("kMainSplitter");
        kMainSplitter->setOrientation(Qt::Vertical);
        kUnitTableViewEdition = new SKGFilteredTableView(kMainSplitter);
        kUnitTableViewEdition->setObjectName("kUnitTableViewEdition");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kUnitTableViewEdition->sizePolicy().hasHeightForWidth());
        kUnitTableViewEdition->setSizePolicy(sizePolicy);
        kUnitTableViewEdition->setAcceptDrops(true);
        kUnitTableViewEdition->setProperty("dragEnabled", QVariant(true));
        kUnitTableViewEdition->setProperty("alternatingRowColors", QVariant(true));
        kUnitTableViewEdition->setProperty("sortingEnabled", QVariant(true));
        kMainSplitter->addWidget(kUnitTableViewEdition);
        kUnitValueFrame = new QFrame(kMainSplitter);
        kUnitValueFrame->setObjectName("kUnitValueFrame");
        kUnitValueFrame->setFrameShape(QFrame::NoFrame);
        kUnitValueFrame->setFrameShadow(QFrame::Raised);
        horizontalLayout_6 = new QHBoxLayout(kUnitValueFrame);
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        horizontalLayout_6->setContentsMargins(0, 0, 0, 0);
        kValuesSplitter = new QSplitter(kUnitValueFrame);
        kValuesSplitter->setObjectName("kValuesSplitter");
        kValuesSplitter->setOrientation(Qt::Horizontal);
        kUnitValueTableViewEdition = new SKGTableView(kValuesSplitter);
        kUnitValueTableViewEdition->setObjectName("kUnitValueTableViewEdition");
        kUnitValueTableViewEdition->setDragDropMode(QAbstractItemView::DropOnly);
        kUnitValueTableViewEdition->setAlternatingRowColors(true);
        kUnitValueTableViewEdition->setSelectionMode(QAbstractItemView::ExtendedSelection);
        kUnitValueTableViewEdition->setSortingEnabled(false);
        kValuesSplitter->addWidget(kUnitValueTableViewEdition);
        frame = new QFrame(kValuesSplitter);
        frame->setObjectName("frame");
        frame->setFrameShape(QFrame::StyledPanel);
        frame->setFrameShadow(QFrame::Raised);
        gridLayout = new QGridLayout(frame);
        gridLayout->setSpacing(0);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        kGraph = new SKGTableWithGraph(frame);
        kGraph->setObjectName("kGraph");
        kGraph->setGraphTypeSelectorVisible(false);
        kGraph->setSelectable(false);
        kGraph->setGraphType(SKGTableWithGraph::LINE);

        gridLayout->addWidget(kGraph, 0, 0, 1, 1);

        kValuesSplitter->addWidget(frame);

        horizontalLayout_6->addWidget(kValuesSplitter);

        kMainSplitter->addWidget(kUnitValueFrame);

        verticalLayout->addWidget(kMainSplitter);

        line = new QFrame(skgunitplugin_base);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(2);
        horizontalLayout->setObjectName("horizontalLayout");
        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setSpacing(2);
        verticalLayout_2->setObjectName("verticalLayout_2");
        kManualFrm = new QWidget(skgunitplugin_base);
        kManualFrm->setObjectName("kManualFrm");
        horizontalLayout_4 = new QHBoxLayout(kManualFrm);
        horizontalLayout_4->setSpacing(2);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        horizontalLayout_4->setContentsMargins(0, 0, 0, 0);
        gridLayout_2 = new QGridLayout();
        gridLayout_2->setSpacing(2);
        gridLayout_2->setObjectName("gridLayout_2");
        kNbDecimal = new QSpinBox(kManualFrm);
        kNbDecimal->setObjectName("kNbDecimal");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(kNbDecimal->sizePolicy().hasHeightForWidth());
        kNbDecimal->setSizePolicy(sizePolicy1);
        kNbDecimal->setMaximum(8);
        kNbDecimal->setValue(2);

        gridLayout_2->addWidget(kNbDecimal, 0, 3, 1, 1);

        kCountryCreatorUnit = new QLineEdit(kManualFrm);
        kCountryCreatorUnit->setObjectName("kCountryCreatorUnit");

        gridLayout_2->addWidget(kCountryCreatorUnit, 1, 3, 1, 1);

        kUnitCreatorUnit = new SKGUnitComboBox(kManualFrm);
        kUnitCreatorUnit->setObjectName("kUnitCreatorUnit");
        sizePolicy1.setHeightForWidth(kUnitCreatorUnit->sizePolicy().hasHeightForWidth());
        kUnitCreatorUnit->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(kUnitCreatorUnit, 2, 3, 1, 1);

        kUnitLbl = new QLabel(kManualFrm);
        kUnitLbl->setObjectName("kUnitLbl");
        kUnitLbl->setText(QString::fromUtf8("Unit:"));
        kUnitLbl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(kUnitLbl, 2, 2, 1, 1);

        kCountyLbl = new QLabel(kManualFrm);
        kCountyLbl->setObjectName("kCountyLbl");
        QFont font;
        font.setBold(false);
        font.setStrikeOut(false);
        font.setKerning(true);
        font.setStyleStrategy(QFont::PreferDefault);
        kCountyLbl->setFont(font);
        kCountyLbl->setText(QString::fromUtf8("Country:"));
        kCountyLbl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(kCountyLbl, 1, 2, 1, 1);

        kDecimalLbl = new QLabel(kManualFrm);
        kDecimalLbl->setObjectName("kDecimalLbl");
        kDecimalLbl->setText(QString::fromUtf8("N&b Decimals:"));
        kDecimalLbl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(kDecimalLbl, 0, 2, 1, 1);

        kNameCreatorUnit = new QLineEdit(kManualFrm);
        kNameCreatorUnit->setObjectName("kNameCreatorUnit");

        gridLayout_2->addWidget(kNameCreatorUnit, 0, 1, 1, 1);

        kSymbolCreatorUnit = new QLineEdit(kManualFrm);
        kSymbolCreatorUnit->setObjectName("kSymbolCreatorUnit");

        gridLayout_2->addWidget(kSymbolCreatorUnit, 1, 1, 1, 1);

        kTypeCreatorUnit = new SKGComboBox(kManualFrm);
        kTypeCreatorUnit->setObjectName("kTypeCreatorUnit");
        sizePolicy1.setHeightForWidth(kTypeCreatorUnit->sizePolicy().hasHeightForWidth());
        kTypeCreatorUnit->setSizePolicy(sizePolicy1);
        kTypeCreatorUnit->setAutoCompletion(false);

        gridLayout_2->addWidget(kTypeCreatorUnit, 2, 1, 1, 1);

        kTypeLbl = new QLabel(kManualFrm);
        kTypeLbl->setObjectName("kTypeLbl");
        QFont font1;
        font1.setBold(true);
        font1.setStrikeOut(false);
        font1.setKerning(true);
        font1.setStyleStrategy(QFont::PreferDefault);
        kTypeLbl->setFont(font1);
        kTypeLbl->setText(QString::fromUtf8("&Type:"));
        kTypeLbl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(kTypeLbl, 2, 0, 1, 1);

        kSymbolLbl = new QLabel(kManualFrm);
        kSymbolLbl->setObjectName("kSymbolLbl");
        kSymbolLbl->setFont(font1);
        kSymbolLbl->setText(QString::fromUtf8("S&ymbol"));
        kSymbolLbl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(kSymbolLbl, 1, 0, 1, 1);

        kNameLbl = new QLabel(kManualFrm);
        kNameLbl->setObjectName("kNameLbl");
        QFont font2;
        font2.setBold(true);
        kNameLbl->setFont(font2);
        kNameLbl->setText(QString::fromUtf8("Name:"));
        kNameLbl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(kNameLbl, 0, 0, 1, 1);

        kDownloadSourceLbl = new QLabel(kManualFrm);
        kDownloadSourceLbl->setObjectName("kDownloadSourceLbl");
        kDownloadSourceLbl->setText(QString::fromUtf8("Download source:"));

        gridLayout_2->addWidget(kDownloadSourceLbl, 0, 4, 1, 1);

        kDownloadSource = new SKGComboBox(kManualFrm);
        kDownloadSource->setObjectName("kDownloadSource");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(kDownloadSource->sizePolicy().hasHeightForWidth());
        kDownloadSource->setSizePolicy(sizePolicy2);
        kDownloadSource->setEditable(true);

        gridLayout_2->addWidget(kDownloadSource, 0, 5, 1, 1);

        kDeleteSource = new QToolButton(kManualFrm);
        kDeleteSource->setObjectName("kDeleteSource");
        kDeleteSource->setMaximumSize(QSize(22, 22));
        kDeleteSource->setAutoRaise(true);

        gridLayout_2->addWidget(kDeleteSource, 0, 6, 1, 1);

        kInternetLbl = new QLabel(kManualFrm);
        kInternetLbl->setObjectName("kInternetLbl");
        kInternetLbl->setFont(font);
        kInternetLbl->setText(QString::fromUtf8("Internet Code:"));
        kInternetLbl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(kInternetLbl, 1, 4, 1, 1);

        kInternetCreatorUnit = new QLineEdit(kManualFrm);
        kInternetCreatorUnit->setObjectName("kInternetCreatorUnit");

        gridLayout_2->addWidget(kInternetCreatorUnit, 1, 5, 1, 3);

        kGetNewHotStuff = new QToolButton(kManualFrm);
        kGetNewHotStuff->setObjectName("kGetNewHotStuff");
        kGetNewHotStuff->setMaximumSize(QSize(22, 22));
        kGetNewHotStuff->setAutoRaise(true);

        gridLayout_2->addWidget(kGetNewHotStuff, 0, 7, 1, 1);

        kSourceHelp = new QLabel(kManualFrm);
        kSourceHelp->setObjectName("kSourceHelp");
        kSourceHelp->setTextFormat(Qt::RichText);
        kSourceHelp->setOpenExternalLinks(true);

        gridLayout_2->addWidget(kSourceHelp, 2, 4, 1, 4);


        horizontalLayout_4->addLayout(gridLayout_2);


        verticalLayout_2->addWidget(kManualFrm);

        kStandardFrm = new QWidget(skgunitplugin_base);
        kStandardFrm->setObjectName("kStandardFrm");
        horizontalLayout_7 = new QHBoxLayout(kStandardFrm);
        horizontalLayout_7->setSpacing(2);
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        horizontalLayout_7->setContentsMargins(0, 0, 0, 0);
        kCurrencyList = new SKGComboBox(kStandardFrm);
        kCurrencyList->setObjectName("kCurrencyList");
        kCurrencyList->setEditable(true);
        kCurrencyList->setSizeAdjustPolicy(QComboBox::AdjustToContents);
        kCurrencyList->setAutoCompletion(false);

        horizontalLayout_7->addWidget(kCurrencyList);

        kObsolete = new QCheckBox(kStandardFrm);
        kObsolete->setObjectName("kObsolete");

        horizontalLayout_7->addWidget(kObsolete);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer_3);


        verticalLayout_2->addWidget(kStandardFrm);

        kValuesFrm = new QFrame(skgunitplugin_base);
        kValuesFrm->setObjectName("kValuesFrm");
        kValuesFrm->setFrameShape(QFrame::NoFrame);
        kValuesFrm->setFrameShadow(QFrame::Raised);
        horizontalLayout_2 = new QHBoxLayout(kValuesFrm);
        horizontalLayout_2->setSpacing(2);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(0, 0, 0, 0);
        kDateLabel = new QLabel(kValuesFrm);
        kDateLabel->setObjectName("kDateLabel");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(kDateLabel->sizePolicy().hasHeightForWidth());
        kDateLabel->setSizePolicy(sizePolicy3);
        kDateLabel->setFont(font2);
        kDateLabel->setText(QString::fromUtf8("Title:"));

        horizontalLayout_2->addWidget(kDateLabel);

        kDateEdit = new SKGDateEdit(kValuesFrm);
        kDateEdit->setObjectName("kDateEdit");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(kDateEdit->sizePolicy().hasHeightForWidth());
        kDateEdit->setSizePolicy(sizePolicy4);
        kDateEdit->setMinimumSize(QSize(120, 0));
        kDateEdit->setMode(SKGDateEdit::PREVIOUS);

        horizontalLayout_2->addWidget(kDateEdit);

        kAmountLabel = new QLabel(kValuesFrm);
        kAmountLabel->setObjectName("kAmountLabel");
        sizePolicy3.setHeightForWidth(kAmountLabel->sizePolicy().hasHeightForWidth());
        kAmountLabel->setSizePolicy(sizePolicy3);
        kAmountLabel->setFont(font2);
        kAmountLabel->setText(QString::fromUtf8("Title:"));

        horizontalLayout_2->addWidget(kAmountLabel);

        kAmountEdit = new SKGCalculatorEdit(kValuesFrm);
        kAmountEdit->setObjectName("kAmountEdit");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(kAmountEdit->sizePolicy().hasHeightForWidth());
        kAmountEdit->setSizePolicy(sizePolicy5);
        kAmountEdit->setMode(SKGCalculatorEdit::EXPRESSION);

        horizontalLayout_2->addWidget(kAmountEdit);

        kUnitOfUnitLbl = new QLabel(kValuesFrm);
        kUnitOfUnitLbl->setObjectName("kUnitOfUnitLbl");
        sizePolicy3.setHeightForWidth(kUnitOfUnitLbl->sizePolicy().hasHeightForWidth());
        kUnitOfUnitLbl->setSizePolicy(sizePolicy3);

        horizontalLayout_2->addWidget(kUnitOfUnitLbl);

        horizontalSpacer = new QSpacerItem(0, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);


        verticalLayout_2->addWidget(kValuesFrm);

        verticalSpacer_2 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Maximum);

        verticalLayout_2->addItem(verticalSpacer_2);

        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setSpacing(2);
        horizontalLayout_12->setObjectName("horizontalLayout_12");
        kWidgetSelector = new SKGWidgetSelector(skgunitplugin_base);
        kWidgetSelector->setObjectName("kWidgetSelector");

        horizontalLayout_12->addWidget(kWidgetSelector);

        kBtnFrm = new QFrame(skgunitplugin_base);
        kBtnFrm->setObjectName("kBtnFrm");
        kBtnFrm->setFrameShape(QFrame::NoFrame);
        kBtnFrm->setFrameShadow(QFrame::Raised);
        horizontalLayout_3 = new QHBoxLayout(kBtnFrm);
        horizontalLayout_3->setSpacing(2);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horizontalLayout_3->setContentsMargins(0, 0, 0, 0);
        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Maximum);

        horizontalLayout_3->addItem(verticalSpacer);

        kUnitAdd = new QPushButton(kBtnFrm);
        kUnitAdd->setObjectName("kUnitAdd");
        kUnitAdd->setEnabled(false);
        kUnitAdd->setAutoDefault(true);

        horizontalLayout_3->addWidget(kUnitAdd);

        kUnitUpdate = new QPushButton(kBtnFrm);
        kUnitUpdate->setObjectName("kUnitUpdate");
        kUnitUpdate->setEnabled(false);

        horizontalLayout_3->addWidget(kUnitUpdate);


        horizontalLayout_12->addWidget(kBtnFrm);

        kUnitValueDownload = new QToolButton(skgunitplugin_base);
        kUnitValueDownload->setObjectName("kUnitValueDownload");
        kUnitValueDownload->setEnabled(false);
        kUnitValueDownload->setPopupMode(QToolButton::DelayedPopup);
        kUnitValueDownload->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);

        horizontalLayout_12->addWidget(kUnitValueDownload);

        kUnitOpen = new QPushButton(skgunitplugin_base);
        kUnitOpen->setObjectName("kUnitOpen");
        kUnitOpen->setEnabled(false);

        horizontalLayout_12->addWidget(kUnitOpen);


        verticalLayout_2->addLayout(horizontalLayout_12);


        horizontalLayout->addLayout(verticalLayout_2);


        verticalLayout->addLayout(horizontalLayout);

#if QT_CONFIG(shortcut)
        kUnitLbl->setBuddy(kUnitCreatorUnit);
        kCountyLbl->setBuddy(kCountryCreatorUnit);
        kDecimalLbl->setBuddy(kNbDecimal);
        kTypeLbl->setBuddy(kTypeCreatorUnit);
        kSymbolLbl->setBuddy(kSymbolCreatorUnit);
        kNameLbl->setBuddy(kNameCreatorUnit);
        kDownloadSourceLbl->setBuddy(kDownloadSource);
        kInternetLbl->setBuddy(kInternetCreatorUnit);
        kDateLabel->setBuddy(kDateEdit);
        kAmountLabel->setBuddy(kAmountEdit);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kUnitValueTableViewEdition, kNameCreatorUnit);
        QWidget::setTabOrder(kNameCreatorUnit, kSymbolCreatorUnit);
        QWidget::setTabOrder(kSymbolCreatorUnit, kTypeCreatorUnit);
        QWidget::setTabOrder(kTypeCreatorUnit, kNbDecimal);
        QWidget::setTabOrder(kNbDecimal, kCountryCreatorUnit);
        QWidget::setTabOrder(kCountryCreatorUnit, kUnitCreatorUnit);
        QWidget::setTabOrder(kUnitCreatorUnit, kDownloadSource);
        QWidget::setTabOrder(kDownloadSource, kDeleteSource);
        QWidget::setTabOrder(kDeleteSource, kGetNewHotStuff);
        QWidget::setTabOrder(kGetNewHotStuff, kInternetCreatorUnit);
        QWidget::setTabOrder(kInternetCreatorUnit, kCurrencyList);
        QWidget::setTabOrder(kCurrencyList, kObsolete);
        QWidget::setTabOrder(kObsolete, kDateEdit);
        QWidget::setTabOrder(kDateEdit, kAmountEdit);
        QWidget::setTabOrder(kAmountEdit, kUnitAdd);
        QWidget::setTabOrder(kUnitAdd, kUnitUpdate);
        QWidget::setTabOrder(kUnitUpdate, kUnitValueDownload);
        QWidget::setTabOrder(kUnitValueDownload, kUnitOpen);

        retranslateUi(skgunitplugin_base);

        kUnitAdd->setDefault(true);


        QMetaObject::connectSlotsByName(skgunitplugin_base);
    } // setupUi

    void retranslateUi(QWidget *skgunitplugin_base)
    {
#if QT_CONFIG(tooltip)
        kUnitValueTableViewEdition->setToolTip(tr2i18n("List of quotes for selected unit", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kUnitValueTableViewEdition->setStatusTip(tr2i18n("List of quotes for selected unit", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kNbDecimal->setToolTip(tr2i18n("The number of decimal to display of the unit.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kNbDecimal->setStatusTip(tr2i18n("The number of decimal to display of the unit.", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kCountryCreatorUnit->setToolTip(tr2i18n("The country of the unit.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kCountryCreatorUnit->setStatusTip(tr2i18n("The country of the unit.", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kUnitCreatorUnit->setToolTip(tr2i18n("The unit of the unit.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kUnitCreatorUnit->setStatusTip(tr2i18n("The unit of the unit.", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kNameCreatorUnit->setToolTip(tr2i18n("The name of the unit.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kNameCreatorUnit->setStatusTip(tr2i18n("The name of the unit.", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kSymbolCreatorUnit->setToolTip(tr2i18n("The symbol of the unit.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kSymbolCreatorUnit->setStatusTip(tr2i18n("The symbol of the unit.", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kTypeCreatorUnit->setToolTip(tr2i18n("The type of the unit.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kTypeCreatorUnit->setStatusTip(tr2i18n("The type of the unit.", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kDownloadSource->setToolTip(tr2i18n("The download source for the unit", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kDownloadSource->setStatusTip(tr2i18n("The download source for the unit", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kDeleteSource->setToolTip(tr2i18n("Delete the selected source", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kDeleteSource->setStatusTip(tr2i18n("Delete the selected source", nullptr));
#endif // QT_CONFIG(statustip)
        kDeleteSource->setText(QString());
#if QT_CONFIG(tooltip)
        kInternetCreatorUnit->setToolTip(tr2i18n("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"https://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Ubuntu'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'DejaVu Sans'; font-size:10pt;\">The Internet code of the unit.</span></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:'DejaVu Sans'; font-size:10pt;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'DejaVu Sans'; font-size:10pt;\">You can add &quot; /&quot; if you are not able to download the expected quote b"
                        "ut you are able to download the inverse.</span></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'DejaVu Sans'; font-size:10pt; text-decoration: underline;\">Example:</span><span style=\" font-family:'DejaVu Sans'; font-size:10pt;\"> EURUSD=X is the symbol to download EURO in USD.</span></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'DejaVu Sans'; font-size:10pt;\">If you want USD in EURO, you have to create a unit USD with &quot;EURUSD=X /&quot; as the Internet code.</span></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:'DejaVu Sans'; font-size:10pt;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0p"
                        "x;\"><span style=\" font-family:'DejaVu Sans'; font-size:10pt;\">This field can also be set with a yearly rate. The values are computed by clicking on download.<br />Example:</span></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'DejaVu Sans'; font-size:10pt;\">=-25 means -25% per year.</span></p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kInternetCreatorUnit->setStatusTip(tr2i18n("The Internet code of the unit.", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kGetNewHotStuff->setToolTip(tr2i18n("Get more templates", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kGetNewHotStuff->setStatusTip(tr2i18n("Get more templates", nullptr));
#endif // QT_CONFIG(statustip)
        kGetNewHotStuff->setText(QString());
        kSourceHelp->setText(QString());
#if QT_CONFIG(tooltip)
        kCurrencyList->setToolTip(tr2i18n("List of known units", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kCurrencyList->setStatusTip(tr2i18n("List of known units", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kObsolete->setToolTip(tr2i18n("To include suspended and obsolete currencies", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kObsolete->setStatusTip(tr2i18n("To include suspended and obsolete currencies", nullptr));
#endif // QT_CONFIG(statustip)
        kObsolete->setText(tr2i18n("Obsolete currencies", nullptr));
#if QT_CONFIG(tooltip)
        kDateEdit->setToolTip(tr2i18n("Date of the unit's quote", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kDateEdit->setStatusTip(tr2i18n("Date of the unit's quote", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kAmountEdit->setToolTip(tr2i18n("Amount of the unit's quote", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kAmountEdit->setStatusTip(tr2i18n("Amount of the unit's quote", nullptr));
#endif // QT_CONFIG(statustip)
        kUnitOfUnitLbl->setText(tr2i18n("$", nullptr));
#if QT_CONFIG(tooltip)
        kUnitAdd->setToolTip(tr2i18n("Create a new unit (Ctrl+Enter)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kUnitAdd->setStatusTip(tr2i18n("Create a new unit (Ctrl+Enter)", nullptr));
#endif // QT_CONFIG(statustip)
        kUnitAdd->setText(tr2i18n("Add", nullptr));
#if QT_CONFIG(tooltip)
        kUnitUpdate->setToolTip(tr2i18n("Update the selected unit (Shift+Enter)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kUnitUpdate->setStatusTip(tr2i18n("Update the selected unit (Shift+Enter)", nullptr));
#endif // QT_CONFIG(statustip)
        kUnitUpdate->setText(tr2i18n("Modify", nullptr));
#if QT_CONFIG(tooltip)
        kUnitValueDownload->setToolTip(tr2i18n("Download quotes for the selected unit.\n"
"See options to modify download frequency.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kUnitValueDownload->setStatusTip(tr2i18n("Download quotes for the selected unit.", nullptr));
#endif // QT_CONFIG(statustip)
        kUnitValueDownload->setText(tr2i18n("Download", nullptr));
#if QT_CONFIG(tooltip)
        kUnitOpen->setToolTip(tr2i18n("Open the url of the source", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kUnitOpen->setStatusTip(tr2i18n("Open the url of the source", nullptr));
#endif // QT_CONFIG(statustip)
        (void)skgunitplugin_base;
    } // retranslateUi

};

namespace Ui {
    class skgunitplugin_base: public Ui_skgunitplugin_base {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGUNITPLUGINWIDGET_BASE_H

