/********************************************************************************
** Form generated from reading UI file 'skgbankpluginwidget_base.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGBANKPLUGINWIDGET_BASE_H
#define UI_SKGBANKPLUGINWIDGET_BASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "skgcalculatoredit.h"
#include "skgcombobox.h"
#include "skgfilteredtableview.h"
#include "skgunitcombobox.h"
#include "skgwidgetselector.h"

QT_BEGIN_NAMESPACE

class Ui_skgbankplugin_base
{
public:
    QVBoxLayout *verticalLayout;
    SKGFilteredTableView *kView;
    QLabel *kInfo;
    QFrame *line;
    QWidget *SKGEditionWidget;
    QGridLayout *gridLayout_4;
    SKGComboBox *kAccountCreatorIcon;
    QLabel *kMinLimitunit;
    QHBoxLayout *horizontalLayout_11;
    SKGCalculatorEdit *kAmountEdit;
    SKGUnitComboBox *kUnitEdit;
    QSpacerItem *horizontalSpacer_2;
    QLineEdit *kAccountCreatorAccount;
    QSpacerItem *horizontalSpacer;
    QLabel *kBankNumberLbl;
    QLabel *kAgencyAddressLbl;
    QLabel *kMaxLimitunit;
    QLabel *kBankLbl;
    QCheckBox *kMinLimit;
    QLineEdit *kAccountCreatorNumber;
    SKGCalculatorEdit *kMaxLimitAmout;
    QCheckBox *kMaxLimit;
    QLineEdit *kAccountCreatorAddress;
    QLineEdit *kAccountCreatorComment;
    SKGComboBox *kAccountCreatorBank;
    QLabel *kCommentLabel;
    SKGCalculatorEdit *kMinLimitAmout;
    QLabel *kAmountLabel;
    QLabel *kAccountLbl;
    QLabel *kAgencyNumberLbl;
    QLabel *kTypeLbl;
    QLabel *kNumberLbl;
    SKGComboBox *kAccountCreatorType;
    QLineEdit *kAccountCreatorAgencyNumber;
    QLineEdit *kAccountCreatorBankNumber;
    QHBoxLayout *horizontalLayout_12;
    SKGWidgetSelector *kWidgetSelector;
    QWidget *SKGEditionButtonswidget;
    QHBoxLayout *horizontalLayout_2;
    QPushButton *kAccountCreatorAdd;
    QPushButton *kAccountCreatorUpdate;

    void setupUi(QWidget *skgbankplugin_base)
    {
        if (skgbankplugin_base->objectName().isEmpty())
            skgbankplugin_base->setObjectName("skgbankplugin_base");
        skgbankplugin_base->resize(604, 360);
        verticalLayout = new QVBoxLayout(skgbankplugin_base);
        verticalLayout->setSpacing(2);
        verticalLayout->setObjectName("verticalLayout");
        kView = new SKGFilteredTableView(skgbankplugin_base);
        kView->setObjectName("kView");

        verticalLayout->addWidget(kView);

        kInfo = new QLabel(skgbankplugin_base);
        kInfo->setObjectName("kInfo");
        kInfo->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        verticalLayout->addWidget(kInfo);

        line = new QFrame(skgbankplugin_base);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        SKGEditionWidget = new QWidget(skgbankplugin_base);
        SKGEditionWidget->setObjectName("SKGEditionWidget");
        gridLayout_4 = new QGridLayout(SKGEditionWidget);
        gridLayout_4->setSpacing(2);
        gridLayout_4->setObjectName("gridLayout_4");
        gridLayout_4->setContentsMargins(0, 0, 0, 0);
        kAccountCreatorIcon = new SKGComboBox(SKGEditionWidget);
        kAccountCreatorIcon->setObjectName("kAccountCreatorIcon");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kAccountCreatorIcon->sizePolicy().hasHeightForWidth());
        kAccountCreatorIcon->setSizePolicy(sizePolicy);
        kAccountCreatorIcon->setMaximumSize(QSize(45, 16777215));

        gridLayout_4->addWidget(kAccountCreatorIcon, 0, 1, 1, 1);

        kMinLimitunit = new QLabel(SKGEditionWidget);
        kMinLimitunit->setObjectName("kMinLimitunit");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(kMinLimitunit->sizePolicy().hasHeightForWidth());
        kMinLimitunit->setSizePolicy(sizePolicy1);
        kMinLimitunit->setText(QString::fromUtf8("F"));

        gridLayout_4->addWidget(kMinLimitunit, 3, 5, 1, 1);

        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setSpacing(2);
        horizontalLayout_11->setObjectName("horizontalLayout_11");
        kAmountEdit = new SKGCalculatorEdit(SKGEditionWidget);
        kAmountEdit->setObjectName("kAmountEdit");

        horizontalLayout_11->addWidget(kAmountEdit);

        kUnitEdit = new SKGUnitComboBox(SKGEditionWidget);
        kUnitEdit->setObjectName("kUnitEdit");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(kUnitEdit->sizePolicy().hasHeightForWidth());
        kUnitEdit->setSizePolicy(sizePolicy2);
        kUnitEdit->setMinimumSize(QSize(100, 0));
        kUnitEdit->setMaximumSize(QSize(100, 16777215));
        kUnitEdit->setEditable(true);
        kUnitEdit->setSizeAdjustPolicy(QComboBox::AdjustToContents);
        kUnitEdit->setAutoCompletion(false);

        horizontalLayout_11->addWidget(kUnitEdit);

        horizontalSpacer_2 = new QSpacerItem(0, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_11->addItem(horizontalSpacer_2);


        gridLayout_4->addLayout(horizontalLayout_11, 3, 1, 1, 2);

        kAccountCreatorAccount = new QLineEdit(SKGEditionWidget);
        kAccountCreatorAccount->setObjectName("kAccountCreatorAccount");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(kAccountCreatorAccount->sizePolicy().hasHeightForWidth());
        kAccountCreatorAccount->setSizePolicy(sizePolicy3);

        gridLayout_4->addWidget(kAccountCreatorAccount, 1, 1, 1, 2);

        horizontalSpacer = new QSpacerItem(0, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_4->addItem(horizontalSpacer, 3, 15, 1, 1);

        kBankNumberLbl = new QLabel(SKGEditionWidget);
        kBankNumberLbl->setObjectName("kBankNumberLbl");
        sizePolicy1.setHeightForWidth(kBankNumberLbl->sizePolicy().hasHeightForWidth());
        kBankNumberLbl->setSizePolicy(sizePolicy1);
        kBankNumberLbl->setText(QString::fromUtf8("Title:"));
        kBankNumberLbl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_4->addWidget(kBankNumberLbl, 0, 3, 1, 1);

        kAgencyAddressLbl = new QLabel(SKGEditionWidget);
        kAgencyAddressLbl->setObjectName("kAgencyAddressLbl");
        sizePolicy1.setHeightForWidth(kAgencyAddressLbl->sizePolicy().hasHeightForWidth());
        kAgencyAddressLbl->setSizePolicy(sizePolicy1);
        kAgencyAddressLbl->setText(QString::fromUtf8("Title:"));
        kAgencyAddressLbl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_4->addWidget(kAgencyAddressLbl, 0, 6, 1, 1);

        kMaxLimitunit = new QLabel(SKGEditionWidget);
        kMaxLimitunit->setObjectName("kMaxLimitunit");
        sizePolicy1.setHeightForWidth(kMaxLimitunit->sizePolicy().hasHeightForWidth());
        kMaxLimitunit->setSizePolicy(sizePolicy1);
        kMaxLimitunit->setText(QString::fromUtf8("F"));

        gridLayout_4->addWidget(kMaxLimitunit, 3, 14, 1, 1);

        kBankLbl = new QLabel(SKGEditionWidget);
        kBankLbl->setObjectName("kBankLbl");
        sizePolicy1.setHeightForWidth(kBankLbl->sizePolicy().hasHeightForWidth());
        kBankLbl->setSizePolicy(sizePolicy1);
        QFont font;
        font.setBold(true);
        kBankLbl->setFont(font);
        kBankLbl->setText(QString::fromUtf8("Title:"));
        kBankLbl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_4->addWidget(kBankLbl, 0, 0, 1, 1);

        kMinLimit = new QCheckBox(SKGEditionWidget);
        kMinLimit->setObjectName("kMinLimit");
        sizePolicy1.setHeightForWidth(kMinLimit->sizePolicy().hasHeightForWidth());
        kMinLimit->setSizePolicy(sizePolicy1);
        kMinLimit->setText(QString::fromUtf8("Title:"));

        gridLayout_4->addWidget(kMinLimit, 3, 3, 1, 1);

        kAccountCreatorNumber = new QLineEdit(SKGEditionWidget);
        kAccountCreatorNumber->setObjectName("kAccountCreatorNumber");
        sizePolicy3.setHeightForWidth(kAccountCreatorNumber->sizePolicy().hasHeightForWidth());
        kAccountCreatorNumber->setSizePolicy(sizePolicy3);

        gridLayout_4->addWidget(kAccountCreatorNumber, 2, 4, 1, 12);

        kMaxLimitAmout = new SKGCalculatorEdit(SKGEditionWidget);
        kMaxLimitAmout->setObjectName("kMaxLimitAmout");
        kMaxLimitAmout->setEnabled(false);
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(kMaxLimitAmout->sizePolicy().hasHeightForWidth());
        kMaxLimitAmout->setSizePolicy(sizePolicy4);

        gridLayout_4->addWidget(kMaxLimitAmout, 3, 13, 1, 1);

        kMaxLimit = new QCheckBox(SKGEditionWidget);
        kMaxLimit->setObjectName("kMaxLimit");
        sizePolicy1.setHeightForWidth(kMaxLimit->sizePolicy().hasHeightForWidth());
        kMaxLimit->setSizePolicy(sizePolicy1);
        kMaxLimit->setText(QString::fromUtf8("Title:"));

        gridLayout_4->addWidget(kMaxLimit, 3, 6, 1, 1);

        kAccountCreatorAddress = new QLineEdit(SKGEditionWidget);
        kAccountCreatorAddress->setObjectName("kAccountCreatorAddress");
        sizePolicy3.setHeightForWidth(kAccountCreatorAddress->sizePolicy().hasHeightForWidth());
        kAccountCreatorAddress->setSizePolicy(sizePolicy3);
        kAccountCreatorAddress->setProperty("showClearButton", QVariant(true));

        gridLayout_4->addWidget(kAccountCreatorAddress, 0, 9, 1, 7);

        kAccountCreatorComment = new QLineEdit(SKGEditionWidget);
        kAccountCreatorComment->setObjectName("kAccountCreatorComment");
        sizePolicy3.setHeightForWidth(kAccountCreatorComment->sizePolicy().hasHeightForWidth());
        kAccountCreatorComment->setSizePolicy(sizePolicy3);
        kAccountCreatorComment->setProperty("showClearButton", QVariant(true));

        gridLayout_4->addWidget(kAccountCreatorComment, 1, 9, 1, 7);

        kAccountCreatorBank = new SKGComboBox(SKGEditionWidget);
        kAccountCreatorBank->setObjectName("kAccountCreatorBank");
        kAccountCreatorBank->setMinimumSize(QSize(112, 0));
        kAccountCreatorBank->setEditable(true);

        gridLayout_4->addWidget(kAccountCreatorBank, 0, 2, 1, 1);

        kCommentLabel = new QLabel(SKGEditionWidget);
        kCommentLabel->setObjectName("kCommentLabel");
        sizePolicy1.setHeightForWidth(kCommentLabel->sizePolicy().hasHeightForWidth());
        kCommentLabel->setSizePolicy(sizePolicy1);
        kCommentLabel->setText(QString::fromUtf8("Title:"));
        kCommentLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_4->addWidget(kCommentLabel, 1, 6, 1, 1);

        kMinLimitAmout = new SKGCalculatorEdit(SKGEditionWidget);
        kMinLimitAmout->setObjectName("kMinLimitAmout");
        kMinLimitAmout->setEnabled(false);
        sizePolicy4.setHeightForWidth(kMinLimitAmout->sizePolicy().hasHeightForWidth());
        kMinLimitAmout->setSizePolicy(sizePolicy4);

        gridLayout_4->addWidget(kMinLimitAmout, 3, 4, 1, 1);

        kAmountLabel = new QLabel(SKGEditionWidget);
        kAmountLabel->setObjectName("kAmountLabel");
        sizePolicy1.setHeightForWidth(kAmountLabel->sizePolicy().hasHeightForWidth());
        kAmountLabel->setSizePolicy(sizePolicy1);
        kAmountLabel->setFont(font);
        kAmountLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_4->addWidget(kAmountLabel, 3, 0, 1, 1);

        kAccountLbl = new QLabel(SKGEditionWidget);
        kAccountLbl->setObjectName("kAccountLbl");
        sizePolicy1.setHeightForWidth(kAccountLbl->sizePolicy().hasHeightForWidth());
        kAccountLbl->setSizePolicy(sizePolicy1);
        QFont font1;
        font1.setBold(true);
        font1.setStrikeOut(false);
        font1.setKerning(true);
        font1.setStyleStrategy(QFont::PreferDefault);
        kAccountLbl->setFont(font1);
        kAccountLbl->setText(QString::fromUtf8("&Title:"));
        kAccountLbl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_4->addWidget(kAccountLbl, 1, 0, 1, 1);

        kAgencyNumberLbl = new QLabel(SKGEditionWidget);
        kAgencyNumberLbl->setObjectName("kAgencyNumberLbl");
        sizePolicy1.setHeightForWidth(kAgencyNumberLbl->sizePolicy().hasHeightForWidth());
        kAgencyNumberLbl->setSizePolicy(sizePolicy1);
        kAgencyNumberLbl->setText(QString::fromUtf8("Title:"));
        kAgencyNumberLbl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_4->addWidget(kAgencyNumberLbl, 1, 3, 1, 1);

        kTypeLbl = new QLabel(SKGEditionWidget);
        kTypeLbl->setObjectName("kTypeLbl");
        sizePolicy1.setHeightForWidth(kTypeLbl->sizePolicy().hasHeightForWidth());
        kTypeLbl->setSizePolicy(sizePolicy1);
        kTypeLbl->setFont(font1);
        kTypeLbl->setText(QString::fromUtf8("&Title:"));
        kTypeLbl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_4->addWidget(kTypeLbl, 2, 0, 1, 1);

        kNumberLbl = new QLabel(SKGEditionWidget);
        kNumberLbl->setObjectName("kNumberLbl");
        sizePolicy1.setHeightForWidth(kNumberLbl->sizePolicy().hasHeightForWidth());
        kNumberLbl->setSizePolicy(sizePolicy1);
        kNumberLbl->setText(QString::fromUtf8("Title:"));
        kNumberLbl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_4->addWidget(kNumberLbl, 2, 3, 1, 1);

        kAccountCreatorType = new SKGComboBox(SKGEditionWidget);
        kAccountCreatorType->setObjectName("kAccountCreatorType");
        sizePolicy4.setHeightForWidth(kAccountCreatorType->sizePolicy().hasHeightForWidth());
        kAccountCreatorType->setSizePolicy(sizePolicy4);
        kAccountCreatorType->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        gridLayout_4->addWidget(kAccountCreatorType, 2, 1, 1, 2);

        kAccountCreatorAgencyNumber = new QLineEdit(SKGEditionWidget);
        kAccountCreatorAgencyNumber->setObjectName("kAccountCreatorAgencyNumber");
        sizePolicy3.setHeightForWidth(kAccountCreatorAgencyNumber->sizePolicy().hasHeightForWidth());
        kAccountCreatorAgencyNumber->setSizePolicy(sizePolicy3);

        gridLayout_4->addWidget(kAccountCreatorAgencyNumber, 1, 4, 1, 2);

        kAccountCreatorBankNumber = new QLineEdit(SKGEditionWidget);
        kAccountCreatorBankNumber->setObjectName("kAccountCreatorBankNumber");
        sizePolicy3.setHeightForWidth(kAccountCreatorBankNumber->sizePolicy().hasHeightForWidth());
        kAccountCreatorBankNumber->setSizePolicy(sizePolicy3);

        gridLayout_4->addWidget(kAccountCreatorBankNumber, 0, 4, 1, 2);


        verticalLayout->addWidget(SKGEditionWidget);

        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setSpacing(2);
        horizontalLayout_12->setObjectName("horizontalLayout_12");
        kWidgetSelector = new SKGWidgetSelector(skgbankplugin_base);
        kWidgetSelector->setObjectName("kWidgetSelector");

        horizontalLayout_12->addWidget(kWidgetSelector);

        SKGEditionButtonswidget = new QWidget(skgbankplugin_base);
        SKGEditionButtonswidget->setObjectName("SKGEditionButtonswidget");
        horizontalLayout_2 = new QHBoxLayout(SKGEditionButtonswidget);
        horizontalLayout_2->setSpacing(2);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(0, 0, 0, 0);
        kAccountCreatorAdd = new QPushButton(SKGEditionButtonswidget);
        kAccountCreatorAdd->setObjectName("kAccountCreatorAdd");
        kAccountCreatorAdd->setEnabled(false);
        kAccountCreatorAdd->setAutoDefault(true);

        horizontalLayout_2->addWidget(kAccountCreatorAdd);

        kAccountCreatorUpdate = new QPushButton(SKGEditionButtonswidget);
        kAccountCreatorUpdate->setObjectName("kAccountCreatorUpdate");
        kAccountCreatorUpdate->setEnabled(false);

        horizontalLayout_2->addWidget(kAccountCreatorUpdate);


        horizontalLayout_12->addWidget(SKGEditionButtonswidget);


        verticalLayout->addLayout(horizontalLayout_12);

#if QT_CONFIG(shortcut)
        kBankNumberLbl->setBuddy(kAccountCreatorBankNumber);
        kAgencyAddressLbl->setBuddy(kAccountCreatorAddress);
        kCommentLabel->setBuddy(kAccountCreatorComment);
        kAmountLabel->setBuddy(kAmountEdit);
        kAccountLbl->setBuddy(kAccountCreatorAccount);
        kAgencyNumberLbl->setBuddy(kAccountCreatorAgencyNumber);
        kTypeLbl->setBuddy(kAccountCreatorType);
        kNumberLbl->setBuddy(kAccountCreatorNumber);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kAccountCreatorIcon, kAccountCreatorBank);
        QWidget::setTabOrder(kAccountCreatorBank, kAccountCreatorAccount);
        QWidget::setTabOrder(kAccountCreatorAccount, kAccountCreatorType);
        QWidget::setTabOrder(kAccountCreatorType, kAmountEdit);
        QWidget::setTabOrder(kAmountEdit, kUnitEdit);
        QWidget::setTabOrder(kUnitEdit, kAccountCreatorBankNumber);
        QWidget::setTabOrder(kAccountCreatorBankNumber, kAccountCreatorAgencyNumber);
        QWidget::setTabOrder(kAccountCreatorAgencyNumber, kAccountCreatorNumber);
        QWidget::setTabOrder(kAccountCreatorNumber, kAccountCreatorAddress);
        QWidget::setTabOrder(kAccountCreatorAddress, kAccountCreatorComment);
        QWidget::setTabOrder(kAccountCreatorComment, kMinLimit);
        QWidget::setTabOrder(kMinLimit, kMinLimitAmout);
        QWidget::setTabOrder(kMinLimitAmout, kMaxLimit);
        QWidget::setTabOrder(kMaxLimit, kMaxLimitAmout);
        QWidget::setTabOrder(kMaxLimitAmout, kAccountCreatorAdd);
        QWidget::setTabOrder(kAccountCreatorAdd, kAccountCreatorUpdate);

        retranslateUi(skgbankplugin_base);

        kAccountCreatorAdd->setDefault(true);


        QMetaObject::connectSlotsByName(skgbankplugin_base);
    } // setupUi

    void retranslateUi(QWidget *skgbankplugin_base)
    {
        kInfo->setText(tr2i18n("Computing\342\200\246", nullptr));
#if QT_CONFIG(tooltip)
        kAccountCreatorIcon->setToolTip(tr2i18n("Icon of the bank", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kAccountCreatorIcon->setStatusTip(tr2i18n("Icon of the bank", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kAmountEdit->setToolTip(tr2i18n("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"https://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Bitstream Vera Sans'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Amount of the transaction.</p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">You can enter expressions here, such as <span style=\" font-style:italic;\">3+4*2</span>, skrooge will compute the result (<span style=\" font-style:italic;\">11</span>)</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kAmountEdit->setStatusTip(tr2i18n("Initial balance of the account (A negative value for a loan account)", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kUnitEdit->setToolTip(tr2i18n("Unit of the initial balance of the account", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kUnitEdit->setStatusTip(tr2i18n("Unit of the initial balance of the account", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kAccountCreatorAccount->setToolTip(tr2i18n("Name of the account", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kAccountCreatorAccount->setStatusTip(tr2i18n("Name of the account", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kAccountCreatorNumber->setToolTip(tr2i18n("Number of the account", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kAccountCreatorNumber->setStatusTip(tr2i18n("Number of the account", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kMaxLimitAmout->setToolTip(tr2i18n("Maximum amount of the account", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kMaxLimitAmout->setStatusTip(tr2i18n("Maximum amount of the account", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kAccountCreatorAddress->setToolTip(tr2i18n("Address of the agency", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kAccountCreatorAddress->setStatusTip(tr2i18n("Address of the agency", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kAccountCreatorComment->setToolTip(tr2i18n("Comment of the account", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kAccountCreatorComment->setStatusTip(tr2i18n("Comment of the account", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kAccountCreatorBank->setToolTip(tr2i18n("Name of the bank", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kAccountCreatorBank->setStatusTip(tr2i18n("Name of the bank", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kMinLimitAmout->setToolTip(tr2i18n("Minimum amount of the account", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kMinLimitAmout->setStatusTip(tr2i18n("Minimum amount of the account", nullptr));
#endif // QT_CONFIG(statustip)
        kAmountLabel->setText(tr2i18n("Initial &balance:", "Noun, a numerical quantity"));
#if QT_CONFIG(tooltip)
        kAccountCreatorType->setToolTip(tr2i18n("Type of the account", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kAccountCreatorType->setStatusTip(tr2i18n("Type of the account", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kAccountCreatorAgencyNumber->setToolTip(tr2i18n("Number of the agency", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kAccountCreatorAgencyNumber->setStatusTip(tr2i18n("Number of the agency", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kAccountCreatorBankNumber->setToolTip(tr2i18n("Number of the bank", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kAccountCreatorBankNumber->setStatusTip(tr2i18n("Number of the bank", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kAccountCreatorAdd->setToolTip(tr2i18n("Add a bank and an account (Ctrl+Enter)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kAccountCreatorAdd->setStatusTip(tr2i18n("Add a bank and an account (Ctrl+Enter)", nullptr));
#endif // QT_CONFIG(statustip)
        kAccountCreatorAdd->setText(tr2i18n("Add", "Verb, add an item to a list"));
#if QT_CONFIG(tooltip)
        kAccountCreatorUpdate->setToolTip(tr2i18n("Update selected banks and accounts (Shift+Enter)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kAccountCreatorUpdate->setStatusTip(tr2i18n("Update selected banks and accounts (Shift+Enter)", nullptr));
#endif // QT_CONFIG(statustip)
        kAccountCreatorUpdate->setText(tr2i18n("Modify", "Verb, modify an item"));
        (void)skgbankplugin_base;
    } // retranslateUi

};

namespace Ui {
    class skgbankplugin_base: public Ui_skgbankplugin_base {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGBANKPLUGINWIDGET_BASE_H

