// This file is generated by kconfig_compiler_kf6 from skgunit_settings.kcfg.
// All changes you do to this file will be lost.

#include "skgunit_settings.h"

#include <qglobal.h>
#include <QFile>

class skgunit_settingsHelper
{
  public:
    skgunit_settingsHelper() noexcept : q(nullptr) {}
    ~skgunit_settingsHelper() noexcept { delete q; q = nullptr; }
    skgunit_settingsHelper(const skgunit_settingsHelper&) = delete;
    skgunit_settingsHelper& operator=(const skgunit_settingsHelper&) = delete;
    skgunit_settings *q;
};
Q_GLOBAL_STATIC(skgunit_settingsHelper, s_globalskgunit_settings)
skgunit_settings *skgunit_settings::self()
{
  if (!s_globalskgunit_settings()->q) {
    new skgunit_settings;
    s_globalskgunit_settings()->q->read();
  }

  return s_globalskgunit_settings()->q;
}

skgunit_settings::skgunit_settings( )
  : KConfigSkeleton()
{
  Q_ASSERT(!s_globalskgunit_settings()->q);
  s_globalskgunit_settings()->q = this;
  setCurrentGroup( QStringLiteral( "skrooge_unit" ) );

  KConfigSkeleton::ItemBool  *itemLast;
  itemLast = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "last" ), mLast, true );
  addItem( itemLast, QStringLiteral( "last" ) );
  KConfigSkeleton::ItemBool  *itemLast_monthly;
  itemLast_monthly = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "last_monthly" ), mLast_monthly, false );
  addItem( itemLast_monthly, QStringLiteral( "last_monthly" ) );
  KConfigSkeleton::ItemBool  *itemLast_weekly;
  itemLast_weekly = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "last_weekly" ), mLast_weekly, false );
  addItem( itemLast_weekly, QStringLiteral( "last_weekly" ) );
  KConfigSkeleton::ItemBool  *itemLast_daily;
  itemLast_daily = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "last_daily" ), mLast_daily, false );
  addItem( itemLast_daily, QStringLiteral( "last_daily" ) );
  KConfigSkeleton::ItemBool  *itemAll_monthly;
  itemAll_monthly = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "all_monthly" ), mAll_monthly, false );
  addItem( itemAll_monthly, QStringLiteral( "all_monthly" ) );
  KConfigSkeleton::ItemBool  *itemAll_weekly;
  itemAll_weekly = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "all_weekly" ), mAll_weekly, false );
  addItem( itemAll_weekly, QStringLiteral( "all_weekly" ) );
  KConfigSkeleton::ItemBool  *itemAll_daily;
  itemAll_daily = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "all_daily" ), mAll_daily, false );
  addItem( itemAll_daily, QStringLiteral( "all_daily" ) );
  KConfigSkeleton::ItemBool  *itemDownload_on_open;
  itemDownload_on_open = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "download_on_open" ), mDownload_on_open, false );
  addItem( itemDownload_on_open, QStringLiteral( "download_on_open" ) );
  KConfigSkeleton::ItemInt  *itemDownload_frequency;
  itemDownload_frequency = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "download_frequency" ), mDownload_frequency, 0 );
  addItem( itemDownload_frequency, QStringLiteral( "download_frequency" ) );
  KConfigSkeleton::ItemInt  *itemNb_loaded_values;
  itemNb_loaded_values = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "nb_loaded_values" ), mNb_loaded_values, 50 );
  addItem( itemNb_loaded_values, QStringLiteral( "nb_loaded_values" ) );
}

skgunit_settings::~skgunit_settings()
{
  if (s_globalskgunit_settings.exists() && !s_globalskgunit_settings.isDestroyed()) {
    s_globalskgunit_settings()->q = nullptr;
  }
}

