/********************************************************************************
** Form generated from reading UI file 'skgimportexportpluginwidget_pref.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGIMPORTEXPORTPLUGINWIDGET_PREF_H
#define UI_SKGIMPORTEXPORTPLUGINWIDGET_PREF_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "skgcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_skgimportexportplugin_pref
{
public:
    QVBoxLayout *verticalLayout_2;
    QTabWidget *tabWidget;
    QWidget *kGeneral;
    QVBoxLayout *verticalLayout_3;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QCheckBox *kcfg_apply_rules;
    QCheckBox *kcfg_automatic_validation;
    QCheckBox *kcfg_open_after_import_or_processing;
    QCheckBox *kcfg_since_last_import;
    QSpacerItem *verticalSpacer_4;
    QWidget *kCsv;
    QVBoxLayout *verticalLayout_5;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QVBoxLayout *verticalLayout_4;
    QGridLayout *gridLayout_3;
    QFrame *kHeaderPositionFrm;
    QGridLayout *gridLayout;
    QLabel *label;
    QSpinBox *kcfg_header_position;
    QLabel *label_7;
    QSpacerItem *horizontalSpacer;
    QCheckBox *kcfg_automatic_search_header;
    QCheckBox *kcfg_automatic_search_columns;
    QFrame *kCsvMappingFrm;
    QGridLayout *gridLayout_4;
    QLabel *kDateLbl;
    QLabel *kNumberLbl;
    QLabel *kTypeLabel;
    QLabel *kPayeeLabel;
    QLabel *kCommentLabel;
    QLabel *kStatusLbl;
    QLabel *kBookmarkedLbl;
    QLabel *kAccountLabel;
    QLabel *kCategoryLabel;
    QLabel *kAmountLabel;
    QLabel *kQuantityLbl;
    QLabel *kSignLbl;
    QLabel *kUnitLbl;
    QLabel *kidtransaction;
    QLabel *label_8;
    QLabel *label_9;
    QLabel *label_6;
    QLineEdit *kcfg_mapping_sign;
    QLineEdit *kcfg_mapping_quantity;
    QLineEdit *kcfg_mapping_amount;
    QLineEdit *kcfg_mapping_category;
    QLineEdit *kcfg_mapping_date;
    QLineEdit *kcfg_mapping_number;
    QLineEdit *kcfg_mapping_unit;
    QLineEdit *kcfg_mapping_idtransaction;
    QLineEdit *kcfg_mapping_idgroup;
    QLineEdit *kcfg_mapping_property;
    QLineEdit *kcfg_mapping_account;
    QLineEdit *kcfg_mapping_bookmarked;
    QLineEdit *kcfg_mapping_status;
    QLineEdit *kcfg_mapping_comment;
    QLineEdit *kcfg_mapping_payee;
    QLineEdit *kcfg_mapping_mode;
    QFrame *kColumnsPositionsFrm;
    QGridLayout *gridLayout_2;
    QLabel *label_2;
    QLineEdit *kcfg_columns_positions;
    QLabel *kLabelColumns;
    QLabel *label_3;
    QLabel *label_4;
    QLabel *label_5;
    QPushButton *More;
    QHBoxLayout *horizontalLayout;
    QLabel *kSignLbl_2;
    QLineEdit *kcfg_mapping_debit;
    QSpacerItem *verticalSpacer_2;
    QSpacerItem *horizontalSpacer_2;
    QLabel *label_12;
    SKGComboBox *kcfg_csv_date_format;
    QWidget *kLedger;
    QFormLayout *formLayout;
    QLabel *label_13;
    QLineEdit *kcfg_ledger_account_identification;
    QWidget *kQif;
    QGridLayout *gridLayout_6;
    QLabel *label_11;
    SKGComboBox *kcfg_qif_date_format;
    QSpacerItem *horizontalSpacer_3;
    QSpacerItem *verticalSpacer_3;
    QWidget *kBackends;
    QGridLayout *gridLayout_5;
    QLineEdit *kcfg_backends;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *kcfg_download_on_open;
    KComboBox *kcfg_download_frequency;
    QSpacerItem *horizontalSpacer_4;
    QLabel *label_10;
    QLabel *kbackendText;

    void setupUi(QWidget *skgimportexportplugin_pref)
    {
        if (skgimportexportplugin_pref->objectName().isEmpty())
            skgimportexportplugin_pref->setObjectName("skgimportexportplugin_pref");
        skgimportexportplugin_pref->resize(696, 506);
        verticalLayout_2 = new QVBoxLayout(skgimportexportplugin_pref);
        verticalLayout_2->setSpacing(2);
        verticalLayout_2->setObjectName("verticalLayout_2");
        tabWidget = new QTabWidget(skgimportexportplugin_pref);
        tabWidget->setObjectName("tabWidget");
        kGeneral = new QWidget();
        kGeneral->setObjectName("kGeneral");
        verticalLayout_3 = new QVBoxLayout(kGeneral);
        verticalLayout_3->setSpacing(2);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        groupBox = new QGroupBox(kGeneral);
        groupBox->setObjectName("groupBox");
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setSpacing(2);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        kcfg_apply_rules = new QCheckBox(groupBox);
        kcfg_apply_rules->setObjectName("kcfg_apply_rules");

        verticalLayout->addWidget(kcfg_apply_rules);

        kcfg_automatic_validation = new QCheckBox(groupBox);
        kcfg_automatic_validation->setObjectName("kcfg_automatic_validation");

        verticalLayout->addWidget(kcfg_automatic_validation);

        kcfg_open_after_import_or_processing = new QCheckBox(groupBox);
        kcfg_open_after_import_or_processing->setObjectName("kcfg_open_after_import_or_processing");

        verticalLayout->addWidget(kcfg_open_after_import_or_processing);

        kcfg_since_last_import = new QCheckBox(groupBox);
        kcfg_since_last_import->setObjectName("kcfg_since_last_import");

        verticalLayout->addWidget(kcfg_since_last_import);

        verticalSpacer_4 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_4);


        verticalLayout_3->addWidget(groupBox);

        tabWidget->addTab(kGeneral, QString());
        kCsv = new QWidget();
        kCsv->setObjectName("kCsv");
        verticalLayout_5 = new QVBoxLayout(kCsv);
        verticalLayout_5->setSpacing(2);
        verticalLayout_5->setObjectName("verticalLayout_5");
        verticalLayout_5->setContentsMargins(0, 0, 0, 0);
        scrollArea = new QScrollArea(kCsv);
        scrollArea->setObjectName("scrollArea");
        scrollArea->setFrameShape(QFrame::Shape::NoFrame);
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 657, 1067));
        verticalLayout_4 = new QVBoxLayout(scrollAreaWidgetContents);
        verticalLayout_4->setSpacing(2);
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout_4->setContentsMargins(0, 0, 0, 0);
        gridLayout_3 = new QGridLayout();
        gridLayout_3->setSpacing(2);
        gridLayout_3->setObjectName("gridLayout_3");
        kHeaderPositionFrm = new QFrame(scrollAreaWidgetContents);
        kHeaderPositionFrm->setObjectName("kHeaderPositionFrm");
        kHeaderPositionFrm->setFrameShape(QFrame::Shape::NoFrame);
        kHeaderPositionFrm->setFrameShadow(QFrame::Shadow::Raised);
        gridLayout = new QGridLayout(kHeaderPositionFrm);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        label = new QLabel(kHeaderPositionFrm);
        label->setObjectName("label");
        label->setEnabled(true);

        gridLayout->addWidget(label, 0, 0, 1, 1);

        kcfg_header_position = new QSpinBox(kHeaderPositionFrm);
        kcfg_header_position->setObjectName("kcfg_header_position");
        kcfg_header_position->setEnabled(true);
        kcfg_header_position->setFocusPolicy(Qt::FocusPolicy::WheelFocus);
        kcfg_header_position->setMinimum(0);

        gridLayout->addWidget(kcfg_header_position, 0, 1, 1, 1);

        label_7 = new QLabel(kHeaderPositionFrm);
        label_7->setObjectName("label_7");

        gridLayout->addWidget(label_7, 0, 2, 1, 1);

        horizontalSpacer = new QSpacerItem(0, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 3, 1, 1);


        gridLayout_3->addWidget(kHeaderPositionFrm, 2, 0, 1, 3);

        kcfg_automatic_search_header = new QCheckBox(scrollAreaWidgetContents);
        kcfg_automatic_search_header->setObjectName("kcfg_automatic_search_header");
        kcfg_automatic_search_header->setChecked(true);

        gridLayout_3->addWidget(kcfg_automatic_search_header, 1, 0, 1, 1);

        kcfg_automatic_search_columns = new QCheckBox(scrollAreaWidgetContents);
        kcfg_automatic_search_columns->setObjectName("kcfg_automatic_search_columns");
        kcfg_automatic_search_columns->setChecked(true);

        gridLayout_3->addWidget(kcfg_automatic_search_columns, 3, 0, 1, 1);

        kCsvMappingFrm = new QFrame(scrollAreaWidgetContents);
        kCsvMappingFrm->setObjectName("kCsvMappingFrm");
        kCsvMappingFrm->setFrameShadow(QFrame::Shadow::Raised);
        gridLayout_4 = new QGridLayout(kCsvMappingFrm);
        gridLayout_4->setSpacing(2);
        gridLayout_4->setObjectName("gridLayout_4");
        gridLayout_4->setContentsMargins(0, 0, 0, 0);
        kDateLbl = new QLabel(kCsvMappingFrm);
        kDateLbl->setObjectName("kDateLbl");
        QFont font;
        font.setUnderline(true);
        kDateLbl->setFont(font);
        kDateLbl->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_4->addWidget(kDateLbl, 1, 0, 1, 1);

        kNumberLbl = new QLabel(kCsvMappingFrm);
        kNumberLbl->setObjectName("kNumberLbl");
        kNumberLbl->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_4->addWidget(kNumberLbl, 2, 0, 1, 1);

        kTypeLabel = new QLabel(kCsvMappingFrm);
        kTypeLabel->setObjectName("kTypeLabel");
        kTypeLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_4->addWidget(kTypeLabel, 3, 0, 1, 1);

        kPayeeLabel = new QLabel(kCsvMappingFrm);
        kPayeeLabel->setObjectName("kPayeeLabel");
        kPayeeLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_4->addWidget(kPayeeLabel, 4, 0, 1, 1);

        kCommentLabel = new QLabel(kCsvMappingFrm);
        kCommentLabel->setObjectName("kCommentLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kCommentLabel->sizePolicy().hasHeightForWidth());
        kCommentLabel->setSizePolicy(sizePolicy);
        kCommentLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_4->addWidget(kCommentLabel, 5, 0, 1, 1);

        kStatusLbl = new QLabel(kCsvMappingFrm);
        kStatusLbl->setObjectName("kStatusLbl");
        kStatusLbl->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_4->addWidget(kStatusLbl, 6, 0, 1, 1);

        kBookmarkedLbl = new QLabel(kCsvMappingFrm);
        kBookmarkedLbl->setObjectName("kBookmarkedLbl");
        kBookmarkedLbl->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_4->addWidget(kBookmarkedLbl, 7, 0, 1, 1);

        kAccountLabel = new QLabel(kCsvMappingFrm);
        kAccountLabel->setObjectName("kAccountLabel");
        kAccountLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_4->addWidget(kAccountLabel, 8, 0, 1, 1);

        kCategoryLabel = new QLabel(kCsvMappingFrm);
        kCategoryLabel->setObjectName("kCategoryLabel");
        sizePolicy.setHeightForWidth(kCategoryLabel->sizePolicy().hasHeightForWidth());
        kCategoryLabel->setSizePolicy(sizePolicy);
        kCategoryLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_4->addWidget(kCategoryLabel, 9, 0, 1, 1);

        kAmountLabel = new QLabel(kCsvMappingFrm);
        kAmountLabel->setObjectName("kAmountLabel");
        sizePolicy.setHeightForWidth(kAmountLabel->sizePolicy().hasHeightForWidth());
        kAmountLabel->setSizePolicy(sizePolicy);
        kAmountLabel->setFont(font);
        kAmountLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_4->addWidget(kAmountLabel, 10, 0, 1, 1);

        kQuantityLbl = new QLabel(kCsvMappingFrm);
        kQuantityLbl->setObjectName("kQuantityLbl");
        kQuantityLbl->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_4->addWidget(kQuantityLbl, 11, 0, 1, 1);

        kSignLbl = new QLabel(kCsvMappingFrm);
        kSignLbl->setObjectName("kSignLbl");
        kSignLbl->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_4->addWidget(kSignLbl, 12, 0, 1, 1);

        kUnitLbl = new QLabel(kCsvMappingFrm);
        kUnitLbl->setObjectName("kUnitLbl");
        kUnitLbl->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_4->addWidget(kUnitLbl, 13, 0, 1, 1);

        kidtransaction = new QLabel(kCsvMappingFrm);
        kidtransaction->setObjectName("kidtransaction");
        kidtransaction->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_4->addWidget(kidtransaction, 14, 0, 1, 1);

        label_8 = new QLabel(kCsvMappingFrm);
        label_8->setObjectName("label_8");
        label_8->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_4->addWidget(label_8, 15, 0, 1, 1);

        label_9 = new QLabel(kCsvMappingFrm);
        label_9->setObjectName("label_9");
        label_9->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_4->addWidget(label_9, 16, 0, 1, 1);

        label_6 = new QLabel(kCsvMappingFrm);
        label_6->setObjectName("label_6");
        label_6->setOpenExternalLinks(true);

        gridLayout_4->addWidget(label_6, 0, 0, 1, 2);

        kcfg_mapping_sign = new QLineEdit(kCsvMappingFrm);
        kcfg_mapping_sign->setObjectName("kcfg_mapping_sign");

        gridLayout_4->addWidget(kcfg_mapping_sign, 12, 1, 1, 1);

        kcfg_mapping_quantity = new QLineEdit(kCsvMappingFrm);
        kcfg_mapping_quantity->setObjectName("kcfg_mapping_quantity");

        gridLayout_4->addWidget(kcfg_mapping_quantity, 11, 1, 1, 1);

        kcfg_mapping_amount = new QLineEdit(kCsvMappingFrm);
        kcfg_mapping_amount->setObjectName("kcfg_mapping_amount");

        gridLayout_4->addWidget(kcfg_mapping_amount, 10, 1, 1, 1);

        kcfg_mapping_category = new QLineEdit(kCsvMappingFrm);
        kcfg_mapping_category->setObjectName("kcfg_mapping_category");

        gridLayout_4->addWidget(kcfg_mapping_category, 9, 1, 1, 1);

        kcfg_mapping_date = new QLineEdit(kCsvMappingFrm);
        kcfg_mapping_date->setObjectName("kcfg_mapping_date");

        gridLayout_4->addWidget(kcfg_mapping_date, 1, 1, 1, 1);

        kcfg_mapping_number = new QLineEdit(kCsvMappingFrm);
        kcfg_mapping_number->setObjectName("kcfg_mapping_number");

        gridLayout_4->addWidget(kcfg_mapping_number, 2, 1, 1, 1);

        kcfg_mapping_unit = new QLineEdit(kCsvMappingFrm);
        kcfg_mapping_unit->setObjectName("kcfg_mapping_unit");

        gridLayout_4->addWidget(kcfg_mapping_unit, 13, 1, 1, 1);

        kcfg_mapping_idtransaction = new QLineEdit(kCsvMappingFrm);
        kcfg_mapping_idtransaction->setObjectName("kcfg_mapping_idtransaction");

        gridLayout_4->addWidget(kcfg_mapping_idtransaction, 14, 1, 1, 1);

        kcfg_mapping_idgroup = new QLineEdit(kCsvMappingFrm);
        kcfg_mapping_idgroup->setObjectName("kcfg_mapping_idgroup");

        gridLayout_4->addWidget(kcfg_mapping_idgroup, 15, 1, 1, 1);

        kcfg_mapping_property = new QLineEdit(kCsvMappingFrm);
        kcfg_mapping_property->setObjectName("kcfg_mapping_property");

        gridLayout_4->addWidget(kcfg_mapping_property, 16, 1, 1, 1);

        kcfg_mapping_account = new QLineEdit(kCsvMappingFrm);
        kcfg_mapping_account->setObjectName("kcfg_mapping_account");

        gridLayout_4->addWidget(kcfg_mapping_account, 8, 1, 1, 1);

        kcfg_mapping_bookmarked = new QLineEdit(kCsvMappingFrm);
        kcfg_mapping_bookmarked->setObjectName("kcfg_mapping_bookmarked");

        gridLayout_4->addWidget(kcfg_mapping_bookmarked, 7, 1, 1, 1);

        kcfg_mapping_status = new QLineEdit(kCsvMappingFrm);
        kcfg_mapping_status->setObjectName("kcfg_mapping_status");

        gridLayout_4->addWidget(kcfg_mapping_status, 6, 1, 1, 1);

        kcfg_mapping_comment = new QLineEdit(kCsvMappingFrm);
        kcfg_mapping_comment->setObjectName("kcfg_mapping_comment");

        gridLayout_4->addWidget(kcfg_mapping_comment, 5, 1, 1, 1);

        kcfg_mapping_payee = new QLineEdit(kCsvMappingFrm);
        kcfg_mapping_payee->setObjectName("kcfg_mapping_payee");

        gridLayout_4->addWidget(kcfg_mapping_payee, 4, 1, 1, 1);

        kcfg_mapping_mode = new QLineEdit(kCsvMappingFrm);
        kcfg_mapping_mode->setObjectName("kcfg_mapping_mode");

        gridLayout_4->addWidget(kcfg_mapping_mode, 3, 1, 1, 1);


        gridLayout_3->addWidget(kCsvMappingFrm, 5, 0, 1, 3);

        kColumnsPositionsFrm = new QFrame(scrollAreaWidgetContents);
        kColumnsPositionsFrm->setObjectName("kColumnsPositionsFrm");
        kColumnsPositionsFrm->setFrameShape(QFrame::Shape::NoFrame);
        kColumnsPositionsFrm->setFrameShadow(QFrame::Shadow::Raised);
        gridLayout_2 = new QGridLayout(kColumnsPositionsFrm);
        gridLayout_2->setSpacing(2);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(0, 0, 0, 0);
        label_2 = new QLabel(kColumnsPositionsFrm);
        label_2->setObjectName("label_2");
        label_2->setEnabled(true);

        gridLayout_2->addWidget(label_2, 0, 0, 1, 1);

        kcfg_columns_positions = new QLineEdit(kColumnsPositionsFrm);
        kcfg_columns_positions->setObjectName("kcfg_columns_positions");

        gridLayout_2->addWidget(kcfg_columns_positions, 0, 1, 1, 1);

        kLabelColumns = new QLabel(kColumnsPositionsFrm);
        kLabelColumns->setObjectName("kLabelColumns");
        QFont font1;
        font1.setItalic(true);
        kLabelColumns->setFont(font1);

        gridLayout_2->addWidget(kLabelColumns, 1, 0, 1, 3);

        label_3 = new QLabel(kColumnsPositionsFrm);
        label_3->setObjectName("label_3");
        label_3->setText(QString::fromUtf8("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"https://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'DejaVu Sans'; font-size:8pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:9pt;\">    </span><span style=\" font-size:9pt; text-decoration: underline;\">date,</span><span style=\" font-size:9pt;\"> number, mode, payee, comment, status, </span></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:9pt;\">    bookmarked, account, category, </span><span style=\" font-size:9pt; text-decoration: underline;\">amount,</span><span style=\" font-size:9pt;\"> quantity, sign, unit, idtransaction, idgroup</span></p></body"
                        "></html>"));

        gridLayout_2->addWidget(label_3, 2, 0, 1, 2);

        label_4 = new QLabel(kColumnsPositionsFrm);
        label_4->setObjectName("label_4");

        gridLayout_2->addWidget(label_4, 3, 0, 1, 2);

        label_5 = new QLabel(kColumnsPositionsFrm);
        label_5->setObjectName("label_5");
        label_5->setText(QString::fromUtf8("date|mode|payee|comment||amount|status|my_property"));

        gridLayout_2->addWidget(label_5, 4, 0, 1, 2);


        gridLayout_3->addWidget(kColumnsPositionsFrm, 7, 0, 1, 3);

        More = new QPushButton(scrollAreaWidgetContents);
        More->setObjectName("More");
        More->setEnabled(true);
        More->setCheckable(true);

        gridLayout_3->addWidget(More, 3, 1, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        kSignLbl_2 = new QLabel(scrollAreaWidgetContents);
        kSignLbl_2->setObjectName("kSignLbl_2");
        kSignLbl_2->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        horizontalLayout->addWidget(kSignLbl_2);

        kcfg_mapping_debit = new QLineEdit(scrollAreaWidgetContents);
        kcfg_mapping_debit->setObjectName("kcfg_mapping_debit");

        horizontalLayout->addWidget(kcfg_mapping_debit);


        gridLayout_3->addLayout(horizontalLayout, 8, 0, 1, 3);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_3->addItem(verticalSpacer_2, 9, 0, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(0, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_2, 3, 2, 1, 1);

        label_12 = new QLabel(scrollAreaWidgetContents);
        label_12->setObjectName("label_12");
        label_12->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_3->addWidget(label_12, 0, 0, 1, 1);

        kcfg_csv_date_format = new SKGComboBox(scrollAreaWidgetContents);
        kcfg_csv_date_format->setObjectName("kcfg_csv_date_format");

        gridLayout_3->addWidget(kcfg_csv_date_format, 0, 1, 1, 1);


        verticalLayout_4->addLayout(gridLayout_3);

        scrollArea->setWidget(scrollAreaWidgetContents);

        verticalLayout_5->addWidget(scrollArea);

        tabWidget->addTab(kCsv, QString());
        tabWidget->setTabText(tabWidget->indexOf(kCsv), QString::fromUtf8("CSV"));
        kLedger = new QWidget();
        kLedger->setObjectName("kLedger");
        formLayout = new QFormLayout(kLedger);
        formLayout->setObjectName("formLayout");
        formLayout->setHorizontalSpacing(2);
        formLayout->setVerticalSpacing(2);
        formLayout->setContentsMargins(0, 0, 0, 0);
        label_13 = new QLabel(kLedger);
        label_13->setObjectName("label_13");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_13);

        kcfg_ledger_account_identification = new QLineEdit(kLedger);
        kcfg_ledger_account_identification->setObjectName("kcfg_ledger_account_identification");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_ledger_account_identification);

        tabWidget->addTab(kLedger, QString());
        tabWidget->setTabText(tabWidget->indexOf(kLedger), QString::fromUtf8("Ledger"));
        kQif = new QWidget();
        kQif->setObjectName("kQif");
        gridLayout_6 = new QGridLayout(kQif);
        gridLayout_6->setSpacing(2);
        gridLayout_6->setObjectName("gridLayout_6");
        gridLayout_6->setContentsMargins(0, 0, 0, 0);
        label_11 = new QLabel(kQif);
        label_11->setObjectName("label_11");
        label_11->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_6->addWidget(label_11, 0, 0, 1, 1);

        kcfg_qif_date_format = new SKGComboBox(kQif);
        kcfg_qif_date_format->setObjectName("kcfg_qif_date_format");

        gridLayout_6->addWidget(kcfg_qif_date_format, 0, 1, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(388, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_6->addItem(horizontalSpacer_3, 0, 2, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_6->addItem(verticalSpacer_3, 1, 0, 1, 1);

        tabWidget->addTab(kQif, QString());
        tabWidget->setTabText(tabWidget->indexOf(kQif), QString::fromUtf8("QIF"));
        kBackends = new QWidget();
        kBackends->setObjectName("kBackends");
        gridLayout_5 = new QGridLayout(kBackends);
        gridLayout_5->setSpacing(2);
        gridLayout_5->setObjectName("gridLayout_5");
        gridLayout_5->setContentsMargins(0, 0, 0, 0);
        kcfg_backends = new QLineEdit(kBackends);
        kcfg_backends->setObjectName("kcfg_backends");

        gridLayout_5->addWidget(kcfg_backends, 1, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_5->addItem(verticalSpacer, 3, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(2);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        kcfg_download_on_open = new QCheckBox(kBackends);
        kcfg_download_on_open->setObjectName("kcfg_download_on_open");

        horizontalLayout_2->addWidget(kcfg_download_on_open);

        kcfg_download_frequency = new KComboBox(kBackends);
        kcfg_download_frequency->addItem(QString());
        kcfg_download_frequency->addItem(QString());
        kcfg_download_frequency->addItem(QString());
        kcfg_download_frequency->setObjectName("kcfg_download_frequency");
        kcfg_download_frequency->setEnabled(false);

        horizontalLayout_2->addWidget(kcfg_download_frequency);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_4);


        gridLayout_5->addLayout(horizontalLayout_2, 0, 0, 1, 2);

        label_10 = new QLabel(kBackends);
        label_10->setObjectName("label_10");
        label_10->setFont(font);

        gridLayout_5->addWidget(label_10, 1, 0, 1, 1);

        kbackendText = new QLabel(kBackends);
        kbackendText->setObjectName("kbackendText");
        kbackendText->setTextFormat(Qt::TextFormat::RichText);

        gridLayout_5->addWidget(kbackendText, 2, 0, 1, 2);

        tabWidget->addTab(kBackends, QString());

        verticalLayout_2->addWidget(tabWidget);

#if QT_CONFIG(shortcut)
        kDateLbl->setBuddy(kcfg_mapping_date);
        kNumberLbl->setBuddy(kcfg_mapping_number);
        kTypeLabel->setBuddy(kcfg_mapping_mode);
        kPayeeLabel->setBuddy(kcfg_mapping_payee);
        kCommentLabel->setBuddy(kcfg_mapping_comment);
        kStatusLbl->setBuddy(kcfg_mapping_status);
        kBookmarkedLbl->setBuddy(kcfg_mapping_bookmarked);
        kAccountLabel->setBuddy(kcfg_mapping_account);
        kCategoryLabel->setBuddy(kcfg_mapping_category);
        kAmountLabel->setBuddy(kcfg_mapping_amount);
        kQuantityLbl->setBuddy(kcfg_mapping_quantity);
        kSignLbl->setBuddy(kcfg_mapping_sign);
        kUnitLbl->setBuddy(kcfg_mapping_unit);
        kidtransaction->setBuddy(kcfg_mapping_idtransaction);
        label_8->setBuddy(kcfg_mapping_idgroup);
        label_9->setBuddy(kcfg_mapping_property);
        label_2->setBuddy(kcfg_columns_positions);
        kSignLbl_2->setBuddy(kcfg_mapping_debit);
        label_12->setBuddy(kcfg_csv_date_format);
        label_11->setBuddy(kcfg_qif_date_format);
        label_10->setBuddy(kcfg_backends);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(tabWidget, scrollArea);
        QWidget::setTabOrder(scrollArea, kcfg_csv_date_format);
        QWidget::setTabOrder(kcfg_csv_date_format, kcfg_automatic_search_header);
        QWidget::setTabOrder(kcfg_automatic_search_header, kcfg_header_position);
        QWidget::setTabOrder(kcfg_header_position, kcfg_automatic_search_columns);
        QWidget::setTabOrder(kcfg_automatic_search_columns, More);
        QWidget::setTabOrder(More, kcfg_mapping_date);
        QWidget::setTabOrder(kcfg_mapping_date, kcfg_mapping_number);
        QWidget::setTabOrder(kcfg_mapping_number, kcfg_mapping_mode);
        QWidget::setTabOrder(kcfg_mapping_mode, kcfg_mapping_payee);
        QWidget::setTabOrder(kcfg_mapping_payee, kcfg_mapping_comment);
        QWidget::setTabOrder(kcfg_mapping_comment, kcfg_mapping_status);
        QWidget::setTabOrder(kcfg_mapping_status, kcfg_mapping_bookmarked);
        QWidget::setTabOrder(kcfg_mapping_bookmarked, kcfg_mapping_account);
        QWidget::setTabOrder(kcfg_mapping_account, kcfg_mapping_category);
        QWidget::setTabOrder(kcfg_mapping_category, kcfg_mapping_amount);
        QWidget::setTabOrder(kcfg_mapping_amount, kcfg_mapping_quantity);
        QWidget::setTabOrder(kcfg_mapping_quantity, kcfg_mapping_sign);
        QWidget::setTabOrder(kcfg_mapping_sign, kcfg_mapping_unit);
        QWidget::setTabOrder(kcfg_mapping_unit, kcfg_mapping_idtransaction);
        QWidget::setTabOrder(kcfg_mapping_idtransaction, kcfg_mapping_idgroup);
        QWidget::setTabOrder(kcfg_mapping_idgroup, kcfg_mapping_property);
        QWidget::setTabOrder(kcfg_mapping_property, kcfg_columns_positions);
        QWidget::setTabOrder(kcfg_columns_positions, kcfg_mapping_debit);
        QWidget::setTabOrder(kcfg_mapping_debit, kcfg_since_last_import);
        QWidget::setTabOrder(kcfg_since_last_import, kcfg_qif_date_format);
        QWidget::setTabOrder(kcfg_qif_date_format, kcfg_open_after_import_or_processing);
        QWidget::setTabOrder(kcfg_open_after_import_or_processing, kcfg_apply_rules);
        QWidget::setTabOrder(kcfg_apply_rules, kcfg_automatic_validation);

        retranslateUi(skgimportexportplugin_pref);

        tabWidget->setCurrentIndex(2);


        QMetaObject::connectSlotsByName(skgimportexportplugin_pref);
    } // setupUi

    void retranslateUi(QWidget *skgimportexportplugin_pref)
    {
        groupBox->setTitle(tr2i18n("After import", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_apply_rules->setToolTip(tr2i18n("This option allows to apply all rules defined in \"Search and process\" on all imported transactions", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_apply_rules->setText(tr2i18n("Apply rules on imported transactions", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_automatic_validation->setToolTip(tr2i18n("This option allows to validate all imported transactions", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_automatic_validation->setText(tr2i18n("Automatic validation", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_open_after_import_or_processing->setToolTip(tr2i18n("This option allows to open all imported transactions at the end of the import", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_open_after_import_or_processing->setText(tr2i18n("Open transactions", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_since_last_import->setToolTip(tr2i18n("<html><head/><body><p><span style=\" font-weight:600; color:#ff0000;\">WARNING: </span>In some conditions, this option can cause missing transactions. </p><p>This option is mainly interesting with OFX import when your bank is not able to generate real unique identifier for transactions.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_since_last_import->setText(tr2i18n("Import only transactions since the last imported one (not recommended)", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(kGeneral), tr2i18n("General", nullptr));
#if QT_CONFIG(tooltip)
        tabWidget->setTabToolTip(tabWidget->indexOf(kGeneral), tr2i18n("General import settings", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(tr2i18n("Header position:", nullptr));
        label_7->setText(tr2i18n("0 if CSV file does not have header", nullptr));
        kcfg_automatic_search_header->setText(tr2i18n("Automatic search of the header", nullptr));
        kcfg_automatic_search_columns->setText(tr2i18n("Automatic search of the columns", nullptr));
#if QT_CONFIG(tooltip)
        kDateLbl->setToolTip(tr2i18n("Date of the transaction", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kDateLbl->setStatusTip(tr2i18n("Date of the transaction", nullptr));
#endif // QT_CONFIG(statustip)
        kDateLbl->setText(tr2i18n("Date:", nullptr));
#if QT_CONFIG(tooltip)
        kNumberLbl->setToolTip(tr2i18n("Number of the transaction, for example the Check number, or a Transfer reference.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kNumberLbl->setStatusTip(tr2i18n("Number of the transaction", nullptr));
#endif // QT_CONFIG(statustip)
        kNumberLbl->setText(tr2i18n("Number:", nullptr));
#if QT_CONFIG(tooltip)
        kTypeLabel->setToolTip(tr2i18n("Transaction mode (how you made the operation).\n"
"Examples: Credit Card, Check, Transfer\342\200\246\n"
"", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kTypeLabel->setStatusTip(tr2i18n("Transaction mode", nullptr));
#endif // QT_CONFIG(statustip)
        kTypeLabel->setText(tr2i18n("Mode:", "Noun, the mode used for payment of the transaction (Credit Card, Cheque, Transfer\342\200\246)"));
#if QT_CONFIG(tooltip)
        kPayeeLabel->setToolTip(tr2i18n("Payee of the transaction", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kPayeeLabel->setStatusTip(tr2i18n("Payee of the transaction", nullptr));
#endif // QT_CONFIG(statustip)
        kPayeeLabel->setText(tr2i18n("Pa&yee:", "Noun, a person or institution receiving a payment, or paying the operation"));
#if QT_CONFIG(tooltip)
        kCommentLabel->setToolTip(tr2i18n("Comment of the transaction", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kCommentLabel->setStatusTip(tr2i18n("Comment of the transaction", nullptr));
#endif // QT_CONFIG(statustip)
        kCommentLabel->setText(tr2i18n("Comment:", "Noun, a user comment on an item"));
#if QT_CONFIG(tooltip)
        kStatusLbl->setToolTip(tr2i18n("Status of the transaction (reconciled or not)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kStatusLbl->setStatusTip(tr2i18n("Status of the transaction", nullptr));
#endif // QT_CONFIG(statustip)
        kStatusLbl->setText(tr2i18n("Status:", nullptr));
#if QT_CONFIG(tooltip)
        kBookmarkedLbl->setToolTip(tr2i18n("Bookmark of the transaction", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kBookmarkedLbl->setStatusTip(tr2i18n("Bookmark of the transaction", nullptr));
#endif // QT_CONFIG(statustip)
        kBookmarkedLbl->setText(tr2i18n("Boo&kmarked:", nullptr));
#if QT_CONFIG(tooltip)
        kAccountLabel->setToolTip(tr2i18n("Account of the transaction", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kAccountLabel->setStatusTip(tr2i18n("Account of the transaction", nullptr));
#endif // QT_CONFIG(statustip)
        kAccountLabel->setText(tr2i18n("Account:", "Noun, an account as in a bank account"));
#if QT_CONFIG(tooltip)
        kCategoryLabel->setToolTip(tr2i18n("Category of the transaction", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kCategoryLabel->setStatusTip(tr2i18n("Category of the transaction", nullptr));
#endif // QT_CONFIG(statustip)
        kCategoryLabel->setText(tr2i18n("Category:", "Noun, the category of an item"));
#if QT_CONFIG(tooltip)
        kAmountLabel->setToolTip(tr2i18n("Amount of the transaction", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kAmountLabel->setStatusTip(tr2i18n("Amount of the transaction", nullptr));
#endif // QT_CONFIG(statustip)
        kAmountLabel->setText(tr2i18n("Amount:", "Noun, a numerical quantity"));
#if QT_CONFIG(tooltip)
        kQuantityLbl->setToolTip(tr2i18n("Amount of the transaction", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kQuantityLbl->setStatusTip(tr2i18n("Amount of the transaction", nullptr));
#endif // QT_CONFIG(statustip)
        kQuantityLbl->setText(tr2i18n("Quantity:", nullptr));
#if QT_CONFIG(tooltip)
        kSignLbl->setToolTip(tr2i18n("Sign of the transaction", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kSignLbl->setStatusTip(tr2i18n("Sign of the transaction", nullptr));
#endif // QT_CONFIG(statustip)
        kSignLbl->setText(tr2i18n("Sign:", nullptr));
#if QT_CONFIG(tooltip)
        kUnitLbl->setToolTip(tr2i18n("Unit of the transaction", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kUnitLbl->setStatusTip(tr2i18n("Unit of the transaction", nullptr));
#endif // QT_CONFIG(statustip)
        kUnitLbl->setText(tr2i18n("Unit:", nullptr));
#if QT_CONFIG(statustip)
        kidtransaction->setStatusTip(tr2i18n("Id to join all transactions as a split transaction", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(whatsthis)
        kidtransaction->setWhatsThis(tr2i18n("Id to join all transactions as a split transaction", nullptr));
#endif // QT_CONFIG(whatsthis)
        kidtransaction->setText(tr2i18n("Idtransaction:", nullptr));
#if QT_CONFIG(statustip)
        label_8->setStatusTip(tr2i18n("Id to join all transactions as a transfer", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(whatsthis)
        label_8->setWhatsThis(tr2i18n("Id to join all transactions as a transfer", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_8->setText(tr2i18n("Idgroup:", nullptr));
#if QT_CONFIG(statustip)
        label_9->setStatusTip(tr2i18n("To identify column to import as properties", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(whatsthis)
        label_9->setWhatsThis(tr2i18n("To identify column to import as properties", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_9->setText(tr2i18n("Property:", nullptr));
        label_6->setText(tr2i18n("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"https://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'DejaVu Sans'; font-size:8pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">You have to define <a href=\"https://en.wikipedia.org/wiki/Regular_expression\"><span style=\" text-decoration: underline; color:#0057ae;\">regular expression</span></a> allowing to automatically map each attribute.</p></body></html>", nullptr));
        label_2->setText(tr2i18n("Column positions:", nullptr));
        kLabelColumns->setText(tr2i18n("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"https://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'DejaVu Sans'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">  Must be a string containing following key words separated by <span style=\" font-weight:600;\">|</span>:</p></body></html>", nullptr));
        label_4->setText(tr2i18n("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"https://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'DejaVu Sans'; font-size:8pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:9pt;\">  </span><span style=\" font-size:9pt;\">or nothing to ignore the column</span><span style=\" font-size:9pt;\"> </span></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:9pt;\">  or anything else to import the column as a property.</span></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:9pt;\"></p>\n"
"<p style=\" "
                        "margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:9pt;\">  </span><span style=\" font-size:9pt; text-decoration: underline;\">Example:</span></p></body></html>", nullptr));
        More->setText(tr2i18n("Edit regular expressions\342\200\246", nullptr));
#if QT_CONFIG(tooltip)
        kSignLbl_2->setToolTip(tr2i18n("How to identify a debit", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kSignLbl_2->setStatusTip(tr2i18n("How to identify a debit", nullptr));
#endif // QT_CONFIG(statustip)
        kSignLbl_2->setText(tr2i18n("Debit values of \"sign\" column:", nullptr));
        label_12->setText(tr2i18n("Date format:", nullptr));
#if QT_CONFIG(tooltip)
        tabWidget->setTabToolTip(tabWidget->indexOf(kCsv), tr2i18n("Settings for CSV import", nullptr));
#endif // QT_CONFIG(tooltip)
        label_13->setText(tr2i18n("Account identification:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ledger_account_identification->setToolTip(tr2i18n("<html><head/><body><p>In ledger file, there is not difference between an account and a category. During import, we need to be able to do this difference. For that, you must enter here some words that will identify accounts.</p></body></html>", "Don't translate the word \"Ledger\" because this is the name of an application"));
#endif // QT_CONFIG(tooltip)
        label_11->setText(tr2i18n("Date format:", nullptr));
#if QT_CONFIG(tooltip)
        tabWidget->setTabToolTip(tabWidget->indexOf(kQif), tr2i18n("Settings for QIF import", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_download_on_open->setText(tr2i18n("Download on open", nullptr));
        kcfg_download_frequency->setItemText(0, tr2i18n("Once a day", nullptr));
        kcfg_download_frequency->setItemText(1, tr2i18n("Once a week", nullptr));
        kcfg_download_frequency->setItemText(2, tr2i18n("Once a month", nullptr));

        label_10->setText(tr2i18n("List of bac&kends used:", nullptr));
        kbackendText->setText(QString());
        tabWidget->setTabText(tabWidget->indexOf(kBackends), tr2i18n("Backends", nullptr));
#if QT_CONFIG(tooltip)
        tabWidget->setTabToolTip(tabWidget->indexOf(kBackends), tr2i18n("Settings for import by backends", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)skgimportexportplugin_pref;
    } // retranslateUi

};

namespace Ui {
    class skgimportexportplugin_pref: public Ui_skgimportexportplugin_pref {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGIMPORTEXPORTPLUGINWIDGET_PREF_H

