// This file is generated by kconfig_compiler_kf6 from skgfile_settings.kcfg.
// All changes you do to this file will be lost.

#include "skgfile_settings.h"

#include <qglobal.h>
#include <QFile>

class skgfile_settingsHelper
{
  public:
    skgfile_settingsHelper() noexcept : q(nullptr) {}
    ~skgfile_settingsHelper() noexcept { delete q; q = nullptr; }
    skgfile_settingsHelper(const skgfile_settingsHelper&) = delete;
    skgfile_settingsHelper& operator=(const skgfile_settingsHelper&) = delete;
    skgfile_settings *q;
};
Q_GLOBAL_STATIC(skgfile_settingsHelper, s_globalskgfile_settings)
skgfile_settings *skgfile_settings::self()
{
  if (!s_globalskgfile_settings()->q) {
    new skgfile_settings;
    s_globalskgfile_settings()->q->read();
  }

  return s_globalskgfile_settings()->q;
}

skgfile_settings::skgfile_settings( )
  : KConfigSkeleton()
{
  Q_ASSERT(!s_globalskgfile_settings()->q);
  s_globalskgfile_settings()->q = this;
  setCurrentGroup( QStringLiteral( "File" ) );

  KConfigSkeleton::ItemBool  *itemOpenlastfile;
  itemOpenlastfile = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "openlastfile" ), mOpenlastfile, true );
  addItem( itemOpenlastfile, QStringLiteral( "openlastfile" ) );
  KConfigSkeleton::ItemBool  *itemSaveonclose;
  itemSaveonclose = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "saveonclose" ), mSaveonclose, false );
  addItem( itemSaveonclose, QStringLiteral( "saveonclose" ) );
  KConfigSkeleton::ItemBool  *itemStoreInKdeWallet;
  itemStoreInKdeWallet = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "storeInKdeWallet" ), mStoreInKdeWallet, false );
  addItem( itemStoreInKdeWallet, QStringLiteral( "storeInKdeWallet" ) );
  KConfigSkeleton::ItemString  *itemSelectedWallet;
  itemSelectedWallet = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "selectedWallet" ), mSelectedWallet, QStringLiteral( "kdewallet" ) );
  addItem( itemSelectedWallet, QStringLiteral( "selectedWallet" ) );
  KConfigSkeleton::ItemBool  *itemBackup_enabled;
  itemBackup_enabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "backup_enabled" ), mBackup_enabled, true );
  addItem( itemBackup_enabled, QStringLiteral( "backup_enabled" ) );
  KConfigSkeleton::ItemString  *itemPrefix;
  itemPrefix = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "prefix" ), mPrefix );
  addItem( itemPrefix, QStringLiteral( "prefix" ) );
  KConfigSkeleton::ItemString  *itemSuffix;
  itemSuffix = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "suffix" ), mSuffix, QStringLiteral( ".old" ) );
  addItem( itemSuffix, QStringLiteral( "suffix" ) );
  KConfigSkeleton::ItemPath  *itemLastfilepath;
  itemLastfilepath = new KConfigSkeleton::ItemPath( currentGroup(), QStringLiteral( "lastfilepath" ), mLastfilepath );
  addItem( itemLastfilepath, QStringLiteral( "lastfilepath" ) );
}

skgfile_settings::~skgfile_settings()
{
  if (s_globalskgfile_settings.exists() && !s_globalskgfile_settings.isDestroyed()) {
    s_globalskgfile_settings()->q = nullptr;
  }
}

