// This file is generated by kconfig_compiler_kf6 from skgimportexport_settings.kcfg.
// All changes you do to this file will be lost.
#ifndef SKGIMPORTEXPORT_SETTINGS_H
#define SKGIMPORTEXPORT_SETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

#include <skgimportexportmanager.h>

class skgimportexport_settings : public KConfigSkeleton
{
  public:

    static skgimportexport_settings *self();
    ~skgimportexport_settings() override;

    /**
      Get Automatic validation after import
    */
    static
    bool automatic_validation()
    {
      return self()->mAutomatic_validation;
    }

    /**
      Is Automatic validation after import Immutable
    */
    static
    bool isAutomatic_validationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "automatic_validation" ) );
    }

    /**
      Get Apply rules on to imported transactions
    */
    static
    bool apply_rules()
    {
      return self()->mApply_rules;
    }

    /**
      Is Apply rules on to imported transactions Immutable
    */
    static
    bool isApply_rulesImmutable()
    {
      return self()->isImmutable( QStringLiteral( "apply_rules" ) );
    }

    /**
      Get Open transactions after import or processing
    */
    static
    bool open_after_import_or_processing()
    {
      return self()->mOpen_after_import_or_processing;
    }

    /**
      Is Open transactions after import or processing Immutable
    */
    static
    bool isOpen_after_import_or_processingImmutable()
    {
      return self()->isImmutable( QStringLiteral( "open_after_import_or_processing" ) );
    }

    /**
      Get Import only transactions since the last imported one
    */
    static
    bool since_last_import()
    {
      return self()->mSince_last_import;
    }

    /**
      Is Import only transactions since the last imported one Immutable
    */
    static
    bool isSince_last_importImmutable()
    {
      return self()->isImmutable( QStringLiteral( "since_last_import" ) );
    }

    /**
      Get Automatic search of the header
    */
    static
    bool automatic_search_header()
    {
      return self()->mAutomatic_search_header;
    }

    /**
      Is Automatic search of the header Immutable
    */
    static
    bool isAutomatic_search_headerImmutable()
    {
      return self()->isImmutable( QStringLiteral( "automatic_search_header" ) );
    }

    /**
      Get Automatic search of the columns
    */
    static
    bool automatic_search_columns()
    {
      return self()->mAutomatic_search_columns;
    }

    /**
      Is Automatic search of the columns Immutable
    */
    static
    bool isAutomatic_search_columnsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "automatic_search_columns" ) );
    }

    /**
      Get Header position
    */
    static
    int header_position()
    {
      return self()->mHeader_position;
    }

    /**
      Is Header position Immutable
    */
    static
    bool isHeader_positionImmutable()
    {
      return self()->isImmutable( QStringLiteral( "header_position" ) );
    }

    /**
      Get Column positions
    */
    static
    QString columns_positions()
    {
      return self()->mColumns_positions;
    }

    /**
      Is Column positions Immutable
    */
    static
    bool isColumns_positionsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "columns_positions" ) );
    }

    /**
      Get Date
    */
    static
    QString mapping_date()
    {
      return self()->mMapping_date;
    }

    /**
      Is Date Immutable
    */
    static
    bool isMapping_dateImmutable()
    {
      return self()->isImmutable( QStringLiteral( "mapping_date" ) );
    }

    /**
      Get Number
    */
    static
    QString mapping_number()
    {
      return self()->mMapping_number;
    }

    /**
      Is Number Immutable
    */
    static
    bool isMapping_numberImmutable()
    {
      return self()->isImmutable( QStringLiteral( "mapping_number" ) );
    }

    /**
      Get Mode
    */
    static
    QString mapping_mode()
    {
      return self()->mMapping_mode;
    }

    /**
      Is Mode Immutable
    */
    static
    bool isMapping_modeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "mapping_mode" ) );
    }

    /**
      Get Payee
    */
    static
    QString mapping_payee()
    {
      return self()->mMapping_payee;
    }

    /**
      Is Payee Immutable
    */
    static
    bool isMapping_payeeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "mapping_payee" ) );
    }

    /**
      Get Comment
    */
    static
    QString mapping_comment()
    {
      return self()->mMapping_comment;
    }

    /**
      Is Comment Immutable
    */
    static
    bool isMapping_commentImmutable()
    {
      return self()->isImmutable( QStringLiteral( "mapping_comment" ) );
    }

    /**
      Get Status
    */
    static
    QString mapping_status()
    {
      return self()->mMapping_status;
    }

    /**
      Is Status Immutable
    */
    static
    bool isMapping_statusImmutable()
    {
      return self()->isImmutable( QStringLiteral( "mapping_status" ) );
    }

    /**
      Get Bookmarked
    */
    static
    QString mapping_bookmarked()
    {
      return self()->mMapping_bookmarked;
    }

    /**
      Is Bookmarked Immutable
    */
    static
    bool isMapping_bookmarkedImmutable()
    {
      return self()->isImmutable( QStringLiteral( "mapping_bookmarked" ) );
    }

    /**
      Get Account
    */
    static
    QString mapping_account()
    {
      return self()->mMapping_account;
    }

    /**
      Is Account Immutable
    */
    static
    bool isMapping_accountImmutable()
    {
      return self()->isImmutable( QStringLiteral( "mapping_account" ) );
    }

    /**
      Get Category
    */
    static
    QString mapping_category()
    {
      return self()->mMapping_category;
    }

    /**
      Is Category Immutable
    */
    static
    bool isMapping_categoryImmutable()
    {
      return self()->isImmutable( QStringLiteral( "mapping_category" ) );
    }

    /**
      Get Amount
    */
    static
    QString mapping_amount()
    {
      return self()->mMapping_amount;
    }

    /**
      Is Amount Immutable
    */
    static
    bool isMapping_amountImmutable()
    {
      return self()->isImmutable( QStringLiteral( "mapping_amount" ) );
    }

    /**
      Get Quantity
    */
    static
    QString mapping_quantity()
    {
      return self()->mMapping_quantity;
    }

    /**
      Is Quantity Immutable
    */
    static
    bool isMapping_quantityImmutable()
    {
      return self()->isImmutable( QStringLiteral( "mapping_quantity" ) );
    }

    /**
      Get Sign
    */
    static
    QString mapping_sign()
    {
      return self()->mMapping_sign;
    }

    /**
      Is Sign Immutable
    */
    static
    bool isMapping_signImmutable()
    {
      return self()->isImmutable( QStringLiteral( "mapping_sign" ) );
    }

    /**
      Get Debit
    */
    static
    QString mapping_debit()
    {
      return self()->mMapping_debit;
    }

    /**
      Is Debit Immutable
    */
    static
    bool isMapping_debitImmutable()
    {
      return self()->isImmutable( QStringLiteral( "mapping_debit" ) );
    }

    /**
      Get Unit
    */
    static
    QString mapping_unit()
    {
      return self()->mMapping_unit;
    }

    /**
      Is Unit Immutable
    */
    static
    bool isMapping_unitImmutable()
    {
      return self()->isImmutable( QStringLiteral( "mapping_unit" ) );
    }

    /**
      Get Idtransaction
    */
    static
    QString mapping_idtransaction()
    {
      return self()->mMapping_idtransaction;
    }

    /**
      Is Idtransaction Immutable
    */
    static
    bool isMapping_idtransactionImmutable()
    {
      return self()->isImmutable( QStringLiteral( "mapping_idtransaction" ) );
    }

    /**
      Get Idgroup
    */
    static
    QString mapping_idgroup()
    {
      return self()->mMapping_idgroup;
    }

    /**
      Is Idgroup Immutable
    */
    static
    bool isMapping_idgroupImmutable()
    {
      return self()->isImmutable( QStringLiteral( "mapping_idgroup" ) );
    }

    /**
      Get Property
    */
    static
    QString mapping_property()
    {
      return self()->mMapping_property;
    }

    /**
      Is Property Immutable
    */
    static
    bool isMapping_propertyImmutable()
    {
      return self()->isImmutable( QStringLiteral( "mapping_property" ) );
    }

    /**
      Get List of backends used
    */
    static
    QString backends()
    {
      return self()->mBackends;
    }

    /**
      Is List of backends used Immutable
    */
    static
    bool isBackendsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "backends" ) );
    }

    /**
      Get CSV date format
    */
    static
    QString csv_date_format()
    {
      return self()->mCsv_date_format;
    }

    /**
      Is CSV date format Immutable
    */
    static
    bool isCsv_date_formatImmutable()
    {
      return self()->isImmutable( QStringLiteral( "csv_date_format" ) );
    }

    /**
      Get Ledger account identification
    */
    static
    QString ledger_account_identification()
    {
      return self()->mLedger_account_identification;
    }

    /**
      Is Ledger account identification Immutable
    */
    static
    bool isLedger_account_identificationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ledger_account_identification" ) );
    }

    /**
      Get QIF date format
    */
    static
    QString qif_date_format()
    {
      return self()->mQif_date_format;
    }

    /**
      Is QIF date format Immutable
    */
    static
    bool isQif_date_formatImmutable()
    {
      return self()->isImmutable( QStringLiteral( "qif_date_format" ) );
    }

    /**
      Get Download all values on open
    */
    static
    bool download_on_open()
    {
      return self()->mDownload_on_open;
    }

    /**
      Is Download all values on open Immutable
    */
    static
    bool isDownload_on_openImmutable()
    {
      return self()->isImmutable( QStringLiteral( "download_on_open" ) );
    }

    /**
      Get Frequency of the automatic download
    */
    static
    int download_frequency()
    {
      return self()->mDownload_frequency;
    }

    /**
      Is Frequency of the automatic download Immutable
    */
    static
    bool isDownload_frequencyImmutable()
    {
      return self()->isImmutable( QStringLiteral( "download_frequency" ) );
    }

  protected:
    skgimportexport_settings();
    friend class skgimportexport_settingsHelper;


    // skrooge_importexport
    bool mAutomatic_validation;
    bool mApply_rules;
    bool mOpen_after_import_or_processing;
    bool mSince_last_import;
    bool mAutomatic_search_header;
    bool mAutomatic_search_columns;
    int mHeader_position;
    QString mColumns_positions;
    QString mMapping_date;
    QString mMapping_number;
    QString mMapping_mode;
    QString mMapping_payee;
    QString mMapping_comment;
    QString mMapping_status;
    QString mMapping_bookmarked;
    QString mMapping_account;
    QString mMapping_category;
    QString mMapping_amount;
    QString mMapping_quantity;
    QString mMapping_sign;
    QString mMapping_debit;
    QString mMapping_unit;
    QString mMapping_idtransaction;
    QString mMapping_idgroup;
    QString mMapping_property;
    QString mBackends;
    QString mCsv_date_format;
    QString mLedger_account_identification;
    QString mQif_date_format;
    bool mDownload_on_open;
    int mDownload_frequency;
};

#endif

