/********************************************************************************
** Form generated from reading UI file 'skgtrackerpluginwidget_pref.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGTRACKERPLUGINWIDGET_PREF_H
#define UI_SKGTRACKERPLUGINWIDGET_PREF_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_skgtrackerplugin_pref
{
public:
    QVBoxLayout *verticalLayout;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *skgtrackerplugin_pref)
    {
        if (skgtrackerplugin_pref->objectName().isEmpty())
            skgtrackerplugin_pref->setObjectName("skgtrackerplugin_pref");
        skgtrackerplugin_pref->resize(367, 184);
        verticalLayout = new QVBoxLayout(skgtrackerplugin_pref);
        verticalLayout->setObjectName("verticalLayout");
        verticalSpacer = new QSpacerItem(20, 126, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(skgtrackerplugin_pref);

        QMetaObject::connectSlotsByName(skgtrackerplugin_pref);
    } // setupUi

    void retranslateUi(QWidget *skgtrackerplugin_pref)
    {
        (void)skgtrackerplugin_pref;
    } // retranslateUi

};

namespace Ui {
    class skgtrackerplugin_pref: public Ui_skgtrackerplugin_pref {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGTRACKERPLUGINWIDGET_PREF_H

