/********************************************************************************
** Form generated from reading UI file 'skgreportpluginwidget_pref.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGREPORTPLUGINWIDGET_PREF_H
#define UI_SKGREPORTPLUGINWIDGET_PREF_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"

QT_BEGIN_NAMESPACE

class Ui_skgreportplugin_pref
{
public:
    QFormLayout *formLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QLabel *label6_2;
    QLabel *label1_2;
    KColorButton *kcfg_backgroundColor;
    KColorButton *kcfg_tendencyColor;
    QLabel *label5;
    QLabel *label2;
    KColorButton *kcfg_minColor;
    QLabel *label3;
    KColorButton *kcfg_maxColor;
    QLabel *label4;
    KColorButton *kcfg_averageColor;
    QLabel *label6;
    KColorButton *kcfg_gridColor;
    QLabel *label1;
    KColorButton *kcfg_axisColor;
    QLabel *label1_3;
    KColorButton *kcfg_textColor;
    KColorButton *kcfg_outlineColor;
    KColorButton *kcfg_paretoColor;
    QLabel *label6_3;
    QCheckBox *kcfg_antialiasing;
    QLabel *label;
    QSpinBox *kcfg_maxForecasts;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *skgreportplugin_pref)
    {
        if (skgreportplugin_pref->objectName().isEmpty())
            skgreportplugin_pref->setObjectName("skgreportplugin_pref");
        skgreportplugin_pref->resize(529, 434);
        formLayout = new QFormLayout(skgreportplugin_pref);
        formLayout->setObjectName("formLayout");
        formLayout->setHorizontalSpacing(2);
        formLayout->setVerticalSpacing(2);
        formLayout->setContentsMargins(0, 0, 0, 0);
        groupBox = new QGroupBox(skgreportplugin_pref);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        label6_2 = new QLabel(groupBox);
        label6_2->setObjectName("label6_2");
        label6_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label6_2, 8, 0, 1, 1);

        label1_2 = new QLabel(groupBox);
        label1_2->setObjectName("label1_2");
        label1_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label1_2, 0, 0, 1, 1);

        kcfg_backgroundColor = new KColorButton(groupBox);
        kcfg_backgroundColor->setObjectName("kcfg_backgroundColor");

        gridLayout->addWidget(kcfg_backgroundColor, 0, 1, 1, 1);

        kcfg_tendencyColor = new KColorButton(groupBox);
        kcfg_tendencyColor->setObjectName("kcfg_tendencyColor");

        gridLayout->addWidget(kcfg_tendencyColor, 7, 4, 1, 1);

        label5 = new QLabel(groupBox);
        label5->setObjectName("label5");
        label5->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label5, 7, 3, 1, 1);

        label2 = new QLabel(groupBox);
        label2->setObjectName("label2");
        label2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label2, 0, 3, 1, 1);

        kcfg_minColor = new KColorButton(groupBox);
        kcfg_minColor->setObjectName("kcfg_minColor");

        gridLayout->addWidget(kcfg_minColor, 0, 4, 1, 1);

        label3 = new QLabel(groupBox);
        label3->setObjectName("label3");
        label3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label3, 2, 3, 1, 1);

        kcfg_maxColor = new KColorButton(groupBox);
        kcfg_maxColor->setObjectName("kcfg_maxColor");

        gridLayout->addWidget(kcfg_maxColor, 2, 4, 1, 1);

        label4 = new QLabel(groupBox);
        label4->setObjectName("label4");
        label4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label4, 3, 3, 1, 1);

        kcfg_averageColor = new KColorButton(groupBox);
        kcfg_averageColor->setObjectName("kcfg_averageColor");

        gridLayout->addWidget(kcfg_averageColor, 3, 4, 1, 1);

        label6 = new QLabel(groupBox);
        label6->setObjectName("label6");
        label6->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label6, 7, 0, 1, 1);

        kcfg_gridColor = new KColorButton(groupBox);
        kcfg_gridColor->setObjectName("kcfg_gridColor");

        gridLayout->addWidget(kcfg_gridColor, 7, 1, 1, 1);

        label1 = new QLabel(groupBox);
        label1->setObjectName("label1");
        label1->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label1, 3, 0, 1, 1);

        kcfg_axisColor = new KColorButton(groupBox);
        kcfg_axisColor->setObjectName("kcfg_axisColor");

        gridLayout->addWidget(kcfg_axisColor, 3, 1, 1, 1);

        label1_3 = new QLabel(groupBox);
        label1_3->setObjectName("label1_3");
        label1_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label1_3, 2, 0, 1, 1);

        kcfg_textColor = new KColorButton(groupBox);
        kcfg_textColor->setObjectName("kcfg_textColor");

        gridLayout->addWidget(kcfg_textColor, 2, 1, 1, 1);

        kcfg_outlineColor = new KColorButton(groupBox);
        kcfg_outlineColor->setObjectName("kcfg_outlineColor");

        gridLayout->addWidget(kcfg_outlineColor, 8, 1, 1, 1);

        kcfg_paretoColor = new KColorButton(groupBox);
        kcfg_paretoColor->setObjectName("kcfg_paretoColor");

        gridLayout->addWidget(kcfg_paretoColor, 8, 4, 1, 1);

        label6_3 = new QLabel(groupBox);
        label6_3->setObjectName("label6_3");
        label6_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label6_3, 8, 3, 1, 1);


        formLayout->setWidget(0, QFormLayout::ItemRole::SpanningRole, groupBox);

        kcfg_antialiasing = new QCheckBox(skgreportplugin_pref);
        kcfg_antialiasing->setObjectName("kcfg_antialiasing");
        kcfg_antialiasing->setChecked(true);

        formLayout->setWidget(2, QFormLayout::ItemRole::SpanningRole, kcfg_antialiasing);

        label = new QLabel(skgreportplugin_pref);
        label->setObjectName("label");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, label);

        kcfg_maxForecasts = new QSpinBox(skgreportplugin_pref);
        kcfg_maxForecasts->setObjectName("kcfg_maxForecasts");

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, kcfg_maxForecasts);

        verticalSpacer = new QSpacerItem(20, 126, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout->setItem(6, QFormLayout::ItemRole::LabelRole, verticalSpacer);

#if QT_CONFIG(shortcut)
        label6_2->setBuddy(kcfg_outlineColor);
        label1_2->setBuddy(kcfg_backgroundColor);
        label5->setBuddy(kcfg_tendencyColor);
        label2->setBuddy(kcfg_minColor);
        label3->setBuddy(kcfg_maxColor);
        label4->setBuddy(kcfg_averageColor);
        label6->setBuddy(kcfg_gridColor);
        label1->setBuddy(kcfg_axisColor);
        label1_3->setBuddy(kcfg_textColor);
        label6_3->setBuddy(kcfg_paretoColor);
        label->setBuddy(kcfg_maxForecasts);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kcfg_backgroundColor, kcfg_textColor);
        QWidget::setTabOrder(kcfg_textColor, kcfg_axisColor);
        QWidget::setTabOrder(kcfg_axisColor, kcfg_gridColor);
        QWidget::setTabOrder(kcfg_gridColor, kcfg_outlineColor);
        QWidget::setTabOrder(kcfg_outlineColor, kcfg_minColor);
        QWidget::setTabOrder(kcfg_minColor, kcfg_maxColor);
        QWidget::setTabOrder(kcfg_maxColor, kcfg_averageColor);
        QWidget::setTabOrder(kcfg_averageColor, kcfg_tendencyColor);
        QWidget::setTabOrder(kcfg_tendencyColor, kcfg_paretoColor);

        retranslateUi(skgreportplugin_pref);

        QMetaObject::connectSlotsByName(skgreportplugin_pref);
    } // setupUi

    void retranslateUi(QWidget *skgreportplugin_pref)
    {
        groupBox->setTitle(tr2i18n("Colors", nullptr));
        label6_2->setText(tr2i18n("Outline color:", nullptr));
        label1_2->setText(tr2i18n("&Background color:", nullptr));
        label5->setText(tr2i18n("Tendenc&y color:", nullptr));
        label2->setText(tr2i18n("Minimum color:", nullptr));
        label3->setText(tr2i18n("Maximum color:", nullptr));
        label4->setText(tr2i18n("A&verage color:", nullptr));
        label6->setText(tr2i18n("Grid color:", nullptr));
        label1->setText(tr2i18n("Axis color:", nullptr));
        label1_3->setText(tr2i18n("Text color:", nullptr));
        label6_3->setText(tr2i18n("Pareto color:", nullptr));
        kcfg_antialiasing->setText(tr2i18n("Antialiasing", nullptr));
        label->setText(tr2i18n("Maximum duration of forecasts on scheduled transactions (years):", nullptr));
        (void)skgreportplugin_pref;
    } // retranslateUi

};

namespace Ui {
    class skgreportplugin_pref: public Ui_skgreportplugin_pref {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGREPORTPLUGINWIDGET_PREF_H

