/********************************************************************************
** Form generated from reading UI file 'skgdebugpluginwidget_base.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGDEBUGPLUGINWIDGET_BASE_H
#define UI_SKGDEBUGPLUGINWIDGET_BASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "skgcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_skgdebugplugin_base
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *hboxLayout;
    SKGComboBox *kExplainCmb;
    SKGComboBox *kSQLInput;
    QPlainTextEdit *kInput;
    QHBoxLayout *horizontalLayout;
    QPushButton *kSQLPushButton;
    QPushButton *kSQLTransactionPushButton;
    QSpacerItem *horizontalSpacer_2;
    QPushButton *kRefreshViewsAndIndexes;
    QTextEdit *kSQLResult;
    QHBoxLayout *hboxLayout1;
    QLabel *kTraceLevelLbl;
    QSlider *kTraceLevel;
    QCheckBox *kEnableProfilingChk;

    void setupUi(QWidget *skgdebugplugin_base)
    {
        if (skgdebugplugin_base->objectName().isEmpty())
            skgdebugplugin_base->setObjectName("skgdebugplugin_base");
        skgdebugplugin_base->resize(579, 335);
        verticalLayout = new QVBoxLayout(skgdebugplugin_base);
        verticalLayout->setObjectName("verticalLayout");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        kExplainCmb = new SKGComboBox(skgdebugplugin_base);
        kExplainCmb->setObjectName("kExplainCmb");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kExplainCmb->sizePolicy().hasHeightForWidth());
        kExplainCmb->setSizePolicy(sizePolicy);
        kExplainCmb->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        hboxLayout->addWidget(kExplainCmb);

        kSQLInput = new SKGComboBox(skgdebugplugin_base);
        kSQLInput->setObjectName("kSQLInput");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(kSQLInput->sizePolicy().hasHeightForWidth());
        kSQLInput->setSizePolicy(sizePolicy1);
        kSQLInput->setFocusPolicy(Qt::StrongFocus);
        kSQLInput->setEditable(true);
        kSQLInput->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);

        hboxLayout->addWidget(kSQLInput);

        kInput = new QPlainTextEdit(skgdebugplugin_base);
        kInput->setObjectName("kInput");

        hboxLayout->addWidget(kInput);


        verticalLayout->addLayout(hboxLayout);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        kSQLPushButton = new QPushButton(skgdebugplugin_base);
        kSQLPushButton->setObjectName("kSQLPushButton");
        sizePolicy1.setHeightForWidth(kSQLPushButton->sizePolicy().hasHeightForWidth());
        kSQLPushButton->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(kSQLPushButton);

        kSQLTransactionPushButton = new QPushButton(skgdebugplugin_base);
        kSQLTransactionPushButton->setObjectName("kSQLTransactionPushButton");
        sizePolicy1.setHeightForWidth(kSQLTransactionPushButton->sizePolicy().hasHeightForWidth());
        kSQLTransactionPushButton->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(kSQLTransactionPushButton);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);

        kRefreshViewsAndIndexes = new QPushButton(skgdebugplugin_base);
        kRefreshViewsAndIndexes->setObjectName("kRefreshViewsAndIndexes");

        horizontalLayout->addWidget(kRefreshViewsAndIndexes);


        verticalLayout->addLayout(horizontalLayout);

        kSQLResult = new QTextEdit(skgdebugplugin_base);
        kSQLResult->setObjectName("kSQLResult");
        QFont font;
        font.setFamilies({QString::fromUtf8("Courier New")});
        kSQLResult->setFont(font);
        kSQLResult->setLineWrapMode(QTextEdit::NoWrap);
        kSQLResult->setReadOnly(true);
        kSQLResult->setAcceptRichText(false);

        verticalLayout->addWidget(kSQLResult);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        kTraceLevelLbl = new QLabel(skgdebugplugin_base);
        kTraceLevelLbl->setObjectName("kTraceLevelLbl");

        hboxLayout1->addWidget(kTraceLevelLbl);

        kTraceLevel = new QSlider(skgdebugplugin_base);
        kTraceLevel->setObjectName("kTraceLevel");
        kTraceLevel->setMaximum(30);
        kTraceLevel->setOrientation(Qt::Horizontal);
        kTraceLevel->setTickPosition(QSlider::TicksAbove);
        kTraceLevel->setTickInterval(1);

        hboxLayout1->addWidget(kTraceLevel);

        kEnableProfilingChk = new QCheckBox(skgdebugplugin_base);
        kEnableProfilingChk->setObjectName("kEnableProfilingChk");

        hboxLayout1->addWidget(kEnableProfilingChk);


        verticalLayout->addLayout(hboxLayout1);

#if QT_CONFIG(shortcut)
        kTraceLevelLbl->setBuddy(kTraceLevel);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kExplainCmb, kSQLInput);
        QWidget::setTabOrder(kSQLInput, kInput);
        QWidget::setTabOrder(kInput, kSQLPushButton);
        QWidget::setTabOrder(kSQLPushButton, kSQLTransactionPushButton);
        QWidget::setTabOrder(kSQLTransactionPushButton, kRefreshViewsAndIndexes);
        QWidget::setTabOrder(kRefreshViewsAndIndexes, kSQLResult);
        QWidget::setTabOrder(kSQLResult, kTraceLevel);
        QWidget::setTabOrder(kTraceLevel, kEnableProfilingChk);

        retranslateUi(skgdebugplugin_base);

        QMetaObject::connectSlotsByName(skgdebugplugin_base);
    } // setupUi

    void retranslateUi(QWidget *skgdebugplugin_base)
    {
#if QT_CONFIG(tooltip)
        kSQLInput->setToolTip(tr2i18n("SQL command to execute", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kSQLInput->setStatusTip(tr2i18n("SQL command to execute", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kInput->setToolTip(tr2i18n("Script to execute", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kInput->setStatusTip(tr2i18n("Script to execute", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kSQLPushButton->setToolTip(tr2i18n("Execute", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kSQLPushButton->setStatusTip(tr2i18n("Execute", nullptr));
#endif // QT_CONFIG(statustip)
        kSQLPushButton->setText(tr2i18n("Execute", nullptr));
#if QT_CONFIG(tooltip)
        kSQLTransactionPushButton->setToolTip(tr2i18n("Execute in a transaction", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kSQLTransactionPushButton->setStatusTip(tr2i18n("Execute in a transaction", nullptr));
#endif // QT_CONFIG(statustip)
        kSQLTransactionPushButton->setText(tr2i18n("Execute in a transaction", nullptr));
#if QT_CONFIG(tooltip)
        kRefreshViewsAndIndexes->setToolTip(tr2i18n("Refresh Database (views, indexes, triggers)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kRefreshViewsAndIndexes->setStatusTip(tr2i18n("Refresh Database (views, indexes, triggers)", nullptr));
#endif // QT_CONFIG(statustip)
        kRefreshViewsAndIndexes->setText(tr2i18n("Refresh Database", nullptr));
#if QT_CONFIG(tooltip)
        kSQLResult->setToolTip(tr2i18n("SQL output", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kSQLResult->setStatusTip(tr2i18n("SQL output", nullptr));
#endif // QT_CONFIG(statustip)
        kTraceLevelLbl->setText(tr2i18n("&Trace level:", nullptr));
#if QT_CONFIG(tooltip)
        kTraceLevel->setToolTip(tr2i18n("Select level of traces", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kTraceLevel->setStatusTip(tr2i18n("Select level of traces", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kEnableProfilingChk->setToolTip(tr2i18n("Enable or disable profiling", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kEnableProfilingChk->setStatusTip(tr2i18n("Enable or disable profiling", nullptr));
#endif // QT_CONFIG(statustip)
        kEnableProfilingChk->setText(tr2i18n("Enable profiling", nullptr));
        (void)skgdebugplugin_base;
    } // retranslateUi

};

namespace Ui {
    class skgdebugplugin_base: public Ui_skgdebugplugin_base {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGDEBUGPLUGINWIDGET_BASE_H

