/********************************************************************************
** Form generated from reading UI file 'skgbudgetpluginwidget_base.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGBUDGETPLUGINWIDGET_BASE_H
#define UI_SKGBUDGETPLUGINWIDGET_BASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "skgcalculatoredit.h"
#include "skgcombobox.h"
#include "skgfilteredtableview.h"
#include "skgwidgetselector.h"

QT_BEGIN_NAMESPACE

class Ui_skgbudgetplugin_base
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_2;
    SKGFilteredTableView *kView;
    QVBoxLayout *layout_3;
    QFrame *kSortButton;
    QVBoxLayout *verticalLayout_2;
    QToolButton *kTopBtn;
    QToolButton *kUpBtn;
    QToolButton *kDownBtn;
    QToolButton *kBottomBtn;
    QSpacerItem *verticalSpacer_3;
    QLabel *kInfo;
    QFrame *line;
    QWidget *horizontalWidget_3;
    QHBoxLayout *_2;
    QWidget *SKGManualSection;
    QGridLayout *gridLayout_3;
    QLabel *kPeriodLbl;
    SKGComboBox *kPeriod;
    QLabel *kYearLbl;
    QSpinBox *kYear;
    QLabel *kMonthLbl;
    QSpinBox *kMonth;
    QLabel *kAmountLabel;
    QLabel *kCategoryLabel;
    SKGCalculatorEdit *kAmountEdit;
    SKGComboBox *kCategoryEdit;
    QCheckBox *kIncludingSubCategories;
    QLabel *kUnit;
    QFrame *SKGAutoSection;
    QGridLayout *gridLayout;
    QFrame *line_2;
    QCheckBox *kAutoBudgetCheck;
    QSpinBox *kYearAutoBase;
    QCheckBox *kBalancingMonthly;
    QCheckBox *kBalancingAnnual;
    QLabel *label_6;
    QSpinBox *kYearAuto;
    QCheckBox *kUseScheduledOperation;
    QCheckBox *kRemovePrevious;
    QWidget *SKGRuleSection;
    QGridLayout *gridLayout_2;
    QLabel *label;
    QFrame *line_3;
    QLabel *label_2;
    QFrame *line_4;
    QLabel *label_3;
    QCheckBox *kYearCheck;
    QSpinBox *kYearRule;
    QSpacerItem *horizontalSpacer_7;
    SKGComboBox *kConditionCmb;
    QLabel *kPeriodLbl2;
    SKGComboBox *kModeCmb;
    QSpinBox *kMonthRule;
    QLabel *kAmountLabel2;
    SKGCalculatorEdit *kAmountEdit2;
    SKGComboBox *kUnitCmb;
    QSpacerItem *horizontalSpacer;
    QCheckBox *kCategoryCheck;
    SKGComboBox *kCategoryRule;
    QCheckBox *kCategoryTransferCheck;
    SKGComboBox *kCategoryTransfer;
    QCheckBox *kMonthCheck;
    QSpacerItem *kSpacer;
    QHBoxLayout *horizontalLayout_12;
    SKGWidgetSelector *kWidgetSelector;
    QWidget *SKGEditionButtonsSection;
    QHBoxLayout *horizontalLayout;
    QPushButton *kAddBtn;
    QPushButton *kModifyBtn;
    QPushButton *kProcessBtn;

    void setupUi(QWidget *skgbudgetplugin_base)
    {
        if (skgbudgetplugin_base->objectName().isEmpty())
            skgbudgetplugin_base->setObjectName("skgbudgetplugin_base");
        skgbudgetplugin_base->resize(1798, 390);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(skgbudgetplugin_base->sizePolicy().hasHeightForWidth());
        skgbudgetplugin_base->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(skgbudgetplugin_base);
        verticalLayout->setSpacing(2);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(6, 6, 6, 6);
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(2);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        kView = new SKGFilteredTableView(skgbudgetplugin_base);
        kView->setObjectName("kView");

        horizontalLayout_2->addWidget(kView);

        layout_3 = new QVBoxLayout();
        layout_3->setSpacing(2);
        layout_3->setObjectName("layout_3");
        kSortButton = new QFrame(skgbudgetplugin_base);
        kSortButton->setObjectName("kSortButton");
        kSortButton->setMinimumSize(QSize(0, 100));
        kSortButton->setFrameShadow(QFrame::Raised);
        verticalLayout_2 = new QVBoxLayout(kSortButton);
        verticalLayout_2->setSpacing(0);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        kTopBtn = new QToolButton(kSortButton);
        kTopBtn->setObjectName("kTopBtn");
        kTopBtn->setAutoRaise(true);

        verticalLayout_2->addWidget(kTopBtn);

        kUpBtn = new QToolButton(kSortButton);
        kUpBtn->setObjectName("kUpBtn");
        kUpBtn->setAutoRaise(true);

        verticalLayout_2->addWidget(kUpBtn);

        kDownBtn = new QToolButton(kSortButton);
        kDownBtn->setObjectName("kDownBtn");
        kDownBtn->setAutoRaise(true);

        verticalLayout_2->addWidget(kDownBtn);

        kBottomBtn = new QToolButton(kSortButton);
        kBottomBtn->setObjectName("kBottomBtn");
        kBottomBtn->setAutoRaise(true);

        verticalLayout_2->addWidget(kBottomBtn);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_3);


        layout_3->addWidget(kSortButton);


        horizontalLayout_2->addLayout(layout_3);


        verticalLayout->addLayout(horizontalLayout_2);

        kInfo = new QLabel(skgbudgetplugin_base);
        kInfo->setObjectName("kInfo");
        kInfo->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        verticalLayout->addWidget(kInfo);

        line = new QFrame(skgbudgetplugin_base);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        horizontalWidget_3 = new QWidget(skgbudgetplugin_base);
        horizontalWidget_3->setObjectName("horizontalWidget_3");
        _2 = new QHBoxLayout(horizontalWidget_3);
        _2->setSpacing(2);
        _2->setObjectName("_2");
        _2->setContentsMargins(0, 0, 0, 0);
        SKGManualSection = new QWidget(horizontalWidget_3);
        SKGManualSection->setObjectName("SKGManualSection");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(SKGManualSection->sizePolicy().hasHeightForWidth());
        SKGManualSection->setSizePolicy(sizePolicy1);
        gridLayout_3 = new QGridLayout(SKGManualSection);
        gridLayout_3->setSpacing(2);
        gridLayout_3->setObjectName("gridLayout_3");
        gridLayout_3->setContentsMargins(0, 0, 0, 0);
        kPeriodLbl = new QLabel(SKGManualSection);
        kPeriodLbl->setObjectName("kPeriodLbl");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(kPeriodLbl->sizePolicy().hasHeightForWidth());
        kPeriodLbl->setSizePolicy(sizePolicy2);
        QFont font;
        font.setBold(true);
        kPeriodLbl->setFont(font);
        kPeriodLbl->setText(QString::fromUtf8("&Title:"));
        kPeriodLbl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(kPeriodLbl, 0, 0, 1, 1);

        kPeriod = new SKGComboBox(SKGManualSection);
        kPeriod->setObjectName("kPeriod");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(kPeriod->sizePolicy().hasHeightForWidth());
        kPeriod->setSizePolicy(sizePolicy3);

        gridLayout_3->addWidget(kPeriod, 0, 1, 1, 1);

        kYearLbl = new QLabel(SKGManualSection);
        kYearLbl->setObjectName("kYearLbl");
        sizePolicy2.setHeightForWidth(kYearLbl->sizePolicy().hasHeightForWidth());
        kYearLbl->setSizePolicy(sizePolicy2);
        kYearLbl->setFont(font);
        kYearLbl->setText(QString::fromUtf8("Title:"));
        kYearLbl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(kYearLbl, 1, 0, 1, 1);

        kYear = new QSpinBox(SKGManualSection);
        kYear->setObjectName("kYear");
        kYear->setMaximum(9999);
        kYear->setValue(2010);

        gridLayout_3->addWidget(kYear, 1, 1, 1, 1);

        kMonthLbl = new QLabel(SKGManualSection);
        kMonthLbl->setObjectName("kMonthLbl");
        sizePolicy2.setHeightForWidth(kMonthLbl->sizePolicy().hasHeightForWidth());
        kMonthLbl->setSizePolicy(sizePolicy2);
        kMonthLbl->setText(QString::fromUtf8("Title:"));
        kMonthLbl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(kMonthLbl, 2, 0, 1, 1);

        kMonth = new QSpinBox(SKGManualSection);
        kMonth->setObjectName("kMonth");
        kMonth->setMaximum(12);
        kMonth->setValue(1);

        gridLayout_3->addWidget(kMonth, 2, 1, 1, 1);

        kAmountLabel = new QLabel(SKGManualSection);
        kAmountLabel->setObjectName("kAmountLabel");
        sizePolicy2.setHeightForWidth(kAmountLabel->sizePolicy().hasHeightForWidth());
        kAmountLabel->setSizePolicy(sizePolicy2);
        kAmountLabel->setFont(font);
        kAmountLabel->setText(QString::fromUtf8("Title:"));
        kAmountLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(kAmountLabel, 0, 2, 1, 1);

        kCategoryLabel = new QLabel(SKGManualSection);
        kCategoryLabel->setObjectName("kCategoryLabel");
        sizePolicy2.setHeightForWidth(kCategoryLabel->sizePolicy().hasHeightForWidth());
        kCategoryLabel->setSizePolicy(sizePolicy2);
        QFont font1;
        font1.setBold(false);
        kCategoryLabel->setFont(font1);
        kCategoryLabel->setText(QString::fromUtf8("Title:"));
        kCategoryLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(kCategoryLabel, 1, 2, 1, 1);

        kAmountEdit = new SKGCalculatorEdit(SKGManualSection);
        kAmountEdit->setObjectName("kAmountEdit");
        kAmountEdit->setMaximumSize(QSize(80, 16777215));
        kAmountEdit->setMode(SKGCalculatorEdit::EXPRESSION);

        gridLayout_3->addWidget(kAmountEdit, 0, 3, 1, 1);

        kCategoryEdit = new SKGComboBox(SKGManualSection);
        kCategoryEdit->setObjectName("kCategoryEdit");
        kCategoryEdit->setEditable(true);
        kCategoryEdit->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        gridLayout_3->addWidget(kCategoryEdit, 1, 3, 1, 3);

        kIncludingSubCategories = new QCheckBox(SKGManualSection);
        kIncludingSubCategories->setObjectName("kIncludingSubCategories");

        gridLayout_3->addWidget(kIncludingSubCategories, 2, 3, 1, 3);

        kUnit = new QLabel(SKGManualSection);
        kUnit->setObjectName("kUnit");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(kUnit->sizePolicy().hasHeightForWidth());
        kUnit->setSizePolicy(sizePolicy4);

        gridLayout_3->addWidget(kUnit, 0, 5, 1, 1);


        _2->addWidget(SKGManualSection);

        SKGAutoSection = new QFrame(horizontalWidget_3);
        SKGAutoSection->setObjectName("SKGAutoSection");
        gridLayout = new QGridLayout(SKGAutoSection);
        gridLayout->setSpacing(2);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        line_2 = new QFrame(SKGAutoSection);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::VLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line_2, 2, 2, 6, 1);

        kAutoBudgetCheck = new QCheckBox(SKGAutoSection);
        kAutoBudgetCheck->setObjectName("kAutoBudgetCheck");
        kAutoBudgetCheck->setFont(font);
        kAutoBudgetCheck->setChecked(true);

        gridLayout->addWidget(kAutoBudgetCheck, 2, 0, 1, 1);

        kYearAutoBase = new QSpinBox(SKGAutoSection);
        kYearAutoBase->setObjectName("kYearAutoBase");
        kYearAutoBase->setMaximum(9999);
        kYearAutoBase->setValue(2010);

        gridLayout->addWidget(kYearAutoBase, 2, 1, 1, 1);

        kBalancingMonthly = new QCheckBox(SKGAutoSection);
        kBalancingMonthly->setObjectName("kBalancingMonthly");
        sizePolicy3.setHeightForWidth(kBalancingMonthly->sizePolicy().hasHeightForWidth());
        kBalancingMonthly->setSizePolicy(sizePolicy3);
        kBalancingMonthly->setChecked(true);

        gridLayout->addWidget(kBalancingMonthly, 2, 3, 1, 1);

        kBalancingAnnual = new QCheckBox(SKGAutoSection);
        kBalancingAnnual->setObjectName("kBalancingAnnual");
        sizePolicy3.setHeightForWidth(kBalancingAnnual->sizePolicy().hasHeightForWidth());
        kBalancingAnnual->setSizePolicy(sizePolicy3);
        kBalancingAnnual->setChecked(true);

        gridLayout->addWidget(kBalancingAnnual, 3, 3, 1, 1);

        label_6 = new QLabel(SKGAutoSection);
        label_6->setObjectName("label_6");
        sizePolicy2.setHeightForWidth(label_6->sizePolicy().hasHeightForWidth());
        label_6->setSizePolicy(sizePolicy2);
        label_6->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_6, 1, 0, 1, 1);

        kYearAuto = new QSpinBox(SKGAutoSection);
        kYearAuto->setObjectName("kYearAuto");
        kYearAuto->setMaximum(9999);
        kYearAuto->setValue(2010);

        gridLayout->addWidget(kYearAuto, 1, 1, 1, 3);

        kUseScheduledOperation = new QCheckBox(SKGAutoSection);
        kUseScheduledOperation->setObjectName("kUseScheduledOperation");
        kUseScheduledOperation->setChecked(true);

        gridLayout->addWidget(kUseScheduledOperation, 3, 0, 1, 1);

        kRemovePrevious = new QCheckBox(SKGAutoSection);
        kRemovePrevious->setObjectName("kRemovePrevious");
        sizePolicy3.setHeightForWidth(kRemovePrevious->sizePolicy().hasHeightForWidth());
        kRemovePrevious->setSizePolicy(sizePolicy3);
        kRemovePrevious->setText(QString::fromUtf8("Remove existing budgets for xxx"));

        gridLayout->addWidget(kRemovePrevious, 4, 0, 1, 1);


        _2->addWidget(SKGAutoSection);

        SKGRuleSection = new QWidget(horizontalWidget_3);
        SKGRuleSection->setObjectName("SKGRuleSection");
        sizePolicy1.setHeightForWidth(SKGRuleSection->sizePolicy().hasHeightForWidth());
        SKGRuleSection->setSizePolicy(sizePolicy1);
        gridLayout_2 = new QGridLayout(SKGRuleSection);
        gridLayout_2->setSpacing(2);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(0, 0, 0, 0);
        label = new QLabel(SKGRuleSection);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignCenter);

        gridLayout_2->addWidget(label, 0, 0, 1, 3);

        line_3 = new QFrame(SKGRuleSection);
        line_3->setObjectName("line_3");
        line_3->setFrameShape(QFrame::Shape::VLine);
        line_3->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout_2->addWidget(line_3, 0, 3, 4, 1);

        label_2 = new QLabel(SKGRuleSection);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignCenter);

        gridLayout_2->addWidget(label_2, 0, 4, 1, 1);

        line_4 = new QFrame(SKGRuleSection);
        line_4->setObjectName("line_4");
        line_4->setFrameShape(QFrame::Shape::VLine);
        line_4->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout_2->addWidget(line_4, 0, 5, 4, 1);

        label_3 = new QLabel(SKGRuleSection);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignCenter);

        gridLayout_2->addWidget(label_3, 0, 6, 1, 4);

        kYearCheck = new QCheckBox(SKGRuleSection);
        kYearCheck->setObjectName("kYearCheck");
        kYearCheck->setText(QString::fromUtf8("Title:"));

        gridLayout_2->addWidget(kYearCheck, 1, 0, 1, 1);

        kYearRule = new QSpinBox(SKGRuleSection);
        kYearRule->setObjectName("kYearRule");
        kYearRule->setEnabled(false);
        kYearRule->setMaximum(9999);
        kYearRule->setValue(2010);

        gridLayout_2->addWidget(kYearRule, 1, 1, 1, 1);

        horizontalSpacer_7 = new QSpacerItem(181, 21, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_7, 1, 2, 1, 1);

        kConditionCmb = new SKGComboBox(SKGRuleSection);
        kConditionCmb->setObjectName("kConditionCmb");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(kConditionCmb->sizePolicy().hasHeightForWidth());
        kConditionCmb->setSizePolicy(sizePolicy5);
        kConditionCmb->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        gridLayout_2->addWidget(kConditionCmb, 1, 4, 1, 1);

        kPeriodLbl2 = new QLabel(SKGRuleSection);
        kPeriodLbl2->setObjectName("kPeriodLbl2");
        sizePolicy2.setHeightForWidth(kPeriodLbl2->sizePolicy().hasHeightForWidth());
        kPeriodLbl2->setSizePolicy(sizePolicy2);
        kPeriodLbl2->setFont(font);
        kPeriodLbl2->setText(QString::fromUtf8("Title:"));
        kPeriodLbl2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(kPeriodLbl2, 1, 6, 1, 1);

        kModeCmb = new SKGComboBox(SKGRuleSection);
        kModeCmb->setObjectName("kModeCmb");
        sizePolicy5.setHeightForWidth(kModeCmb->sizePolicy().hasHeightForWidth());
        kModeCmb->setSizePolicy(sizePolicy5);
        kModeCmb->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        gridLayout_2->addWidget(kModeCmb, 1, 7, 1, 2);

        kMonthRule = new QSpinBox(SKGRuleSection);
        kMonthRule->setObjectName("kMonthRule");
        kMonthRule->setEnabled(false);
        kMonthRule->setMaximum(12);
        kMonthRule->setValue(1);

        gridLayout_2->addWidget(kMonthRule, 2, 1, 1, 1);

        kAmountLabel2 = new QLabel(SKGRuleSection);
        kAmountLabel2->setObjectName("kAmountLabel2");
        sizePolicy2.setHeightForWidth(kAmountLabel2->sizePolicy().hasHeightForWidth());
        kAmountLabel2->setSizePolicy(sizePolicy2);
        kAmountLabel2->setFont(font);
        kAmountLabel2->setText(QString::fromUtf8("Title:"));
        kAmountLabel2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(kAmountLabel2, 2, 6, 1, 1);

        kAmountEdit2 = new SKGCalculatorEdit(SKGRuleSection);
        kAmountEdit2->setObjectName("kAmountEdit2");
        kAmountEdit2->setMaximumSize(QSize(80, 16777215));
        kAmountEdit2->setValue(100.000000000000000);
        kAmountEdit2->setMode(SKGCalculatorEdit::EXPRESSION);

        gridLayout_2->addWidget(kAmountEdit2, 2, 7, 1, 1);

        kUnitCmb = new SKGComboBox(SKGRuleSection);
        kUnitCmb->setObjectName("kUnitCmb");

        gridLayout_2->addWidget(kUnitCmb, 2, 8, 1, 1);

        horizontalSpacer = new QSpacerItem(81, 21, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer, 2, 9, 1, 1);

        kCategoryCheck = new QCheckBox(SKGRuleSection);
        kCategoryCheck->setObjectName("kCategoryCheck");
        kCategoryCheck->setText(QString::fromUtf8("Title:"));

        gridLayout_2->addWidget(kCategoryCheck, 3, 0, 1, 1);

        kCategoryRule = new SKGComboBox(SKGRuleSection);
        kCategoryRule->setObjectName("kCategoryRule");
        kCategoryRule->setEnabled(false);
        QSizePolicy sizePolicy6(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(0);
        sizePolicy6.setHeightForWidth(kCategoryRule->sizePolicy().hasHeightForWidth());
        kCategoryRule->setSizePolicy(sizePolicy6);
        kCategoryRule->setEditable(true);
        kCategoryRule->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);
        kCategoryRule->setMinimumContentsLength(30);

        gridLayout_2->addWidget(kCategoryRule, 3, 1, 1, 2);

        kCategoryTransferCheck = new QCheckBox(SKGRuleSection);
        kCategoryTransferCheck->setObjectName("kCategoryTransferCheck");
        kCategoryTransferCheck->setText(QString::fromUtf8("Title:"));

        gridLayout_2->addWidget(kCategoryTransferCheck, 3, 6, 1, 1);

        kCategoryTransfer = new SKGComboBox(SKGRuleSection);
        kCategoryTransfer->setObjectName("kCategoryTransfer");
        kCategoryTransfer->setEnabled(false);
        sizePolicy6.setHeightForWidth(kCategoryTransfer->sizePolicy().hasHeightForWidth());
        kCategoryTransfer->setSizePolicy(sizePolicy6);
        kCategoryTransfer->setEditable(true);
        kCategoryTransfer->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);
        kCategoryTransfer->setMinimumContentsLength(30);

        gridLayout_2->addWidget(kCategoryTransfer, 3, 7, 1, 3);

        kMonthCheck = new QCheckBox(SKGRuleSection);
        kMonthCheck->setObjectName("kMonthCheck");
        kMonthCheck->setText(QString::fromUtf8("Title:"));

        gridLayout_2->addWidget(kMonthCheck, 2, 0, 1, 1);


        _2->addWidget(SKGRuleSection);

        kSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        _2->addItem(kSpacer);


        verticalLayout->addWidget(horizontalWidget_3);

        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setSpacing(2);
        horizontalLayout_12->setObjectName("horizontalLayout_12");
        kWidgetSelector = new SKGWidgetSelector(skgbudgetplugin_base);
        kWidgetSelector->setObjectName("kWidgetSelector");

        horizontalLayout_12->addWidget(kWidgetSelector);

        SKGEditionButtonsSection = new QWidget(skgbudgetplugin_base);
        SKGEditionButtonsSection->setObjectName("SKGEditionButtonsSection");
        horizontalLayout = new QHBoxLayout(SKGEditionButtonsSection);
        horizontalLayout->setSpacing(2);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        kAddBtn = new QPushButton(SKGEditionButtonsSection);
        kAddBtn->setObjectName("kAddBtn");
        kAddBtn->setEnabled(false);
        QSizePolicy sizePolicy7(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy7.setHorizontalStretch(0);
        sizePolicy7.setVerticalStretch(0);
        sizePolicy7.setHeightForWidth(kAddBtn->sizePolicy().hasHeightForWidth());
        kAddBtn->setSizePolicy(sizePolicy7);

        horizontalLayout->addWidget(kAddBtn);

        kModifyBtn = new QPushButton(SKGEditionButtonsSection);
        kModifyBtn->setObjectName("kModifyBtn");
        kModifyBtn->setEnabled(false);

        horizontalLayout->addWidget(kModifyBtn);


        horizontalLayout_12->addWidget(SKGEditionButtonsSection);

        kProcessBtn = new QPushButton(skgbudgetplugin_base);
        kProcessBtn->setObjectName("kProcessBtn");
        sizePolicy7.setHeightForWidth(kProcessBtn->sizePolicy().hasHeightForWidth());
        kProcessBtn->setSizePolicy(sizePolicy7);

        horizontalLayout_12->addWidget(kProcessBtn);


        verticalLayout->addLayout(horizontalLayout_12);

#if QT_CONFIG(shortcut)
        kPeriodLbl->setBuddy(kPeriod);
        kYearLbl->setBuddy(kYear);
        kMonthLbl->setBuddy(kMonth);
        kAmountLabel->setBuddy(kAmountEdit);
        kCategoryLabel->setBuddy(kCategoryEdit);
        label_6->setBuddy(kYearAuto);
        kPeriodLbl2->setBuddy(kModeCmb);
        kAmountLabel2->setBuddy(kAmountEdit2);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kPeriod, kYear);
        QWidget::setTabOrder(kYear, kMonth);
        QWidget::setTabOrder(kMonth, kAmountEdit);
        QWidget::setTabOrder(kAmountEdit, kCategoryEdit);
        QWidget::setTabOrder(kCategoryEdit, kIncludingSubCategories);
        QWidget::setTabOrder(kIncludingSubCategories, kAutoBudgetCheck);
        QWidget::setTabOrder(kAutoBudgetCheck, kUseScheduledOperation);
        QWidget::setTabOrder(kUseScheduledOperation, kRemovePrevious);
        QWidget::setTabOrder(kRemovePrevious, kYearAuto);
        QWidget::setTabOrder(kYearAuto, kYearAutoBase);
        QWidget::setTabOrder(kYearAutoBase, kBalancingMonthly);
        QWidget::setTabOrder(kBalancingMonthly, kBalancingAnnual);
        QWidget::setTabOrder(kBalancingAnnual, kYearCheck);
        QWidget::setTabOrder(kYearCheck, kMonthCheck);
        QWidget::setTabOrder(kMonthCheck, kCategoryCheck);
        QWidget::setTabOrder(kCategoryCheck, kYearRule);
        QWidget::setTabOrder(kYearRule, kMonthRule);
        QWidget::setTabOrder(kMonthRule, kCategoryRule);
        QWidget::setTabOrder(kCategoryRule, kConditionCmb);
        QWidget::setTabOrder(kConditionCmb, kModeCmb);
        QWidget::setTabOrder(kModeCmb, kAmountEdit2);
        QWidget::setTabOrder(kAmountEdit2, kUnitCmb);
        QWidget::setTabOrder(kUnitCmb, kCategoryTransferCheck);
        QWidget::setTabOrder(kCategoryTransferCheck, kCategoryTransfer);
        QWidget::setTabOrder(kCategoryTransfer, kAddBtn);
        QWidget::setTabOrder(kAddBtn, kModifyBtn);
        QWidget::setTabOrder(kModifyBtn, kProcessBtn);

        retranslateUi(skgbudgetplugin_base);

        QMetaObject::connectSlotsByName(skgbudgetplugin_base);
    } // setupUi

    void retranslateUi(QWidget *skgbudgetplugin_base)
    {
        kInfo->setText(QString());
#if QT_CONFIG(tooltip)
        kPeriod->setToolTip(tr2i18n("Period of the budget", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kPeriod->setStatusTip(tr2i18n("Period of the budget", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kYear->setToolTip(tr2i18n("Year of the budget", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kYear->setStatusTip(tr2i18n("Year of the budget", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kMonth->setToolTip(tr2i18n("Month of the budget", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kMonth->setStatusTip(tr2i18n("Month of the budget", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kAmountEdit->setToolTip(tr2i18n("Amount of the budget", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kAmountEdit->setStatusTip(tr2i18n("Amount of the budget", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kCategoryEdit->setToolTip(tr2i18n("Category of the budget", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kCategoryEdit->setStatusTip(tr2i18n("Category of the budget", nullptr));
#endif // QT_CONFIG(statustip)
        kIncludingSubCategories->setText(tr2i18n("Including sub categories", nullptr));
        kUnit->setText(QString());
#if QT_CONFIG(statustip)
        kAutoBudgetCheck->setStatusTip(tr2i18n("Enable automatic budget creation", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(whatsthis)
        kAutoBudgetCheck->setWhatsThis(tr2i18n("Enable automatic budget creation", nullptr));
#endif // QT_CONFIG(whatsthis)
        kAutoBudgetCheck->setText(tr2i18n("Automatic creation based on the transactions of:", nullptr));
#if QT_CONFIG(tooltip)
        kYearAutoBase->setToolTip(tr2i18n("Year of the budget", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kYearAutoBase->setStatusTip(tr2i18n("Year of the budget", nullptr));
#endif // QT_CONFIG(statustip)
        kBalancingMonthly->setText(tr2i18n("Balancing each monthly budget.", nullptr));
        kBalancingAnnual->setText(tr2i18n("Balancing the annual budget", nullptr));
        label_6->setText(tr2i18n("&Year:", nullptr));
#if QT_CONFIG(tooltip)
        kYearAuto->setToolTip(tr2i18n("Year of the budget", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kYearAuto->setStatusTip(tr2i18n("Year of the budget", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kUseScheduledOperation->setToolTip(tr2i18n("Use the scheduled transactions for a better automatic creation", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kUseScheduledOperation->setStatusTip(tr2i18n("Use the scheduled transactions for a better automatic creation", nullptr));
#endif // QT_CONFIG(statustip)
        kUseScheduledOperation->setText(tr2i18n("Use scheduled transactions", nullptr));
        label->setText(tr2i18n("For budgets having", "Title"));
        label_2->setText(tr2i18n("When delta", "Title"));
        label_3->setText(tr2i18n("Modify budget", "Title"));
#if QT_CONFIG(statustip)
        kYearCheck->setStatusTip(tr2i18n("Enable condition on the year", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(whatsthis)
        kYearCheck->setWhatsThis(tr2i18n("Enable condition on the year", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        kYearRule->setToolTip(tr2i18n("Year of the condition", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kYearRule->setStatusTip(tr2i18n("Year of the condition", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kConditionCmb->setToolTip(tr2i18n("Condition to transfer the delta", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kConditionCmb->setStatusTip(tr2i18n("Condition to transfer the delta", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kModeCmb->setToolTip(tr2i18n("Condition to transfer the delta", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kModeCmb->setStatusTip(tr2i18n("Condition to transfer the delta", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kMonthRule->setToolTip(tr2i18n("Month of the condition", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kMonthRule->setStatusTip(tr2i18n("Month of the condition", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kAmountEdit2->setToolTip(tr2i18n("Amount of the transfer", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kAmountEdit2->setStatusTip(tr2i18n("Amount of the transfer", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(statustip)
        kCategoryCheck->setStatusTip(tr2i18n("Enable condition on the category", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(whatsthis)
        kCategoryCheck->setWhatsThis(tr2i18n("Enable condition on the category", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        kCategoryRule->setToolTip(tr2i18n("Category of the condition", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kCategoryRule->setStatusTip(tr2i18n("Category of the condition", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(statustip)
        kCategoryTransferCheck->setStatusTip(tr2i18n("Enable condition on the category", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(whatsthis)
        kCategoryTransferCheck->setWhatsThis(tr2i18n("Enable condition on the category", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        kCategoryTransfer->setToolTip(tr2i18n("Category of the transfer", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kCategoryTransfer->setStatusTip(tr2i18n("Category of the transfer", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(statustip)
        kMonthCheck->setStatusTip(tr2i18n("Enable condition on the month", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(whatsthis)
        kMonthCheck->setWhatsThis(tr2i18n("Enable condition on the month", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        kAddBtn->setToolTip(tr2i18n("Create a new budget (Ctrl+Enter)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kAddBtn->setStatusTip(tr2i18n("Create a new budget (Ctrl+Enter)", nullptr));
#endif // QT_CONFIG(statustip)
        kAddBtn->setText(tr2i18n("Add", "Verb, add an item to a list"));
#if QT_CONFIG(tooltip)
        kModifyBtn->setToolTip(tr2i18n("Update selected budget (Shift+Enter)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kModifyBtn->setStatusTip(tr2i18n("Update selected budget (Shift+Enter)", nullptr));
#endif // QT_CONFIG(statustip)
        kModifyBtn->setText(tr2i18n("Modify", "Verb, modify an item"));
#if QT_CONFIG(tooltip)
        kProcessBtn->setToolTip(tr2i18n("Process rules", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kProcessBtn->setStatusTip(tr2i18n("Process rules", nullptr));
#endif // QT_CONFIG(statustip)
        kProcessBtn->setText(tr2i18n("Process", "Verb, add an item to a list"));
        (void)skgbudgetplugin_base;
    } // retranslateUi

};

namespace Ui {
    class skgbudgetplugin_base: public Ui_skgbudgetplugin_base {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGBUDGETPLUGINWIDGET_BASE_H

