/********************************************************************************
** Form generated from reading UI file 'skgbookmarkpluginwidget_pref.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGBOOKMARKPLUGINWIDGET_PREF_H
#define UI_SKGBOOKMARKPLUGINWIDGET_PREF_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_skgbookmarkplugin_pref
{
public:
    QGridLayout *gridLayout_2;
    QSpacerItem *verticalSpacer;
    QCheckBox *kcfg_pinhomebookmarks;

    void setupUi(QWidget *skgbookmarkplugin_pref)
    {
        if (skgbookmarkplugin_pref->objectName().isEmpty())
            skgbookmarkplugin_pref->setObjectName("skgbookmarkplugin_pref");
        skgbookmarkplugin_pref->resize(412, 306);
        gridLayout_2 = new QGridLayout(skgbookmarkplugin_pref);
        gridLayout_2->setObjectName("gridLayout_2");
        verticalSpacer = new QSpacerItem(20, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 1, 0, 1, 1);

        kcfg_pinhomebookmarks = new QCheckBox(skgbookmarkplugin_pref);
        kcfg_pinhomebookmarks->setObjectName("kcfg_pinhomebookmarks");

        gridLayout_2->addWidget(kcfg_pinhomebookmarks, 0, 0, 1, 1);


        retranslateUi(skgbookmarkplugin_pref);

        QMetaObject::connectSlotsByName(skgbookmarkplugin_pref);
    } // setupUi

    void retranslateUi(QWidget *skgbookmarkplugin_pref)
    {
        kcfg_pinhomebookmarks->setText(tr2i18n("Pin home bookmarks", nullptr));
        (void)skgbookmarkplugin_pref;
    } // retranslateUi

};

namespace Ui {
    class skgbookmarkplugin_pref: public Ui_skgbookmarkplugin_pref {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGBOOKMARKPLUGINWIDGET_PREF_H

