/****************************************************************************
** Meta object code from reading C++ file 'skgreport.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../skrooge-26.8.0/skgbasemodeler/skgreport.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'skgreport.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9SKGReportE_t {};
} // unnamed namespace

template <> constexpr inline auto SKGReport::qt_create_metaobjectdata<qt_meta_tag_ZN9SKGReportE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SKGReport",
        "changed",
        "",
        "setPeriod",
        "iPeriod",
        "getPeriod",
        "setSqlFilter",
        "iFilter",
        "getSqlFilter",
        "getPreviousPeriod",
        "getPrevious",
        "SKGReport*",
        "setPointSize",
        "iPointSize",
        "getPointSize",
        "setTipsOfDay",
        "iTipsOfDays",
        "getTipOfDay",
        "getTipsOfDay",
        "cleanCache",
        "iEmitSignal",
        "getContextProperty",
        "QVariantHash",
        "addParameter",
        "iName",
        "QVariant",
        "ivalue",
        "addItemsInMapping",
        "QVariantHash&",
        "iMapping",
        "period",
        "month",
        "previous",
        "previous_period",
        "previous_month",
        "point_size",
        "tips_of_day",
        "tip_of_day"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'setPeriod'
        QtMocHelpers::MethodData<void(const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Method 'getPeriod'
        QtMocHelpers::MethodData<QString()>(5, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'setSqlFilter'
        QtMocHelpers::MethodData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Method 'getSqlFilter'
        QtMocHelpers::MethodData<QString()>(8, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'getPreviousPeriod'
        QtMocHelpers::MethodData<QString()>(9, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'getPrevious'
        QtMocHelpers::MethodData<SKGReport *()>(10, 2, QMC::AccessPublic, 0x80000000 | 11),
        // Method 'setPointSize'
        QtMocHelpers::MethodData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Method 'getPointSize'
        QtMocHelpers::MethodData<int() const>(14, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'setTipsOfDay'
        QtMocHelpers::MethodData<void(const QStringList &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 16 },
        }}),
        // Method 'getTipOfDay'
        QtMocHelpers::MethodData<QString() const>(17, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'getTipsOfDay'
        QtMocHelpers::MethodData<QStringList() const>(18, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Method 'cleanCache'
        QtMocHelpers::MethodData<void(bool)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Method 'cleanCache'
        QtMocHelpers::MethodData<void()>(19, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Method 'getContextProperty'
        QtMocHelpers::MethodData<QVariantHash()>(21, 2, QMC::AccessPublic, 0x80000000 | 22),
        // Method 'addParameter'
        QtMocHelpers::MethodData<void(const QString &, const QVariant &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 24 }, { 0x80000000 | 25, 26 },
        }}),
        // Method 'addItemsInMapping'
        QtMocHelpers::MethodData<void(QVariantHash &)>(27, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'period'
        QtMocHelpers::PropertyData<QString>(30, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'month'
        QtMocHelpers::PropertyData<QString>(31, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'previous'
        QtMocHelpers::PropertyData<SKGReport*>(32, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'previous_period'
        QtMocHelpers::PropertyData<QString>(33, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'previous_month'
        QtMocHelpers::PropertyData<QString>(34, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'point_size'
        QtMocHelpers::PropertyData<double>(35, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'tips_of_day'
        QtMocHelpers::PropertyData<QStringList>(36, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'tip_of_day'
        QtMocHelpers::PropertyData<QString>(37, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SKGReport, qt_meta_tag_ZN9SKGReportE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SKGReport::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9SKGReportE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9SKGReportE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9SKGReportE_t>.metaTypes,
    nullptr
} };

void SKGReport::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SKGReport *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->changed(); break;
        case 1: _t->setPeriod((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: { QString _r = _t->getPeriod();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->setSqlFilter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: { QString _r = _t->getSqlFilter();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 5: { QString _r = _t->getPreviousPeriod();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 6: { SKGReport* _r = _t->getPrevious();
            if (_a[0]) *reinterpret_cast<SKGReport**>(_a[0]) = std::move(_r); }  break;
        case 7: _t->setPointSize((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: { int _r = _t->getPointSize();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->setTipsOfDay((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 10: { QString _r = _t->getTipOfDay();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 11: { QStringList _r = _t->getTipsOfDay();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->cleanCache((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->cleanCache(); break;
        case 14: { QVariantHash _r = _t->getContextProperty();
            if (_a[0]) *reinterpret_cast<QVariantHash*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->addParameter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        case 16: _t->addItemsInMapping((*reinterpret_cast<std::add_pointer_t<QVariantHash&>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SKGReport::*)()>(_a, &SKGReport::changed, 0))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< SKGReport* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->getPeriod(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->getPeriod(); break;
        case 2: *reinterpret_cast<SKGReport**>(_v) = _t->getPrevious(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->getPreviousPeriod(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->getPreviousPeriod(); break;
        case 5: *reinterpret_cast<double*>(_v) = _t->getPointSize(); break;
        case 6: *reinterpret_cast<QStringList*>(_v) = _t->getTipsOfDay(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->getTipOfDay(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPeriod(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setPointSize(*reinterpret_cast<double*>(_v)); break;
        case 6: _t->setTipsOfDay(*reinterpret_cast<QStringList*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *SKGReport::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SKGReport::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9SKGReportE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SKGReport::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void SKGReport::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
