// This file is generated by kconfig_compiler_kf6 from skgreport_settings.kcfg.
// All changes you do to this file will be lost.

#include "skgreport_settings.h"

#include <qglobal.h>
#include <QFile>

class skgreport_settingsHelper
{
  public:
    skgreport_settingsHelper() noexcept : q(nullptr) {}
    ~skgreport_settingsHelper() noexcept { delete q; q = nullptr; }
    skgreport_settingsHelper(const skgreport_settingsHelper&) = delete;
    skgreport_settingsHelper& operator=(const skgreport_settingsHelper&) = delete;
    skgreport_settings *q;
};
Q_GLOBAL_STATIC(skgreport_settingsHelper, s_globalskgreport_settings)
skgreport_settings *skgreport_settings::self()
{
  if (!s_globalskgreport_settings()->q) {
    new skgreport_settings;
    s_globalskgreport_settings()->q->read();
  }

  return s_globalskgreport_settings()->q;
}

skgreport_settings::skgreport_settings( )
  : KConfigSkeleton()
{
  Q_ASSERT(!s_globalskgreport_settings()->q);
  s_globalskgreport_settings()->q = this;
  setCurrentGroup( QStringLiteral( "skrooge_report" ) );

  KConfigSkeleton::ItemColor  *itemBackgroundColor;
  itemBackgroundColor = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "backgroundColor" ), mBackgroundColor, Qt::white );
  addItem( itemBackgroundColor, QStringLiteral( "backgroundColor" ) );
  KConfigSkeleton::ItemColor  *itemTextColor;
  itemTextColor = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "textColor" ), mTextColor, Qt::black );
  addItem( itemTextColor, QStringLiteral( "textColor" ) );
  KConfigSkeleton::ItemColor  *itemOutlineColor;
  itemOutlineColor = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "outlineColor" ), mOutlineColor, Qt::black );
  addItem( itemOutlineColor, QStringLiteral( "outlineColor" ) );
  KConfigSkeleton::ItemColor  *itemAxisColor;
  itemAxisColor = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "axisColor" ), mAxisColor, Qt::gray );
  addItem( itemAxisColor, QStringLiteral( "axisColor" ) );
  KConfigSkeleton::ItemColor  *itemGridColor;
  itemGridColor = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "gridColor" ), mGridColor, Qt::lightGray );
  addItem( itemGridColor, QStringLiteral( "gridColor" ) );
  KConfigSkeleton::ItemColor  *itemMinColor;
  itemMinColor = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "minColor" ), mMinColor, Qt::red );
  addItem( itemMinColor, QStringLiteral( "minColor" ) );
  KConfigSkeleton::ItemColor  *itemMaxColor;
  itemMaxColor = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "maxColor" ), mMaxColor, Qt::green );
  addItem( itemMaxColor, QStringLiteral( "maxColor" ) );
  KConfigSkeleton::ItemColor  *itemAverageColor;
  itemAverageColor = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "averageColor" ), mAverageColor, Qt::blue );
  addItem( itemAverageColor, QStringLiteral( "averageColor" ) );
  KConfigSkeleton::ItemColor  *itemTendencyColor;
  itemTendencyColor = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "tendencyColor" ), mTendencyColor, Qt::darkYellow );
  addItem( itemTendencyColor, QStringLiteral( "tendencyColor" ) );
  KConfigSkeleton::ItemColor  *itemParetoColor;
  itemParetoColor = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "paretoColor" ), mParetoColor, Qt::darkRed );
  addItem( itemParetoColor, QStringLiteral( "paretoColor" ) );
  KConfigSkeleton::ItemBool  *itemAntialiasing;
  itemAntialiasing = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "antialiasing" ), mAntialiasing, true );
  addItem( itemAntialiasing, QStringLiteral( "antialiasing" ) );
  KConfigSkeleton::ItemInt  *itemMaxForecasts;
  itemMaxForecasts = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "maxForecasts" ), mMaxForecasts, 1 );
  addItem( itemMaxForecasts, QStringLiteral( "maxForecasts" ) );
}

skgreport_settings::~skgreport_settings()
{
  if (s_globalskgreport_settings.exists() && !s_globalskgreport_settings.isDestroyed()) {
    s_globalskgreport_settings()->q = nullptr;
  }
}

