/****************************************************************************
** Meta object code from reading C++ file 'skgtablewithgraph.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../skrooge-26.8.0/skgbasegui/skgtablewithgraph.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'skgtablewithgraph.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17SKGTableWithGraphE_t {};
} // unnamed namespace

template <> constexpr inline auto SKGTableWithGraph::qt_create_metaobjectdata<qt_meta_tag_ZN17SKGTableWithGraphE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SKGTableWithGraph",
        "cellDoubleClicked",
        "",
        "row",
        "column",
        "selectionChanged",
        "modified",
        "setState",
        "iState",
        "setData",
        "SKGStringListList",
        "iData",
        "SKGServices::SKGUnitInfo",
        "iPrimaryUnit",
        "iSecondaryUnit",
        "SKGTableWithGraph::DisplayAdditionalFlag",
        "iAdditionalInformation",
        "iNbVirtualColumn",
        "setGraphTypeSelectorVisible",
        "iVisible",
        "setSelectable",
        "iSelectable",
        "setShadowVisible",
        "iShadow",
        "setGraphType",
        "SKGTableWithGraph::GraphType",
        "iType",
        "setFilterVisibility",
        "iVisibility",
        "setAxisColor",
        "QColor",
        "iColor",
        "setGridColor",
        "setMinColor",
        "setMaxColor",
        "setParetoColor",
        "setAverageColor",
        "setTendencyColor",
        "setOutlineColor",
        "setBackgroundColor",
        "setTextColor",
        "setAntialiasing",
        "iAntialiasing",
        "redrawGraphDelayed",
        "switchLimitsVisibility",
        "switchAverageVisibility",
        "switchLinearRegressionVisibility",
        "switchParetoVisibility",
        "switchLegendVisibility",
        "swithOriginVisibility",
        "swithDecimalsVisibility",
        "resetColors",
        "exportInFile",
        "SKGError",
        "iFileName",
        "onExport",
        "onSelectionChanged",
        "onSelectionChangedInGraph",
        "onDoubleClick",
        "onDoubleClickGraph",
        "onLinkClicked",
        "QUrl",
        "url",
        "onFilterModified",
        "onDisplayModeChanged",
        "onChangeColor",
        "onHorizontalScrollBarChanged",
        "refresh",
        "redrawText",
        "redrawGraph",
        "showMenu",
        "QPoint",
        "iPos",
        "graphTypeSelectorVisible",
        "selectable",
        "shadow",
        "graphType",
        "GraphType",
        "STACK",
        "HISTOGRAM",
        "PIE",
        "CONCENTRICPIE",
        "POINT",
        "LINE",
        "STACKAREA",
        "BUBBLE",
        "STACKCOLUMNS",
        "TREEMAP",
        "DisplayAdditional",
        "NONE",
        "SUM",
        "AVERAGE",
        "LIMITS",
        "ALL"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'cellDoubleClicked'
        QtMocHelpers::SignalData<void(int, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 },
        }}),
        // Signal 'selectionChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modified'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setState'
        QtMocHelpers::SlotData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Slot 'setData'
        QtMocHelpers::SlotData<void(const SKGStringListList &, const SKGServices::SKGUnitInfo &, const SKGServices::SKGUnitInfo &, SKGTableWithGraph::DisplayAdditionalFlag, int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 }, { 0x80000000 | 12, 13 }, { 0x80000000 | 12, 14 }, { 0x80000000 | 15, 16 },
            { QMetaType::Int, 17 },
        }}),
        // Slot 'setData'
        QtMocHelpers::SlotData<void(const SKGStringListList &, const SKGServices::SKGUnitInfo &, const SKGServices::SKGUnitInfo &, SKGTableWithGraph::DisplayAdditionalFlag)>(9, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 10, 11 }, { 0x80000000 | 12, 13 }, { 0x80000000 | 12, 14 }, { 0x80000000 | 15, 16 },
        }}),
        // Slot 'setData'
        QtMocHelpers::SlotData<void(const SKGStringListList &, const SKGServices::SKGUnitInfo &, const SKGServices::SKGUnitInfo &)>(9, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 10, 11 }, { 0x80000000 | 12, 13 }, { 0x80000000 | 12, 14 },
        }}),
        // Slot 'setGraphTypeSelectorVisible'
        QtMocHelpers::SlotData<void(bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
        // Slot 'setSelectable'
        QtMocHelpers::SlotData<void(bool)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 21 },
        }}),
        // Slot 'setShadowVisible'
        QtMocHelpers::SlotData<void(bool)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
        // Slot 'setGraphType'
        QtMocHelpers::SlotData<void(SKGTableWithGraph::GraphType)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Slot 'setFilterVisibility'
        QtMocHelpers::SlotData<void(bool) const>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 28 },
        }}),
        // Slot 'setAxisColor'
        QtMocHelpers::SlotData<void(const QColor &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'setAxisColor'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'setGridColor'
        QtMocHelpers::SlotData<void(const QColor &)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'setGridColor'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'setMinColor'
        QtMocHelpers::SlotData<void(const QColor &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'setMinColor'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'setMaxColor'
        QtMocHelpers::SlotData<void(const QColor &)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'setMaxColor'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'setParetoColor'
        QtMocHelpers::SlotData<void(const QColor &)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'setParetoColor'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'setAverageColor'
        QtMocHelpers::SlotData<void(const QColor &)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'setAverageColor'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'setTendencyColor'
        QtMocHelpers::SlotData<void(const QColor &)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'setTendencyColor'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'setOutlineColor'
        QtMocHelpers::SlotData<void(const QColor &)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'setOutlineColor'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'setBackgroundColor'
        QtMocHelpers::SlotData<void(const QColor &)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'setBackgroundColor'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'setTextColor'
        QtMocHelpers::SlotData<void(const QColor &)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'setTextColor'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'setAntialiasing'
        QtMocHelpers::SlotData<void(bool)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 42 },
        }}),
        // Slot 'setAntialiasing'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'redrawGraphDelayed'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'switchLimitsVisibility'
        QtMocHelpers::SlotData<bool()>(44, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'switchAverageVisibility'
        QtMocHelpers::SlotData<bool()>(45, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'switchLinearRegressionVisibility'
        QtMocHelpers::SlotData<bool()>(46, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'switchParetoVisibility'
        QtMocHelpers::SlotData<bool()>(47, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'switchLegendVisibility'
        QtMocHelpers::SlotData<bool()>(48, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'swithOriginVisibility'
        QtMocHelpers::SlotData<bool()>(49, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'swithDecimalsVisibility'
        QtMocHelpers::SlotData<bool()>(50, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'resetColors'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'exportInFile'
        QtMocHelpers::SlotData<SKGError(const QString &)>(52, 2, QMC::AccessPublic, 0x80000000 | 53, {{
            { QMetaType::QString, 54 },
        }}),
        // Slot 'onExport'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onSelectionChanged'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onSelectionChangedInGraph'
        QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onDoubleClick'
        QtMocHelpers::SlotData<void(int, int)>(58, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 },
        }}),
        // Slot 'onDoubleClickGraph'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onLinkClicked'
        QtMocHelpers::SlotData<void(const QUrl &)>(60, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 61, 62 },
        }}),
        // Slot 'onFilterModified'
        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onDisplayModeChanged'
        QtMocHelpers::SlotData<void()>(64, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onChangeColor'
        QtMocHelpers::SlotData<void()>(65, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onHorizontalScrollBarChanged'
        QtMocHelpers::SlotData<void(int)>(66, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'refresh'
        QtMocHelpers::SlotData<void()>(67, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'redrawText'
        QtMocHelpers::SlotData<void()>(68, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'redrawGraph'
        QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showMenu'
        QtMocHelpers::SlotData<void(QPoint)>(70, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 71, 72 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'graphTypeSelectorVisible'
        QtMocHelpers::PropertyData<bool>(73, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'selectable'
        QtMocHelpers::PropertyData<bool>(74, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'shadow'
        QtMocHelpers::PropertyData<bool>(75, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 2),
        // property 'graphType'
        QtMocHelpers::PropertyData<enum GraphType>(76, 0x80000000 | 77, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'GraphType'
        QtMocHelpers::EnumData<enum GraphType>(77, 77, QMC::EnumFlags{}).add({
            {   78, GraphType::STACK },
            {   79, GraphType::HISTOGRAM },
            {   80, GraphType::PIE },
            {   81, GraphType::CONCENTRICPIE },
            {   82, GraphType::POINT },
            {   83, GraphType::LINE },
            {   84, GraphType::STACKAREA },
            {   85, GraphType::BUBBLE },
            {   86, GraphType::STACKCOLUMNS },
            {   87, GraphType::TREEMAP },
        }),
        // enum 'DisplayAdditional'
        QtMocHelpers::EnumData<enum DisplayAdditional>(88, 88, QMC::EnumFlags{}).add({
            {   89, DisplayAdditional::NONE },
            {   90, DisplayAdditional::SUM },
            {   91, DisplayAdditional::AVERAGE },
            {   92, DisplayAdditional::LIMITS },
            {   93, DisplayAdditional::ALL },
        }),
    };
    return QtMocHelpers::metaObjectData<SKGTableWithGraph, qt_meta_tag_ZN17SKGTableWithGraphE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SKGTableWithGraph::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17SKGTableWithGraphE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17SKGTableWithGraphE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17SKGTableWithGraphE_t>.metaTypes,
    nullptr
} };

void SKGTableWithGraph::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SKGTableWithGraph *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->cellDoubleClicked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->selectionChanged(); break;
        case 2: _t->modified(); break;
        case 3: _t->setState((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->setData((*reinterpret_cast<std::add_pointer_t<SKGStringListList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<SKGServices::SKGUnitInfo>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<SKGServices::SKGUnitInfo>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<SKGTableWithGraph::DisplayAdditionalFlag>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5]))); break;
        case 5: _t->setData((*reinterpret_cast<std::add_pointer_t<SKGStringListList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<SKGServices::SKGUnitInfo>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<SKGServices::SKGUnitInfo>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<SKGTableWithGraph::DisplayAdditionalFlag>>(_a[4]))); break;
        case 6: _t->setData((*reinterpret_cast<std::add_pointer_t<SKGStringListList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<SKGServices::SKGUnitInfo>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<SKGServices::SKGUnitInfo>>(_a[3]))); break;
        case 7: _t->setGraphTypeSelectorVisible((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->setSelectable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->setShadowVisible((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->setGraphType((*reinterpret_cast<std::add_pointer_t<SKGTableWithGraph::GraphType>>(_a[1]))); break;
        case 11: _t->setFilterVisibility((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->setAxisColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 13: _t->setAxisColor(); break;
        case 14: _t->setGridColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 15: _t->setGridColor(); break;
        case 16: _t->setMinColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 17: _t->setMinColor(); break;
        case 18: _t->setMaxColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 19: _t->setMaxColor(); break;
        case 20: _t->setParetoColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 21: _t->setParetoColor(); break;
        case 22: _t->setAverageColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 23: _t->setAverageColor(); break;
        case 24: _t->setTendencyColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 25: _t->setTendencyColor(); break;
        case 26: _t->setOutlineColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 27: _t->setOutlineColor(); break;
        case 28: _t->setBackgroundColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 29: _t->setBackgroundColor(); break;
        case 30: _t->setTextColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 31: _t->setTextColor(); break;
        case 32: _t->setAntialiasing((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 33: _t->setAntialiasing(); break;
        case 34: _t->redrawGraphDelayed(); break;
        case 35: { bool _r = _t->switchLimitsVisibility();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 36: { bool _r = _t->switchAverageVisibility();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 37: { bool _r = _t->switchLinearRegressionVisibility();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 38: { bool _r = _t->switchParetoVisibility();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 39: { bool _r = _t->switchLegendVisibility();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 40: { bool _r = _t->swithOriginVisibility();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 41: { bool _r = _t->swithDecimalsVisibility();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 42: _t->resetColors(); break;
        case 43: { SKGError _r = _t->exportInFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<SKGError*>(_a[0]) = std::move(_r); }  break;
        case 44: _t->onExport(); break;
        case 45: _t->onSelectionChanged(); break;
        case 46: _t->onSelectionChangedInGraph(); break;
        case 47: _t->onDoubleClick((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 48: _t->onDoubleClickGraph(); break;
        case 49: _t->onLinkClicked((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 50: _t->onFilterModified(); break;
        case 51: _t->onDisplayModeChanged(); break;
        case 52: _t->onChangeColor(); break;
        case 53: _t->onHorizontalScrollBarChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 54: _t->refresh(); break;
        case 55: _t->redrawText(); break;
        case 56: _t->redrawGraph(); break;
        case 57: _t->showMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SKGTableWithGraph::*)(int , int )>(_a, &SKGTableWithGraph::cellDoubleClicked, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SKGTableWithGraph::*)()>(_a, &SKGTableWithGraph::selectionChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SKGTableWithGraph::*)()>(_a, &SKGTableWithGraph::modified, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isGraphTypeSelectorVisible(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isSelectable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isShadowVisible(); break;
        case 3: *reinterpret_cast<enum GraphType*>(_v) = _t->getGraphType(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setGraphTypeSelectorVisible(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setSelectable(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setShadowVisible(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setGraphType(*reinterpret_cast<enum GraphType*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *SKGTableWithGraph::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SKGTableWithGraph::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17SKGTableWithGraphE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int SKGTableWithGraph::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 58)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 58;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 58)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 58;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void SKGTableWithGraph::cellDoubleClicked(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void SKGTableWithGraph::selectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void SKGTableWithGraph::modified()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
