/********************************************************************************
** Form generated from reading UI file 'skgbookmarkplugindockwidget_base.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGBOOKMARKPLUGINDOCKWIDGET_BASE_H
#define UI_SKGBOOKMARKPLUGINDOCKWIDGET_BASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "skgtreeview.h"

QT_BEGIN_NAMESPACE

class Ui_skgbookmarkplugindockwidget_base
{
public:
    QGridLayout *gridLayout;
    QLineEdit *kFilterEdit;
    SKGTreeView *kBookmarksList;
    QToolButton *kTools;

    void setupUi(QWidget *skgbookmarkplugindockwidget_base)
    {
        if (skgbookmarkplugindockwidget_base->objectName().isEmpty())
            skgbookmarkplugindockwidget_base->setObjectName("skgbookmarkplugindockwidget_base");
        skgbookmarkplugindockwidget_base->resize(330, 215);
        gridLayout = new QGridLayout(skgbookmarkplugindockwidget_base);
        gridLayout->setSpacing(2);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        kFilterEdit = new QLineEdit(skgbookmarkplugindockwidget_base);
        kFilterEdit->setObjectName("kFilterEdit");
        kFilterEdit->setFocusPolicy(Qt::WheelFocus);
        kFilterEdit->setClearButtonEnabled(true);

        gridLayout->addWidget(kFilterEdit, 0, 0, 1, 1);

        kBookmarksList = new SKGTreeView(skgbookmarkplugindockwidget_base);
        kBookmarksList->setObjectName("kBookmarksList");
        kBookmarksList->setFocusPolicy(Qt::NoFocus);
        kBookmarksList->setFrameShape(QFrame::NoFrame);
        kBookmarksList->setLineWidth(0);
        kBookmarksList->setDragEnabled(true);
        kBookmarksList->setDragDropMode(QAbstractItemView::DragDrop);
        kBookmarksList->setSelectionMode(QAbstractItemView::ExtendedSelection);
        kBookmarksList->setIconSize(QSize(32, 32));
        kBookmarksList->setUniformRowHeights(true);
        kBookmarksList->setAnimated(true);
        kBookmarksList->setAllColumnsShowFocus(true);
        kBookmarksList->setHeaderHidden(true);
        kBookmarksList->setExpandsOnDoubleClick(false);

        gridLayout->addWidget(kBookmarksList, 1, 0, 1, 2);

        kTools = new QToolButton(skgbookmarkplugindockwidget_base);
        kTools->setObjectName("kTools");
        kTools->setMaximumSize(QSize(22, 22));
        kTools->setFocusPolicy(Qt::NoFocus);
        kTools->setPopupMode(QToolButton::InstantPopup);
        kTools->setAutoRaise(true);

        gridLayout->addWidget(kTools, 0, 1, 1, 1);

        QWidget::setTabOrder(kFilterEdit, kTools);
        QWidget::setTabOrder(kTools, kBookmarksList);

        retranslateUi(skgbookmarkplugindockwidget_base);

        QMetaObject::connectSlotsByName(skgbookmarkplugindockwidget_base);
    } // setupUi

    void retranslateUi(QWidget *skgbookmarkplugindockwidget_base)
    {
        kFilterEdit->setPlaceholderText(tr2i18n("Search", nullptr));
#if QT_CONFIG(tooltip)
        kBookmarksList->setToolTip(tr2i18n("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"https://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'DejaVu Sans'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">this list allows you to open bookmarked pages</p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Ctrl</span> to open in a new page</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kBookmarksList->setStatusTip(tr2i18n("this list allows you to open bookmarked pages", nullptr));
#endif // QT_CONFIG(statustip)
        (void)skgbookmarkplugindockwidget_base;
    } // retranslateUi

};

namespace Ui {
    class skgbookmarkplugindockwidget_base: public Ui_skgbookmarkplugindockwidget_base {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGBOOKMARKPLUGINDOCKWIDGET_BASE_H

