/****************************************************************************
** Meta object code from reading C++ file 'skgunitpluginwidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../skrooge-26.8.0/plugins/skrooge/skrooge_unit/skgunitpluginwidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'skgunitpluginwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19SKGUnitPluginWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto SKGUnitPluginWidget::qt_create_metaobjectdata<qt_meta_tag_ZN19SKGUnitPluginWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SKGUnitPluginWidget",
        "dataModified",
        "",
        "iTableName",
        "iIdTransaction",
        "onSelectionChanged",
        "onSelectionValueChanged",
        "onUnitCreatorModified",
        "onAddUnit",
        "onModifyUnit",
        "onDownloadUnitValue",
        "onSimplify",
        "onDeleteSource",
        "onAddSource",
        "onSourceChanged",
        "onGetNewHotStuff",
        "onPutNewHotStuff",
        "onOpenURL",
        "cleanEditor",
        "refreshUnitList",
        "fillSourceList"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'dataModified'
        QtMocHelpers::SlotData<void(const QString &, int)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Int, 4 },
        }}),
        // Slot 'onSelectionChanged'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onSelectionValueChanged'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onUnitCreatorModified'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onAddUnit'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onModifyUnit'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onDownloadUnitValue'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onSimplify'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onDeleteSource'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onAddSource'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onSourceChanged'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onGetNewHotStuff'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onPutNewHotStuff'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onOpenURL'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'cleanEditor'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'refreshUnitList'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'fillSourceList'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SKGUnitPluginWidget, qt_meta_tag_ZN19SKGUnitPluginWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SKGUnitPluginWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<SKGTabPage::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19SKGUnitPluginWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19SKGUnitPluginWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19SKGUnitPluginWidgetE_t>.metaTypes,
    nullptr
} };

void SKGUnitPluginWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SKGUnitPluginWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->dataModified((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->onSelectionChanged(); break;
        case 2: _t->onSelectionValueChanged(); break;
        case 3: _t->onUnitCreatorModified(); break;
        case 4: _t->onAddUnit(); break;
        case 5: _t->onModifyUnit(); break;
        case 6: _t->onDownloadUnitValue(); break;
        case 7: _t->onSimplify(); break;
        case 8: _t->onDeleteSource(); break;
        case 9: _t->onAddSource(); break;
        case 10: _t->onSourceChanged(); break;
        case 11: _t->onGetNewHotStuff(); break;
        case 12: _t->onPutNewHotStuff(); break;
        case 13: _t->onOpenURL(); break;
        case 14: _t->cleanEditor(); break;
        case 15: _t->refreshUnitList(); break;
        case 16: _t->fillSourceList(); break;
        default: ;
        }
    }
}

const QMetaObject *SKGUnitPluginWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SKGUnitPluginWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19SKGUnitPluginWidgetE_t>.strings))
        return static_cast<void*>(this);
    return SKGTabPage::qt_metacast(_clname);
}

int SKGUnitPluginWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SKGTabPage::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    return _id;
}
QT_WARNING_POP
