/****************************************************************************
** Meta object code from reading C++ file 'skgimportexportplugin.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../skrooge-26.8.0/plugins/skrooge/skrooge_importexport/skgimportexportplugin.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'skgimportexportplugin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21SKGImportExportPluginE_t {};
} // unnamed namespace

template <> constexpr inline auto SKGImportExportPlugin::qt_create_metaobjectdata<qt_meta_tag_ZN21SKGImportExportPluginE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SKGImportExportPlugin",
        "importFileName",
        "",
        "iFile",
        "importFile",
        "iBlockOpenLastModified",
        "importFiles",
        "QList<QUrl>",
        "iFiles",
        "mode",
        "importbackends",
        "SKGError",
        "exportFile",
        "findTransfers",
        "anonymize",
        "cleanBanks",
        "swithvalidationImportedOperations",
        "validateAllOperations",
        "mergeImportedOperation",
        "onInstall"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'importFileName'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'importFile'
        QtMocHelpers::SlotData<void(const QString &, bool)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Bool, 5 },
        }}),
        // Slot 'importFile'
        QtMocHelpers::SlotData<void(const QString &)>(4, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'importFile'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'importFiles'
        QtMocHelpers::SlotData<void(const QList<QUrl> &, int, bool)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::Int, 9 }, { QMetaType::Bool, 5 },
        }}),
        // Slot 'importFiles'
        QtMocHelpers::SlotData<void(const QList<QUrl> &, int)>(6, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::Int, 9 },
        }}),
        // Slot 'importFiles'
        QtMocHelpers::SlotData<void(const QList<QUrl> &)>(6, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'importFiles'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'importbackends'
        QtMocHelpers::SlotData<SKGError()>(10, 2, QMC::AccessPrivate, 0x80000000 | 11),
        // Slot 'exportFile'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'findTransfers'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'anonymize'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'cleanBanks'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'swithvalidationImportedOperations'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'validateAllOperations'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'mergeImportedOperation'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onInstall'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SKGImportExportPlugin, qt_meta_tag_ZN21SKGImportExportPluginE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SKGImportExportPlugin::staticMetaObject = { {
    QMetaObject::SuperData::link<SKGInterfacePlugin::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21SKGImportExportPluginE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21SKGImportExportPluginE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21SKGImportExportPluginE_t>.metaTypes,
    nullptr
} };

void SKGImportExportPlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SKGImportExportPlugin *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->importFileName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->importFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 2: _t->importFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->importFile(); break;
        case 4: _t->importFiles((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 5: _t->importFiles((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 6: _t->importFiles((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 7: _t->importFiles(); break;
        case 8: { SKGError _r = _t->importbackends();
            if (_a[0]) *reinterpret_cast<SKGError*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->exportFile(); break;
        case 10: _t->findTransfers(); break;
        case 11: _t->anonymize(); break;
        case 12: _t->cleanBanks(); break;
        case 13: _t->swithvalidationImportedOperations(); break;
        case 14: _t->validateAllOperations(); break;
        case 15: _t->mergeImportedOperation(); break;
        case 16: _t->onInstall(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SKGImportExportPlugin::*)(const QString & )>(_a, &SKGImportExportPlugin::importFileName, 0))
            return;
    }
}

const QMetaObject *SKGImportExportPlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SKGImportExportPlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21SKGImportExportPluginE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "skrooge.com.SKGInterfacePlugin/1.0"))
        return static_cast< SKGInterfacePlugin*>(this);
    return SKGInterfacePlugin::qt_metacast(_clname);
}

int SKGImportExportPlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SKGInterfacePlugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void SKGImportExportPlugin::importFileName(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
