/****************************************************************************
** Meta object code from reading C++ file 'skgsearchpluginwidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../skrooge-26.8.0/plugins/skrooge/skrooge_search/skgsearchpluginwidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'skgsearchpluginwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21SKGSearchPluginWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto SKGSearchPluginWidget::qt_create_metaobjectdata<qt_meta_tag_ZN21SKGSearchPluginWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SKGSearchPluginWidget",
        "dataModified",
        "",
        "iTableName",
        "iIdTransaction",
        "onAddRule",
        "onModifyRule",
        "onOpen",
        "onSelectionChanged",
        "onTop",
        "onUp",
        "onDown",
        "onBottom",
        "onEditorModified",
        "cleanEditor",
        "OpenMode",
        "TABLE",
        "REPORT"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'dataModified'
        QtMocHelpers::SlotData<void(const QString &, int)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Int, 4 },
        }}),
        // Slot 'onAddRule'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onModifyRule'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onOpen'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onSelectionChanged'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onTop'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onUp'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onDown'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onBottom'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onEditorModified'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'cleanEditor'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'OpenMode'
        QtMocHelpers::EnumData<enum OpenMode>(15, 15, QMC::EnumFlags{}).add({
            {   16, OpenMode::TABLE },
            {   17, OpenMode::REPORT },
        }),
    };
    return QtMocHelpers::metaObjectData<SKGSearchPluginWidget, qt_meta_tag_ZN21SKGSearchPluginWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SKGSearchPluginWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<SKGTabPage::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21SKGSearchPluginWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21SKGSearchPluginWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21SKGSearchPluginWidgetE_t>.metaTypes,
    nullptr
} };

void SKGSearchPluginWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SKGSearchPluginWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->dataModified((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->onAddRule(); break;
        case 2: _t->onModifyRule(); break;
        case 3: _t->onOpen(); break;
        case 4: _t->onSelectionChanged(); break;
        case 5: _t->onTop(); break;
        case 6: _t->onUp(); break;
        case 7: _t->onDown(); break;
        case 8: _t->onBottom(); break;
        case 9: _t->onEditorModified(); break;
        case 10: _t->cleanEditor(); break;
        default: ;
        }
    }
}

const QMetaObject *SKGSearchPluginWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SKGSearchPluginWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21SKGSearchPluginWidgetE_t>.strings))
        return static_cast<void*>(this);
    return SKGTabPage::qt_metacast(_clname);
}

int SKGSearchPluginWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SKGTabPage::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}
QT_WARNING_POP
