/****************************************************************************
** Meta object code from reading C++ file 'skgerror.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../skrooge-26.8.0/skgbasemodeler/skgerror.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'skgerror.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8SKGErrorE_t {};
} // unnamed namespace

template <> constexpr inline auto SKGError::qt_create_metaobjectdata<qt_meta_tag_ZN8SKGErrorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SKGError",
        "setReturnCode",
        "",
        "iReturnCode",
        "setMessage",
        "iMessage",
        "setProperty",
        "iProperty",
        "setAction",
        "iAction",
        "addError",
        "iRc",
        "iError",
        "returnCode",
        "message",
        "property",
        "action",
        "succeeded",
        "failed"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'setReturnCode'
        QtMocHelpers::SlotData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'setMessage'
        QtMocHelpers::SlotData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'setProperty'
        QtMocHelpers::SlotData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'setAction'
        QtMocHelpers::SlotData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'addError'
        QtMocHelpers::SlotData<void(int, const QString &, const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 }, { QMetaType::QString, 5 }, { QMetaType::QString, 9 },
        }}),
        // Slot 'addError'
        QtMocHelpers::SlotData<void(int, const QString &)>(10, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 11 }, { QMetaType::QString, 5 },
        }}),
        // Slot 'addError'
        QtMocHelpers::SlotData<void(const SKGError &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 0, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'returnCode'
        QtMocHelpers::PropertyData<int>(13, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'message'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'property'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'action'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'succeeded'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'failed'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SKGError, qt_meta_tag_ZN8SKGErrorE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SKGError::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8SKGErrorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8SKGErrorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8SKGErrorE_t>.metaTypes,
    nullptr
} };

void SKGError::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<SKGError *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->setReturnCode((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->setMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->setProperty((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->setAction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->addError((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 5: _t->addError((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->addError((*reinterpret_cast<std::add_pointer_t<SKGError>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->getReturnCode(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->getMessage(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->getProperty(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->getAction(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isSucceeded(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isFailed(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setReturnCode(*reinterpret_cast<int*>(_v)); break;
        case 1: _t->setMessage(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setProperty(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setAction(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}
QT_WARNING_POP
