/***************************************************************************
 * SPDX-FileCopyrightText: 2026 S. MANKOWSKI stephane@mankowski.fr
 * SPDX-License-Identifier: GPL-3.0-or-later
 ***************************************************************************/
#ifndef SKGASSISTANTPLUGINWIDGET_H
#define SKGASSISTANTPLUGINWIDGET_H
/** @file
 * A dock widget for the AI assistant plugin.
 */
#include "skgtabpage.h"

/**
 * A skrooge plugin for the AI assistant
 */
class SKGAssistantPluginWidget : public SKGTabPage
{
    Q_OBJECT

public:
    /**
     * Default Constructor
     * @param iParent the parent widget
     * @param iDocument the document
     */
    explicit SKGAssistantPluginWidget(QWidget *iParent, SKGDocument *iDocument);

    /**
     * Default Destructor
     */
    ~SKGAssistantPluginWidget() override;
};

#endif // SKGASSISTANTPLUGINWIDGET_H
