// This file is generated by kconfig_compiler_kf6 from skgbookmark_settings.kcfg.
// All changes you do to this file will be lost.
#ifndef SKGBOOKMARK_SETTINGS_H
#define SKGBOOKMARK_SETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class skgbookmark_settings : public KConfigSkeleton
{
  public:

    static skgbookmark_settings *self();
    ~skgbookmark_settings() override;

    /**
      Get Pin home bookmarks
    */
    static
    bool pinhomebookmarks()
    {
      return self()->mPinhomebookmarks;
    }

    /**
      Is Pin home bookmarks Immutable
    */
    static
    bool isPinhomebookmarksImmutable()
    {
      return self()->isImmutable( QStringLiteral( "pinhomebookmarks" ) );
    }

  protected:
    skgbookmark_settings();
    friend class skgbookmark_settingsHelper;


    // Bookmark
    bool mPinhomebookmarks;
};

#endif

