/********************************************************************************
** Form generated from reading UI file 'skggraphicsview.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGGRAPHICSVIEW_H
#define UI_SKGGRAPHICSVIEW_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "skgzoomselector.h"

QT_BEGIN_NAMESPACE

class Ui_skggraphicview_base
{
public:
    QVBoxLayout *verticalLayout;
    QGraphicsView *kGraphicsView;
    QFrame *toolBar;
    QHBoxLayout *layout;
    QToolButton *kPrint;
    QToolButton *kCopy;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *horizontalSpacer_2;
    SKGZoomSelector *kZoom;

    void setupUi(QWidget *skggraphicview_base)
    {
        if (skggraphicview_base->objectName().isEmpty())
            skggraphicview_base->setObjectName("skggraphicview_base");
        skggraphicview_base->resize(518, 259);
        verticalLayout = new QVBoxLayout(skggraphicview_base);
        verticalLayout->setSpacing(2);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        kGraphicsView = new QGraphicsView(skggraphicview_base);
        kGraphicsView->setObjectName("kGraphicsView");
        kGraphicsView->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
        kGraphicsView->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
        kGraphicsView->setDragMode(QGraphicsView::ScrollHandDrag);

        verticalLayout->addWidget(kGraphicsView);

        toolBar = new QFrame(skggraphicview_base);
        toolBar->setObjectName("toolBar");
        layout = new QHBoxLayout(toolBar);
        layout->setSpacing(2);
        layout->setObjectName("layout");
        layout->setContentsMargins(0, 0, 0, 0);
        kPrint = new QToolButton(toolBar);
        kPrint->setObjectName("kPrint");
        kPrint->setAutoRaise(true);

        layout->addWidget(kPrint);

        kCopy = new QToolButton(toolBar);
        kCopy->setObjectName("kCopy");
        kCopy->setAutoRaise(true);

        layout->addWidget(kCopy);

        horizontalSpacer = new QSpacerItem(0, 26, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        layout->addItem(horizontalSpacer);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        layout->addItem(horizontalSpacer_2);

        kZoom = new SKGZoomSelector(toolBar);
        kZoom->setObjectName("kZoom");
        kZoom->setMaximumSize(QSize(200, 16777215));
        kZoom->setValue(-10);
        kZoom->setResetValue(-10);

        layout->addWidget(kZoom);


        verticalLayout->addWidget(toolBar);


        retranslateUi(skggraphicview_base);

        QMetaObject::connectSlotsByName(skggraphicview_base);
    } // setupUi

    void retranslateUi(QWidget *skggraphicview_base)
    {
#if QT_CONFIG(tooltip)
        kPrint->setToolTip(tr2i18n("Print the graph", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kPrint->setStatusTip(tr2i18n("Print the graph", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kCopy->setToolTip(tr2i18n("Copy picture", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kCopy->setStatusTip(tr2i18n("Copy picture", nullptr));
#endif // QT_CONFIG(statustip)
        (void)skggraphicview_base;
    } // retranslateUi

};

namespace Ui {
    class skggraphicview_base: public Ui_skggraphicview_base {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGGRAPHICSVIEW_H

