// This file is generated by kconfig_compiler_kf6 from skgpayee_settings.kcfg.
// All changes you do to this file will be lost.

#include "skgpayee_settings.h"

#include <qglobal.h>
#include <QFile>

class skgpayee_settingsHelper
{
  public:
    skgpayee_settingsHelper() noexcept : q(nullptr) {}
    ~skgpayee_settingsHelper() noexcept { delete q; q = nullptr; }
    skgpayee_settingsHelper(const skgpayee_settingsHelper&) = delete;
    skgpayee_settingsHelper& operator=(const skgpayee_settingsHelper&) = delete;
    skgpayee_settings *q;
};
Q_GLOBAL_STATIC(skgpayee_settingsHelper, s_globalskgpayee_settings)
skgpayee_settings *skgpayee_settings::self()
{
  if (!s_globalskgpayee_settings()->q) {
    new skgpayee_settings;
    s_globalskgpayee_settings()->q->read();
  }

  return s_globalskgpayee_settings()->q;
}

skgpayee_settings::skgpayee_settings( )
  : KConfigSkeleton()
{
  Q_ASSERT(!s_globalskgpayee_settings()->q);
  s_globalskgpayee_settings()->q = this;
  setCurrentGroup( QStringLiteral( "skrooge_payee" ) );

  KConfigSkeleton::ItemString  *itemUndefined;
  itemUndefined = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "undefined" ), mUndefined );
  addItem( itemUndefined, QStringLiteral( "undefined" ) );
}

skgpayee_settings::~skgpayee_settings()
{
  if (s_globalskgpayee_settings.exists() && !s_globalskgpayee_settings.isDestroyed()) {
    s_globalskgpayee_settings()->q = nullptr;
  }
}

