/********************************************************************************
** Form generated from reading UI file 'skgsearchpluginwidget_base.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGSEARCHPLUGINWIDGET_BASE_H
#define UI_SKGSEARCHPLUGINWIDGET_BASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "skgcalculatoredit.h"
#include "skgcombobox.h"
#include "skgfilteredtableview.h"
#include "skgquerycreator.h"
#include "skgwidgetselector.h"

QT_BEGIN_NAMESPACE

class Ui_skgsearchplugin_base
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_5;
    SKGFilteredTableView *kView;
    QVBoxLayout *verticalLayout_3;
    QToolButton *kTopBtn;
    QToolButton *kUpBtn;
    QToolButton *kDownBtn;
    QToolButton *kBottomBtn;
    QSpacerItem *verticalSpacer_3;
    QHBoxLayout *horizontalLayout_2;
    QLabel *kQueryInfo;
    QToolButton *kApply;
    QGroupBox *kQueryGrp;
    QVBoxLayout *verticalLayout_4;
    SKGQueryCreator *kQueryCreator;
    QGroupBox *kAlarmFrm;
    QGridLayout *gridLayout;
    QLabel *kAlarmLbl;
    QLabel *kAlarmMessageLbl;
    QLineEdit *kAlarmMessage;
    QLabel *kAlarmUnit;
    SKGCalculatorEdit *kAlarmAmount;
    QSpacerItem *horizontalSpacer;
    QGroupBox *kTemplateFrm;
    QGridLayout *gridLayout_2;
    QSpacerItem *horizontalSpacer_2;
    SKGComboBox *kTemplate;
    QLabel *kAlarmLbl_2;
    QGroupBox *kActionGrp;
    QVBoxLayout *verticalLayout_6;
    SKGQueryCreator *kActionCreator;
    QHBoxLayout *horizontalLayout_12;
    SKGWidgetSelector *kWidgetSelector;
    QFrame *kBtnFrm;
    QHBoxLayout *_2;
    QSpacerItem *verticalSpacer;
    QPushButton *kAdd;
    QPushButton *kUpdate;
    QSpacerItem *horizontalSpacer_3;
    QPushButton *kSearch;
    QPushButton *kOpenReport;

    void setupUi(QWidget *skgsearchplugin_base)
    {
        if (skgsearchplugin_base->objectName().isEmpty())
            skgsearchplugin_base->setObjectName("skgsearchplugin_base");
        skgsearchplugin_base->resize(750, 754);
        verticalLayout = new QVBoxLayout(skgsearchplugin_base);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setSpacing(2);
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        kView = new SKGFilteredTableView(skgsearchplugin_base);
        kView->setObjectName("kView");

        horizontalLayout_5->addWidget(kView);

        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setSpacing(2);
        verticalLayout_3->setObjectName("verticalLayout_3");
        kTopBtn = new QToolButton(skgsearchplugin_base);
        kTopBtn->setObjectName("kTopBtn");
        kTopBtn->setAutoRaise(true);

        verticalLayout_3->addWidget(kTopBtn);

        kUpBtn = new QToolButton(skgsearchplugin_base);
        kUpBtn->setObjectName("kUpBtn");
        kUpBtn->setAutoRaise(true);

        verticalLayout_3->addWidget(kUpBtn);

        kDownBtn = new QToolButton(skgsearchplugin_base);
        kDownBtn->setObjectName("kDownBtn");
        kDownBtn->setAutoRaise(true);

        verticalLayout_3->addWidget(kDownBtn);

        kBottomBtn = new QToolButton(skgsearchplugin_base);
        kBottomBtn->setObjectName("kBottomBtn");
        kBottomBtn->setAutoRaise(true);

        verticalLayout_3->addWidget(kBottomBtn);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_3);


        horizontalLayout_5->addLayout(verticalLayout_3);


        verticalLayout->addLayout(horizontalLayout_5);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(2);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        kQueryInfo = new QLabel(skgsearchplugin_base);
        kQueryInfo->setObjectName("kQueryInfo");
        kQueryInfo->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_2->addWidget(kQueryInfo);

        kApply = new QToolButton(skgsearchplugin_base);
        kApply->setObjectName("kApply");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kApply->sizePolicy().hasHeightForWidth());
        kApply->setSizePolicy(sizePolicy);
        kApply->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);

        horizontalLayout_2->addWidget(kApply);


        verticalLayout->addLayout(horizontalLayout_2);

        kQueryGrp = new QGroupBox(skgsearchplugin_base);
        kQueryGrp->setObjectName("kQueryGrp");
        verticalLayout_4 = new QVBoxLayout(kQueryGrp);
        verticalLayout_4->setObjectName("verticalLayout_4");
        kQueryCreator = new SKGQueryCreator(kQueryGrp);
        kQueryCreator->setObjectName("kQueryCreator");

        verticalLayout_4->addWidget(kQueryCreator);


        verticalLayout->addWidget(kQueryGrp);

        kAlarmFrm = new QGroupBox(skgsearchplugin_base);
        kAlarmFrm->setObjectName("kAlarmFrm");
        gridLayout = new QGridLayout(kAlarmFrm);
        gridLayout->setObjectName("gridLayout");
        kAlarmLbl = new QLabel(kAlarmFrm);
        kAlarmLbl->setObjectName("kAlarmLbl");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(kAlarmLbl->sizePolicy().hasHeightForWidth());
        kAlarmLbl->setSizePolicy(sizePolicy1);
        kAlarmLbl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(kAlarmLbl, 1, 0, 1, 1);

        kAlarmMessageLbl = new QLabel(kAlarmFrm);
        kAlarmMessageLbl->setObjectName("kAlarmMessageLbl");
        kAlarmMessageLbl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(kAlarmMessageLbl, 3, 0, 1, 1);

        kAlarmMessage = new QLineEdit(kAlarmFrm);
        kAlarmMessage->setObjectName("kAlarmMessage");

        gridLayout->addWidget(kAlarmMessage, 3, 1, 1, 3);

        kAlarmUnit = new QLabel(kAlarmFrm);
        kAlarmUnit->setObjectName("kAlarmUnit");
        sizePolicy1.setHeightForWidth(kAlarmUnit->sizePolicy().hasHeightForWidth());
        kAlarmUnit->setSizePolicy(sizePolicy1);
        QFont font;
        font.setBold(true);
        kAlarmUnit->setFont(font);

        gridLayout->addWidget(kAlarmUnit, 1, 2, 1, 1);

        kAlarmAmount = new SKGCalculatorEdit(kAlarmFrm);
        kAlarmAmount->setObjectName("kAlarmAmount");
        kAlarmAmount->setMinimumSize(QSize(50, 0));
        kAlarmAmount->setMaximumSize(QSize(100, 16777215));
        kAlarmAmount->setMode(SKGCalculatorEdit::EXPRESSION);

        gridLayout->addWidget(kAlarmAmount, 1, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 1, 3, 1, 1);


        verticalLayout->addWidget(kAlarmFrm);

        kTemplateFrm = new QGroupBox(skgsearchplugin_base);
        kTemplateFrm->setObjectName("kTemplateFrm");
        gridLayout_2 = new QGridLayout(kTemplateFrm);
        gridLayout_2->setObjectName("gridLayout_2");
        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_2, 1, 2, 1, 1);

        kTemplate = new SKGComboBox(kTemplateFrm);
        kTemplate->setObjectName("kTemplate");
        kTemplate->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        gridLayout_2->addWidget(kTemplate, 1, 1, 1, 1);

        kAlarmLbl_2 = new QLabel(kTemplateFrm);
        kAlarmLbl_2->setObjectName("kAlarmLbl_2");
        sizePolicy1.setHeightForWidth(kAlarmLbl_2->sizePolicy().hasHeightForWidth());
        kAlarmLbl_2->setSizePolicy(sizePolicy1);
        kAlarmLbl_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(kAlarmLbl_2, 1, 0, 1, 1);


        verticalLayout->addWidget(kTemplateFrm);

        kActionGrp = new QGroupBox(skgsearchplugin_base);
        kActionGrp->setObjectName("kActionGrp");
        verticalLayout_6 = new QVBoxLayout(kActionGrp);
        verticalLayout_6->setObjectName("verticalLayout_6");
        kActionCreator = new SKGQueryCreator(kActionGrp);
        kActionCreator->setObjectName("kActionCreator");

        verticalLayout_6->addWidget(kActionCreator);


        verticalLayout->addWidget(kActionGrp);

        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setSpacing(2);
        horizontalLayout_12->setObjectName("horizontalLayout_12");
        kWidgetSelector = new SKGWidgetSelector(skgsearchplugin_base);
        kWidgetSelector->setObjectName("kWidgetSelector");

        horizontalLayout_12->addWidget(kWidgetSelector);

        kBtnFrm = new QFrame(skgsearchplugin_base);
        kBtnFrm->setObjectName("kBtnFrm");
        kBtnFrm->setFrameShadow(QFrame::Raised);
        _2 = new QHBoxLayout(kBtnFrm);
        _2->setSpacing(2);
        _2->setObjectName("_2");
        _2->setContentsMargins(0, 0, 0, 0);
        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Maximum);

        _2->addItem(verticalSpacer);

        kAdd = new QPushButton(kBtnFrm);
        kAdd->setObjectName("kAdd");
        kAdd->setAutoDefault(true);

        _2->addWidget(kAdd);

        kUpdate = new QPushButton(kBtnFrm);
        kUpdate->setObjectName("kUpdate");
        kUpdate->setEnabled(false);

        _2->addWidget(kUpdate);

        horizontalSpacer_3 = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        _2->addItem(horizontalSpacer_3);

        kSearch = new QPushButton(kBtnFrm);
        kSearch->setObjectName("kSearch");

        _2->addWidget(kSearch);

        kOpenReport = new QPushButton(kBtnFrm);
        kOpenReport->setObjectName("kOpenReport");

        _2->addWidget(kOpenReport);


        horizontalLayout_12->addWidget(kBtnFrm);


        verticalLayout->addLayout(horizontalLayout_12);

#if QT_CONFIG(shortcut)
        kAlarmLbl->setBuddy(kAlarmAmount);
        kAlarmMessageLbl->setBuddy(kAlarmMessage);
        kAlarmLbl_2->setBuddy(kTemplate);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kTopBtn, kUpBtn);
        QWidget::setTabOrder(kUpBtn, kDownBtn);
        QWidget::setTabOrder(kDownBtn, kBottomBtn);
        QWidget::setTabOrder(kBottomBtn, kApply);
        QWidget::setTabOrder(kApply, kAlarmAmount);
        QWidget::setTabOrder(kAlarmAmount, kAlarmMessage);
        QWidget::setTabOrder(kAlarmMessage, kTemplate);
        QWidget::setTabOrder(kTemplate, kAdd);
        QWidget::setTabOrder(kAdd, kUpdate);
        QWidget::setTabOrder(kUpdate, kSearch);
        QWidget::setTabOrder(kSearch, kOpenReport);

        retranslateUi(skgsearchplugin_base);

        kAdd->setDefault(true);


        QMetaObject::connectSlotsByName(skgsearchplugin_base);
    } // setupUi

    void retranslateUi(QWidget *skgsearchplugin_base)
    {
        kQueryInfo->setText(QString());
#if QT_CONFIG(tooltip)
        kApply->setToolTip(tr2i18n("Apply processes", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kApply->setStatusTip(tr2i18n("Apply processes", nullptr));
#endif // QT_CONFIG(statustip)
        kApply->setText(tr2i18n("Execute", nullptr));
        kQueryGrp->setTitle(tr2i18n("Search", nullptr));
#if QT_CONFIG(statustip)
        kQueryCreator->setStatusTip(tr2i18n("Allow search definition", nullptr));
#endif // QT_CONFIG(statustip)
        kAlarmFrm->setTitle(tr2i18n("Alarm", nullptr));
        kAlarmLbl->setText(tr2i18n("Ala&rm amount:", nullptr));
        kAlarmMessageLbl->setText(tr2i18n("Alarm &message:", nullptr));
        kAlarmUnit->setText(tr2i18n("$", nullptr));
#if QT_CONFIG(tooltip)
        kAlarmAmount->setToolTip(tr2i18n("Amount triggering the alarm", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kAlarmAmount->setStatusTip(tr2i18n("Amount triggering the alarm", nullptr));
#endif // QT_CONFIG(statustip)
        kTemplateFrm->setTitle(tr2i18n("Template", nullptr));
#if QT_CONFIG(tooltip)
        kTemplate->setToolTip(tr2i18n("The template to apply on all transactions matching the condition", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kTemplate->setStatusTip(tr2i18n("The template to apply on all transactions matching the condition", nullptr));
#endif // QT_CONFIG(statustip)
        kAlarmLbl_2->setText(tr2i18n("&Template to apply:", nullptr));
        kActionGrp->setTitle(tr2i18n("Process", nullptr));
#if QT_CONFIG(statustip)
        kActionCreator->setStatusTip(tr2i18n("Allow process definition", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kAdd->setToolTip(tr2i18n("Add a search or a process (Ctrl+Enter)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kAdd->setStatusTip(tr2i18n("Add a search or a process (Ctrl+Enter)", nullptr));
#endif // QT_CONFIG(statustip)
        kAdd->setText(tr2i18n("Add", nullptr));
#if QT_CONFIG(tooltip)
        kUpdate->setToolTip(tr2i18n("Update selected search or process (Shift+Enter)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kUpdate->setStatusTip(tr2i18n("Update selected search or process (Shift+Enter)", nullptr));
#endif // QT_CONFIG(statustip)
        kUpdate->setText(tr2i18n("Modify", nullptr));
#if QT_CONFIG(tooltip)
        kSearch->setToolTip(tr2i18n("Search without creating rule", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kSearch->setStatusTip(tr2i18n("Search without creating rule", nullptr));
#endif // QT_CONFIG(statustip)
        kSearch->setText(tr2i18n("Search", nullptr));
#if QT_CONFIG(tooltip)
        kOpenReport->setToolTip(tr2i18n("Open report without creating rule", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kOpenReport->setStatusTip(tr2i18n("Open report without creating rule", nullptr));
#endif // QT_CONFIG(statustip)
        kOpenReport->setText(tr2i18n("Open report", nullptr));
        (void)skgsearchplugin_base;
    } // retranslateUi

};

namespace Ui {
    class skgsearchplugin_base: public Ui_skgsearchplugin_base {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGSEARCHPLUGINWIDGET_BASE_H

