/****************************************************************************
** Meta object code from reading C++ file 'skgmcontroler.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../skrooge-26.8.0/skroogecompanion/skgmcontroler.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'skgmcontroler.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13SKGMControlerE_t {};
} // unnamed namespace

template <> constexpr inline auto SKGMControler::qt_create_metaobjectdata<qt_meta_tag_ZN13SKGMControlerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SKGMControler",
        "filePathChanged",
        "",
        "passwordChanged",
        "showClosedAccountsChanged",
        "showClosedTrackersChanged",
        "errorMessageChanged",
        "globalFilterTextChanged",
        "globalAccountsTotalTextChanged",
        "openAccountsChanged",
        "selectedOpenAccountIndexChanged",
        "selectedAccountBalanceTextChanged",
        "selectedTrackerNameChanged",
        "transactionFilterTextChanged",
        "transactionStatusFilterChanged",
        "passwordRequiredChanged",
        "dashboardDataChanged",
        "referenceDataChanged",
        "openFile",
        "iFilePath",
        "iPassword",
        "selectOpenAccount",
        "iBank",
        "iAccountName",
        "selectTracker",
        "iTrackerName",
        "selectCategory",
        "iCategoryFullName",
        "selectTransaction",
        "iOperationId",
        "ensureDataForPage",
        "iPageIndex",
        "filePath",
        "password",
        "showClosedAccounts",
        "showClosedTrackers",
        "errorMessage",
        "globalFilterText",
        "accountsModel",
        "SKGMAccountListModel*",
        "globalAccountsTotalText",
        "openAccountNames",
        "selectedOpenAccountIndex",
        "selectedAccountBalanceText",
        "transactionsModel",
        "SKGMTransactionListModel*",
        "subTransactionsModel",
        "selectedTrackerName",
        "transactionFilterText",
        "transactionStatusFilter",
        "passwordRequired",
        "dashboardBankTotals",
        "QVariantList",
        "dashboardBankGrandTotalText",
        "dashboardCurrentPeriodLabel",
        "dashboardPreviousPeriodLabel",
        "dashboardCurrentIncomeText",
        "dashboardCurrentExpenseText",
        "dashboardPreviousIncomeText",
        "dashboardPreviousExpenseText",
        "dashboardCurrentSavingsText",
        "dashboardPreviousSavingsText",
        "dashboardCurrentSavings",
        "dashboardPreviousSavings",
        "dashboardPersonalFinanceScoreText",
        "dashboardPersonalFinanceScoreMessage",
        "dashboardPersonalFinanceScoreColor",
        "dashboardNetWorthText",
        "dashboardAnnualSpendingText",
        "trackersModel",
        "QAbstractItemModel*",
        "payeesModel",
        "categoriesModel",
        "unitsModel"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'filePathChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'passwordChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showClosedAccountsChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showClosedTrackersChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'errorMessageChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'globalFilterTextChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'globalAccountsTotalTextChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openAccountsChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectedOpenAccountIndexChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectedAccountBalanceTextChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectedTrackerNameChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'transactionFilterTextChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'transactionStatusFilterChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'passwordRequiredChanged'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dashboardDataChanged'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'referenceDataChanged'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'openFile'
        QtMocHelpers::MethodData<bool()>(18, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'openFile'
        QtMocHelpers::MethodData<bool(const QString &, const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 19 }, { QMetaType::QString, 20 },
        }}),
        // Method 'openFile'
        QtMocHelpers::MethodData<bool(const QString &)>(18, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::QString, 19 },
        }}),
        // Method 'selectOpenAccount'
        QtMocHelpers::MethodData<bool(const QString &, const QString &)>(21, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 22 }, { QMetaType::QString, 23 },
        }}),
        // Method 'selectTracker'
        QtMocHelpers::MethodData<bool(const QString &)>(24, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 25 },
        }}),
        // Method 'selectCategory'
        QtMocHelpers::MethodData<bool(const QString &)>(26, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 27 },
        }}),
        // Method 'selectTransaction'
        QtMocHelpers::MethodData<bool(int)>(28, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 29 },
        }}),
        // Method 'ensureDataForPage'
        QtMocHelpers::MethodData<void(int)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 31 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'filePath'
        QtMocHelpers::PropertyData<QString>(32, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'password'
        QtMocHelpers::PropertyData<QString>(33, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'showClosedAccounts'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'showClosedTrackers'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'errorMessage'
        QtMocHelpers::PropertyData<QString>(36, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
        // property 'globalFilterText'
        QtMocHelpers::PropertyData<QString>(37, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'accountsModel'
        QtMocHelpers::PropertyData<SKGMAccountListModel*>(38, 0x80000000 | 39, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'globalAccountsTotalText'
        QtMocHelpers::PropertyData<QString>(40, QMetaType::QString, QMC::DefaultPropertyFlags, 6),
        // property 'openAccountNames'
        QtMocHelpers::PropertyData<QStringList>(41, QMetaType::QStringList, QMC::DefaultPropertyFlags, 7),
        // property 'selectedOpenAccountIndex'
        QtMocHelpers::PropertyData<int>(42, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'selectedAccountBalanceText'
        QtMocHelpers::PropertyData<QString>(43, QMetaType::QString, QMC::DefaultPropertyFlags, 9),
        // property 'transactionsModel'
        QtMocHelpers::PropertyData<SKGMTransactionListModel*>(44, 0x80000000 | 45, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'subTransactionsModel'
        QtMocHelpers::PropertyData<SKGMTransactionListModel*>(46, 0x80000000 | 45, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'selectedTrackerName'
        QtMocHelpers::PropertyData<QString>(47, QMetaType::QString, QMC::DefaultPropertyFlags, 10),
        // property 'transactionFilterText'
        QtMocHelpers::PropertyData<QString>(48, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'transactionStatusFilter'
        QtMocHelpers::PropertyData<int>(49, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'passwordRequired'
        QtMocHelpers::PropertyData<bool>(50, QMetaType::Bool, QMC::DefaultPropertyFlags, 13),
        // property 'dashboardBankTotals'
        QtMocHelpers::PropertyData<QVariantList>(51, 0x80000000 | 52, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 14),
        // property 'dashboardBankGrandTotalText'
        QtMocHelpers::PropertyData<QString>(53, QMetaType::QString, QMC::DefaultPropertyFlags, 14),
        // property 'dashboardCurrentPeriodLabel'
        QtMocHelpers::PropertyData<QString>(54, QMetaType::QString, QMC::DefaultPropertyFlags, 14),
        // property 'dashboardPreviousPeriodLabel'
        QtMocHelpers::PropertyData<QString>(55, QMetaType::QString, QMC::DefaultPropertyFlags, 14),
        // property 'dashboardCurrentIncomeText'
        QtMocHelpers::PropertyData<QString>(56, QMetaType::QString, QMC::DefaultPropertyFlags, 14),
        // property 'dashboardCurrentExpenseText'
        QtMocHelpers::PropertyData<QString>(57, QMetaType::QString, QMC::DefaultPropertyFlags, 14),
        // property 'dashboardPreviousIncomeText'
        QtMocHelpers::PropertyData<QString>(58, QMetaType::QString, QMC::DefaultPropertyFlags, 14),
        // property 'dashboardPreviousExpenseText'
        QtMocHelpers::PropertyData<QString>(59, QMetaType::QString, QMC::DefaultPropertyFlags, 14),
        // property 'dashboardCurrentSavingsText'
        QtMocHelpers::PropertyData<QString>(60, QMetaType::QString, QMC::DefaultPropertyFlags, 14),
        // property 'dashboardPreviousSavingsText'
        QtMocHelpers::PropertyData<QString>(61, QMetaType::QString, QMC::DefaultPropertyFlags, 14),
        // property 'dashboardCurrentSavings'
        QtMocHelpers::PropertyData<double>(62, QMetaType::Double, QMC::DefaultPropertyFlags, 14),
        // property 'dashboardPreviousSavings'
        QtMocHelpers::PropertyData<double>(63, QMetaType::Double, QMC::DefaultPropertyFlags, 14),
        // property 'dashboardPersonalFinanceScoreText'
        QtMocHelpers::PropertyData<QString>(64, QMetaType::QString, QMC::DefaultPropertyFlags, 14),
        // property 'dashboardPersonalFinanceScoreMessage'
        QtMocHelpers::PropertyData<QString>(65, QMetaType::QString, QMC::DefaultPropertyFlags, 14),
        // property 'dashboardPersonalFinanceScoreColor'
        QtMocHelpers::PropertyData<QString>(66, QMetaType::QString, QMC::DefaultPropertyFlags, 14),
        // property 'dashboardNetWorthText'
        QtMocHelpers::PropertyData<QString>(67, QMetaType::QString, QMC::DefaultPropertyFlags, 14),
        // property 'dashboardAnnualSpendingText'
        QtMocHelpers::PropertyData<QString>(68, QMetaType::QString, QMC::DefaultPropertyFlags, 14),
        // property 'trackersModel'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(69, 0x80000000 | 70, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'payeesModel'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(71, 0x80000000 | 70, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'categoriesModel'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(72, 0x80000000 | 70, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'unitsModel'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(73, 0x80000000 | 70, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SKGMControler, qt_meta_tag_ZN13SKGMControlerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SKGMControler::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13SKGMControlerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13SKGMControlerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13SKGMControlerE_t>.metaTypes,
    nullptr
} };

void SKGMControler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SKGMControler *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->filePathChanged(); break;
        case 1: _t->passwordChanged(); break;
        case 2: _t->showClosedAccountsChanged(); break;
        case 3: _t->showClosedTrackersChanged(); break;
        case 4: _t->errorMessageChanged(); break;
        case 5: _t->globalFilterTextChanged(); break;
        case 6: _t->globalAccountsTotalTextChanged(); break;
        case 7: _t->openAccountsChanged(); break;
        case 8: _t->selectedOpenAccountIndexChanged(); break;
        case 9: _t->selectedAccountBalanceTextChanged(); break;
        case 10: _t->selectedTrackerNameChanged(); break;
        case 11: _t->transactionFilterTextChanged(); break;
        case 12: _t->transactionStatusFilterChanged(); break;
        case 13: _t->passwordRequiredChanged(); break;
        case 14: _t->dashboardDataChanged(); break;
        case 15: _t->referenceDataChanged(); break;
        case 16: { bool _r = _t->openFile();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { bool _r = _t->openFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 18: { bool _r = _t->openFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 19: { bool _r = _t->selectOpenAccount((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 20: { bool _r = _t->selectTracker((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 21: { bool _r = _t->selectCategory((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 22: { bool _r = _t->selectTransaction((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 23: _t->ensureDataForPage((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SKGMControler::*)()>(_a, &SKGMControler::filePathChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SKGMControler::*)()>(_a, &SKGMControler::passwordChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SKGMControler::*)()>(_a, &SKGMControler::showClosedAccountsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SKGMControler::*)()>(_a, &SKGMControler::showClosedTrackersChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SKGMControler::*)()>(_a, &SKGMControler::errorMessageChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SKGMControler::*)()>(_a, &SKGMControler::globalFilterTextChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (SKGMControler::*)()>(_a, &SKGMControler::globalAccountsTotalTextChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (SKGMControler::*)()>(_a, &SKGMControler::openAccountsChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (SKGMControler::*)()>(_a, &SKGMControler::selectedOpenAccountIndexChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (SKGMControler::*)()>(_a, &SKGMControler::selectedAccountBalanceTextChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (SKGMControler::*)()>(_a, &SKGMControler::selectedTrackerNameChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (SKGMControler::*)()>(_a, &SKGMControler::transactionFilterTextChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (SKGMControler::*)()>(_a, &SKGMControler::transactionStatusFilterChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (SKGMControler::*)()>(_a, &SKGMControler::passwordRequiredChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (SKGMControler::*)()>(_a, &SKGMControler::dashboardDataChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (SKGMControler::*)()>(_a, &SKGMControler::referenceDataChanged, 15))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 37:
        case 36:
        case 35:
        case 34:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractItemModel* >(); break;
        case 6:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< SKGMAccountListModel* >(); break;
        case 12:
        case 11:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< SKGMTransactionListModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->filePath(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->password(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->showClosedAccounts(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->showClosedTrackers(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->errorMessage(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->globalFilterText(); break;
        case 6: *reinterpret_cast<SKGMAccountListModel**>(_v) = _t->accountsModel(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->globalAccountsTotalText(); break;
        case 8: *reinterpret_cast<QStringList*>(_v) = _t->openAccountNames(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->selectedOpenAccountIndex(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->selectedAccountBalanceText(); break;
        case 11: *reinterpret_cast<SKGMTransactionListModel**>(_v) = _t->transactionsModel(); break;
        case 12: *reinterpret_cast<SKGMTransactionListModel**>(_v) = _t->subTransactionsModel(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->selectedTrackerName(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->transactionFilterText(); break;
        case 15: *reinterpret_cast<int*>(_v) = _t->transactionStatusFilter(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->passwordRequired(); break;
        case 17: *reinterpret_cast<QVariantList*>(_v) = _t->dashboardBankTotals(); break;
        case 18: *reinterpret_cast<QString*>(_v) = _t->dashboardBankGrandTotalText(); break;
        case 19: *reinterpret_cast<QString*>(_v) = _t->dashboardCurrentPeriodLabel(); break;
        case 20: *reinterpret_cast<QString*>(_v) = _t->dashboardPreviousPeriodLabel(); break;
        case 21: *reinterpret_cast<QString*>(_v) = _t->dashboardCurrentIncomeText(); break;
        case 22: *reinterpret_cast<QString*>(_v) = _t->dashboardCurrentExpenseText(); break;
        case 23: *reinterpret_cast<QString*>(_v) = _t->dashboardPreviousIncomeText(); break;
        case 24: *reinterpret_cast<QString*>(_v) = _t->dashboardPreviousExpenseText(); break;
        case 25: *reinterpret_cast<QString*>(_v) = _t->dashboardCurrentSavingsText(); break;
        case 26: *reinterpret_cast<QString*>(_v) = _t->dashboardPreviousSavingsText(); break;
        case 27: *reinterpret_cast<double*>(_v) = _t->dashboardCurrentSavings(); break;
        case 28: *reinterpret_cast<double*>(_v) = _t->dashboardPreviousSavings(); break;
        case 29: *reinterpret_cast<QString*>(_v) = _t->dashboardPersonalFinanceScoreText(); break;
        case 30: *reinterpret_cast<QString*>(_v) = _t->dashboardPersonalFinanceScoreMessage(); break;
        case 31: *reinterpret_cast<QString*>(_v) = _t->dashboardPersonalFinanceScoreColor(); break;
        case 32: *reinterpret_cast<QString*>(_v) = _t->dashboardNetWorthText(); break;
        case 33: *reinterpret_cast<QString*>(_v) = _t->dashboardAnnualSpendingText(); break;
        case 34: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->trackersModel(); break;
        case 35: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->payeesModel(); break;
        case 36: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->categoriesModel(); break;
        case 37: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->unitsModel(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setFilePath(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setPassword(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setShowClosedAccounts(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setShowClosedTrackers(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setGlobalFilterText(*reinterpret_cast<QString*>(_v)); break;
        case 9: _t->setSelectedOpenAccountIndex(*reinterpret_cast<int*>(_v)); break;
        case 14: _t->setTransactionFilterText(*reinterpret_cast<QString*>(_v)); break;
        case 15: _t->setTransactionStatusFilter(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *SKGMControler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SKGMControler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13SKGMControlerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SKGMControler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 24;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 38;
    }
    return _id;
}

// SIGNAL 0
void SKGMControler::filePathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SKGMControler::passwordChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void SKGMControler::showClosedAccountsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void SKGMControler::showClosedTrackersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void SKGMControler::errorMessageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void SKGMControler::globalFilterTextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void SKGMControler::globalAccountsTotalTextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void SKGMControler::openAccountsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void SKGMControler::selectedOpenAccountIndexChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void SKGMControler::selectedAccountBalanceTextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void SKGMControler::selectedTrackerNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void SKGMControler::transactionFilterTextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void SKGMControler::transactionStatusFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void SKGMControler::passwordRequiredChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void SKGMControler::dashboardDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void SKGMControler::referenceDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}
QT_WARNING_POP
