// This file is generated by kconfig_compiler_kf6 from skgunit_settings.kcfg.
// All changes you do to this file will be lost.
#ifndef SKGUNIT_SETTINGS_H
#define SKGUNIT_SETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class skgunit_settings : public KConfigSkeleton
{
  public:

    static skgunit_settings *self();
    ~skgunit_settings() override;

    /**
      Get Download mode
    */
    static
    bool last()
    {
      return self()->mLast;
    }

    /**
      Is Download mode Immutable
    */
    static
    bool isLastImmutable()
    {
      return self()->isImmutable( QStringLiteral( "last" ) );
    }

    /**
      Get Download mode
    */
    static
    bool last_monthly()
    {
      return self()->mLast_monthly;
    }

    /**
      Is Download mode Immutable
    */
    static
    bool isLast_monthlyImmutable()
    {
      return self()->isImmutable( QStringLiteral( "last_monthly" ) );
    }

    /**
      Get Download mode
    */
    static
    bool last_weekly()
    {
      return self()->mLast_weekly;
    }

    /**
      Is Download mode Immutable
    */
    static
    bool isLast_weeklyImmutable()
    {
      return self()->isImmutable( QStringLiteral( "last_weekly" ) );
    }

    /**
      Get Download mode
    */
    static
    bool last_daily()
    {
      return self()->mLast_daily;
    }

    /**
      Is Download mode Immutable
    */
    static
    bool isLast_dailyImmutable()
    {
      return self()->isImmutable( QStringLiteral( "last_daily" ) );
    }

    /**
      Get Download mode
    */
    static
    bool all_monthly()
    {
      return self()->mAll_monthly;
    }

    /**
      Is Download mode Immutable
    */
    static
    bool isAll_monthlyImmutable()
    {
      return self()->isImmutable( QStringLiteral( "all_monthly" ) );
    }

    /**
      Get Download mode
    */
    static
    bool all_weekly()
    {
      return self()->mAll_weekly;
    }

    /**
      Is Download mode Immutable
    */
    static
    bool isAll_weeklyImmutable()
    {
      return self()->isImmutable( QStringLiteral( "all_weekly" ) );
    }

    /**
      Get Download mode
    */
    static
    bool all_daily()
    {
      return self()->mAll_daily;
    }

    /**
      Is Download mode Immutable
    */
    static
    bool isAll_dailyImmutable()
    {
      return self()->isImmutable( QStringLiteral( "all_daily" ) );
    }

    /**
      Get Download all values on open
    */
    static
    bool download_on_open()
    {
      return self()->mDownload_on_open;
    }

    /**
      Is Download all values on open Immutable
    */
    static
    bool isDownload_on_openImmutable()
    {
      return self()->isImmutable( QStringLiteral( "download_on_open" ) );
    }

    /**
      Get Frequency of the automatic download
    */
    static
    int download_frequency()
    {
      return self()->mDownload_frequency;
    }

    /**
      Is Frequency of the automatic download Immutable
    */
    static
    bool isDownload_frequencyImmutable()
    {
      return self()->isImmutable( QStringLiteral( "download_frequency" ) );
    }

    /**
      Get Maximum number of imported values:
    */
    static
    int nb_loaded_values()
    {
      return self()->mNb_loaded_values;
    }

    /**
      Is Maximum number of imported values: Immutable
    */
    static
    bool isNb_loaded_valuesImmutable()
    {
      return self()->isImmutable( QStringLiteral( "nb_loaded_values" ) );
    }

  protected:
    skgunit_settings();
    friend class skgunit_settingsHelper;


    // skrooge_unit
    bool mLast;
    bool mLast_monthly;
    bool mLast_weekly;
    bool mLast_daily;
    bool mAll_monthly;
    bool mAll_weekly;
    bool mAll_daily;
    bool mDownload_on_open;
    int mDownload_frequency;
    int mNb_loaded_values;
};

#endif

