// This file is generated by kconfig_compiler_kf6 from skgbasegui_settings.kcfg.
// All changes you do to this file will be lost.
#ifndef SKGBASEGUI_SETTINGS_H
#define SKGBASEGUI_SETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class skgbasegui_settings : public KConfigSkeleton
{
  public:

    static skgbasegui_settings *self();
    ~skgbasegui_settings() override;

    /**
      Get Show splash screen
    */
    static
    bool show_splash_screen()
    {
      return self()->mShow_splash_screen;
    }

    /**
      Is Show splash screen Immutable
    */
    static
    bool isShow_splash_screenImmutable()
    {
      return self()->isImmutable( QStringLiteral( "show_splash_screen" ) );
    }

    /**
      Get Update modified bookmarks on close
    */
    static
    int update_modified_bookmarks()
    {
      return self()->mUpdate_modified_bookmarks;
    }

    /**
      Is Update modified bookmarks on close Immutable
    */
    static
    bool isUpdate_modified_bookmarksImmutable()
    {
      return self()->isImmutable( QStringLiteral( "update_modified_bookmarks" ) );
    }

    /**
      Get Update modified pages on close
    */
    static
    int update_modified_contexts()
    {
      return self()->mUpdate_modified_contexts;
    }

    /**
      Is Update modified pages on close Immutable
    */
    static
    bool isUpdate_modified_contextsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "update_modified_contexts" ) );
    }

    /**
      Get Main tabs position
    */
    static
    int main_tabs_position()
    {
      return self()->mMain_tabs_position;
    }

    /**
      Is Main tabs position Immutable
    */
    static
    bool isMain_tabs_positionImmutable()
    {
      return self()->isImmutable( QStringLiteral( "main_tabs_position" ) );
    }

    /**
      Get Date format
    */
    static
    int date_format()
    {
      return self()->mDate_format;
    }

    /**
      Is Date format Immutable
    */
    static
    bool isDate_formatImmutable()
    {
      return self()->isImmutable( QStringLiteral( "date_format" ) );
    }

    /**
      Get Currency format
    */
    static
    int currency_format()
    {
      return self()->mCurrency_format;
    }

    /**
      Is Currency format Immutable
    */
    static
    bool isCurrency_formatImmutable()
    {
      return self()->isImmutable( QStringLiteral( "currency_format" ) );
    }

    /**
      Get Icon in system tray
    */
    static
    bool icon_in_system_tray()
    {
      return self()->mIcon_in_system_tray;
    }

    /**
      Is Icon in system tray Immutable
    */
    static
    bool isIcon_in_system_trayImmutable()
    {
      return self()->isImmutable( QStringLiteral( "icon_in_system_tray" ) );
    }

  protected:
    skgbasegui_settings();
    friend class skgbasegui_settingsHelper;


    // Main Panel
    bool mShow_splash_screen;
    int mUpdate_modified_bookmarks;
    int mUpdate_modified_contexts;
    int mMain_tabs_position;
    int mDate_format;
    int mCurrency_format;
    bool mIcon_in_system_tray;
};

#endif

