/****************************************************************************
** Meta object code from reading C++ file 'skgoperationpluginwidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../skrooge-26.8.0/plugins/skrooge/skrooge_operation/skgoperationpluginwidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'skgoperationpluginwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24SKGOperationPluginWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto SKGOperationPluginWidget::qt_create_metaobjectdata<qt_meta_tag_ZN24SKGOperationPluginWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SKGOperationPluginWidget",
        "dataModified",
        "",
        "iTableName",
        "iIdTransaction",
        "iLightTransaction",
        "onOperationCreatorModified",
        "onPayeeChanged",
        "onAddOperationClicked",
        "onUpdateOperationClicked",
        "onFilterChanged",
        "onAccountChanged",
        "onSelectionChanged",
        "onFocusChanged",
        "onFastEdition",
        "onDoubleClick",
        "onQuantityChanged",
        "onDateChanged",
        "iDate",
        "onSubopCellChanged",
        "row",
        "column",
        "onRemoveSubOperation",
        "iRow",
        "onRefreshInformationZone",
        "onRefreshInformationZoneDelayed",
        "onRotateAccountTools",
        "onValidateMarkedOperations",
        "onBtnModeClicked",
        "mode",
        "onAutoPoint",
        "onAddFakeOperation",
        "onFreeze",
        "refreshSubOperationAmount",
        "cleanEditor",
        "displayReconciliationInfo",
        "displayBalance",
        "fillTargetAccount"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'dataModified'
        QtMocHelpers::SlotData<void(const QString &, int, bool)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Int, 4 }, { QMetaType::Bool, 5 },
        }}),
        // Slot 'dataModified'
        QtMocHelpers::SlotData<void(const QString &, int)>(1, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Int, 4 },
        }}),
        // Slot 'onOperationCreatorModified'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onPayeeChanged'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onAddOperationClicked'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onUpdateOperationClicked'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onFilterChanged'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onAccountChanged'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onSelectionChanged'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onFocusChanged'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onFastEdition'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onDoubleClick'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onQuantityChanged'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onDateChanged'
        QtMocHelpers::SlotData<void(QDate)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QDate, 18 },
        }}),
        // Slot 'onSubopCellChanged'
        QtMocHelpers::SlotData<void(int, int)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 20 }, { QMetaType::Int, 21 },
        }}),
        // Slot 'onRemoveSubOperation'
        QtMocHelpers::SlotData<void(int)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 23 },
        }}),
        // Slot 'onRefreshInformationZone'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onRefreshInformationZoneDelayed'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onRotateAccountTools'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onValidateMarkedOperations'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onBtnModeClicked'
        QtMocHelpers::SlotData<void(int)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 29 },
        }}),
        // Slot 'onAutoPoint'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onAddFakeOperation'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onFreeze'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'refreshSubOperationAmount'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'cleanEditor'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'displayReconciliationInfo'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'displayBalance'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'fillTargetAccount'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SKGOperationPluginWidget, qt_meta_tag_ZN24SKGOperationPluginWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SKGOperationPluginWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<SKGTabPage::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24SKGOperationPluginWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24SKGOperationPluginWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24SKGOperationPluginWidgetE_t>.metaTypes,
    nullptr
} };

void SKGOperationPluginWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SKGOperationPluginWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->dataModified((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 1: _t->dataModified((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 2: _t->onOperationCreatorModified(); break;
        case 3: _t->onPayeeChanged(); break;
        case 4: _t->onAddOperationClicked(); break;
        case 5: _t->onUpdateOperationClicked(); break;
        case 6: _t->onFilterChanged(); break;
        case 7: _t->onAccountChanged(); break;
        case 8: _t->onSelectionChanged(); break;
        case 9: _t->onFocusChanged(); break;
        case 10: _t->onFastEdition(); break;
        case 11: _t->onDoubleClick(); break;
        case 12: _t->onQuantityChanged(); break;
        case 13: _t->onDateChanged((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 14: _t->onSubopCellChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 15: _t->onRemoveSubOperation((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->onRefreshInformationZone(); break;
        case 17: _t->onRefreshInformationZoneDelayed(); break;
        case 18: _t->onRotateAccountTools(); break;
        case 19: _t->onValidateMarkedOperations(); break;
        case 20: _t->onBtnModeClicked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 21: _t->onAutoPoint(); break;
        case 22: _t->onAddFakeOperation(); break;
        case 23: _t->onFreeze(); break;
        case 24: _t->refreshSubOperationAmount(); break;
        case 25: _t->cleanEditor(); break;
        case 26: _t->displayReconciliationInfo(); break;
        case 27: _t->displayBalance(); break;
        case 28: _t->fillTargetAccount(); break;
        default: ;
        }
    }
}

const QMetaObject *SKGOperationPluginWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SKGOperationPluginWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24SKGOperationPluginWidgetE_t>.strings))
        return static_cast<void*>(this);
    return SKGTabPage::qt_metacast(_clname);
}

int SKGOperationPluginWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SKGTabPage::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 29;
    }
    return _id;
}
QT_WARNING_POP
