/****************************************************************************
** Meta object code from reading C++ file 'skgmainpanel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../skrooge-26.8.0/skgbasegui/skgmainpanel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'skgmainpanel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12SKGMainPanelE_t {};
} // unnamed namespace

template <> constexpr inline auto SKGMainPanel::qt_create_metaobjectdata<qt_meta_tag_ZN12SKGMainPanelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SKGMainPanel",
        "pageOpened",
        "",
        "pageClosed",
        "currentPageChanged",
        "settingsChanged",
        "selectionChanged",
        "displayMessage",
        "KMessageWidget*",
        "iMessage",
        "SKGDocument::MessageType",
        "iType",
        "iAction",
        "displayErrorMessage",
        "processArguments",
        "iArgument",
        "setCurrentPage",
        "iIndex",
        "setContextVisibility",
        "iPage",
        "iVisibility",
        "QListWidgetItem*",
        "iItem",
        "openPage",
        "QUrl",
        "iUrl",
        "iNewPage",
        "SKGTabPage*",
        "SKGInterfacePlugin*",
        "plugin",
        "index",
        "parameters",
        "title",
        "iID",
        "iSetCurrent",
        "switchPinPage",
        "QWidget*",
        "iWidget",
        "closePageByIndex",
        "closePage",
        "iForce",
        "closeCurrentPage",
        "closeAllOtherPages",
        "closeAllPages",
        "refresh",
        "notify",
        "iTransaction",
        "optionsPreferences",
        "iPluginName",
        "unRegisterGlobalAction",
        "getMessageWidget",
        "iAutoKillOnClick",
        "showMenu",
        "QPoint",
        "iPos",
        "onSettingsChanged",
        "onCancelCurrentAction",
        "onQuitAction",
        "addTab",
        "onBeforeOpenContext",
        "onOpenContext",
        "saveDefaultState",
        "resetDefaultState",
        "overwriteBookmarkState",
        "enableEditor",
        "onPrevious",
        "onNext",
        "onReopenLastClosed",
        "onFullScreen",
        "onShowPreviousMenu",
        "onShowNextMenu",
        "onZoomChanged",
        "onShowMenuBar",
        "onShowButtonMenu",
        "onHideContextItem",
        "onShowAllContextItems",
        "onLockDocks",
        "onUnlockDocks",
        "onConfigureNotifications",
        "onClearMessages",
        "onMigrateToSQLCipher"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'pageOpened'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pageClosed'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentPageChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'settingsChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectionChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'displayMessage'
        QtMocHelpers::SlotData<KMessageWidget *(const QString &, SKGDocument::MessageType, const QString &)>(7, 2, QMC::AccessPublic, 0x80000000 | 8, {{
            { QMetaType::QString, 9 }, { 0x80000000 | 10, 11 }, { QMetaType::QString, 12 },
        }}),
        // Slot 'displayMessage'
        QtMocHelpers::SlotData<KMessageWidget *(const QString &, SKGDocument::MessageType)>(7, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 8, {{
            { QMetaType::QString, 9 }, { 0x80000000 | 10, 11 },
        }}),
        // Slot 'displayMessage'
        QtMocHelpers::SlotData<KMessageWidget *(const QString &)>(7, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 8, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'displayErrorMessage'
        QtMocHelpers::SlotData<KMessageWidget *(const QString &)>(13, 2, QMC::AccessPublic, 0x80000000 | 8, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'displayErrorMessage'
        QtMocHelpers::SlotData<KMessageWidget *()>(13, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 8),
        // Slot 'processArguments'
        QtMocHelpers::SlotData<QStringList(const QStringList &)>(14, 2, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QStringList, 15 },
        }}),
        // Slot 'setCurrentPage'
        QtMocHelpers::SlotData<void(int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Slot 'setContextVisibility'
        QtMocHelpers::SlotData<void(int, bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 }, { QMetaType::Bool, 20 },
        }}),
        // Slot 'setContextVisibility'
        QtMocHelpers::SlotData<void(QListWidgetItem *, bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 }, { QMetaType::Bool, 20 },
        }}),
        // Slot 'openPage'
        QtMocHelpers::SlotData<bool()>(23, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'openPage'
        QtMocHelpers::SlotData<bool(const QUrl &, bool)>(23, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 24, 25 }, { QMetaType::Bool, 26 },
        }}),
        // Slot 'openPage'
        QtMocHelpers::SlotData<bool(const QUrl &)>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'openPage'
        QtMocHelpers::SlotData<bool(const QString &, bool)>(23, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 25 }, { QMetaType::Bool, 26 },
        }}),
        // Slot 'openPage'
        QtMocHelpers::SlotData<bool(const QString &)>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'openPage'
        QtMocHelpers::SlotData<SKGTabPage *(int, bool)>(23, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { QMetaType::Int, 19 }, { QMetaType::Bool, 26 },
        }}),
        // Slot 'openPage'
        QtMocHelpers::SlotData<SKGTabPage *(int)>(23, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 27, {{
            { QMetaType::Int, 19 },
        }}),
        // Slot 'openPage'
        QtMocHelpers::SlotData<SKGTabPage *(SKGInterfacePlugin *, int, const QString &, const QString &, const QString &, bool)>(23, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { 0x80000000 | 28, 29 }, { QMetaType::Int, 30 }, { QMetaType::QString, 31 }, { QMetaType::QString, 32 },
            { QMetaType::QString, 33 }, { QMetaType::Bool, 34 },
        }}),
        // Slot 'openPage'
        QtMocHelpers::SlotData<SKGTabPage *(SKGInterfacePlugin *, int, const QString &, const QString &, const QString &)>(23, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 27, {{
            { 0x80000000 | 28, 29 }, { QMetaType::Int, 30 }, { QMetaType::QString, 31 }, { QMetaType::QString, 32 },
            { QMetaType::QString, 33 },
        }}),
        // Slot 'openPage'
        QtMocHelpers::SlotData<SKGTabPage *(SKGInterfacePlugin *, int, const QString &, const QString &)>(23, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 27, {{
            { 0x80000000 | 28, 29 }, { QMetaType::Int, 30 }, { QMetaType::QString, 31 }, { QMetaType::QString, 32 },
        }}),
        // Slot 'openPage'
        QtMocHelpers::SlotData<SKGTabPage *(SKGInterfacePlugin *, int, const QString &)>(23, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 27, {{
            { 0x80000000 | 28, 29 }, { QMetaType::Int, 30 }, { QMetaType::QString, 31 },
        }}),
        // Slot 'openPage'
        QtMocHelpers::SlotData<SKGTabPage *(SKGInterfacePlugin *, int)>(23, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 27, {{
            { 0x80000000 | 28, 29 }, { QMetaType::Int, 30 },
        }}),
        // Slot 'openPage'
        QtMocHelpers::SlotData<SKGTabPage *(SKGInterfacePlugin *)>(23, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 27, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Slot 'switchPinPage'
        QtMocHelpers::SlotData<void(QWidget *)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 37 },
        }}),
        // Slot 'closePageByIndex'
        QtMocHelpers::SlotData<void(int)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Slot 'closePageByIndex'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'closePage'
        QtMocHelpers::SlotData<void(QWidget *, bool)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 37 }, { QMetaType::Bool, 40 },
        }}),
        // Slot 'closePage'
        QtMocHelpers::SlotData<void(QWidget *)>(39, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 36, 37 },
        }}),
        // Slot 'closeCurrentPage'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'closeAllOtherPages'
        QtMocHelpers::SlotData<void(QWidget *)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 37 },
        }}),
        // Slot 'closeAllPages'
        QtMocHelpers::SlotData<void(bool)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 40 },
        }}),
        // Slot 'closeAllPages'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'refresh'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'notify'
        QtMocHelpers::SlotData<void(int)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 46 },
        }}),
        // Slot 'notify'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'optionsPreferences'
        QtMocHelpers::SlotData<void(const QString &)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 48 },
        }}),
        // Slot 'optionsPreferences'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'unRegisterGlobalAction'
        QtMocHelpers::SlotData<void(QObject *)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 12 },
        }}),
        // Slot 'getMessageWidget'
        QtMocHelpers::SlotData<KMessageWidget *(const QString &, SKGDocument::MessageType, const QString &, bool)>(50, 2, QMC::AccessPrivate, 0x80000000 | 8, {{
            { QMetaType::QString, 9 }, { 0x80000000 | 10, 11 }, { QMetaType::QString, 12 }, { QMetaType::Bool, 51 },
        }}),
        // Slot 'showMenu'
        QtMocHelpers::SlotData<void(QPoint)>(52, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'onSettingsChanged'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onCancelCurrentAction'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onQuitAction'
        QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addTab'
        QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onBeforeOpenContext'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onOpenContext'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveDefaultState'
        QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'resetDefaultState'
        QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'overwriteBookmarkState'
        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'enableEditor'
        QtMocHelpers::SlotData<void()>(64, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onPrevious'
        QtMocHelpers::SlotData<void()>(65, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onNext'
        QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onReopenLastClosed'
        QtMocHelpers::SlotData<void()>(67, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onFullScreen'
        QtMocHelpers::SlotData<void()>(68, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onShowPreviousMenu'
        QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onShowNextMenu'
        QtMocHelpers::SlotData<void()>(70, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onZoomChanged'
        QtMocHelpers::SlotData<void()>(71, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onShowMenuBar'
        QtMocHelpers::SlotData<void()>(72, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onShowButtonMenu'
        QtMocHelpers::SlotData<void()>(73, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onHideContextItem'
        QtMocHelpers::SlotData<void()>(74, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onShowAllContextItems'
        QtMocHelpers::SlotData<void()>(75, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onLockDocks'
        QtMocHelpers::SlotData<void()>(76, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onUnlockDocks'
        QtMocHelpers::SlotData<void()>(77, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onConfigureNotifications'
        QtMocHelpers::SlotData<void()>(78, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onClearMessages'
        QtMocHelpers::SlotData<void()>(79, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onMigrateToSQLCipher'
        QtMocHelpers::SlotData<void()>(80, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SKGMainPanel, qt_meta_tag_ZN12SKGMainPanelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SKGMainPanel::staticMetaObject = { {
    QMetaObject::SuperData::link<KXmlGuiWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12SKGMainPanelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12SKGMainPanelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12SKGMainPanelE_t>.metaTypes,
    nullptr
} };

void SKGMainPanel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SKGMainPanel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->pageOpened(); break;
        case 1: _t->pageClosed(); break;
        case 2: _t->currentPageChanged(); break;
        case 3: _t->settingsChanged(); break;
        case 4: _t->selectionChanged(); break;
        case 5: { KMessageWidget* _r = _t->displayMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<SKGDocument::MessageType>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<KMessageWidget**>(_a[0]) = std::move(_r); }  break;
        case 6: { KMessageWidget* _r = _t->displayMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<SKGDocument::MessageType>>(_a[2])));
            if (_a[0]) *reinterpret_cast<KMessageWidget**>(_a[0]) = std::move(_r); }  break;
        case 7: { KMessageWidget* _r = _t->displayMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<KMessageWidget**>(_a[0]) = std::move(_r); }  break;
        case 8: { KMessageWidget* _r = _t->displayErrorMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<KMessageWidget**>(_a[0]) = std::move(_r); }  break;
        case 9: { KMessageWidget* _r = _t->displayErrorMessage();
            if (_a[0]) *reinterpret_cast<KMessageWidget**>(_a[0]) = std::move(_r); }  break;
        case 10: { QStringList _r = _t->processArguments((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->setCurrentPage((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->setContextVisibility((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 13: _t->setContextVisibility((*reinterpret_cast<std::add_pointer_t<QListWidgetItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 14: { bool _r = _t->openPage();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 15: { bool _r = _t->openPage((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: { bool _r = _t->openPage((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { bool _r = _t->openPage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 18: { bool _r = _t->openPage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 19: { SKGTabPage* _r = _t->openPage((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<SKGTabPage**>(_a[0]) = std::move(_r); }  break;
        case 20: { SKGTabPage* _r = _t->openPage((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<SKGTabPage**>(_a[0]) = std::move(_r); }  break;
        case 21: { SKGTabPage* _r = _t->openPage((*reinterpret_cast<std::add_pointer_t<SKGInterfacePlugin*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6])));
            if (_a[0]) *reinterpret_cast<SKGTabPage**>(_a[0]) = std::move(_r); }  break;
        case 22: { SKGTabPage* _r = _t->openPage((*reinterpret_cast<std::add_pointer_t<SKGInterfacePlugin*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])));
            if (_a[0]) *reinterpret_cast<SKGTabPage**>(_a[0]) = std::move(_r); }  break;
        case 23: { SKGTabPage* _r = _t->openPage((*reinterpret_cast<std::add_pointer_t<SKGInterfacePlugin*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<SKGTabPage**>(_a[0]) = std::move(_r); }  break;
        case 24: { SKGTabPage* _r = _t->openPage((*reinterpret_cast<std::add_pointer_t<SKGInterfacePlugin*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<SKGTabPage**>(_a[0]) = std::move(_r); }  break;
        case 25: { SKGTabPage* _r = _t->openPage((*reinterpret_cast<std::add_pointer_t<SKGInterfacePlugin*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<SKGTabPage**>(_a[0]) = std::move(_r); }  break;
        case 26: { SKGTabPage* _r = _t->openPage((*reinterpret_cast<std::add_pointer_t<SKGInterfacePlugin*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<SKGTabPage**>(_a[0]) = std::move(_r); }  break;
        case 27: _t->switchPinPage((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1]))); break;
        case 28: _t->closePageByIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 29: _t->closePageByIndex(); break;
        case 30: _t->closePage((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 31: _t->closePage((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1]))); break;
        case 32: _t->closeCurrentPage(); break;
        case 33: _t->closeAllOtherPages((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1]))); break;
        case 34: _t->closeAllPages((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 35: _t->closeAllPages(); break;
        case 36: _t->refresh(); break;
        case 37: _t->notify((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 38: _t->notify(); break;
        case 39: _t->optionsPreferences((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 40: _t->optionsPreferences(); break;
        case 41: _t->unRegisterGlobalAction((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 42: { KMessageWidget* _r = _t->getMessageWidget((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<SKGDocument::MessageType>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])));
            if (_a[0]) *reinterpret_cast<KMessageWidget**>(_a[0]) = std::move(_r); }  break;
        case 43: _t->showMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 44: _t->onSettingsChanged(); break;
        case 45: _t->onCancelCurrentAction(); break;
        case 46: _t->onQuitAction(); break;
        case 47: _t->addTab(); break;
        case 48: _t->onBeforeOpenContext(); break;
        case 49: _t->onOpenContext(); break;
        case 50: _t->saveDefaultState(); break;
        case 51: _t->resetDefaultState(); break;
        case 52: _t->overwriteBookmarkState(); break;
        case 53: _t->enableEditor(); break;
        case 54: _t->onPrevious(); break;
        case 55: _t->onNext(); break;
        case 56: _t->onReopenLastClosed(); break;
        case 57: _t->onFullScreen(); break;
        case 58: _t->onShowPreviousMenu(); break;
        case 59: _t->onShowNextMenu(); break;
        case 60: _t->onZoomChanged(); break;
        case 61: _t->onShowMenuBar(); break;
        case 62: _t->onShowButtonMenu(); break;
        case 63: _t->onHideContextItem(); break;
        case 64: _t->onShowAllContextItems(); break;
        case 65: _t->onLockDocks(); break;
        case 66: _t->onUnlockDocks(); break;
        case 67: _t->onConfigureNotifications(); break;
        case 68: _t->onClearMessages(); break;
        case 69: _t->onMigrateToSQLCipher(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< SKGInterfacePlugin* >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< SKGInterfacePlugin* >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< SKGInterfacePlugin* >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< SKGInterfacePlugin* >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< SKGInterfacePlugin* >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< SKGInterfacePlugin* >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 31:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SKGMainPanel::*)()>(_a, &SKGMainPanel::pageOpened, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SKGMainPanel::*)()>(_a, &SKGMainPanel::pageClosed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SKGMainPanel::*)()>(_a, &SKGMainPanel::currentPageChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SKGMainPanel::*)()>(_a, &SKGMainPanel::settingsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SKGMainPanel::*)()>(_a, &SKGMainPanel::selectionChanged, 4))
            return;
    }
}

const QMetaObject *SKGMainPanel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SKGMainPanel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12SKGMainPanelE_t>.strings))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int SKGMainPanel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 70)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 70;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 70)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 70;
    }
    return _id;
}

// SIGNAL 0
void SKGMainPanel::pageOpened()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SKGMainPanel::pageClosed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void SKGMainPanel::currentPageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void SKGMainPanel::settingsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void SKGMainPanel::selectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
