// This file is generated by kconfig_compiler_kf6 from skgprint_settings.kcfg.
// All changes you do to this file will be lost.

#include "skgprint_settings.h"

#include <qglobal.h>
#include <QFile>

class skgprint_settingsHelper
{
  public:
    skgprint_settingsHelper() noexcept : q(nullptr) {}
    ~skgprint_settingsHelper() noexcept { delete q; q = nullptr; }
    skgprint_settingsHelper(const skgprint_settingsHelper&) = delete;
    skgprint_settingsHelper& operator=(const skgprint_settingsHelper&) = delete;
    skgprint_settings *q;
};
Q_GLOBAL_STATIC(skgprint_settingsHelper, s_globalskgprint_settings)
skgprint_settings *skgprint_settings::self()
{
  if (!s_globalskgprint_settings()->q) {
    new skgprint_settings;
    s_globalskgprint_settings()->q->read();
  }

  return s_globalskgprint_settings()->q;
}

skgprint_settings::skgprint_settings( )
  : KConfigSkeleton()
{
  Q_ASSERT(!s_globalskgprint_settings()->q);
  s_globalskgprint_settings()->q = this;
  setCurrentGroup( QStringLiteral( "skg_print" ) );

  KConfigSkeleton::ItemString  *itemUndefined;
  itemUndefined = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "undefined" ), mUndefined );
  addItem( itemUndefined, QStringLiteral( "undefined" ) );
}

skgprint_settings::~skgprint_settings()
{
  if (s_globalskgprint_settings.exists() && !s_globalskgprint_settings.isDestroyed()) {
    s_globalskgprint_settings()->q = nullptr;
  }
}

