/********************************************************************************
** Form generated from reading UI file 'skgtablewithgraph.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGTABLEWITHGRAPH_H
#define UI_SKGTABLEWITHGRAPH_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "skggraphicsview.h"
#include "skgshow.h"
#include "skgtablewidget.h"
#include "skgwebview.h"

QT_BEGIN_NAMESPACE

class Ui_skgtablewithgraph_base
{
public:
    QVBoxLayout *verticalLayout;
    QWidget *kToolbar;
    QHBoxLayout *horizontalLayout_2;
    SKGShow *kShow;
    QSpacerItem *horizontalSpacer_2;
    QLineEdit *kFilterEdit;
    QSplitter *splitter;
    SKGTableWidget *kTable;
    SKGGraphicsView *graphicView;
    SKGWebView *kTextEdit;

    void setupUi(QWidget *skgtablewithgraph_base)
    {
        if (skgtablewithgraph_base->objectName().isEmpty())
            skgtablewithgraph_base->setObjectName("skgtablewithgraph_base");
        skgtablewithgraph_base->resize(413, 273);
        verticalLayout = new QVBoxLayout(skgtablewithgraph_base);
        verticalLayout->setSpacing(2);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        kToolbar = new QWidget(skgtablewithgraph_base);
        kToolbar->setObjectName("kToolbar");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kToolbar->sizePolicy().hasHeightForWidth());
        kToolbar->setSizePolicy(sizePolicy);
        horizontalLayout_2 = new QHBoxLayout(kToolbar);
        horizontalLayout_2->setSpacing(2);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(0, 0, 0, 0);
        kShow = new SKGShow(kToolbar);
        kShow->setObjectName("kShow");

        horizontalLayout_2->addWidget(kShow);

        horizontalSpacer_2 = new QSpacerItem(271, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        kFilterEdit = new QLineEdit(kToolbar);
        kFilterEdit->setObjectName("kFilterEdit");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(kFilterEdit->sizePolicy().hasHeightForWidth());
        kFilterEdit->setSizePolicy(sizePolicy1);
        kFilterEdit->setMinimumSize(QSize(200, 0));
        kFilterEdit->setMaximumSize(QSize(200, 16777215));
        kFilterEdit->setProperty("showClearButton", QVariant(true));

        horizontalLayout_2->addWidget(kFilterEdit);


        verticalLayout->addWidget(kToolbar);

        splitter = new QSplitter(skgtablewithgraph_base);
        splitter->setObjectName("splitter");
        splitter->setOrientation(Qt::Horizontal);
        kTable = new SKGTableWidget(splitter);
        kTable->setObjectName("kTable");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(kTable->sizePolicy().hasHeightForWidth());
        kTable->setSizePolicy(sizePolicy2);
        kTable->setEditTriggers(QAbstractItemView::NoEditTriggers);
        kTable->setAlternatingRowColors(true);
        kTable->setSelectionMode(QAbstractItemView::ExtendedSelection);
        kTable->setShowGrid(false);
        kTable->setSortingEnabled(false);
        splitter->addWidget(kTable);
        graphicView = new SKGGraphicsView(splitter);
        graphicView->setObjectName("graphicView");
        sizePolicy2.setHeightForWidth(graphicView->sizePolicy().hasHeightForWidth());
        graphicView->setSizePolicy(sizePolicy2);
        splitter->addWidget(graphicView);

        verticalLayout->addWidget(splitter);

        kTextEdit = new SKGWebView(skgtablewithgraph_base);
        kTextEdit->setObjectName("kTextEdit");
        sizePolicy2.setHeightForWidth(kTextEdit->sizePolicy().hasHeightForWidth());
        kTextEdit->setSizePolicy(sizePolicy2);

        verticalLayout->addWidget(kTextEdit);

        QWidget::setTabOrder(kShow, kFilterEdit);
        QWidget::setTabOrder(kFilterEdit, kTable);
        QWidget::setTabOrder(kTable, kTextEdit);

        retranslateUi(skgtablewithgraph_base);

        QMetaObject::connectSlotsByName(skgtablewithgraph_base);
    } // setupUi

    void retranslateUi(QWidget *skgtablewithgraph_base)
    {
#if QT_CONFIG(tooltip)
        kFilterEdit->setToolTip(tr2i18n("Filter", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kFilterEdit->setStatusTip(tr2i18n("Filter", nullptr));
#endif // QT_CONFIG(statustip)
        (void)skgtablewithgraph_base;
    } // retranslateUi

};

namespace Ui {
    class skgtablewithgraph_base: public Ui_skgtablewithgraph_base {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGTABLEWITHGRAPH_H

