/********************************************************************************
** Form generated from reading UI file 'skgtipofdayboardwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGTIPOFDAYBOARDWIDGET_H
#define UI_SKGTIPOFDAYBOARDWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_skgtipofdayboardwidget
{
public:
    QGridLayout *gridLayout;
    QLabel *label;
    QLabel *kText;
    QSpacerItem *verticalSpacer;
    QPushButton *kIcon;

    void setupUi(QWidget *skgtipofdayboardwidget)
    {
        if (skgtipofdayboardwidget->objectName().isEmpty())
            skgtipofdayboardwidget->setObjectName("skgtipofdayboardwidget");
        skgtipofdayboardwidget->resize(194, 47);
        gridLayout = new QGridLayout(skgtipofdayboardwidget);
        gridLayout->setSpacing(2);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        label = new QLabel(skgtipofdayboardwidget);
        label->setObjectName("label");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);
        QFont font;
        font.setPointSize(10);
        font.setBold(true);
        label->setFont(font);
        label->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(label, 0, 0, 1, 1);

        kText = new QLabel(skgtipofdayboardwidget);
        kText->setObjectName("kText");
        kText->setTextFormat(Qt::RichText);
        kText->setWordWrap(true);
        kText->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        gridLayout->addWidget(kText, 1, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 2, 0, 1, 1);

        kIcon = new QPushButton(skgtipofdayboardwidget);
        kIcon->setObjectName("kIcon");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(kIcon->sizePolicy().hasHeightForWidth());
        kIcon->setSizePolicy(sizePolicy1);
        kIcon->setFocusPolicy(Qt::NoFocus);
        kIcon->setIconSize(QSize(64, 64));
        kIcon->setFlat(true);

        gridLayout->addWidget(kIcon, 0, 1, 2, 1);

#if QT_CONFIG(shortcut)
        kText->setBuddy(kIcon);
#endif // QT_CONFIG(shortcut)

        retranslateUi(skgtipofdayboardwidget);

        QMetaObject::connectSlotsByName(skgtipofdayboardwidget);
    } // setupUi

    void retranslateUi(QWidget *skgtipofdayboardwidget)
    {
        label->setText(tr2i18n("Did you know \342\200\246?", nullptr));
        kText->setText(QString());
        (void)skgtipofdayboardwidget;
    } // retranslateUi

};

namespace Ui {
    class skgtipofdayboardwidget: public Ui_skgtipofdayboardwidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGTIPOFDAYBOARDWIDGET_H

