/********************************************************************************
** Form generated from reading UI file 'skgundoredopluginwidget_pref.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGUNDOREDOPLUGINWIDGET_PREF_H
#define UI_SKGUNDOREDOPLUGINWIDGET_PREF_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_skgundoredoplugin_pref
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QSpinBox *kcfg_maxNumberOfUndo;
    QSpacerItem *horizontalSpacer;
    QCheckBox *kcfg_cleanHistoryOnSave;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *skgundoredoplugin_pref)
    {
        if (skgundoredoplugin_pref->objectName().isEmpty())
            skgundoredoplugin_pref->setObjectName("skgundoredoplugin_pref");
        skgundoredoplugin_pref->resize(421, 184);
        verticalLayout = new QVBoxLayout(skgundoredoplugin_pref);
        verticalLayout->setSpacing(2);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(2);
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(skgundoredoplugin_pref);
        label->setObjectName("label");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(label);

        kcfg_maxNumberOfUndo = new QSpinBox(skgundoredoplugin_pref);
        kcfg_maxNumberOfUndo->setObjectName("kcfg_maxNumberOfUndo");
        kcfg_maxNumberOfUndo->setMinimum(-1);
        kcfg_maxNumberOfUndo->setMaximum(999);
        kcfg_maxNumberOfUndo->setValue(0);

        horizontalLayout->addWidget(kcfg_maxNumberOfUndo);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);

        kcfg_cleanHistoryOnSave = new QCheckBox(skgundoredoplugin_pref);
        kcfg_cleanHistoryOnSave->setObjectName("kcfg_cleanHistoryOnSave");

        verticalLayout->addWidget(kcfg_cleanHistoryOnSave);

        verticalSpacer = new QSpacerItem(20, 126, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(skgundoredoplugin_pref);

        QMetaObject::connectSlotsByName(skgundoredoplugin_pref);
    } // setupUi

    void retranslateUi(QWidget *skgundoredoplugin_pref)
    {
        label->setText(tr2i18n("Maximum undo depth:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_maxNumberOfUndo->setToolTip(tr2i18n("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"https://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">The number of undoable actions to keep in the history. If you want to keep <span style=\" font-weight:600;\">all</span> actions in the history, set this to <span style=\" font-weight:600;\">-1</span>, but be warned that the file size will increase steeply.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kcfg_maxNumberOfUndo->setStatusTip(tr2i18n("-1 for no limit", nullptr));
#endif // QT_CONFIG(statustip)
        kcfg_cleanHistoryOnSave->setText(tr2i18n("Clean history on save", nullptr));
        (void)skgundoredoplugin_pref;
    } // retranslateUi

};

namespace Ui {
    class skgundoredoplugin_pref: public Ui_skgundoredoplugin_pref {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGUNDOREDOPLUGINWIDGET_PREF_H

