/********************************************************************************
** Form generated from reading UI file 'skgzoomselector.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGZOOMSELECTOR_H
#define UI_SKGZOOMSELECTOR_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QSlider>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_skgzoomselector
{
public:
    QHBoxLayout *horizontalLayout;
    QToolButton *kZoomOriginal;
    QToolButton *kZoomOut;
    QSlider *kZoomSlider;
    QToolButton *kZoomIn;

    void setupUi(QWidget *skgzoomselector)
    {
        if (skgzoomselector->objectName().isEmpty())
            skgzoomselector->setObjectName("skgzoomselector");
        skgzoomselector->resize(140, 28);
        horizontalLayout = new QHBoxLayout(skgzoomselector);
        horizontalLayout->setSpacing(2);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        kZoomOriginal = new QToolButton(skgzoomselector);
        kZoomOriginal->setObjectName("kZoomOriginal");
        kZoomOriginal->setFocusPolicy(Qt::NoFocus);
#if QT_CONFIG(shortcut)
        kZoomOriginal->setShortcut(QString::fromUtf8("Ctrl+0"));
#endif // QT_CONFIG(shortcut)
        kZoomOriginal->setCheckable(true);
        kZoomOriginal->setChecked(true);
        kZoomOriginal->setAutoRaise(true);

        horizontalLayout->addWidget(kZoomOriginal);

        kZoomOut = new QToolButton(skgzoomselector);
        kZoomOut->setObjectName("kZoomOut");
        kZoomOut->setFocusPolicy(Qt::NoFocus);
#if QT_CONFIG(shortcut)
        kZoomOut->setShortcut(QString::fromUtf8("Ctrl+-"));
#endif // QT_CONFIG(shortcut)
        kZoomOut->setAutoRepeat(true);
        kZoomOut->setAutoRaise(true);

        horizontalLayout->addWidget(kZoomOut);

        kZoomSlider = new QSlider(skgzoomselector);
        kZoomSlider->setObjectName("kZoomSlider");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kZoomSlider->sizePolicy().hasHeightForWidth());
        kZoomSlider->setSizePolicy(sizePolicy);
        kZoomSlider->setMinimumSize(QSize(50, 0));
        kZoomSlider->setMaximumSize(QSize(200, 16777215));
        kZoomSlider->setFocusPolicy(Qt::NoFocus);
        kZoomSlider->setMinimum(-10);
        kZoomSlider->setMaximum(10);
        kZoomSlider->setPageStep(1);
        kZoomSlider->setOrientation(Qt::Horizontal);
        kZoomSlider->setTickPosition(QSlider::NoTicks);

        horizontalLayout->addWidget(kZoomSlider);

        kZoomIn = new QToolButton(skgzoomselector);
        kZoomIn->setObjectName("kZoomIn");
        kZoomIn->setFocusPolicy(Qt::NoFocus);
#if QT_CONFIG(shortcut)
        kZoomIn->setShortcut(QString::fromUtf8("Ctrl++"));
#endif // QT_CONFIG(shortcut)
        kZoomIn->setAutoRepeat(true);
        kZoomIn->setAutoRaise(true);

        horizontalLayout->addWidget(kZoomIn);


        retranslateUi(skgzoomselector);

        QMetaObject::connectSlotsByName(skgzoomselector);
    } // setupUi

    void retranslateUi(QWidget *skgzoomselector)
    {
#if QT_CONFIG(tooltip)
        kZoomOriginal->setToolTip(tr2i18n("Fit zoom", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kZoomOriginal->setStatusTip(tr2i18n("Fit zoom", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kZoomOut->setToolTip(tr2i18n("Zoom out", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kZoomOut->setStatusTip(tr2i18n("Zoom out", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kZoomSlider->setToolTip(tr2i18n("Custom zoom", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kZoomSlider->setStatusTip(tr2i18n("Custom zoom", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(tooltip)
        kZoomIn->setToolTip(tr2i18n("Zoom in", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kZoomIn->setStatusTip(tr2i18n("Zoom in", nullptr));
#endif // QT_CONFIG(statustip)
        (void)skgzoomselector;
    } // retranslateUi

};

namespace Ui {
    class skgzoomselector: public Ui_skgzoomselector {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGZOOMSELECTOR_H

