/***************************************************************************
 * SPDX-FileCopyrightText: 2026 S. MANKOWSKI stephane@mankowski.fr
 * SPDX-License-Identifier: GPL-3.0-or-later
 ***************************************************************************/

/** @file
 * A dock widget for the AI assistant plugin.
 */
#include "skgassistantpluginwidget.h"
#include "skgassistantplugindockwidget.h"

SKGAssistantPluginWidget::SKGAssistantPluginWidget(QWidget *iParent, SKGDocument *iDocument)
    : SKGTabPage(iParent, iDocument)
{
    QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
    sizePolicy.setHorizontalStretch(0);
    sizePolicy.setVerticalStretch(0);
    sizePolicy.setHeightForWidth(this->sizePolicy().hasHeightForWidth());
    this->setSizePolicy(sizePolicy);

    auto layout = new QHBoxLayout(this);
    layout->setSpacing(2);
    layout->setContentsMargins(0, 0, 0, 0);
    auto t = new SKGAssistantPluginDockWidget(this, iDocument);
    layout->addWidget(t);
}

SKGAssistantPluginWidget::~SKGAssistantPluginWidget()
{
}