/********************************************************************************
** Form generated from reading UI file 'skgmainpanel_base.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGMAINPANEL_BASE_H
#define UI_SKGMAINPANEL_BASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDockWidget>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QMainWindow>
#include <QtWidgets/QMenuBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStatusBar>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_skgmainpanel_base
{
public:
    QWidget *centralwidget;
    QMenuBar *menubar;
    QStatusBar *statusbar;
    QDockWidget *kDockContext;
    QWidget *dockWidgetContents;
    QVBoxLayout *verticalLayout;
    QListWidget *kContextList;
    QDockWidget *kDockMessages;
    QWidget *layout;
    QVBoxLayout *verticalLayout_2;
    QScrollArea *kMessagesArea;
    QWidget *kMessagesLayout;
    QVBoxLayout *verticalLayout_3;
    QSpacerItem *verticalSpacer;
    QPushButton *kClearMessageBtn;

    void setupUi(QMainWindow *skgmainpanel_base)
    {
        if (skgmainpanel_base->objectName().isEmpty())
            skgmainpanel_base->setObjectName("skgmainpanel_base");
        skgmainpanel_base->resize(361, 335);
        centralwidget = new QWidget(skgmainpanel_base);
        centralwidget->setObjectName("centralwidget");
        skgmainpanel_base->setCentralWidget(centralwidget);
        menubar = new QMenuBar(skgmainpanel_base);
        menubar->setObjectName("menubar");
        menubar->setGeometry(QRect(0, 0, 361, 30));
        skgmainpanel_base->setMenuBar(menubar);
        statusbar = new QStatusBar(skgmainpanel_base);
        statusbar->setObjectName("statusbar");
        skgmainpanel_base->setStatusBar(statusbar);
        kDockContext = new QDockWidget(skgmainpanel_base);
        kDockContext->setObjectName("kDockContext");
        kDockContext->setAllowedAreas(Qt::LeftDockWidgetArea|Qt::RightDockWidgetArea);
        dockWidgetContents = new QWidget();
        dockWidgetContents->setObjectName("dockWidgetContents");
        verticalLayout = new QVBoxLayout(dockWidgetContents);
        verticalLayout->setSpacing(0);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        kContextList = new QListWidget(dockWidgetContents);
        kContextList->setObjectName("kContextList");
        kContextList->setFocusPolicy(Qt::NoFocus);
        kContextList->setFrameShape(QFrame::NoFrame);
        kContextList->setLineWidth(0);
        kContextList->setAlternatingRowColors(false);
        kContextList->setSelectionBehavior(QAbstractItemView::SelectRows);
        kContextList->setIconSize(QSize(32, 32));
        kContextList->setVerticalScrollMode(QAbstractItemView::ScrollPerPixel);
        kContextList->setResizeMode(QListView::Adjust);
        kContextList->setUniformItemSizes(true);
        kContextList->setWordWrap(true);

        verticalLayout->addWidget(kContextList);

        kDockContext->setWidget(dockWidgetContents);
        skgmainpanel_base->addDockWidget(Qt::DockWidgetArea::LeftDockWidgetArea, kDockContext);
        kDockMessages = new QDockWidget(skgmainpanel_base);
        kDockMessages->setObjectName("kDockMessages");
        layout = new QWidget();
        layout->setObjectName("layout");
        verticalLayout_2 = new QVBoxLayout(layout);
        verticalLayout_2->setSpacing(2);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        kMessagesArea = new QScrollArea(layout);
        kMessagesArea->setObjectName("kMessagesArea");
        kMessagesArea->setFocusPolicy(Qt::NoFocus);
        kMessagesArea->setFrameShape(QFrame::NoFrame);
        kMessagesArea->setWidgetResizable(true);
        kMessagesLayout = new QWidget();
        kMessagesLayout->setObjectName("kMessagesLayout");
        kMessagesLayout->setGeometry(QRect(0, 0, 256, 72));
        verticalLayout_3 = new QVBoxLayout(kMessagesLayout);
        verticalLayout_3->setSpacing(2);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer);

        kMessagesArea->setWidget(kMessagesLayout);

        verticalLayout_2->addWidget(kMessagesArea);

        kClearMessageBtn = new QPushButton(layout);
        kClearMessageBtn->setObjectName("kClearMessageBtn");
        kClearMessageBtn->setFocusPolicy(Qt::NoFocus);

        verticalLayout_2->addWidget(kClearMessageBtn);

        kDockMessages->setWidget(layout);
        skgmainpanel_base->addDockWidget(Qt::DockWidgetArea::LeftDockWidgetArea, kDockMessages);

        retranslateUi(skgmainpanel_base);

        QMetaObject::connectSlotsByName(skgmainpanel_base);
    } // setupUi

    void retranslateUi(QMainWindow *skgmainpanel_base)
    {
        skgmainpanel_base->setWindowTitle(tr2i18n("Skrooge", nullptr));
        kDockContext->setWindowTitle(tr2i18n("Pages", nullptr));
#if QT_CONFIG(tooltip)
        kContextList->setToolTip(tr2i18n("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"https://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'DejaVu Sans'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">this list allows you to open new pages</p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Ctrl</span> to open in a new page</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kContextList->setStatusTip(tr2i18n("this list allows you to open new pages", nullptr));
#endif // QT_CONFIG(statustip)
        kDockMessages->setWindowTitle(tr2i18n("&Messages", nullptr));
#if QT_CONFIG(tooltip)
        kClearMessageBtn->setToolTip(tr2i18n("Clear all messages", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        kClearMessageBtn->setStatusTip(tr2i18n("Clear all messages", nullptr));
#endif // QT_CONFIG(statustip)
        kClearMessageBtn->setText(tr2i18n("Clear messages", nullptr));
    } // retranslateUi

};

namespace Ui {
    class skgmainpanel_base: public Ui_skgmainpanel_base {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGMAINPANEL_BASE_H

