// This file is generated by kconfig_compiler_kf6 from skgsearch_settings.kcfg.
// All changes you do to this file will be lost.
#ifndef SKGSEARCH_SETTINGS_H
#define SKGSEARCH_SETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class skgsearch_settings : public KConfigSkeleton
{
  public:

    static skgsearch_settings *self();
    ~skgsearch_settings() override;

    /**
      Get alarm_frequency
    */
    static
    int alarm_frequency()
    {
      return self()->mAlarm_frequency;
    }

    /**
      Is alarm_frequency Immutable
    */
    static
    bool isAlarm_frequencyImmutable()
    {
      return self()->isImmutable( QStringLiteral( "alarm_frequency" ) );
    }

  protected:
    skgsearch_settings();
    friend class skgsearch_settingsHelper;


    // skrooge_search
    int mAlarm_frequency;
};

#endif

