/********************************************************************************
** Form generated from reading UI file 'skgfilepluginwidget_pref.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SKGFILEPLUGINWIDGET_PREF_H
#define UI_SKGFILEPLUGINWIDGET_PREF_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "skgcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_skgfileplugin_pref
{
public:
    QGridLayout *gridLayout_2;
    QCheckBox *kcfg_openlastfile;
    QCheckBox *kcfg_saveonclose;
    QCheckBox *kcfg_storeInKdeWallet;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QCheckBox *kcfg_backup_enabled;
    QLabel *label;
    SKGComboBox *kcfg_prefix;
    QLabel *label_2;
    SKGComboBox *kcfg_suffix;
    QSpacerItem *horizontalSpacer;
    QLabel *label_3;
    QSpacerItem *verticalSpacer;
    SKGComboBox *kcfg_selectedWallet;
    QSpacerItem *horizontalSpacer_2;

    void setupUi(QWidget *skgfileplugin_pref)
    {
        if (skgfileplugin_pref->objectName().isEmpty())
            skgfileplugin_pref->setObjectName("skgfileplugin_pref");
        skgfileplugin_pref->resize(520, 435);
        gridLayout_2 = new QGridLayout(skgfileplugin_pref);
        gridLayout_2->setObjectName("gridLayout_2");
        kcfg_openlastfile = new QCheckBox(skgfileplugin_pref);
        kcfg_openlastfile->setObjectName("kcfg_openlastfile");
        kcfg_openlastfile->setChecked(true);

        gridLayout_2->addWidget(kcfg_openlastfile, 0, 0, 1, 1);

        kcfg_saveonclose = new QCheckBox(skgfileplugin_pref);
        kcfg_saveonclose->setObjectName("kcfg_saveonclose");

        gridLayout_2->addWidget(kcfg_saveonclose, 1, 0, 1, 1);

        kcfg_storeInKdeWallet = new QCheckBox(skgfileplugin_pref);
        kcfg_storeInKdeWallet->setObjectName("kcfg_storeInKdeWallet");

        gridLayout_2->addWidget(kcfg_storeInKdeWallet, 2, 0, 1, 1);

        groupBox = new QGroupBox(skgfileplugin_pref);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setSpacing(2);
        gridLayout->setObjectName("gridLayout");
        kcfg_backup_enabled = new QCheckBox(groupBox);
        kcfg_backup_enabled->setObjectName("kcfg_backup_enabled");
        kcfg_backup_enabled->setChecked(true);

        gridLayout->addWidget(kcfg_backup_enabled, 0, 0, 1, 2);

        label = new QLabel(groupBox);
        label->setObjectName("label");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label, 1, 0, 1, 1);

        kcfg_prefix = new SKGComboBox(groupBox);
        kcfg_prefix->setObjectName("kcfg_prefix");
        kcfg_prefix->setEditable(true);

        gridLayout->addWidget(kcfg_prefix, 1, 1, 1, 1);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");
        sizePolicy.setHeightForWidth(label_2->sizePolicy().hasHeightForWidth());
        label_2->setSizePolicy(sizePolicy);
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_2, 2, 0, 1, 1);

        kcfg_suffix = new SKGComboBox(groupBox);
        kcfg_suffix->setObjectName("kcfg_suffix");
        kcfg_suffix->setEditable(true);

        gridLayout->addWidget(kcfg_suffix, 2, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 1, 2, 1, 1);

        label_3 = new QLabel(groupBox);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 3, 0, 1, 3);


        gridLayout_2->addWidget(groupBox, 3, 0, 1, 3);

        verticalSpacer = new QSpacerItem(20, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 4, 0, 1, 1);

        kcfg_selectedWallet = new SKGComboBox(skgfileplugin_pref);
        kcfg_selectedWallet->setObjectName("kcfg_selectedWallet");

        gridLayout_2->addWidget(kcfg_selectedWallet, 2, 1, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_2, 2, 2, 1, 1);

#if QT_CONFIG(shortcut)
        label->setBuddy(kcfg_prefix);
        label_2->setBuddy(kcfg_suffix);
#endif // QT_CONFIG(shortcut)

        retranslateUi(skgfileplugin_pref);

        QMetaObject::connectSlotsByName(skgfileplugin_pref);
    } // setupUi

    void retranslateUi(QWidget *skgfileplugin_pref)
    {
        kcfg_openlastfile->setText(tr2i18n("Open last file on startup", nullptr));
        kcfg_saveonclose->setText(tr2i18n("Save on close", nullptr));
        kcfg_storeInKdeWallet->setText(tr2i18n("Store passwords in KDE Wallet:", nullptr));
        groupBox->setTitle(tr2i18n("Backup on save", nullptr));
        kcfg_backup_enabled->setText(tr2i18n("Enable backup", nullptr));
        label->setText(tr2i18n("Prefix:", nullptr));
        label_2->setText(tr2i18n("Suffix:", nullptr));
        label_3->setText(tr2i18n("<html><head/><body><p>The following key words can be used in prefix and suffix:<br/>&lt;DATE&gt;: to add the current date in the backuped file<br/>&lt;TIME&gt;: to add the current time in the backuped file</p><p>By default, the backup is stored in the same directory than the saved file.<br/>But, you can force the backup directory by setting an absolute path in the prefix.<br/>(example: /backup/)</p></body></html>", nullptr));
        (void)skgfileplugin_pref;
    } // retranslateUi

};

namespace Ui {
    class skgfileplugin_pref: public Ui_skgfileplugin_pref {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SKGFILEPLUGINWIDGET_PREF_H

